@@ -2,7 +2,7 @@
  * Routines for X.525 (X.500 Directory Shadow Asbtract Service) and X.519 DISP packet dissection
  * Graeme Lunt 2005
  *
- * $Id: packet-disp-template.c 19895 2006-11-14 20:32:29Z jmayer $
+ * $Id: packet-disp-template.c 23318 2007-10-31 08:26:52Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -31,7 +31,8 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/conversation.h>
-#include <epan/oid_resolv.h>
+#include <epan/oids.h>
+#include <epan/asn1.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -87,8 +88,11 @@ dissect_disp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	int old_offset;
 	proto_item *item=NULL;
 	proto_tree *tree=NULL;
-	int (*disp_dissector)(gboolean implicit_tag _U_, tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *tree, int hf_index _U_) = NULL;
+	int (*disp_dissector)(gboolean implicit_tag _U_, tvbuff_t *tvb, int offset, asn1_ctx_t *actx, proto_tree *tree, int hf_index _U_) = NULL;
 	char *disp_op_name;
+	asn1_ctx_t asn1_ctx;
+
+	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
 	/* do we have operation information from the ROS dissector?  */
 	if( !pinfo->private_data ){
@@ -180,11 +184,11 @@ dissect_disp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 
 	if(disp_dissector) {
 	  if (check_col(pinfo->cinfo, COL_INFO))
-	    col_add_str(pinfo->cinfo, COL_INFO, disp_op_name);
+	    col_set_str(pinfo->cinfo, COL_INFO, disp_op_name);
 
 	  while (tvb_reported_length_remaining(tvb, offset) > 0){
 	    old_offset=offset;
-	    offset=(*disp_dissector)(FALSE, tvb, offset, pinfo , tree, -1);
+	    offset=(*disp_dissector)(FALSE, tvb, offset, &asn1_ctx, tree, -1);
 	    if(offset == old_offset){
 	      proto_tree_add_text(tree, tvb, offset, -1,"Internal error, zero-byte DISP PDU");
 	      offset = tvb_length(tvb);
@@ -243,10 +247,10 @@ void proto_reg_handoff_disp(void) {
 
   /* APPLICATION CONTEXT */
 
-  add_oid_str_name("2.5.3.4", "id-ac-shadow-consumer-initiated");
-  add_oid_str_name("2.5.3.5", "id-ac-shadow-supplier-initiated");
-  add_oid_str_name("2.5.3.6", "id-ac-reliable-shadow-consumer-initiated");
-  add_oid_str_name("2.5.3.7", "id-ac-reliable-shadow-supplier-initiated");
+  oid_add_from_string("id-ac-shadow-consumer-initiated","2.5.3.4");
+  oid_add_from_string("id-ac-shadow-supplier-initiated","2.5.3.5");
+  oid_add_from_string("id-ac-reliable-shadow-consumer-initiated","2.5.3.6");
+  oid_add_from_string("id-ac-reliable-shadow-supplier-initiated","2.5.3.7");
 
   /* ABSTRACT SYNTAXES */
 
@@ -259,7 +263,7 @@ void proto_reg_handoff_disp(void) {
   } 
 
   /* OPERATIONAL BINDING */
-  add_oid_str_name("2.5.1.0.5.1", "id-op-binding-shadow");
+  oid_add_from_string("id-op-binding-shadow","2.5.1.0.5.1");
 
   tpkt_handle = find_dissector("tpkt");
 
