@@ -3,7 +3,7 @@
  *
  * See RFC 1777 (LDAP v2), RFC 2251 (LDAP v3), and RFC 2222 (SASL).
  *
- * $Id: packet-ldap-template.c 24664 2008-03-17 12:03:36Z morriss $
+ * $Id: packet-ldap-template.c 25463 2008-06-16 23:29:12Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1478,7 +1478,7 @@ ldap_reinit(void)
 
   /* Free up state attached to the ldap_info structures */
   for (ldap_info = ldap_info_items; ldap_info != NULL; ) {
-    ldap_conv_info_t *last;
+    ldap_conv_info_t *next;
 
     if (ldap_info->auth_mech != NULL) {
       g_free(ldap_info->auth_mech);
@@ -1489,9 +1489,9 @@ ldap_reinit(void)
     g_hash_table_destroy(ldap_info->unmatched);
     ldap_info->unmatched=NULL;
 
-    last = ldap_info;
-    ldap_info = ldap_info->next;
+    next = ldap_info->next;
     g_free(ldap_info);
+    ldap_info = next;
   }
 
   ldap_info_items = NULL;
