@@ -2,7 +2,7 @@
  * Routines for X.413 (P7) packet dissection
  * Graeme Lunt 2007
  *
- * $Id: packet-p7-template.h 23479 2007-11-17 18:08:01Z gal $
+ * $Id: packet-p7-template.h 23980 2008-01-02 09:30:45Z gal $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,6 @@
 #ifndef PACKET_P7_H
 #define PACKET_P7_H
 
-/* #include "packet-p7-exp.h" */
+#include "packet-p7-exp.h"
 
 #endif  /* PACKET_P7_H */
