@@ -2,7 +2,7 @@
  * Routines for Wireless Certificate Extension (RFC3770)
  *  Ronnie Sahlberg 2005
  *
- * $Id: packet-wlancertextn-template.c 21753 2007-05-13 20:58:29Z etxrab $
+ * $Id: packet-wlancertextn-template.c 23324 2007-10-31 21:24:16Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,7 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/conversation.h>
-#include <epan/oid_resolv.h>
+#include <epan/oids.h>
 #include <epan/asn1.h>
 
 #include <stdio.h>
@@ -82,7 +82,7 @@ void proto_register_wlancertextn(void) {
 /*--- proto_reg_handoff_wlancertextn -------------------------------------------*/
 void proto_reg_handoff_wlancertextn(void) {
 #include "packet-wlancertextn-dis-tab.c"
-  add_oid_str_name("1.3.6.1.5.5.7.3.13","id-kp-eapOverPPP");
-  add_oid_str_name("1.3.6.1.5.5.7.3.14","id-kp-eapOverLAN");
+  oid_add_from_string("id-kp-eapOverPPP","1.3.6.1.5.5.7.3.13");
+  oid_add_from_string("id-kp-eapOverLAN","1.3.6.1.5.5.7.3.14");
 }
 
