@@ -1,6 +1,6 @@
 /* airpdcap.c
  *
- * $Id: airpdcap.c 22212 2007-06-27 21:44:57Z gerald $
+ * $Id: airpdcap.c 24605 2008-03-11 18:32:20Z gerald $
  * Copyright (c) 2006 CACE Technologies, Davis (California)
  * All rights reserved.
  *
@@ -16,6 +16,10 @@
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
+ * Alternatively, this software may be distributed under the terms of the
+ * GNU General Public License ("GPL") version 2 as published by the Free
+ * Software Foundation.
+ *
  * THIS SOFTWARE IS PROVIDED BY THE PROJECT AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -32,6 +36,10 @@
 /****************************************************************************/
 /*	File includes								*/
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <epan/tvbuff.h>
 #include <epan/crc32.h>
 #include <epan/strutil.h>
@@ -49,6 +57,10 @@
 
 #include "wep-wpadefs.h"
 
+#ifdef NEED_G_ASCII_STRCASECMP_H
+#include "../g_ascii_strcasecmp.h"
+#endif
+
 /****************************************************************************/
 
 /****************************************************************************/
@@ -444,8 +456,8 @@ INT AirPDcapSetKeys(
         return 0;
     }
 
-    /* clean keys collection before setting new ones	*/
-    AirPDcapCleanKeys(ctx);
+    /* clean key and SA collections before setting new ones	*/
+    AirPDcapInitContext(ctx);
 
     /* check and insert keys	*/
     for (i=0, success=0; i<(INT)keys_nr; i++) {
@@ -474,29 +486,6 @@ INT AirPDcapSetKeys(
     return success;
 }
 
-INT AirPDcapCleanKeys(
-    PAIRPDCAP_CONTEXT ctx)
-{
-    INT i;
-    AIRPDCAP_DEBUG_TRACE_START("AirPDcapCleanKeys");
-
-    if (ctx==NULL) {
-        AIRPDCAP_DEBUG_PRINT_LINE("AirPDcapCleanKeys", "NULL context", AIRPDCAP_DEBUG_LEVEL_5);
-        AIRPDCAP_DEBUG_TRACE_END("AirPDcapCleanKeys");
-        return 0;
-    }
-
-    for (i=0; i<AIRPDCAP_MAX_KEYS_NR; i++) {
-        memset(&ctx->keys[i], 0, sizeof(AIRPDCAP_KEY_ITEM));
-    }
-
-    ctx->keys_nr=0;
-
-    AIRPDCAP_DEBUG_PRINT_LINE("AirPDcapCleanKeys", "Keys collection cleaned!", AIRPDCAP_DEBUG_LEVEL_5);
-    AIRPDCAP_DEBUG_TRACE_END("AirPDcapCleanKeys");
-
-    return i;
-}
 
 INT AirPDcapGetKeys(
     const PAIRPDCAP_CONTEXT ctx,
@@ -558,11 +547,13 @@ INT AirPDcapInitContext(
         return AIRPDCAP_RET_UNSUCCESS;
     }
 
-    AirPDcapCleanKeys(ctx);
+    memset(ctx->keys, 0, sizeof(AIRPDCAP_KEY_ITEM) * AIRPDCAP_MAX_KEYS_NR);
+    ctx->keys_nr=0;
+    memset(ctx->sa, 0, AIRPDCAP_MAX_SEC_ASSOCIATIONS_NR * sizeof(AIRPDCAP_SEC_ASSOCIATION));
 
     ctx->first_free_index=0;
     ctx->index=-1;
-    ctx->last_stored_index=-1;
+    ctx->sa_index=-1;
     ctx->pkt_ssid_len = 0;
 
     AIRPDCAP_DEBUG_PRINT_LINE("AirPDcapInitContext", "Context initialized!", AIRPDCAP_DEBUG_LEVEL_5);
@@ -581,11 +572,9 @@ INT AirPDcapDestroyContext(
         return AIRPDCAP_RET_UNSUCCESS;
     }
 
-    AirPDcapCleanKeys(ctx);
-
     ctx->first_free_index=0;
     ctx->index=-1;
-    ctx->last_stored_index=-1;
+    ctx->sa_index=-1;
 
     AIRPDCAP_DEBUG_PRINT_LINE("AirPDcapDestroyContext", "Context destroyed!", AIRPDCAP_DEBUG_LEVEL_5);
     AIRPDCAP_DEBUG_TRACE_END("AirPDcapDestroyContext");
@@ -831,7 +820,7 @@ AirPDcapRsna4WHandshake(
         if (AIRPDCAP_EAP_SEC(data[offset])==0) {
 
             /* PATCH:	some implementations set secure bit to 0 also in the 4th message		*/
-            /*		to recognize which message is this check if wep_key data lenght is 0		*/
+            /*		to recognize which message is this check if wep_key data length is 0		*/
             /*		in the 4th message								*/
             if (data[offset+92]!=0 || data[offset+93]!=0) {
                 /* message 2	*/
@@ -930,7 +919,7 @@ AirPDcapRsna4WHandshake(
 
                 if (ret_value) {
                     AIRPDCAP_DEBUG_PRINT_LINE("AirPDcapRsna4WHandshake", "handshake step failed", AIRPDCAP_DEBUG_LEVEL_3);
-                    return ret_value;
+                    return AIRPDCAP_RET_NO_VALID_HANDSHAKE;
                 }
 
                 sa->handshake=2;
@@ -1099,10 +1088,10 @@ AirPDcapGetSa(
 {
     INT index;
 
-    if (ctx->last_stored_index!=-1) {
+    if (ctx->sa_index!=-1) {
         /* at least one association was stored														*/
-        /* search for the association from last_stored_index to 0 (most recent added)	*/
-        for (index=ctx->last_stored_index; index>=0; index--) {
+        /* search for the association from sa_index to 0 (most recent added)	*/
+        for (index=ctx->sa_index; index>=0; index--) {
             if (ctx->sa[index].used) {
                 if (memcmp(id, &(ctx->sa[index].saId), sizeof(AIRPDCAP_SEC_ASSOCIATION_ID))==0) {
                     ctx->index=index;
@@ -1153,9 +1142,9 @@ AirPDcapStoreSa(
     /* increment by 1 the first_free_index (heuristic)	*/
     ctx->first_free_index++;
 
-    /* set the last_stored_index if the added index is greater the the last_stored_index	*/
-    if (ctx->index > ctx->last_stored_index)
-        ctx->last_stored_index=ctx->index;
+    /* set the sa_index if the added index is greater the the sa_index	*/
+    if (ctx->index > ctx->sa_index)
+        ctx->sa_index=ctx->index;
 
     return ctx->index;
 }
@@ -1353,7 +1342,7 @@ parse_key_string(gchar* input_string)
 
     /* First, check for a WEP string */
     /* XXX - This duplicates code in packet-ieee80211.c */
-    if (g_strncasecmp(input_string, STRING_KEY_TYPE_WEP ":", 4) == 0) {
+    if (g_ascii_strncasecmp(input_string, STRING_KEY_TYPE_WEP ":", 4) == 0) {
         first_nibble += 4;
     }
 
@@ -1407,7 +1396,7 @@ parse_key_string(gchar* input_string)
         ssid = g_strdup(tokens[2]);
     }
 
-    if (g_strcasecmp(type,STRING_KEY_TYPE_WPA_PSK) == 0) /* WPA key */
+    if (g_ascii_strcasecmp(type,STRING_KEY_TYPE_WPA_PSK) == 0) /* WPA key */
     {
         /* Create a new string */
         key_string = g_string_new(key);
@@ -1416,7 +1405,7 @@ parse_key_string(gchar* input_string)
         res = hex_str_to_bytes(key, key_ba, FALSE);
 
         /* Two tokens means that the user should have entered a WPA-BIN key ... */
-        if( ((key_ba->len) != WPA_PSK_KEY_CHAR_SIZE))
+        if(!res || ((key_string->len) != WPA_PSK_KEY_CHAR_SIZE))
         {
             g_string_free(key_string, TRUE);
             g_byte_array_free(key_ba, TRUE);
@@ -1434,7 +1423,7 @@ parse_key_string(gchar* input_string)
 
         dk->type = AIRPDCAP_KEY_TYPE_WPA_PMK;
         dk->key  = g_string_new(key);
-        dk->bits = key_ba->len * 4;
+        dk->bits = dk->key->len * 4;
         dk->ssid = NULL;
 
         g_string_free(key_string, TRUE);
@@ -1446,7 +1435,7 @@ parse_key_string(gchar* input_string)
         g_strfreev(tokens);
         return dk;
     }
-    else if(g_strcasecmp(type,STRING_KEY_TYPE_WPA_PWD) == 0) /* WPA key *//* If the number of tokens is more than three, we accept the string... if the first three tokens are correct... */
+    else if(g_ascii_strcasecmp(type,STRING_KEY_TYPE_WPA_PWD) == 0) /* WPA key *//* If the number of tokens is more than three, we accept the string... if the first three tokens are correct... */
     {
         /* Create a new string */
         key_string = g_string_new(key);
