@@ -1,7 +1,7 @@
 /**
  * airpdcap_rijndael.c
  *
- * $Id: airpdcap_rijndael.c 20401 2007-01-12 00:54:13Z gerald $
+ * $Id: airpdcap_rijndael.c 21429 2007-04-14 11:55:19Z standel $
  *
  * @version 3.0 (December 2000)
  *
@@ -689,73 +689,6 @@ static const UINT32 Td3[256] = {
 	0xcb84617bU, 0x32b670d5U, 0x6c5c7448U, 0xb85742d0U,
 };
 
-static const UINT32 Td4[256] = {
-	0x52525252U, 0x09090909U, 0x6a6a6a6aU, 0xd5d5d5d5U,
-	0x30303030U, 0x36363636U, 0xa5a5a5a5U, 0x38383838U,
-	0xbfbfbfbfU, 0x40404040U, 0xa3a3a3a3U, 0x9e9e9e9eU,
-	0x81818181U, 0xf3f3f3f3U, 0xd7d7d7d7U, 0xfbfbfbfbU,
-	0x7c7c7c7cU, 0xe3e3e3e3U, 0x39393939U, 0x82828282U,
-	0x9b9b9b9bU, 0x2f2f2f2fU, 0xffffffffU, 0x87878787U,
-	0x34343434U, 0x8e8e8e8eU, 0x43434343U, 0x44444444U,
-	0xc4c4c4c4U, 0xdedededeU, 0xe9e9e9e9U, 0xcbcbcbcbU,
-	0x54545454U, 0x7b7b7b7bU, 0x94949494U, 0x32323232U,
-	0xa6a6a6a6U, 0xc2c2c2c2U, 0x23232323U, 0x3d3d3d3dU,
-	0xeeeeeeeeU, 0x4c4c4c4cU, 0x95959595U, 0x0b0b0b0bU,
-	0x42424242U, 0xfafafafaU, 0xc3c3c3c3U, 0x4e4e4e4eU,
-	0x08080808U, 0x2e2e2e2eU, 0xa1a1a1a1U, 0x66666666U,
-	0x28282828U, 0xd9d9d9d9U, 0x24242424U, 0xb2b2b2b2U,
-	0x76767676U, 0x5b5b5b5bU, 0xa2a2a2a2U, 0x49494949U,
-	0x6d6d6d6dU, 0x8b8b8b8bU, 0xd1d1d1d1U, 0x25252525U,
-	0x72727272U, 0xf8f8f8f8U, 0xf6f6f6f6U, 0x64646464U,
-	0x86868686U, 0x68686868U, 0x98989898U, 0x16161616U,
-	0xd4d4d4d4U, 0xa4a4a4a4U, 0x5c5c5c5cU, 0xccccccccU,
-	0x5d5d5d5dU, 0x65656565U, 0xb6b6b6b6U, 0x92929292U,
-	0x6c6c6c6cU, 0x70707070U, 0x48484848U, 0x50505050U,
-	0xfdfdfdfdU, 0xededededU, 0xb9b9b9b9U, 0xdadadadaU,
-	0x5e5e5e5eU, 0x15151515U, 0x46464646U, 0x57575757U,
-	0xa7a7a7a7U, 0x8d8d8d8dU, 0x9d9d9d9dU, 0x84848484U,
-	0x90909090U, 0xd8d8d8d8U, 0xababababU, 0x00000000U,
-	0x8c8c8c8cU, 0xbcbcbcbcU, 0xd3d3d3d3U, 0x0a0a0a0aU,
-	0xf7f7f7f7U, 0xe4e4e4e4U, 0x58585858U, 0x05050505U,
-	0xb8b8b8b8U, 0xb3b3b3b3U, 0x45454545U, 0x06060606U,
-	0xd0d0d0d0U, 0x2c2c2c2cU, 0x1e1e1e1eU, 0x8f8f8f8fU,
-	0xcacacacaU, 0x3f3f3f3fU, 0x0f0f0f0fU, 0x02020202U,
-	0xc1c1c1c1U, 0xafafafafU, 0xbdbdbdbdU, 0x03030303U,
-	0x01010101U, 0x13131313U, 0x8a8a8a8aU, 0x6b6b6b6bU,
-	0x3a3a3a3aU, 0x91919191U, 0x11111111U, 0x41414141U,
-	0x4f4f4f4fU, 0x67676767U, 0xdcdcdcdcU, 0xeaeaeaeaU,
-	0x97979797U, 0xf2f2f2f2U, 0xcfcfcfcfU, 0xcecececeU,
-	0xf0f0f0f0U, 0xb4b4b4b4U, 0xe6e6e6e6U, 0x73737373U,
-	0x96969696U, 0xacacacacU, 0x74747474U, 0x22222222U,
-	0xe7e7e7e7U, 0xadadadadU, 0x35353535U, 0x85858585U,
-	0xe2e2e2e2U, 0xf9f9f9f9U, 0x37373737U, 0xe8e8e8e8U,
-	0x1c1c1c1cU, 0x75757575U, 0xdfdfdfdfU, 0x6e6e6e6eU,
-	0x47474747U, 0xf1f1f1f1U, 0x1a1a1a1aU, 0x71717171U,
-	0x1d1d1d1dU, 0x29292929U, 0xc5c5c5c5U, 0x89898989U,
-	0x6f6f6f6fU, 0xb7b7b7b7U, 0x62626262U, 0x0e0e0e0eU,
-	0xaaaaaaaaU, 0x18181818U, 0xbebebebeU, 0x1b1b1b1bU,
-	0xfcfcfcfcU, 0x56565656U, 0x3e3e3e3eU, 0x4b4b4b4bU,
-	0xc6c6c6c6U, 0xd2d2d2d2U, 0x79797979U, 0x20202020U,
-	0x9a9a9a9aU, 0xdbdbdbdbU, 0xc0c0c0c0U, 0xfefefefeU,
-	0x78787878U, 0xcdcdcdcdU, 0x5a5a5a5aU, 0xf4f4f4f4U,
-	0x1f1f1f1fU, 0xddddddddU, 0xa8a8a8a8U, 0x33333333U,
-	0x88888888U, 0x07070707U, 0xc7c7c7c7U, 0x31313131U,
-	0xb1b1b1b1U, 0x12121212U, 0x10101010U, 0x59595959U,
-	0x27272727U, 0x80808080U, 0xececececU, 0x5f5f5f5fU,
-	0x60606060U, 0x51515151U, 0x7f7f7f7fU, 0xa9a9a9a9U,
-	0x19191919U, 0xb5b5b5b5U, 0x4a4a4a4aU, 0x0d0d0d0dU,
-	0x2d2d2d2dU, 0xe5e5e5e5U, 0x7a7a7a7aU, 0x9f9f9f9fU,
-	0x93939393U, 0xc9c9c9c9U, 0x9c9c9c9cU, 0xefefefefU,
-	0xa0a0a0a0U, 0xe0e0e0e0U, 0x3b3b3b3bU, 0x4d4d4d4dU,
-	0xaeaeaeaeU, 0x2a2a2a2aU, 0xf5f5f5f5U, 0xb0b0b0b0U,
-	0xc8c8c8c8U, 0xebebebebU, 0xbbbbbbbbU, 0x3c3c3c3cU,
-	0x83838383U, 0x53535353U, 0x99999999U, 0x61616161U,
-	0x17171717U, 0x2b2b2b2bU, 0x04040404U, 0x7e7e7e7eU,
-	0xbabababaU, 0x77777777U, 0xd6d6d6d6U, 0x26262626U,
-	0xe1e1e1e1U, 0x69696969U, 0x14141414U, 0x63636363U,
-	0x55555555U, 0x21212121U, 0x0c0c0c0cU, 0x7d7d7d7dU,
-};
-
 static const UINT32 rcon[] = {
 	0x01000000, 0x02000000, 0x04000000, 0x08000000,
 	0x10000000, 0x20000000, 0x40000000, 0x80000000,
