@@ -8,7 +8,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id: packet-bthci_acl.c 18894 2006-08-14 08:29:29Z sahlberg $
+ * $Id: packet-bthci_acl.c 24263 2008-02-03 21:11:53Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -54,7 +54,7 @@ static int hf_btacl_reassembled_in = -1;
 /* Initialize the subtree pointers */
 static gint ett_btacl = -1;
 
-dissector_handle_t btl2cap_handle=NULL;
+static dissector_handle_t btl2cap_handle=NULL;
 
 static gboolean acl_reassembly = TRUE;
 
@@ -170,7 +170,7 @@ dissect_btacl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				mfp->last_frame=0;
 				mfp->tot_len=l2cap_length+4;
 				mfp->reassembled=se_alloc(l2cap_length+4);
-				tvb_memcpy(tvb, mfp->reassembled, offset, tvb_length_remaining(tvb, offset));
+				tvb_memcpy(tvb, (guint8*)mfp->reassembled, offset, tvb_length_remaining(tvb, offset));
 				mfp->cur_off=tvb_length_remaining(tvb, offset);
 				se_tree_insert32(chandle_data->start_fragments, pinfo->fd->num, mfp);
 			} else {
@@ -189,7 +189,7 @@ dissect_btacl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			mfp=se_tree_lookup32_le(chandle_data->start_fragments, pinfo->fd->num);
 			if(!pinfo->fd->flags.visited){
 				if(mfp && !mfp->last_frame && (mfp->tot_len>=mfp->cur_off+tvb_length_remaining(tvb, offset))){
-					tvb_memcpy(tvb, mfp->reassembled+mfp->cur_off, offset, tvb_length_remaining(tvb, offset));
+					tvb_memcpy(tvb, (guint8*)mfp->reassembled+mfp->cur_off, offset, tvb_length_remaining(tvb, offset));
 					mfp->cur_off+=tvb_length_remaining(tvb, offset);
 					if(mfp->cur_off==mfp->tot_len){
 						mfp->last_frame=pinfo->fd->num;
@@ -205,7 +205,7 @@ dissect_btacl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				}
 			}
 			if(mfp && mfp->last_frame==pinfo->fd->num){
-				next_tvb = tvb_new_real_data(mfp->reassembled, mfp->tot_len, mfp->tot_len);
+				next_tvb = tvb_new_real_data((guint8*)mfp->reassembled, mfp->tot_len, mfp->tot_len);
 				tvb_set_child_real_data_tvbuff(tvb, next_tvb);
 				add_new_data_source(pinfo, next_tvb, "Reassembled BTHCI ACL");
 
@@ -290,6 +290,7 @@ proto_reg_handoff_btacl(void)
 
 	bthci_acl_handle = find_dissector("bthci_acl");
 	dissector_add("hci_h4.type", HCI_H4_TYPE_ACL, bthci_acl_handle);
+	dissector_add("hci_h1.type", BTHCI_CHANNEL_ACL, bthci_acl_handle);
 
 
 	btl2cap_handle = find_dissector("btl2cap");
