@@ -19,7 +19,7 @@
  * Refactored for wireshark checkin
  *   Ronnie Sahlberg 2006
  *
- * $Id: packet-btrfcomm.c 18894 2006-08-14 08:29:29Z sahlberg $
+ * $Id: packet-btrfcomm.c 23252 2007-10-23 05:50:00Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -139,65 +139,6 @@ static const value_string vs_ctl_pn_cl[] = {
 	{0, NULL}
 };
 
-static const value_string vs_ctl_rpn_b[] = {
-	{0, "2400"},
-	{1, "4800"},
-	{2, "7200"},
-	{3, "9600"},
-	{4, "19200"},
-	{5, "38400"},
-	{6, "57600"},
-	{7, "115200"},
-	{8, "230400"},
-	{0, NULL}
-};
-
-
-static const value_string vs_ctl_rpn_d[] = {
-	{0x0, "5"},
-	{0x2, "6"},
-	{0x1, "7"},
-	{0x3, "8"},
-	{0, NULL}
-};
-
-
-static const value_string vs_ctl_rpn_s[] = {
-	{0, "1"},
-	{1, "1.5"},
-	{0, NULL}
-};
-
-
-static const true_false_string tfs_ctl_rpn_p = {
-	"parity", "no parity"
-};
-
-
-static const value_string vs_ctl_rpn_pt[] = {
-	{0, "odd parity"},
-	{1, "even parity"},
-	{2, "mark parity"},
-	{3, "space parity"},
-	{0, NULL}
-};
-
-
-static const value_string vs_ctl_rls_l[] = {
-	/* L1 == 1, masked 0x0e */
-	{0x1, "Overrun error"},
-	{0x2, "Parity error"},
-	{0x4, "Framing error"},
-	{0, NULL}
-};
-
-
-static const value_string vs_rfcomm_addr_d[] = {
-        {1, "Server Device"},
-	{0, "Initiating Device"},
-	{0, NULL}
-};
-
 
 static const value_string vs_frame_type[] = {
 	/* masked 0xef */
@@ -691,7 +632,7 @@ dissect_btrfcomm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "RFCOMM");
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		col_clear(pinfo->cinfo, COL_INFO);
-		col_add_str(pinfo->cinfo, COL_INFO, pinfo->p2p_dir == P2P_DIR_SENT ? "Sent " : "Rcvd ");
+		col_set_str(pinfo->cinfo, COL_INFO, pinfo->p2p_dir == P2P_DIR_SENT ? "Sent " : "Rcvd ");
 	}
 
 
