@@ -5,7 +5,7 @@
  *
  * Copyright 2003, Dave Sclarsky <dave_sclarsky[AT]cnt.com>
  *
- * $Id: packet-cpfi.c 23048 2007-10-02 14:45:20Z morriss $
+ * $Id: packet-cpfi.c 24525 2008-03-01 17:23:39Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,7 @@
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
+#include <epan/strutil.h>
 
 void proto_reg_handoff_cpfi(void);
 
@@ -182,7 +183,7 @@ dissect_cpfi_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   tda = (word1 & CPFI_DEST_MASK) >> CPFI_DEST_SHIFT;
   if ( tda >= FIRST_TIO_CARD_ADDRESS )
   {
-    strncpy(src_str, " CPFI", sizeof(src_str));
+    g_strlcpy(src_str, " CPFI", sizeof(src_str));
     src = 0;                            /* Make it smallest */
   }
   else
@@ -204,7 +205,7 @@ dissect_cpfi_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   tda = (word1 & CPFI_SOURCE_MASK) >> CPFI_SOURCE_SHIFT;
   if ( tda >= FIRST_TIO_CARD_ADDRESS )
   {
-    strncpy(dst_str, " CPFI", sizeof(dst_str));
+    g_strlcpy(dst_str, " CPFI", sizeof(dst_str));
     dst = 0;                            /* Make it smallest */
   }
   else
