@@ -1,7 +1,7 @@
 /* packet-diameter.c
  * Routines for Diameter packet disassembly
  *
- * $Id: packet-diameter.c 23631 2007-11-28 00:08:20Z gerald $
+ * $Id: packet-diameter.c 24377 2008-02-18 19:10:50Z etxrab $
  *
  * Copyright (c) 2001 by David Frascone <dave@frascone.com>
  * Copyright (c) 2007 by Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
@@ -61,7 +61,7 @@
 #define SCTP_PORT_DIAMETER	3868
 
 /* Diameter Header Flags */
-/*                                      RPrrrrrrCCCCCCCCCCCCCCCCCCCCCCCC  */
+/*                                      RPETrrrrCCCCCCCCCCCCCCCCCCCCCCCC  */
 #define DIAM_FLAGS_R 0x80
 #define DIAM_FLAGS_P 0x40
 #define DIAM_FLAGS_E 0x20
@@ -268,6 +268,11 @@ static range_t *diameter_tcp_port_range;
 /* desegmentation of Diameter over TCP */
 static gboolean gbl_diameter_desegment = TRUE;
 
+/* Dissector tables */
+#define VND_3GPP		10415
+static dissector_table_t diameter_dissector_table;
+static dissector_table_t diameter_3gpp_avp_dissector_table;
+
 static const char* avpflags_str[] = {
 	"---",
 	"--P",
@@ -279,6 +284,21 @@ static const char* avpflags_str[] = {
 	"VMP",
 };
 
+/* Special decoding of some AVP:s */
+
+static int
+dissect_diameter_vedor_id(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_) {
+
+	int offset = 0;
+
+	proto_tree_add_item(tree, hf_diameter_vendor_id, tvb, 0, 4, FALSE);
+
+	offset++;
+	return offset;
+
+}
+
+
 /* Dissect an AVP at offset */
 static int dissect_diameter_avp(diam_ctx_t* c, tvbuff_t* tvb, int offset) {
 	guint32 code = tvb_get_ntohl(tvb,offset);
@@ -382,6 +402,9 @@ static int dissect_diameter_avp(diam_ctx_t* c, tvbuff_t* tvb, int offset) {
 
 	if ( len == (guint32)(vendor_flag ? 12 : 8) ) {
 		/* Data is empty so return now */
+		proto_item* iu = proto_tree_add_text(avp_tree,tvb,offset,0,"No data");
+		expert_add_info_format(c->pinfo, iu, PI_UNDECODED, PI_WARN, "Data is empty");
+		PROTO_ITEM_SET_GENERATED(iu);
 		return len;
 	}
 
@@ -398,6 +421,21 @@ static int dissect_diameter_avp(diam_ctx_t* c, tvbuff_t* tvb, int offset) {
 
 	if (avp_str) proto_item_append_text(avp_item," val=%s", avp_str);
 
+	/* Call subdissectors for AVP:s */
+	switch (vendorid){
+	case 0:
+		dissector_try_port(diameter_dissector_table, code, subtvb, c->pinfo, avp_tree);
+		break;
+	case VND_3GPP:
+		dissector_try_port(diameter_3gpp_avp_dissector_table, code, subtvb, c->pinfo, avp_tree);
+		break;
+	default:
+		break;
+	}
+	/* Debug
+	proto_tree_add_text(avp_tree, subtvb, 0, -1, "AVP %u data, Vendor Id %u ",code,vendorid);
+	*/
+
 	return len;
 }
 
@@ -1216,6 +1254,11 @@ proto_reg_handoff_diameter(void)
 	SctpPort=gbl_diameterSctpPort;
 
 	dissector_add("sctp.port", gbl_diameterSctpPort, diameter_handle);
+
+	/* Register special decoding for some AVP:s */
+	/* AVP Code: 266 Vendor-Id */
+	dissector_add("diameter.base", 266, new_create_dissector_handle(dissect_diameter_vedor_id, proto_diameter));
+
 }
 
 /* registration with the filtering engine */
@@ -1342,6 +1385,10 @@ proto_register_diameter(void)
 
 	/* Allow dissector to find be found by name. */
 	new_register_dissector("diameter", dissect_diameter, proto_diameter);
+	
+	/* Register dissector table(s) to do sub dissection of AVP:s ( OctetStrings) */ 
+	diameter_dissector_table = register_dissector_table("diameter.base", "DIAMETER_3GPP_AVPS", FT_UINT32, BASE_DEC);
+	diameter_3gpp_avp_dissector_table = register_dissector_table("diameter.3gpp", "DIAMETER_3GPP_AVPS", FT_UINT32, BASE_DEC);
 
 	/* Set default TCP ports */
 	range_convert_str(&global_diameter_tcp_port_range, DEFAULT_DIAMETER_PORT_RANGE, MAX_UDP_PORT);
