@@ -2,7 +2,7 @@
  * Routines for dsi packet dissection
  * Copyright 2001, Randy McEoin <rmceoin@pe.com>
  *
- * $Id: packet-dsi.c 19751 2006-10-31 09:29:07Z sahlberg $
+ * $Id: packet-dsi.c 24624 2008-03-14 03:28:12Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,14 +41,17 @@
 
 /* The information in this module (DSI) comes from:
 
-  AFP 2.1 & 2.2.pdf contained in AppleShare_IP_6.3_SDK
-  available from http://www.apple.com
+  AFP 2.1 & 2.2 documentation, in PDF form, at
+
+http://developer.apple.com/DOCUMENTATION/macos8/pdf/ASAppleTalkFiling2.1_2.2.pdf
 
   The netatalk source code by Wesley Craig & Adrian Sun
 
   The Data Stream Interface description from
   http://developer.apple.com/documentation/Networking/Conceptual/AFPClient/AFPClient-6.html
 
+(no longer available, apparently)
+
  * What a Data Stream Interface packet looks like:
  * 0                               32
  * |-------------------------------|
