@@ -3,7 +3,7 @@
  * Copyright (c) 2006, Authesserre Samuel <sauthess@gmail.com>
  * Copyright (c) 2007, Mikael Magnusson <mikma@users.sourceforge.net>
  *
- * $Id: packet-dtls.c 23369 2007-11-05 23:05:20Z sake $
+ * $Id: packet-dtls.c 24301 2008-02-11 17:04:51Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -806,7 +806,7 @@ dissect_dtls_record(tvbuff_t *tvb, packet_info *pinfo,
 
 	/* find out a dissector using server port*/
 	if (association && association->handle) {
-	  ssl_debug_printf("dissect_dtls_record found association %p\n", association);
+	  ssl_debug_printf("dissect_dtls_record found association %p\n", (void *)association);
 	  ssl_print_text_data("decrypted app data",appl_data->plain_data.data, appl_data->plain_data.data_len);
 
 	  call_dissector(association->handle, next_tvb, pinfo, top_tree);
