@@ -3,7 +3,7 @@
  *
  * Copyright 2001, Paul Ionescu	<paul@acorp.ro>
  *
- * $Id: packet-fr.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-fr.c 23038 2007-09-30 22:34:19Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -551,6 +551,8 @@ dissect_fr_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
       }
       proto_tree_add_boolean(octet_tree, hf_fr_dc, tvb, offset, 1, fr_octet);
       proto_tree_add_boolean(octet_tree, hf_fr_ea, tvb, offset, 1, fr_octet);
+      
+      offset++;
     }
   }
   if (tree) {
@@ -561,6 +563,11 @@ dissect_fr_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   pinfo->ctype = CT_DLCI;
   pinfo->circuit_id = address;
 
+  /* Add DLCI to a collumn */
+  if ( check_col(pinfo->cinfo, COL_FR_DLCI)) {
+      col_add_fstr(pinfo->cinfo, COL_FR_DLCI, "%u", address);
+  }
+  
   if (check_col(pinfo->cinfo, COL_INFO))
       col_add_fstr(pinfo->cinfo, COL_INFO, "DLCI %u", address);
 
@@ -857,10 +864,10 @@ void proto_register_fr(void)
 	  "Supervisory frame type", "fr.control.s_ftype", FT_UINT16, BASE_HEX,
 	  VALS(stype_vals), XDLC_S_FTYPE_MASK, "", HFILL }},
 	{ &hf_fr_u_modifier_cmd, {
-	  "Command", "lapd.control.u_modifier_cmd", FT_UINT8, BASE_HEX,
+	  "Command", "fr.control.u_modifier_cmd", FT_UINT8, BASE_HEX,
 	  VALS(modifier_vals_cmd), XDLC_U_MODIFIER_MASK, "", HFILL }},
 	{ &hf_fr_u_modifier_resp, {
-	  "Response", "lapd.control.u_modifier_resp", FT_UINT8, BASE_HEX,
+	  "Response", "fr.control.u_modifier_resp", FT_UINT8, BASE_HEX,
 	    VALS(modifier_vals_resp), XDLC_U_MODIFIER_MASK, "", HFILL }},
 	{ &hf_fr_ftype_i, {
 	  "Frame type", "fr.control.ftype", FT_UINT16, BASE_HEX,
