@@ -2,7 +2,7 @@
  * Routines for gnutella dissection
  * Copyright 2001, B. Johannessen <bob@havoq.com>
  *
- * $Id: packet-gnutella.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-gnutella.c 19751 2006-10-31 09:29:07Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -325,7 +325,7 @@ static void dissect_gnutella_push(tvbuff_t *tvb, guint offset, proto_tree *tree)
 }
 
 static guint
-get_gnutella_pdu_len(tvbuff_t *tvb, int offset) {
+get_gnutella_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset) {
 	guint32 size;
 
 	size = tvb_get_letohl(
