@@ -8,23 +8,25 @@
  * IAX2 is a VoIP protocol for the open source PBX Asterisk. Please see
  * http://www.asterisk.org for more information.
  *
- * $Id: packet-iax2.c 18558 2006-06-23 12:04:00Z sahlberg $
+ * $Id: packet-iax2.c 23252 2007-10-23 05:50:00Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version. This program is distributed in the hope
- * that it will be useful, but WITHOUT ANY WARRANTY; without even the
- * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
- * PURPOSE.  See the GNU General Public License for more details. You
- * should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc., 
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -87,6 +89,7 @@ static int hf_iax2_voice_codec = -1;
 static int hf_iax2_video_csub = -1;
 static int hf_iax2_video_codec = -1;
 static int hf_iax2_marker = -1;
+static int hf_iax2_modem_csub = -1;
 
 static int hf_iax2_cap_g723_1 = -1;
 static int hf_iax2_cap_gsm = -1;
@@ -167,14 +170,18 @@ static dissector_table_t iax2_codec_dissector_table;
 /* IAX2 Full-frame types */
 static const value_string iax_frame_types[] = {
   {0, "(0?)"},
-  {1, "DTMF"},
-  {2, "Voice"},
-  {3, "Video"},
-  {4, "Control"},
-  {5, "NULL"},
-  {6, "IAX"},
-  {7, "Text"},
-  {8, "Image"},
+  {AST_FRAME_DTMF_END, "DTMF End"},
+  {AST_FRAME_VOICE, "Voice"},
+  {AST_FRAME_VIDEO, "Video"},
+  {AST_FRAME_CONTROL, "Control"},
+  {AST_FRAME_NULL, "NULL"},
+  {AST_FRAME_IAX, "IAX"},
+  {AST_FRAME_TEXT, "Text"},
+  {AST_FRAME_IMAGE, "Image"},
+  {AST_FRAME_HTML, "HTML"},
+  {AST_FRAME_CNG, "Comfort Noise"},
+  {AST_FRAME_MODEM, "Modem"}, 
+  {AST_FRAME_DTMF_BEGIN, "DTMF Begin"},
   {0,NULL}
 };
 
@@ -235,6 +242,14 @@ static const value_string iax_cmd_subclasses[] = {
   {0,NULL}
 };
 
+/* Subclassess for Modem packets */
+static const value_string iax_modem_subclasses[] = {
+  {0, "(0?)"},
+  {1, "T.38"},
+  {2, "V.150"},
+  {0,NULL}
+};
+
 /* Information elements */
 static const value_string iax_ies_type[] = {
   {IAX_IE_CALLED_NUMBER, "Number/extension being called"},
@@ -473,12 +488,9 @@ static guint iax_circuit_hash (gconstpointer v)
 {
   const iax_circuit_key *key = (const iax_circuit_key *)v;
   guint hash_val;
-  int i;
 
   hash_val = 0;
-  for (i = 0; i < key->addr.len; i++)
-    hash_val += (guint)(key->addr.data[i]);
-
+  ADD_ADDRESS_TO_HASH(hash_val, &key->addr);
   hash_val += (guint)(key->ptype);
   hash_val += (guint)(key->port);
   hash_val += (guint)(key->callno);
@@ -514,7 +526,7 @@ static guint iax_circuit_lookup(const address *address,
     new_key->addr.type = address->type;
     new_key->addr.len = MIN(address->len,MAX_ADDRESS);
     new_key->addr.data = new_key->address_data;
-    memmove(new_key->address_data,address->data,new_key->addr.len);
+    memcpy(new_key->address_data,address->data,new_key->addr.len);
     new_key->ptype = ptype;
     new_key->port = port;
     new_key->callno = callno;
@@ -1088,7 +1100,41 @@ static guint32 dissect_ies (tvbuff_t * tvb, guint32 offset,
 
     int ies_type = tvb_get_guint8(tvb, offset);
     int ies_len = tvb_get_guint8(tvb, offset + 1);
+    guint16 apparent_addr_family;
 
+    /* do non-tree-dependent stuff first */
+    switch(ies_type) {
+      case IAX_IE_DATAFORMAT:
+        if (ies_len != 4) THROW(ReportedBoundsError);
+        ie_data -> dataformat = tvb_get_ntohl(tvb, offset+2);
+        break;
+
+      case IAX_IE_APPARENT_ADDR:
+        /* the family is little-endian. That's probably broken, given
+           everything else is big-endian, but that's not our fault.
+        */
+        apparent_addr_family = tvb_get_letohs(tvb, offset+2);
+        switch( apparent_addr_family ) {
+          /* these come from linux/socket.h */
+          case 2: /* AF_INET */
+            /* IAX is always over UDP */
+            ie_data->peer_ptype = PT_UDP;
+            ie_data->peer_port = tvb_get_ntohs(tvb, offset+4);
+
+            /* the ip address is big-endian, but then so is peer_address.data */
+            SET_ADDRESS(&ie_data->peer_address,AT_IPv4,4,tvb_get_ptr(tvb,offset+6,4));
+            break;
+
+          default:
+            g_warning("Not supported in IAX dissector: peer address family of %u", apparent_addr_family);
+            break;
+        }
+        break;
+    }
+
+
+    /* the rest of this stuff only needs doing if we have an iax_tree */
+    
     if( iax_tree ) {
       proto_item *ti, *ie_item = NULL;
       proto_tree *ies_tree;
@@ -1150,7 +1196,6 @@ static guint32 dissect_ies (tvbuff_t * tvb, guint32 offset,
 	case IAX_IE_APPARENT_ADDR:
 	{
 	  proto_tree *sockaddr_tree = NULL;
-	  guint16 family;
 
 	  ie_item = proto_tree_add_text(ies_tree, tvb, offset + 2, 16, "Apparent Address");
 	  sockaddr_tree = proto_item_add_subtree(ie_item, ett_iax2_ies_apparent_addr);
@@ -1158,40 +1203,23 @@ static guint32 dissect_ies (tvbuff_t * tvb, guint32 offset,
 	  /* the family is little-endian. That's probably broken, given
 	     everything else is big-endian, but that's not our fault.
 	  */
-	  family = tvb_get_letohs(tvb, offset+2);
-	  proto_tree_add_uint(sockaddr_tree, hf_IAX_IE_APPARENTADDR_SINFAMILY, tvb, offset + 2, 2, family);
+	  apparent_addr_family = tvb_get_letohs(tvb, offset+2);
+	  proto_tree_add_uint(sockaddr_tree, hf_IAX_IE_APPARENTADDR_SINFAMILY, tvb, offset + 2, 2, apparent_addr_family);
 	      
-	  switch( family ) {
+	  switch(  apparent_addr_family ) {
 	    /* these come from linux/socket.h */
 	    case 2: /* AF_INET */
 	    {
 	      guint32 addr;
-	      
-	      /* IAX is always over UDP */
-	      ie_data->peer_ptype = PT_UDP;
-	      ie_data->peer_port = tvb_get_ntohs(tvb, offset+4);
 	      proto_tree_add_uint(sockaddr_tree, hf_IAX_IE_APPARENTADDR_SINPORT, tvb, offset + 4, 2, ie_data->peer_port);
-	      /* the ip address is big-endian, but then so is address.data */
-	      SET_ADDRESS(&ie_data->peer_address,AT_IPv4,4,tvb_get_ptr(tvb,offset+6,4));
 	      memcpy(&addr, ie_data->peer_address.data, 4);
 	      proto_tree_add_ipv4(sockaddr_tree, hf_IAX_IE_APPARENTADDR_SINADDR, tvb, offset + 6, 4, addr);
 	      break;
 	    }
-
-	    default:
-	      g_warning("Not supported in IAX dissector: peer address family of %u", family);
-	      break;
 	  }
 	  break;
 	}
 	      
-        case IAX_IE_DATAFORMAT:
-          if (ies_len != 4) THROW(ReportedBoundsError);
-          ie_item = proto_tree_add_item (ies_tree, ie_hf, tvb,
-                               offset + 2, ies_len, FALSE);
-          ie_data -> dataformat = tvb_get_ntohl(tvb, offset+2);
-          break;
-
 	default:
 	  if( ie_hf != -1 ) {
             /* throw an error if the IE isn't the expected length */
@@ -1358,13 +1386,13 @@ static void iax2_add_ts_fields(packet_info * pinfo, proto_tree * iax2_tree, iax_
 
   if(iax_packet->abstime.secs == -1) {
     time_t start_secs = iax_packet->call_data->start_time.secs;
-    gint32 abs_secs = start_secs + longts/1000;
+    gint32 abs_secs = (gint32) (start_secs + longts/1000);
 
     /* deal with short timestamps by assuming that packets are never more than
      * 16 seconds late */
     while(abs_secs < pinfo->fd->abs_ts.secs - 16) {
       longts += 32768;
-      abs_secs = start_secs + longts/1000;
+      abs_secs = (gint32) (start_secs + longts/1000);
     }
 
     iax_packet->abstime.secs=abs_secs;
@@ -1479,7 +1507,8 @@ dissect_fullpacket (tvbuff_t * tvb, guint32 offset,
     offset=dissect_iax2_command(tvb,offset+9,pinfo,packet_type_tree,iax_packet);
     break;
     
-  case AST_FRAME_DTMF:
+  case AST_FRAME_DTMF_BEGIN:
+  case AST_FRAME_DTMF_END:
     proto_tree_add_item (packet_type_tree, hf_iax2_dtmf_csub, tvb, offset+9, 1, FALSE);
     offset += 10;
 
@@ -1546,13 +1575,23 @@ dissect_fullpacket (tvbuff_t * tvb, guint32 offset,
     }
 
     if( rtp_marker && check_col (pinfo->cinfo, COL_INFO))
-      col_append_fstr (pinfo->cinfo, COL_INFO, ", Mark" );
+      col_append_str (pinfo->cinfo, COL_INFO, ", Mark" );
 
 
     dissect_payload(tvb, offset, pinfo, iax2_tree, main_tree, ts, TRUE, iax_packet);
     break;
 
+  case AST_FRAME_MODEM:
+    proto_tree_add_item (packet_type_tree, hf_iax2_modem_csub, tvb, offset+9, 1, FALSE);
+    offset += 10;
 
+    if (check_col (pinfo->cinfo, COL_INFO))
+      col_append_fstr (pinfo->cinfo, COL_INFO, " %s",
+		    val_to_str (csub, iax_modem_subclasses, "unknown (0x%02x)"));
+    break;
+
+  case AST_FRAME_HTML:
+  case AST_FRAME_CNG:
   default:
     proto_tree_add_uint (packet_type_tree, hf_iax2_csub, tvb, offset+9,
 			 1, csub);
@@ -1789,12 +1828,17 @@ static void desegment_iax(tvbuff_t *tvb, packet_info *pinfo, proto_tree *iax2_tr
          within that section, the higher-level dissector was unable to find any
          pdus; if it's after that, it found one or more complete PDUs.
       */
-      old_len = (gint32)(tvb_reported_length(next_tvb) - tvb_reported_length(tvb));
+      old_len = (gint32)(tvb_reported_length(next_tvb) - frag_len);
       if( pinfo->desegment_len &&
 	  pinfo->desegment_offset < old_len ) {
 	/* oops, it wasn't actually complete */
 	fragment_set_partial_reassembly(pinfo, fid, iax_call->fragment_table);
-	dirdata->current_frag_minlen = fd_head->datalen + pinfo->desegment_len;
+        if(pinfo->desegment_len == DESEGMENT_ONE_MORE_SEGMENT) {
+          /* only one more byte should be enough for a retry */
+          dirdata->current_frag_minlen = fd_head->datalen + 1;
+        } else {
+          dirdata->current_frag_minlen = fd_head->datalen + pinfo->desegment_len;
+        }
       } else {
 	/* we successfully dissected some data; create the proto tree items for
 	 * the fragments, and flag any remaining data for desegmentation */
@@ -1847,7 +1891,14 @@ static void desegment_iax(tvbuff_t *tvb, packet_info *pinfo, proto_tree *iax2_tr
       guint32 frag_len = tvb_reported_length_remaining(tvb,deseg_offset);
       dirdata->current_frag_id = fid;
       dirdata->current_frag_bytes = frag_len;
-      dirdata->current_frag_minlen = frag_len + pinfo->desegment_len;
+
+      if(pinfo->desegment_len == DESEGMENT_ONE_MORE_SEGMENT) {
+        /* only one more byte should be enough for a retry */
+          dirdata->current_frag_minlen = frag_len + 1;
+        } else {
+          dirdata->current_frag_minlen = frag_len + pinfo->desegment_len;
+        }
+
       fd_head = fragment_add(tvb, deseg_offset, pinfo, fid,
 			     iax_call->fragment_table,
                              0, frag_len, TRUE );
@@ -1907,7 +1958,7 @@ static void dissect_payload(tvbuff_t *tvb, guint32 offset,
 
   if( offset >= tvb_reported_length (tvb)) {
     if (check_col (pinfo->cinfo, COL_INFO))
-      col_append_fstr (pinfo->cinfo, COL_INFO, ", empty frame" );
+      col_append_str (pinfo->cinfo, COL_INFO, ", empty frame" );
     return;
   }
 
@@ -1922,7 +1973,7 @@ static void dissect_payload(tvbuff_t *tvb, guint32 offset,
 				   iax_dataformats, "unknown (0x%02x)"));
 #if 0
       if( out_of_order )
-	col_append_fstr (pinfo->cinfo, COL_INFO, " (out-of-order packet)");
+	col_append_str (pinfo->cinfo, COL_INFO, " (out-of-order packet)");
 #endif
     } else {
       col_append_fstr (pinfo->cinfo, COL_INFO, ", %s",
@@ -2099,6 +2150,12 @@ proto_register_iax2 (void)
     {&hf_iax2_video_codec,
      {"CODEC", "iax2.video.codec", FT_UINT32, BASE_HEX, VALS (codec_types), 0, 
       "The codec used to encode video data", HFILL}},
+
+    {&hf_iax2_modem_csub,
+     {"Modem subclass", "iax2.modem.subclass", FT_UINT8, BASE_DEC,
+      VALS (iax_modem_subclasses),
+      0x0, 
+      "Modem subclass gives the type of modem", HFILL}},
     
     /*
      * Decoding for the ies
