@@ -1,7 +1,7 @@
 /* packet-icmpv6.c
  * Routines for ICMPv6 packet disassembly
  *
- * $Id: packet-icmpv6.c 19779 2006-11-02 16:47:13Z jake $
+ * $Id: packet-icmpv6.c 24672 2008-03-17 21:21:48Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,12 +45,19 @@
 #include <glib.h>
 
 #include <epan/packet.h>
-#include "packet-ipv6.h"
-#include "packet-dns.h"
 #include <epan/in_cksum.h>
 #include <epan/addr_resolv.h>
 #include <epan/ipproto.h>
 #include <epan/emem.h>
+#include <epan/asn1.h>
+#include <epan/strutil.h>
+
+#include "packet-ber.h"
+#include "packet-ipv6.h"
+#include "packet-dns.h"
+#include "packet-x509af.h"
+#include "packet-x509if.h"
+
 
 #ifndef offsetof
 #define	offsetof(type, member)	((size_t)(&((type *)0)->member))
@@ -68,9 +75,9 @@
  * and
  *
  *	draft-ietf-mobileip-hmipv6-05.txt
- * 
+ *
  * and
- * 
+ *
  * 	rfc4068.txt
  */
 
@@ -88,6 +95,19 @@ static int hf_icmpv6_ra_retrans_timer = -1;
 static int hf_icmpv6_option = -1;
 static int hf_icmpv6_option_type = -1;
 static int hf_icmpv6_option_length = -1;
+static int hf_icmpv6_opt_cga_pad_len = -1;
+static int hf_icmpv6_opt_cga = -1;
+static int hf_icmpv6_opt_rsa_key_hash = -1;
+static int hf_icmpv6_opt_name_type = -1;
+static int hf_icmpv6_opt_name_x501 = -1;
+static int hf_icmpv6_opt_name_fqdn = -1;
+static int hf_icmpv6_opt_cert_type = -1;
+static int hf_icmpv6_identifier = -1;
+static int hf_icmpv6_all_comp = -1;
+static int hf_icmpv6_comp = -1;
+static int hf_icmpv6_x509if_Name = -1;
+static int hf_icmpv6_x509af_Certificate = -1;
+static int hf_icmpv6_recursive_dns_serv = -1;
 
 static gint ett_icmpv6 = -1;
 static gint ett_icmpv6opt = -1;
@@ -100,6 +120,7 @@ static gint ett_nodeinfo_node6 = -1;
 static gint ett_nodeinfo_nodebitmap = -1;
 static gint ett_nodeinfo_nodedns = -1;
 static gint ett_multicastRR = -1;
+static gint ett_icmpv6opt_name = -1;
 
 static dissector_handle_t ipv6_handle;
 static dissector_handle_t data_handle;
@@ -181,16 +202,48 @@ static const value_string names_fmip6_naack_opt_status[] = {
 	{ 0,			NULL }
 };
 
+/* http://www.iana.org/assignments/icmpv6-parameters */
 static const value_string option_vals[] = {
-	{ ND_OPT_SOURCE_LINKADDR,	"Source link-layer address" },
-	{ ND_OPT_TARGET_LINKADDR,	"Target link-layer address" },
-	{ ND_OPT_PREFIX_INFORMATION,	"Prefix information" },
-	{ ND_OPT_REDIRECTED_HEADER,	"Redirected header" },
-	{ ND_OPT_MTU,			"MTU" },
-	{ ND_OPT_ADVINTERVAL,		"Advertisement Interval" },
-	{ ND_OPT_HOMEAGENT_INFO,	"Home Agent Information" },
-	{ ND_OPT_MAP,			"HMIPv6 MAP option" },
-	{ FMIP6_OPT_NEIGHBOR_ADV_ACK,	"Neighbor Advertisement Acknowledgment" },
+	{ ND_OPT_SOURCE_LINKADDR,			"Source link-layer address" },
+	{ ND_OPT_TARGET_LINKADDR,			"Target link-layer address" },
+	{ ND_OPT_PREFIX_INFORMATION,		"Prefix information" },
+	{ ND_OPT_REDIRECTED_HEADER,			"Redirected header" },
+	{ ND_OPT_MTU,						"MTU" },
+	{ ND_OPT_ADVINTERVAL,				"Advertisement Interval" },
+	{ ND_OPT_HOMEAGENT_INFO,			"Home Agent Information" },
+	{ ND_OPT_CGA,						"CGA" },								/* [RFC3971] */
+	{ ND_OPT_RSA,						"RSA Signature" },						/* [RFC3971] */
+	{ ND_OPT_TIMESTAMP,					"Timestamp" },							/* [RFC3971] */
+	{ ND_OPT_NONCE,						"Nonce" },														/* [RFC3971] */
+	{ ND_OPT_TRUST_ANCHOR,				"Trust Anchor" },												/* [RFC3971] */
+	{ 16,		"Certificate" },												/* [RFC3971] */
+	{ FMIP6_OPT_IP_ADDRESS,				"IP Address Option" },						/* [RFC4068] */
+	{ FMIP6_OPT_NEW_ROUTER_PREFIX_INFO,	"New Router Prefix Information" },			/* [RFC4068] */
+	{ FMIP6_OPT_LINK_LAYER_ADDRESS,		"Link-layer Address" },						/* [RFC4068] */
+	{ FMIP6_OPT_NEIGHBOR_ADV_ACK,		"Neighbor Advertisement Acknowledgment" },	/* [RFC4068] */
+	{ 21,		"CARD Request" },                     /* [RFC4065] */
+	{ 22,		"CARD Reply" },                       /* [RFC4065] */
+	{ 23,		"MAP" },                              /* [RFC4140] */
+	{ 24,		"Route Information" },                /* [RFC4191] */
+	{ ND_OPT_RECURSIVE_DNS_SERVER,		"Recursive DNS Server" },             /* [RFC5006] */
+	{ 26,		"RA Flags Extension" },               /* [RFC5075] */
+	{ 27,		"Handover Key Request" },             /* [RFC-ietf-mipshop-handover-key-03.txt] */
+	{ 28,		"Handover Key Reply" },               /* [RFC-ietf-mipshop-handover-key-03.txt] */
+	{ ND_OPT_MAP,						"HMIPv6 MAP option" },
+/*29-252  Unassigned */
+	{ 253,		"RFC3692-style Experiment 1" },          /* [RFC4727] */
+	{ 254,		"RFC3692-style Experiment 2" },          /* [RFC4727] */
+	{ 0,			NULL }
+};
+
+static const value_string icmpv6_option_name_type_vals[] = {
+	{ 1,	"DER Encoded X.501 Name" },
+	{ 2,	"FQDN" },
+	{ 0,			NULL }
+};
+
+static const value_string icmpv6_option_cert_type_vals[] = {
+	{ 1,	"X.509v3 Certificate" },
 	{ 0,			NULL }
 };
 
@@ -223,13 +276,22 @@ dissect_contained_icmpv6(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tr
 static void
 dissect_icmpv6ndopt(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-    proto_tree *icmp6opt_tree, *field_tree;
-    proto_item *ti, *tf;
+    proto_tree *icmp6opt_tree, *field_tree, *name_tree;
+    proto_item *ti, *tf, *name_item;
     struct nd_opt_hdr nd_opt_hdr, *opt;
     int len;
     const char *typename;
     static const guint8 nd_redirect_reserved[6] = {0, 0, 0, 0, 0, 0};
     guint8 nd_redirect_res[6];
+	int opt_offset;
+	guint8 padd_length = 0;
+	int par_len;
+	guint8 name_type = 0;
+	guint8 cert_type = 0;
+	asn1_ctx_t asn1_ctx;
+	guint32 lifetime;
+	guint32 no_of_pars;
+	guint32 i;
 
     if (!tree)
 	return;
@@ -260,9 +322,8 @@ again:
     proto_item_append_text(ti, " (%s)", typename);
 
     /* Option type */
-    proto_tree_add_uint(icmp6opt_tree, hf_icmpv6_option_type, tvb,
-	offset + offsetof(struct nd_opt_hdr, nd_opt_type), 1,
-	opt->nd_opt_type);
+	proto_tree_add_item(icmp6opt_tree, hf_icmpv6_option_type, tvb,
+		offset + offsetof(struct nd_opt_hdr, nd_opt_type), 1, FALSE);
     /* Option length */
     proto_tree_add_uint(icmp6opt_tree, hf_icmpv6_option_length, tvb,
 	offset + offsetof(struct nd_opt_hdr, nd_opt_len), 1,
@@ -341,7 +402,7 @@ again:
 	    offset + 2, 6, "Reserved: 0 (correct)");
 	else
 	   proto_tree_add_text(icmp6opt_tree, tvb,
-	    offset +2, 6, "Reserved: MUST be 0 (incorrect!)");	
+	    offset +2, 6, "Reserved: MUST be 0 (incorrect!)");
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + 8, (opt->nd_opt_len << 3) - 8, "Redirected packet");
 	dissect_contained_icmpv6(tvb, offset + 8, pinfo, icmp6opt_tree);
@@ -357,7 +418,7 @@ again:
 	    "Advertisement Interval: %u",
 	    tvb_get_ntohl(tvb, offset + offsetof(struct nd_opt_adv_int, nd_opt_adv_int_advint)));
 	break;
-    case ND_OPT_HOMEAGENT_INFO:
+    case ND_OPT_HOMEAGENT_INFO: /* 8 */
       {
 	struct nd_opt_ha_info pibuf, *pi;
 
@@ -373,6 +434,122 @@ again:
 	    pntohs(&pi->nd_opt_ha_info_ha_life));
 	break;
       }
+	case ND_OPT_CGA: /* 11 */
+		/* RFC 3971 5.1.  CGA Option */
+		/* Pad Length */
+		opt_offset = offset +2;
+		padd_length = tvb_get_guint8(tvb,opt_offset);
+		proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_cga_pad_len, tvb, opt_offset, 1, FALSE);
+		opt_offset++;
+		/* Reserved 8 bits */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,1,"Reserved");
+		opt_offset++;
+		/* CGA Parameters A variable-length field containing the CGA Parameters data
+		 * structure described in Section 4 of
+		 * "Cryptographically Generated Addresses (CGA)", RFC3972.
+		 */
+		par_len = len-4-padd_length;
+		proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_cga, tvb, opt_offset, par_len, FALSE);
+		opt_offset = opt_offset + par_len;
+		/* Padding */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,padd_length,"Padding");
+		break;
+	case ND_OPT_RSA: /* 12 */
+		/*5.2.  RSA Signature Option */
+		opt_offset = offset +2;
+		/* Reserved, A 16-bit field reserved for future use. */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,2,"Reserved");
+		opt_offset = opt_offset + 2;
+		/* Key Hash
+		 * A 128-bit field containing the most significant (leftmost) 128
+		 * bits of a SHA-1 [14] hash of the public key used for constructing
+		 * the signature.
+		 */
+		proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_rsa_key_hash, tvb, opt_offset, 16, FALSE);
+		opt_offset = opt_offset + 16;
+		/* Digital Signature */
+		par_len = len - 20;
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,par_len,"Digital Signature + Padding");
+		/* Padding */
+		/* TODO: Calculate padding length and exlude from the signature */
+		break;
+	case ND_OPT_TIMESTAMP: /* 13 */
+		opt_offset = offset +2;
+		/* Reserved A 48-bit field reserved for future use. */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,6,"Reserved");
+		opt_offset = opt_offset + 6;
+		/* Timestamp
+		 * A 64-bit unsigned integer field containing a timestamp.  The value
+		 * indicates the number of seconds since January 1, 1970, 00:00 UTC,
+		 * by using a fixed point format.  In this format, the integer number
+		 * of seconds is contained in the first 48 bits of the field, and the
+		 * remaining 16 bits indicate the number of 1/64K fractions of a
+		 * second.
+		 */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,6,"Timestamp(number of seconds since January 1, 1970, 00:00 UTC)");
+		opt_offset = opt_offset + 6;
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,2,"Timestamp(1/64K fractions of a second)");
+		break;
+	case ND_OPT_NONCE:
+		/* 5.3.2.  Nonce Option */
+		opt_offset = offset +2;
+		/* Nonce */
+		break;
+	case ND_OPT_TRUST_ANCHOR:
+		opt_offset = offset +2;
+		/* Name Type */
+		name_type = tvb_get_guint8(tvb,opt_offset);
+		proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_name_type, tvb, opt_offset, 1, FALSE);
+		opt_offset++;
+		/* Pad Length */
+		padd_length = tvb_get_guint8(tvb,opt_offset);
+		proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_cga_pad_len, tvb, opt_offset, 1, FALSE);
+		opt_offset++;
+		par_len = len - 4 - padd_length;
+		switch (name_type){
+		case 1:
+			/* DER Encoded X.501 Name */
+			name_item =proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_name_x501, tvb, opt_offset, par_len, FALSE);
+			name_tree = proto_item_add_subtree(name_item, ett_icmpv6opt_name);
+			asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
+			dissect_x509if_Name(FALSE, tvb, opt_offset, &asn1_ctx, name_tree, hf_icmpv6_x509if_Name);
+			break;
+		case 2:
+			/* FQDN */
+			proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_name_fqdn, tvb, opt_offset, par_len, FALSE);
+			break;
+		default:
+			proto_tree_add_text(icmp6opt_tree, tvb,opt_offset, par_len,"Unknown name type");
+			break;
+		}
+		opt_offset = opt_offset + par_len;
+		/* Padding */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,padd_length,"Padding");
+		opt_offset = opt_offset + padd_length;
+		break;
+	case ND_OPT_CERTIFICATE:
+		opt_offset = offset +2;
+		/* Cert Type */
+		cert_type = tvb_get_guint8(tvb,opt_offset);
+		proto_tree_add_item(icmp6opt_tree, hf_icmpv6_opt_cert_type, tvb, opt_offset, 1, FALSE);
+		opt_offset++;
+		/* Reserved */
+		proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,1,"Reserved");
+		opt_offset++;
+		/* Certificate */
+
+		if(cert_type == 1){
+			asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
+			opt_offset = dissect_x509af_Certificate(FALSE, tvb, opt_offset, &asn1_ctx, icmp6opt_tree, hf_icmpv6_x509af_Certificate);
+			par_len = len - (opt_offset - offset);
+			/* Padding */
+			proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,par_len,"Padding");
+		}else{
+			par_len = len - 4;
+			proto_tree_add_text(icmp6opt_tree, tvb,opt_offset,par_len,"Unknown Certificate + padding");
+		}
+
+		break;
     case ND_OPT_MAP:
       {
 	struct nd_opt_map_info mapbuf, *map;
@@ -484,35 +661,64 @@ again:
       }
 
     case FMIP6_OPT_NEIGHBOR_ADV_ACK:
-      {
-	struct fmip6_opt_neighbor_advertisement_ack fmip6_opt_neighbor_advertisement_ack, *opt_naack;
-	struct e_in6_addr in6;
+		{
+			struct fmip6_opt_neighbor_advertisement_ack fmip6_opt_neighbor_advertisement_ack, *opt_naack;
+			struct e_in6_addr in6;
 
-	opt_naack = &fmip6_opt_neighbor_advertisement_ack;
-	tvb_memcpy(tvb, (guint8 *)opt_naack, offset, sizeof *opt_naack);
+			opt_naack = &fmip6_opt_neighbor_advertisement_ack;
+			tvb_memcpy(tvb, (guint8 *)opt_naack, offset, sizeof *opt_naack);
 
-	proto_tree_add_text(icmp6opt_tree, tvb,
-			offset + offsetof(struct fmip6_opt_neighbor_advertisement_ack, fmip6_opt_optcode),
-			1, "Option-Code: %u",
-			opt_naack->fmip6_opt_optcode);
+			proto_tree_add_text(icmp6opt_tree, tvb,
+				offset + offsetof(struct fmip6_opt_neighbor_advertisement_ack, fmip6_opt_optcode),
+				1, "Option-Code: %u",
+				opt_naack->fmip6_opt_optcode);
 
-	proto_tree_add_text(icmp6opt_tree, tvb,
-			offset + offsetof(struct fmip6_opt_neighbor_advertisement_ack, fmip6_opt_status),
-			1, "Status: %s",
-			val_to_str(opt_naack->fmip6_opt_status, names_fmip6_naack_opt_status, "Unknown"));
+			proto_tree_add_text(icmp6opt_tree, tvb,
+				offset + offsetof(struct fmip6_opt_neighbor_advertisement_ack, fmip6_opt_status),
+				1, "Status: %s",
+				val_to_str(opt_naack->fmip6_opt_status, names_fmip6_naack_opt_status, "Unknown"));
 
-	if (opt_naack->fmip6_opt_len == 3) 
-	{
-		tvb_memcpy(tvb, (guint8 *)&in6, offset + sizeof(*opt_naack), 16);
-		proto_tree_add_text(icmp6opt_tree, tvb,
-			offset + sizeof(*opt_naack), 
-			16, "New Care-of Address: %s",
-			ip6_to_str(&in6));
-	}
+			if (opt_naack->fmip6_opt_len == 3){
+				tvb_memcpy(tvb, (guint8 *)&in6, offset + sizeof(*opt_naack), 16);
+				proto_tree_add_text(icmp6opt_tree, tvb,
+				offset + sizeof(*opt_naack),
+				16, "New Care-of Address: %s",
+				ip6_to_str(&in6));
+			}
 
-	break;
-      }
-    }
+		break;
+		}
+		case ND_OPT_RECURSIVE_DNS_SERVER:
+
+			opt_offset = offset + 2;
+			proto_tree_add_text(icmp6opt_tree, tvb, opt_offset ,2 ,"Reserved");
+			opt_offset = opt_offset + 2;
+			/* A value of all one bits (0xffffffff) represents infinity.  A value of
+			 * zero means that the RDNSS address MUST no longer be used.
+			 */
+			lifetime = tvb_get_ntohl(tvb, opt_offset);
+			if (lifetime == 0xffffffff){
+				proto_tree_add_text(icmp6opt_tree, tvb, opt_offset ,4 ,"Lifetime: infinity");
+			}else{ 
+				if(lifetime==0){
+					proto_tree_add_text(icmp6opt_tree, tvb, opt_offset ,4 ,"Lifetime: RDNSS address MUST no longer be used");
+				}else{
+					proto_tree_add_text(icmp6opt_tree, tvb, opt_offset ,4 ,"Lifetime: %u", lifetime);
+				}
+			}
+			opt_offset = opt_offset+4;
+			/* Addresses of IPv6 Recursive DNS Servers */
+			no_of_pars = opt->nd_opt_len - 1;
+			no_of_pars = no_of_pars >> 2;
+
+			for (i = 0; i <= no_of_pars; i++) {			
+				proto_tree_add_item(icmp6opt_tree, hf_icmpv6_recursive_dns_serv, tvb, opt_offset, 16, FALSE);
+				opt_offset = opt_offset+16;
+			}
+
+
+			break;
+		}
 
     offset += (opt->nd_opt_len << 3);
 
@@ -593,7 +799,7 @@ again:
 						1, "Prefix length: %u", opt_ip->fmip6_opt_prefix_len);
 
 				proto_tree_add_text(icmp6opt_tree, tvb,
-						offset + offsetof(struct fmip6_opt_ip_address, fmip6_opt_ip6_address), 
+						offset + offsetof(struct fmip6_opt_ip_address, fmip6_opt_ip6_address),
 						16, "IPv6 Address: %s",
 						ip6_to_str(&opt_ip->fmip6_opt_ip6_address));
 				break;
@@ -614,12 +820,11 @@ again:
 						1, "Prefix length: %u", opt_nr->fmip6_opt_prefix_len);
 
 				proto_tree_add_text(icmp6opt_tree, tvb,
-						offset + offsetof(struct fmip6_opt_new_router_prefix_info, fmip6_opt_prefix), 
+						offset + offsetof(struct fmip6_opt_new_router_prefix_info, fmip6_opt_prefix),
 						16, "Prefix: %s",
 						ip6_to_str(&opt_nr->fmip6_opt_prefix));
 				break;
 			}
-			break;
 		case FMIP6_OPT_LINK_LAYER_ADDRESS:
 			{
 				int len, p;
@@ -713,7 +918,7 @@ bitrange(tvbuff_t *tvb, int offset, int l, int s)
     for (i = 0; i < l; i++) {
 	if (bitrange0(tvb_get_ntohl(tvb, offset + i * 4), s + i * 4, q, eq - q) == NULL) {
 	    if (q != buf && q + 5 < buf + sizeof(buf))
-		strncpy(q, ",...", 5);
+		g_strlcpy(q, ",...", 5);
 	    return buf;
 	}
     }
@@ -731,7 +936,7 @@ dissect_nodeinfo(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree
     unsigned int j;
     int i, n, l, p;
     guint16 flags;
-    char *dname;
+    const char *dname;
     guint32 ipaddr;
 
     ni = &icmp6_nodeinfo;
@@ -1176,18 +1381,18 @@ dissect_mldrv2( tvbuff_t *tvb, guint32 offset, guint16 count, proto_tree *tree )
     recordSize = 4 + 16 + (16 * sourceNb) + (auxDataLen * 4);
 
     tvb_get_ipv6(tvb, localOffset, &addr);
-    tf = proto_tree_add_text( tree, tvb, offset, recordSize, 
+    tf = proto_tree_add_text( tree, tvb, offset, recordSize,
 #ifdef INET6
 			      "%s: %s (%s)", val_to_str(recordType, mldrv2ModesNames,"Unknown mode"),
-			      get_hostname6(&addr), ip6_to_str(&addr) 
+			      get_hostname6(&addr), ip6_to_str(&addr)
 #else
 			      "%s: %s", val_to_str(recordType, mldrv2ModesNames,"Unknown mode"),
-			      ip6_to_str(&addr) 
+			      ip6_to_str(&addr)
 #endif
 			      );
     sub_tree = proto_item_add_subtree(tf, ett_multicastRR);
 
-    proto_tree_add_text( sub_tree, tvb, offset,   1, "Mode: %s", 
+    proto_tree_add_text( sub_tree, tvb, offset,   1, "Mode: %s",
 			 val_to_str(recordType, mldrv2ModesNames,"Unknown mode") );
     proto_tree_add_text( sub_tree, tvb, offset+1, 1, "Aux data len: %u", auxDataLen * 4);
     proto_tree_add_text( sub_tree, tvb, localOffset, 16, "Multicast Address: %s", ip6_to_str(&addr) );
@@ -1195,7 +1400,7 @@ dissect_mldrv2( tvbuff_t *tvb, guint32 offset, guint16 count, proto_tree *tree )
 
     for( ; sourceNb; sourceNb--, localOffset += 16 ) {
       tvb_get_ipv6(tvb, localOffset, &addr);
-      proto_tree_add_text( sub_tree, tvb, localOffset, 16, 
+      proto_tree_add_text( sub_tree, tvb, localOffset, 16,
 #ifdef INET6
 			   "Source Address: %s (%s)", get_hostname6(&addr), ip6_to_str(&addr) );
 #else
@@ -1212,7 +1417,7 @@ dissect_mldqv2(tvbuff_t *tvb, guint32 offset, guint16 count, proto_tree *tree)
 
   for ( ; count; count--, offset += 16) {
       tvb_get_ipv6(tvb, offset, &addr);
-      proto_tree_add_text(tree, tvb, offset, 16, 
+      proto_tree_add_text(tree, tvb, offset, 16,
 			  "Source Address: %s (%s)", get_hostname6(&addr), ip6_to_str(&addr));
   }
 }
@@ -1411,6 +1616,16 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	codename = "Should always be zero";
 	colcodename = NULL;
 	break;
+	case ICMP6_CERT_PATH_SOL:
+		typename = coltypename = "Certification Path Solicitation";
+	codename = "Should always be zero";
+	colcodename = NULL;
+	break;
+	case ICMP6_CERT_PATH_AD:
+		typename = coltypename = "Certification Path Advertisement";
+	codename = "Should always be zero";
+	colcodename = NULL;
+	break;
     case ICMP6_MLDV2_REPORT:
 	typename = coltypename = "Multicast Listener Report Message v2";
 	codename = "Should always be zero";
@@ -1459,7 +1674,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (colcodename) {
 	    col_add_fstr(pinfo->cinfo, COL_INFO, "%s (%s)", coltypename, colcodename);
 	} else {
-	    col_add_fstr(pinfo->cinfo, COL_INFO, "%s", coltypename);
+	    col_add_str(pinfo->cinfo, COL_INFO, coltypename);
 	}
     }
 
@@ -1569,14 +1784,14 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		    guint16 qqi;
 		    guint8 flag;
 		    guint16 nsrcs;
-		    
+
 		    mrc = g_ntohs(dp->icmp6_maxdelay);
 		    flag = tvb_get_guint8(tvb, offset + sizeof(*dp) + 16);
 		    qqi = tvb_get_guint8(tvb, offset + sizeof(*dp) + 16 + 1);
 		    nsrcs = tvb_get_ntohs(tvb, offset + sizeof(*dp) + 16 + 2);
 
 		    if (mrc >= 32768)
-		    	mrc = ((mrc & 0x0fff) | 0x1000) << 
+		    	mrc = ((mrc & 0x0fff) | 0x1000) <<
 				(((mrc & 0x7000) >> 12) + 3);
 		    proto_tree_add_text(icmp6_tree, tvb,
 		        offset + offsetof(struct icmp6_hdr, icmp6_maxdelay), 2,
@@ -1623,7 +1838,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    break;
 	case ICMP6_MLDV2_REPORT: {
 	  guint16 nbRecords;
-	  
+
 	  nbRecords = tvb_get_ntohs( tvb, offset+4+2 );
 	  dissect_mldrv2( tvb, offset+4+2+2, nbRecords, icmp6_tree );
 	  break;
@@ -1839,7 +2054,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    /* Show all options */
 	    dissect_icmpv6ndopt(tvb, offset + 8, pinfo, icmp6_tree);
 	    break;
-			case ICMP6_EXPERIMENTAL_MOBILITY:
+	case ICMP6_EXPERIMENTAL_MOBILITY:
 		switch (dp->icmp6_data8[0]) {
 			case FMIP6_SUBTYPE_RTSOLPR:
 				{
@@ -1908,6 +2123,30 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				}
 		}
 	    break;
+	case ICMP6_CERT_PATH_AD:
+		/*RFC 3971 6.4.2.  Certification Path Advertisement Message Format */
+		offset = offset +4;
+		proto_tree_add_text(icmp6_tree, tvb, offset, -1,"Certification Path Advertisement Message");
+
+		/* Identifier A 16-bit unsigned integer field */
+		proto_tree_add_item(icmp6_tree, hf_icmpv6_identifier, tvb, offset, 2, FALSE);
+		offset = offset + 2;
+		/* All Components  A 16-bit unsigned integer field*/
+		proto_tree_add_item(icmp6_tree, hf_icmpv6_all_comp, tvb, offset, 2, FALSE);
+		offset = offset + 2;
+
+		/* Component A 16-bit unsigned integer field, used to inform the receiver
+		 * which certificate is being sent.
+		 */
+		proto_tree_add_item(icmp6_tree, hf_icmpv6_comp, tvb, offset, 2, FALSE);
+		offset = offset + 2;
+
+		/* Reserved */
+		proto_tree_add_text(icmp6_tree, tvb, offset, 2,"Reserved");
+		offset = offset + 2;
+
+		dissect_icmpv6ndopt(tvb, offset, pinfo, icmp6_tree);
+		break;
 	default:
 	    next_tvb = tvb_new_subset(tvb, offset + sizeof(*dp), -1, -1);
 	    call_dissector(data_handle,next_tvb, pinfo, tree);
@@ -1957,7 +2196,49 @@ proto_register_icmpv6(void)
     { &hf_icmpv6_option_length,
       { "Length",           "icmpv6.option.length", FT_UINT8,  BASE_DEC, NULL, 0x0,
       	"Options length (in bytes)", HFILL }},
+	{ &hf_icmpv6_opt_cga_pad_len,
+      { "Pad Length",           "icmpv6.option.cga.pad_length", FT_UINT8,  BASE_DEC, NULL, 0x0,
+      	"Pad Length (in bytes)", HFILL }},
+	{ &hf_icmpv6_opt_cga,
+      { "CGA",           "icmpv6.option.cga", FT_BYTES,  BASE_NONE, NULL, 0x0,
+      	"CGA", HFILL }},
+	{ &hf_icmpv6_opt_rsa_key_hash,
+      { "Key Hash",           "icmpv6.option.rsa.key_hash", FT_BYTES,  BASE_HEX, NULL, 0x0,
+      	"Key Hash", HFILL }},
+	{ &hf_icmpv6_opt_name_type,
+      { "Name Type",           "icmpv6.option.name_type", FT_UINT8,  BASE_DEC, VALS(icmpv6_option_name_type_vals), 0x0,
+      	"Name Type", HFILL }},
+	{ &hf_icmpv6_opt_name_x501,
+      { "DER Encoded X.501 Name",           "icmpv6.option.name_x501", FT_BYTES,  BASE_HEX, NULL, 0x0,
+      	"DER Encoded X.501 Name", HFILL }},
+	{ &hf_icmpv6_opt_name_fqdn,
+      { "FQDN",           "icmpv6.option.name_type.fqdn", FT_STRING,  BASE_NONE, NULL, 0x0,
+      	"FQDN", HFILL }},
+	{ &hf_icmpv6_opt_cert_type,
+      { "Cert Type",           "icmpv6.option.name_type", FT_UINT8,  BASE_DEC, VALS(icmpv6_option_cert_type_vals), 0x0,
+      	"Cert Type", HFILL }},
+	{ &hf_icmpv6_identifier,
+      { "Identifier",           "icmpv6.identifier", FT_UINT16,  BASE_DEC, NULL, 0x0,
+      	"Identifier", HFILL }},
+	{ &hf_icmpv6_all_comp,
+      { "All Components",           "icmpv6.all_comp", FT_UINT16,  BASE_DEC, NULL, 0x0,
+      	"All Components", HFILL }},
+	{ &hf_icmpv6_comp,
+      { "Component",           "icmpv6.comp", FT_UINT16,  BASE_DEC, NULL, 0x0,
+      	"Component", HFILL }},
+    { &hf_icmpv6_x509if_Name,
+      { "Name", "icmpv6.x509_Name", FT_UINT32, BASE_DEC, VALS(x509if_Name_vals), 0,
+        "Name", HFILL }},
+    { &hf_icmpv6_x509af_Certificate,
+      { "Certificate", "icmpv6_x509_Certificate", FT_NONE, BASE_NONE, NULL, 0,
+        "Certificate", HFILL }},
+    { &hf_icmpv6_recursive_dns_serv,
+      { "Recursive DNS Servers", "icmpv6.recursive_dns_serv",
+       FT_IPv6, BASE_HEX, NULL, 0x0,
+       "Recursive DNS Servers", HFILL }},
+
   };
+
   static gint *ett[] = {
     &ett_icmpv6,
     &ett_icmpv6opt,
@@ -1970,12 +2251,15 @@ proto_register_icmpv6(void)
     &ett_nodeinfo_nodebitmap,
     &ett_nodeinfo_nodedns,
     &ett_multicastRR,
+	&ett_icmpv6opt_name,
   };
 
   proto_icmpv6 = proto_register_protocol("Internet Control Message Protocol v6",
 					 "ICMPv6", "icmpv6");
   proto_register_field_array(proto_icmpv6, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+
+  register_dissector("icmpv6", dissect_icmpv6, proto_icmpv6);
 }
 
 void
