@@ -1,6 +1,6 @@
 /* packet-ieee802154.c
  *
- * $Id: packet-ieee802154.c 24729 2008-03-25 22:23:10Z gerald $
+ * $Id: packet-ieee802154.c 25463 2008-06-16 23:29:12Z gerald $
  *
  * IEEE 802.15.4 Dissectors for Wireshark
  * By Owen Kirby <osk@exegin.com>
@@ -1559,7 +1559,7 @@ void proto_register_ieee802154(void)
             /*  Association response fields */
         { &hf_ieee802154_cmd_asrsp_addr,
         { "Short Address",              "wpan.cmd.asrsp.addr", FT_UINT16, BASE_HEX, NULL, 0x0,
-            "The short address that the device should assume.\nAn address of 0xfffe indicates that the device should use its IEEE 64-bit long address.", HFILL }},
+            "The short address that the device should assume. An address of 0xfffe indicates that the device should use its IEEE 64-bit long address.", HFILL }},
 
         { &hf_ieee802154_cmd_asrsp_status,
         { "Association Status",         "wpan.cmd.asrsp.status", FT_UINT8, BASE_HEX, NULL, 0x0,
