@@ -1,7 +1,10 @@
-/* packet-igmp.c   2001 Ronnie Sahlberg <See AUTHORS for email>
+/* packet-igmp.c   
  * Routines for IGMP packet disassembly
+ * 2001 Ronnie Sahlberg
+ * 2007 Thomas Morin
+ * <See AUTHORS for emails>
  *
- * $Id: packet-igmp.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-igmp.c 24190 2008-01-25 06:32:53Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -19,7 +22,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 /*
 	IGMP is defined in the following RFCs
@@ -30,7 +33,7 @@
 	RFC3376	Version 3
 
 	Size in bytes for each packet
-	type	RFC988	RFC1054	RFC2236 RFC3376  DVMRP  MRDISC  MSNIP  IGAP
+	type	RFC988	RFC1054	RFC2236 RFC3376  DVMRP  MRDISC  MSNIP  IGAP  RGMP
 	        v0      v1      v2      v3       v1/v3
 	0x01      20
 	0x02      20
@@ -53,6 +56,10 @@
 	0x40                                                           ??c
 	0x41                                                           ??c
 	0x42                                                           ??c
+	0xfc                                                                  8
+	0xfd                                                                  8
+	0xfe                                                                  8
+	0xff                                                                  8
 
    * Differs in second byte of protocol. Always 0 in V1
 
@@ -93,6 +100,12 @@
         IGAP : Internet Group membership Authentication Protocol
 	draft-hayashi-igap-03.txt
 
+   d RGMP Protocol  see packet-rgmp.c
+
+	RGMP : Router-port Group Management Protocol
+	RFC3488
+	TTL == 1 and IP.DST==224.0.0.25 for all packets
+
 */
 
 #ifdef HAVE_CONFIG_H
@@ -112,6 +125,7 @@
 #include "packet-mrdisc.h"
 #include "packet-msnip.h"
 #include "packet-igap.h"
+#include "packet-rgmp.h"
 
 static int proto_igmp = -1;
 static int hf_type = -1;
@@ -164,6 +178,7 @@ static int ett_mtrace_block = -1;
 
 #define MC_ALL_ROUTERS		0xe0000002
 #define MC_ALL_IGMPV3_ROUTERS	0xe0000016
+#define MC_RGMP			0xe0000019
 
 
 #define IGMP_V0_CREATE_GROUP_REQUEST	0x01
@@ -437,7 +452,7 @@ dissect_v3_sqrv_bits(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 }
 
 static int
-dissect_v3_group_record(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
+dissect_v3_group_record(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, int offset)
 {
 	proto_tree *tree;
 	proto_item *item;
@@ -445,6 +460,8 @@ dissect_v3_group_record(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 	guint8	adl;
 	guint16 num;
 	guint32 ip;
+	guint32 maddr;
+        guint8 record_type;
 
 	ip = tvb_get_ipv4(tvb, offset+4);
 	item = proto_tree_add_text(parent_tree, tvb, offset, -1,
@@ -455,6 +472,7 @@ dissect_v3_group_record(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 	tree = proto_item_add_subtree(item, ett_group_record);
 
 	/* record type */
+	record_type = tvb_get_guint8(tvb, offset);
 	proto_tree_add_item(tree, hf_record_type, tvb, offset, 1, FALSE);
 	offset += 1;
 
@@ -470,10 +488,73 @@ dissect_v3_group_record(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 
 	/* multicast address */
 	proto_tree_add_item(tree, hf_maddr, tvb, offset, 4, FALSE);
+	maddr = tvb_get_ipv4(tvb, offset);
 	offset += 4;
 
+        if (check_col(pinfo->cinfo, COL_INFO)) {
+           if (num == 0) {
+              switch(record_type) {
+               case IGMP_V3_MODE_IS_INCLUDE:
+               case IGMP_V3_CHANGE_TO_INCLUDE_MODE:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Leave group %s",
+                                   ip_to_str((guint8*)&maddr) ); 
+                   break;
+	       case IGMP_V3_MODE_IS_EXCLUDE:
+               case IGMP_V3_CHANGE_TO_EXCLUDE_MODE:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Join group %s for any sources",
+                                   ip_to_str((guint8*)&maddr) ); 
+                   break;
+               case IGMP_V3_ALLOW_NEW_SOURCES:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Group %s, ALLOW_NEW_SOURCES but no source specified (?)",
+                                                           ip_to_str((guint8*)&maddr) );
+                   break;
+               case IGMP_V3_BLOCK_OLD_SOURCES:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Group %s, BLOCK_OLD_SOURCES but no source specified (?)",
+                                                           ip_to_str((guint8*)&maddr) );
+                   break;
+               default:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Group %s, unknown record type (?)",
+                                                           ip_to_str((guint8*)&maddr) );
+              }
+           } else {
+              switch(record_type) {
+               case IGMP_V3_MODE_IS_INCLUDE:
+               case IGMP_V3_CHANGE_TO_INCLUDE_MODE:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Join group %s for source%s {",
+                                   ip_to_str((guint8*)&maddr),
+                                   (num>1) ? "s in" : "" ); 
+                   break;
+	       case IGMP_V3_MODE_IS_EXCLUDE:
+               case IGMP_V3_CHANGE_TO_EXCLUDE_MODE:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Join group %s, for source%s {",
+                                   ip_to_str((guint8*)&maddr),
+                                   (num>1) ? "s not in" : " not" ); 
+                   break;
+               case IGMP_V3_ALLOW_NEW_SOURCES:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Group %s, new source%s {",
+                                   ip_to_str((guint8*)&maddr), 
+                                   (num>1) ? "s" : "" ); 
+                   break;
+               case IGMP_V3_BLOCK_OLD_SOURCES:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Group %s, block source%s {",
+                                   ip_to_str((guint8*)&maddr),
+                                   (num>1) ? "s" : "" ); 
+                   break;
+               default:
+                   col_append_fstr(pinfo->cinfo, COL_INFO, " / Group %s, unknown record type (?), sources {",
+                                                           ip_to_str((guint8*)&maddr) );
+              }
+           }
+        }
+
 	/* source addresses */
 	while(num--){
+                if (check_col(pinfo->cinfo, COL_INFO)) {
+                   col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s",
+                                         ip_to_str(tvb_get_ptr(tvb, offset, 4)),
+                                         (num?", ":"}")
+                                  );
+                }
 		proto_tree_add_item(tree, hf_saddr, tvb, offset, 4, FALSE);
 		offset += 4;
 	}
@@ -489,9 +570,9 @@ dissect_v3_group_record(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 	return offset;
 }
 
-/* dissectors for version 3, rfc???? */
+/* dissectors for version 3, rfc3376 */
 static int
-dissect_igmp_v3_response(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, int offset)
+dissect_igmp_v3_report(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, int offset)
 {
 	guint16 num;
 
@@ -509,11 +590,16 @@ dissect_igmp_v3_response(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, in
 
 	/* number of group records */
 	num = tvb_get_ntohs(tvb, offset);
+	if (check_col(pinfo->cinfo, COL_INFO)) {			
+          if (!num) {
+              col_append_fstr(pinfo->cinfo, COL_INFO, " - General query" ); 
+          }
+        }
 	proto_tree_add_uint(tree, hf_num_grp_recs, tvb, offset, 2, num);
 	offset += 2;
 
 	while (num--) {
-		offset = dissect_v3_group_record(tvb, tree, offset);
+		offset = dissect_v3_group_record(tvb, pinfo, tree, offset);
 	}
 
 	return offset;
@@ -523,6 +609,7 @@ static int
 dissect_igmp_v3_query(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, int offset)
 {
 	guint16 num;
+	guint32 maddr;
 
 	PRINT_IGMP_VERSION(3);
 
@@ -536,6 +623,17 @@ dissect_igmp_v3_query(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int t
 
 	/* group address */
 	proto_tree_add_item(tree, hf_maddr, tvb, offset, 4, FALSE);
+
+	maddr = tvb_get_ipv4(tvb, offset);
+	if (check_col(pinfo->cinfo, COL_INFO)) {			
+           if (! maddr) {
+               col_append_fstr(pinfo->cinfo, COL_INFO, ", general" ); 
+           } else {
+               col_append_fstr(pinfo->cinfo, COL_INFO, ", specific for group %s"
+                   , ip_to_str((guint8*)&maddr) );
+           }
+        }
+
 	offset +=4;
 
 	/* bitmask for S and QRV */
@@ -547,9 +645,15 @@ dissect_igmp_v3_query(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int t
 
 	/*number of sources*/
 	proto_tree_add_uint(tree, hf_num_src, tvb, offset, 2, num);
+        if (num) {
+	    if (check_col(pinfo->cinfo, COL_INFO))
+                col_append_fstr(pinfo->cinfo, COL_INFO, ", source%s {", (num>1)?"s":"");
+        }
 	offset += 2;
 
 	while(num--){
+	        if (check_col(pinfo->cinfo, COL_INFO))
+                    col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", ip_to_str(tvb_get_ptr(tvb, offset, 4)), (num?", ":"}"));
 		proto_tree_add_item(tree, hf_saddr, tvb, offset, 4, FALSE);
 		offset += 4;
 	}
@@ -557,11 +661,12 @@ dissect_igmp_v3_query(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int t
 	return offset;
 }
 
-/* dissector for version 2, rfc2236 */
+/* dissector for version 2 query and report, rfc2236 */
 static int
 dissect_igmp_v2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, int offset)
 {
 	guint8 tsecs;
+	guint32 maddr;
 
 	PRINT_IGMP_VERSION(2);
 
@@ -577,12 +682,25 @@ dissect_igmp_v2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, i
 
 	/* group address */
 	proto_tree_add_item(tree, hf_maddr, tvb, offset, 4, FALSE);
+
+	maddr = tvb_get_ipv4(tvb, offset);
+	if (check_col(pinfo->cinfo, COL_INFO)) {			
+		if (! maddr) {
+		    col_append_fstr(pinfo->cinfo, COL_INFO, ", general" );
+		} else {
+                    if (type == IGMP_V2_LEAVE_GROUP) {
+                       col_append_fstr(pinfo->cinfo, COL_INFO, " %s", ip_to_str((guint8*)&maddr) );
+                    } else {
+                       col_append_fstr(pinfo->cinfo, COL_INFO, " / Join group %s", ip_to_str((guint8*)&maddr) );
+                    }
+		}
+        }
 	offset +=4;
 
 	return offset;
 }
 
-/* dissector for version 1, rfc1054 */
+/* dissector for version 1 query and report, rfc1054 */
 static int
 dissect_igmp_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int type, int offset)
 {
@@ -845,7 +963,7 @@ dissect_igmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		break;
 
 	case IGMP_V3_MEMBERSHIP_REPORT:
-		offset = dissect_igmp_v3_response(tvb, pinfo, tree, type, offset);
+		offset = dissect_igmp_v3_report(tvb, pinfo, tree, type, offset);
 		break;
 
 	case IGMP_TYPE_0x23:
@@ -892,6 +1010,16 @@ dissect_igmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 		offset = dissect_igap(tvb, pinfo, parent_tree, offset);
 		break;
 
+	case IGMP_RGMP_HELLO:
+	case IGMP_RGMP_BYE:
+	case IGMP_RGMP_JOIN:
+	case IGMP_RGMP_LEAVE:
+		dst = g_htonl(MC_RGMP);
+		if (!memcmp(pinfo->dst.data, &dst, 4)) {
+			offset = dissect_rgmp(tvb, pinfo, parent_tree, offset);
+		}
+		break;
+
 	default:
 		offset = dissect_igmp_unknown(tvb, pinfo, tree, type, offset);
 		break;
