@@ -3,7 +3,7 @@
  *
  * (c) 2005 Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
  *
- * $Id$
+ * $Id: packet-iuup.c 23406 2007-11-08 22:49:03Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,6 +43,8 @@
 #include <epan/prefs.h>
 #include <epan/emem.h>
 #include <epan/expert.h>
+#include <epan/crc10.h>
+#include <epan/crc6.h>
 
 
 typedef struct _iuup_rfci_t {
@@ -320,99 +322,10 @@ static const value_string iuup_fqcs[] = {
     {3, "spare"},
     {0,NULL}
 };
-/*
- * Charles Michael Heard's CRC-10 code, from
- *
- *      http://cell-relay.indiana.edu/cell-relay/publications/software/CRC/crc10.html
- *
- * with the CRC table initialized with values computed by
- * his "gen_byte_crc10_table()" routine, rather than by calling that
- * routine at run time, and with various data type cleanups.
- */
-static const guint16 byte_crc10_table[256] = {
-        0x0000, 0x0233, 0x0255, 0x0066, 0x0299, 0x00aa, 0x00cc, 0x02ff,
-        0x0301, 0x0132, 0x0154, 0x0367, 0x0198, 0x03ab, 0x03cd, 0x01fe,
-        0x0031, 0x0202, 0x0264, 0x0057, 0x02a8, 0x009b, 0x00fd, 0x02ce,
-        0x0330, 0x0103, 0x0165, 0x0356, 0x01a9, 0x039a, 0x03fc, 0x01cf,
-        0x0062, 0x0251, 0x0237, 0x0004, 0x02fb, 0x00c8, 0x00ae, 0x029d,
-        0x0363, 0x0150, 0x0136, 0x0305, 0x01fa, 0x03c9, 0x03af, 0x019c,
-        0x0053, 0x0260, 0x0206, 0x0035, 0x02ca, 0x00f9, 0x009f, 0x02ac,
-        0x0352, 0x0161, 0x0107, 0x0334, 0x01cb, 0x03f8, 0x039e, 0x01ad,
-        0x00c4, 0x02f7, 0x0291, 0x00a2, 0x025d, 0x006e, 0x0008, 0x023b,
-        0x03c5, 0x01f6, 0x0190, 0x03a3, 0x015c, 0x036f, 0x0309, 0x013a,
-        0x00f5, 0x02c6, 0x02a0, 0x0093, 0x026c, 0x005f, 0x0039, 0x020a,
-        0x03f4, 0x01c7, 0x01a1, 0x0392, 0x016d, 0x035e, 0x0338, 0x010b,
-        0x00a6, 0x0295, 0x02f3, 0x00c0, 0x023f, 0x000c, 0x006a, 0x0259,
-        0x03a7, 0x0194, 0x01f2, 0x03c1, 0x013e, 0x030d, 0x036b, 0x0158,
-        0x0097, 0x02a4, 0x02c2, 0x00f1, 0x020e, 0x003d, 0x005b, 0x0268,
-        0x0396, 0x01a5, 0x01c3, 0x03f0, 0x010f, 0x033c, 0x035a, 0x0169,
-        0x0188, 0x03bb, 0x03dd, 0x01ee, 0x0311, 0x0122, 0x0144, 0x0377,
-        0x0289, 0x00ba, 0x00dc, 0x02ef, 0x0010, 0x0223, 0x0245, 0x0076,
-        0x01b9, 0x038a, 0x03ec, 0x01df, 0x0320, 0x0113, 0x0175, 0x0346,
-        0x02b8, 0x008b, 0x00ed, 0x02de, 0x0021, 0x0212, 0x0274, 0x0047,
-        0x01ea, 0x03d9, 0x03bf, 0x018c, 0x0373, 0x0140, 0x0126, 0x0315,
-        0x02eb, 0x00d8, 0x00be, 0x028d, 0x0072, 0x0241, 0x0227, 0x0014,
-        0x01db, 0x03e8, 0x038e, 0x01bd, 0x0342, 0x0171, 0x0117, 0x0324,
-        0x02da, 0x00e9, 0x008f, 0x02bc, 0x0043, 0x0270, 0x0216, 0x0025,
-        0x014c, 0x037f, 0x0319, 0x012a, 0x03d5, 0x01e6, 0x0180, 0x03b3,
-        0x024d, 0x007e, 0x0018, 0x022b, 0x00d4, 0x02e7, 0x0281, 0x00b2,
-        0x017d, 0x034e, 0x0328, 0x011b, 0x03e4, 0x01d7, 0x01b1, 0x0382,
-        0x027c, 0x004f, 0x0029, 0x021a, 0x00e5, 0x02d6, 0x02b0, 0x0083,
-        0x012e, 0x031d, 0x037b, 0x0148, 0x03b7, 0x0184, 0x01e2, 0x03d1,
-        0x022f, 0x001c, 0x007a, 0x0249, 0x00b6, 0x0285, 0x02e3, 0x00d0,
-        0x011f, 0x032c, 0x034a, 0x0179, 0x0386, 0x01b5, 0x01d3, 0x03e0,
-        0x021e, 0x002d, 0x004b, 0x0278, 0x0087, 0x02b4, 0x02d2, 0x00e1
-};
-
-/* update the data block's CRC-10 remainder one byte at a time */
-static guint16
-update_crc10_by_bytes(guint16 crc10, const guint8 *data_blk_ptr,
-    		      int data_blk_size)
-{
-    register int i;
-    guint16 crc10_accum = 0;
-
-    for (i = 0;  i < data_blk_size; i++) {
-   	crc10_accum = ((crc10_accum << 8) & 0x3ff)
-         	^ byte_crc10_table[( crc10_accum >> 2) & 0xff]
-                ^ *data_blk_ptr++;
-    }
-    crc10_accum = ((crc10_accum << 8) & 0x3ff)
-	            ^ byte_crc10_table[( crc10_accum >> 2) & 0xff]
-                    ^ (crc10>>2);
-    crc10_accum = ((crc10_accum << 8) & 0x3ff)
-                    ^ byte_crc10_table[( crc10_accum >> 2) & 0xff]
-	            ^ ((crc10<<6) & 0xFF);
-    
-    return crc10_accum;
-}
-
-
-static guint16
-update_crc6_by_bytes(guint16 crc6, unsigned char byte1, unsigned char byte2)
-{
-    char bit;
-    unsigned int remainder = 0;
-    unsigned int polynomial = 0x6F << 15;
-
-    unsigned int data = ( byte1<<8 | byte2 ) << 6;
-    remainder = data;
-
-    for (bit = 15; bit >= 0; --bit)
-    {
-        if (remainder & (0x40 << bit))
-        {
-            remainder ^= polynomial;
-        }
-        polynomial >>= 1;
-    }
-
-    return (remainder ^ crc6);
-}
 
 
 static proto_item*
-proto_tree_add_bits(proto_tree* tree, int hf, tvbuff_t* tvb, int offset, int bit_offset, guint bits, gchar** buf) {
+iuup_proto_tree_add_bits(proto_tree* tree, int hf, tvbuff_t* tvb, int offset, int bit_offset, guint bits, guint8** buf) {
     static const guint8 masks[] = {0x00,0x80,0xc0,0xe0,0xf0,0xf8,0xfc,0xfe};
     int len = (bits + bit_offset)/8 + ((bits + bit_offset)%8 ? 0 : 1);
     guint8* shifted_buffer;
@@ -432,7 +345,7 @@ proto_tree_add_bits(proto_tree* tree, int hf, tvbuff_t* tvb, int offset, int bit
     shifted_buffer[len] &= masks[(bits + bit_offset)%8];
     
     if (buf)
-        *buf = (gchar*)shifted_buffer;
+        *buf = shifted_buffer;
     
     pi = proto_tree_add_bytes(tree, hf, tvb, offset, len + ((bits + bit_offset) % 8 ? 1 : 0) , shifted_buffer);
     proto_item_append_text(pi, " (%i Bits)", bits);
@@ -484,7 +397,7 @@ static void dissect_iuup_payload(tvbuff_t* tvb, packet_info* pinfo _U_, proto_tr
             if (! rfci->subflow[i].len)
                 continue;
             
-            proto_tree_add_bits(flow_tree, hf_iuup_rfci_subflow[rfci->id][i], tvb,
+            iuup_proto_tree_add_bits(flow_tree, hf_iuup_rfci_subflow[rfci->id][i], tvb,
                                 offset + (bit_offset/8),
                                 bit_offset % 8,
                                 rfci->subflow[i].len,
@@ -571,7 +484,7 @@ static void dissect_iuup_init(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tre
     iuup_circuit_t* iuup_circuit = NULL;
     
     if (pinfo->circuit_id) {
-        g_hash_table_lookup(circuits,GUINT_TO_POINTER(pinfo->circuit_id));
+        iuup_circuit = g_hash_table_lookup(circuits,GUINT_TO_POINTER(pinfo->circuit_id));
     
         if (iuup_circuit) {
             g_hash_table_remove(circuits,GUINT_TO_POINTER(pinfo->circuit_id));
@@ -734,7 +647,7 @@ static void dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree)
     }
 
     if (check_col(pinfo->cinfo, COL_INFO)) {
-        col_set_str(pinfo->cinfo, COL_INFO, val_to_str(pdutype, iuup_colinfo_pdu_types, "Unknown PDU Type(%u) "));
+        col_add_str(pinfo->cinfo, COL_INFO, val_to_str(pdutype, iuup_colinfo_pdu_types, "Unknown PDU Type(%u) "));
     }
     
     switch(pdutype) {
@@ -852,12 +765,12 @@ static void dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree)
                     if (ta >= 1 && ta <= 80) {
                         pi = proto_tree_add_uint(time_tree,hf_iuup_delay,tvb,4,1,ta * 500);
                         PROTO_ITEM_SET_GENERATED(pi);
-                        pi = proto_tree_add_float(time_tree,hf_iuup_delta,tvb,4,1,((gfloat)((gint)(ta) * 500))/1000000.0);
+                        pi = proto_tree_add_float(time_tree,hf_iuup_delta,tvb,4,1,((gfloat)((gint)(ta) * 500))/(gfloat)1000000.0);
                         PROTO_ITEM_SET_GENERATED(pi);
                     } else if (ta >= 129 && ta <= 208) {
                         pi = proto_tree_add_uint(time_tree,hf_iuup_advance,tvb,4,1,(ta-128) * 500);
                         PROTO_ITEM_SET_GENERATED(pi);
-                        pi = proto_tree_add_float(time_tree,hf_iuup_delta,tvb,4,1,((gfloat)((gint)(-(((gint)ta)-128))) * 500)/1000000.0);
+                        pi = proto_tree_add_float(time_tree,hf_iuup_delta,tvb,4,1,((gfloat)((gint)(-(((gint)ta)-128))) * 500)/(gfloat)1000000.0);
                         PROTO_ITEM_SET_GENERATED(pi);
                     } else {
                         proto_item_set_expert_flags(pi, PI_MALFORMED, PI_ERROR);
@@ -885,7 +798,54 @@ static void dissect_iuup(tvbuff_t* tvb_in, packet_info* pinfo, proto_tree* tree)
             if (!tree) return;
             proto_item_set_expert_flags(pdutype_item, PI_MALFORMED, PI_ERROR);
             return;
-    };
+    }
+}
+
+
+static gboolean dissect_iuup_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
+	int len = tvb_length(tvb);
+	
+	guint8 first_octet =  tvb_get_guint8(tvb,0);
+	guint8 second_octet =  tvb_get_guint8(tvb,1);
+	guint16 hdrcrc6 = tvb_get_guint8(tvb, 2) >> 2;
+	
+	if (update_crc6_by_bytes(hdrcrc6, first_octet, second_octet)) return FALSE;
+	
+	switch ( first_octet & 0xf0 ) {
+		case 0x00: {
+			if (len<7) return FALSE;
+			if (update_crc10_by_bytes((guint16)(tvb_get_ntohs(tvb, 4) & 0x3FF), tvb_get_ptr(tvb, 6, len-4), len-4) ) return FALSE;
+			break;
+		}
+		case 0x10:
+			/* a FALSE positive factory */
+			if (len<5) return FALSE;
+			break;
+		case 0xe0:
+			if (len<5) return FALSE;
+			if( (second_octet & 0x0f) > 3) return FALSE;
+		default:
+			return FALSE;
+	}
+	
+	dissect_iuup(tvb, pinfo, tree);
+	return TRUE;
+}
+
+
+static void find_iuup(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
+	int len = tvb_length(tvb);
+	int offset = 0;
+	
+	while (len > 3) {
+		if ( dissect_iuup_heur(tvb_new_subset(tvb,offset,-1,-1), pinfo, tree) )
+			return;
+
+		offset++;
+		len--;
+	}
+	
+	call_dissector(data_handle, tvb, pinfo, tree);
 }
 
 static void init_iuup(void) {
@@ -930,11 +890,11 @@ void proto_reg_handoff_iuup(void) {
 { &hf_iuup_rfci_subflow[i][0], { "RFCI " #i " Flow 0", "iuup.rfci."#i".flow.0", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
 { &hf_iuup_rfci_subflow[i][1], { "RFCI " #i " Flow 1", "iuup.rfci."#i".flow.1", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
 { &hf_iuup_rfci_subflow[i][2], { "RFCI " #i " Flow 2", "iuup.rfci."#i".flow.2", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
-{ &hf_iuup_rfci_subflow[i][3], { "RFCI " #i " Flow 3 Len", "iuup.rfci."#i".flow.3", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
-{ &hf_iuup_rfci_subflow[i][4], { "RFCI " #i " Flow 4 Len", "iuup.rfci."#i".flow.4", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
-{ &hf_iuup_rfci_subflow[i][5], { "RFCI " #i " Flow 5 Len", "iuup.rfci."#i".flow.5", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
-{ &hf_iuup_rfci_subflow[i][6], { "RFCI " #i " Flow 6 Len", "iuup.rfci."#i".flow.6", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
-{ &hf_iuup_rfci_subflow[i][7], { "RFCI " #i " Flow 7 Len", "iuup.rfci."#i".flow.7", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
+{ &hf_iuup_rfci_subflow[i][3], { "RFCI " #i " Flow 3", "iuup.rfci."#i".flow.3", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
+{ &hf_iuup_rfci_subflow[i][4], { "RFCI " #i " Flow 4", "iuup.rfci."#i".flow.4", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
+{ &hf_iuup_rfci_subflow[i][5], { "RFCI " #i " Flow 5", "iuup.rfci."#i".flow.5", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
+{ &hf_iuup_rfci_subflow[i][6], { "RFCI " #i " Flow 6", "iuup.rfci."#i".flow.6", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
+{ &hf_iuup_rfci_subflow[i][7], { "RFCI " #i " Flow 7", "iuup.rfci."#i".flow.7", FT_BYTES, BASE_HEX, NULL,0x0,"",HFILL}}, \
 { &hf_iuup_init_ipti[i], { "RFCI " #i " IPTI", "iuup.rfci."#i".ipti", FT_UINT8, BASE_HEX, NULL,i%2 ? 0x0F : 0xF0,"",HFILL}}
 
 
@@ -1030,6 +990,8 @@ void proto_register_iuup(void) {
     proto_register_field_array(proto_iuup, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
     register_dissector("iuup", dissect_iuup, proto_iuup);
+    register_dissector("find_iuup", find_iuup, proto_iuup);
+	
     register_init_routine(&init_iuup);
     
     iuup_handle = create_dissector_handle(dissect_iuup, proto_iuup);
@@ -1051,7 +1013,5 @@ void proto_register_iuup(void) {
 								   "The dynamic payload type which will be interpreted as IuUP",
 								   10,
 								   &temp_dynamic_payload_type);
-    
-    
 }
 
