@@ -2,7 +2,7 @@
  * Routines for IEEE 802.2 LLC layer
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-llc.c 19492 2006-10-11 10:38:59Z sahlberg $
+ * $Id: packet-llc.c 23252 2007-10-23 05:50:00Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -420,7 +420,7 @@ dissect_basicxid(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	} else
 		xid_tree = NULL;
 	if (check_col(pinfo->cinfo, COL_INFO)) {
-		col_append_fstr(pinfo->cinfo, COL_INFO,
+		col_append_str(pinfo->cinfo, COL_INFO,
 		    "Basic Format");
 	}
 
@@ -835,15 +835,15 @@ proto_register_basicxid(void)
 {
 	static hf_register_info hf[] = {
 		{ &hf_llc_xid_format,
-		{ "XID Format", "llc.xid.format", FT_UINT8, BASE_HEX,
+		{ "XID Format", "basicxid.llc.xid.format", FT_UINT8, BASE_HEX,
 			VALS(format_vals), 0x0, "", HFILL }},
 
 		{ &hf_llc_xid_types,
-		{ "LLC Types/Classes", "llc.xid.types", FT_UINT8, BASE_HEX,
+		{ "LLC Types/Classes", "basicxid.llc.xid.types", FT_UINT8, BASE_HEX,
 			VALS(type_vals), 0x0, "", HFILL }},
 
 		{ &hf_llc_xid_wsize,
-		{ "Receive Window Size", "llc.xid.wsize", FT_UINT8, BASE_DEC,
+		{ "Receive Window Size", "basicxid.llc.xid.wsize", FT_UINT8, BASE_DEC,
 			NULL, 0x0, "", HFILL }},
 	};
 	static gint *ett[] = {
