@@ -3,7 +3,7 @@
  * Routines for LWAPP encapsulated packet disassembly
  * draft-ohara-capwap-lwapp-N (the current draft is 0)
  *
- * $Id: packet-lwapp.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-lwapp.c 23281 2007-10-26 16:57:54Z martinm $
  *
  * Copyright (c) 2003 by David Frascone <dave@frascone.com>
  *
@@ -37,7 +37,6 @@
 #include <time.h>
 #include <glib.h>
 #include <epan/filesystem.h>
-#include <epan/xmlstub.h>
 #include <epan/packet.h>
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
@@ -275,7 +274,7 @@ static void dissect_control(tvbuff_t *tvb, packet_info *pinfo,
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "LWAPP");
     if (check_col(pinfo->cinfo, COL_INFO)) {
 	col_clear(pinfo->cinfo, COL_INFO);
-        col_add_str(pinfo->cinfo, COL_INFO,
+        col_set_str(pinfo->cinfo, COL_INFO,
                     "CNTL ");
     }
 
@@ -339,7 +338,7 @@ static void dissect_lwapp_l3(tvbuff_t *tvb, packet_info *pinfo,
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "LWAPP-L3");
     if (check_col(pinfo->cinfo, COL_INFO)) {
 	col_clear(pinfo->cinfo, COL_INFO);
-        col_add_str(pinfo->cinfo, COL_INFO, "802.3 Packets over Layer 3");
+        col_set_str(pinfo->cinfo, COL_INFO, "802.3 Packets over Layer 3");
     }
 
     if (tree) {
@@ -383,7 +382,7 @@ static void dissect_lwapp(tvbuff_t *tvb, packet_info *pinfo,
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "LWAPP");
     if (check_col(pinfo->cinfo, COL_INFO)) {
 	col_clear(pinfo->cinfo, COL_INFO);
-        col_add_str(pinfo->cinfo, COL_INFO,
+        col_set_str(pinfo->cinfo, COL_INFO,
                     "LWAPP IP or Layer 2");
     }
 
@@ -540,7 +539,7 @@ proto_register_lwapp(void)
     proto_lwapp_l3 = proto_register_protocol ("LWAPP Layer 3 Packet", 
                                          "LWAPP-L3", "lwapp-l3");
 
-    proto_lwapp_control = proto_register_protocol ("LWAP Control Message", 
+    proto_lwapp_control = proto_register_protocol ("LWAPP Control Message", 
                                          "LWAPP-CNTL", "lwapp-cntl");
     proto_register_field_array(proto_lwapp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
@@ -593,7 +592,7 @@ proto_reg_handoff_lwapp(void)
      *
      */
 
-    /* Obsceleted LWAP via encapsulated 802.3 over UDP */
+    /* Obsoleted LWAPP via encapsulated 802.3 over UDP */
 
     dissector_add("udp.port", 12220, lwapp_l3_handle);
 
