@@ -8,7 +8,7 @@
  * Copyright 2001, 2002, Jeff Morriss <jeff.morriss[AT]ulticom.com>,
  * updated by Michael Tuexen <tuexen [AT] fh-muenster.de>
  *
- * $Id: packet-m2pa.c 18715 2006-07-11 18:19:09Z tuexen $
+ * $Id: packet-m2pa.c 21020 2007-03-12 11:21:02Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -584,6 +584,9 @@ proto_register_m2pa(void)
   proto_register_field_array(proto_m2pa, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
+  /* Allow other dissectors to find this one by name. */
+  register_dissector("m2pa", dissect_m2pa, proto_m2pa);
+
   m2pa_module = prefs_register_protocol(proto_m2pa, proto_reg_handoff_m2pa);
 
   prefs_register_enum_preference(m2pa_module, "version", "M2PA version", "Version used by Wireshark", &m2pa_version, m2pa_version_options, FALSE);
