@@ -2,7 +2,7 @@
  * Routines for Multimedia Internet KEYing dissection
  * Copyright 2007, Mikael Magnusson <mikma@users.sourceforge.net>
  *
- * $Id: packet-mikey.c 22911 2007-09-19 20:12:38Z jake $
+ * $Id: packet-mikey.c 25465 2008-06-17 17:10:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -678,7 +678,6 @@ dissect_payload_kemac(mikey_t *mikey, tvbuff_t *tvb, packet_info *pinfo, proto_t
 		mac_length = 160/8;
 		break;
 	default:
-		proto_tree_add_debug_text(tree, "Unknown mac alg %d", mac_alg);
 		return -1;
 	}
 
@@ -930,7 +929,6 @@ dissect_payload_v(mikey_t *mikey _U_, tvbuff_t *tvb, packet_info *pinfo _U_, pro
 		length = 160/8;
 		break;
 	default:
-		proto_tree_add_debug_text(tree, "Unknown mac alg %d", alg);
 		return -1;
 	}
 
@@ -1156,7 +1154,6 @@ dissect_mikey(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		len = dissect_payload(payload, mikey, subtvb, pinfo, mikey_payload_tree);
 		if (len < 0) {
-			proto_tree_add_debug_text(mikey_payload_tree, "Negative length");
 			return -1;
 		}
 
