@@ -2,7 +2,7 @@
  * Routines for Multiprotocol Label Switching Echo dissection
  * Copyright 2004, Carlos Pignataro <cpignata@cisco.com>
  *
- * $Id: packet-mpls-echo.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-mpls-echo.c 23406 2007-11-08 22:49:03Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -945,7 +945,7 @@ dissect_mpls_echo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         const guint8 *ts_sent, *ts_rec;
 
         /* If version != 1 we assume it's not an mpls ping packet */
-        if (!tvb_bytes_exist(tvb, 0, 5)) {
+        if (tvb_length(tvb) < 5) {
                 return; /* Not enough information to tell version and message type. */
         }
         if (tvb_get_ntohs(tvb, 0) != 1) {
@@ -976,7 +976,7 @@ dissect_mpls_echo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
         }
 
         if (check_col(pinfo->cinfo, COL_INFO))
-            col_set_str(pinfo->cinfo, COL_INFO,
+            col_add_str(pinfo->cinfo, COL_INFO,
                 val_to_str(msgtype, mpls_echo_msgtype, "Unknown Message Type (0x%02X)"));
 
 
