@@ -1,6 +1,6 @@
 /* packet-mtp3.h
  *
- * $Id: packet-mtp3.h 19231 2006-09-14 10:51:44Z jmayer $
+ * $Id: packet-mtp3.h 24297 2008-02-10 21:38:52Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -20,6 +20,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+#ifndef __PACKET_MTP3_H_
+#define __PACKET_MTP3_H_
 
 typedef enum {
   ITU_STANDARD  = 1,
@@ -39,7 +41,7 @@ typedef enum {
 } mtp3_net_addr_fmt_e;
 
 typedef struct _mtp3_addr_pc_t {
-  mtp3_net_addr_fmt_e	type;
+  Standard_Type		type;
   guint32		pc;
   guint8		ni;
 } mtp3_addr_pc_t;
@@ -68,11 +70,11 @@ typedef struct _mtp3_tap_rec_t {
 #define JAPAN_PC_LENGTH   2
 #define JAPAN_PC_MASK     0xffff
 
-extern void     mtp3_addr_to_str_buf(const guint8 *data, gchar *buf, int buf_len);
+extern void     mtp3_addr_to_str_buf(const mtp3_addr_pc_t *addr_pc_p, gchar *buf, int buf_len);
 extern void     mtp3_pc_to_str_buf(const guint32 pc, gchar *buf, int buf_len);
 extern gchar*   mtp3_pc_to_str(const guint32 pc);
 extern gboolean mtp3_pc_structured(void);
-extern guint32  mtp3_pc_hash(const guint8* data);
+extern guint32  mtp3_pc_hash(const mtp3_addr_pc_t *addr_pc_p);
 
 #ifdef __PROTO_H__
 /* epan/to_str.c includes this file, but it does not include proto.h so
@@ -98,3 +100,5 @@ WS_VAR_IMPORT const value_string mtp3_service_indicator_code_short_vals[];
  * I only want to gather stats for non-spare SI codes
  */
 #define	MTP3_NUM_SI_CODE	9
+
+#endif
