@@ -2,7 +2,7 @@
  * Routines for PIM disassembly
  * (c) Copyright Jun-ichiro itojun Hagino <itojun@itojun.org>
  *
- * $Id: packet-pim.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-pim.c 23991 2008-01-03 07:29:34Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -788,7 +788,7 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 			override_interval = opt_value & 0x0000ffff;
 			proto_tree_add_text(sub_tree, tvb, offset + 4, 1,
 					    "T bit is %s",
-					    opt_value & 0x8000 ? "set" : "not set");
+					    (opt_value & 0x80000000) ? "set" : "not set");
 			proto_tree_add_text(sub_tree, tvb, offset + 4, 2,
 					    "LAN Delay: %ums", lan_delay);
 			proto_tree_add_text(sub_tree, tvb, offset + 6, 2,
