@@ -3,7 +3,7 @@
  *
  * Duncan Laurie <duncan@sun.com>
  *
- * $Id: packet-rmcp.c 19052 2006-08-27 11:27:47Z ulfl $
+ * $Id: packet-rmcp.c 21072 2007-03-20 15:05:04Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,10 +50,6 @@ static int hf_rmcp_type = -1;
 static int proto_rsp = -1;
 static int hf_rsp_session_id = -1;
 static int hf_rsp_sequence = -1;
-static int hf_rsp_pad = -1;
-static int hf_rsp_pad_length = -1;
-static int hf_rsp_next_header = -1;
-static int hf_rsp_integrity_data = -1;
 
 static gint ett_rmcp = -1;
 static gint ett_rmcp_typeclass = -1;
