@@ -18,7 +18,7 @@
  * References:
  *     RFC 3940, Negative-acknowledgment (NACK)-Oriented Reliable Multicast (NORM) Protocol
  *
- * $Id: packet-rmt-norm.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-rmt-norm.c 23412 2007-11-09 06:01:18Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,6 +52,7 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/strutil.h>
+#include <epan/garrayfix.h>
 
 #include "packet-rmt-norm.h"
 #include <math.h>
@@ -654,14 +655,14 @@ dissect_norm_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint8 byte1;
 	if (!global_norm_heur)
 		return FALSE;
-	if (!tvb_bytes_exist(tvb, 0, 2))
+	if (tvb_length(tvb) < 2)
 		return FALSE;	/* not enough to check */
 	byte1 = tvb_get_guint8(tvb, 0);
 
 	if (hi_nibble(byte1) != 1) return FALSE;
 	if (lo_nibble(byte1) < 1 || lo_nibble(byte1) > 6) return FALSE;
 	if (tvb_get_guint8(tvb, 1) > 20) return FALSE;
-	if (tvb_length_remaining(tvb, 0) < 12)
+	if (tvb_length(tvb) < 12)
 		return FALSE;
 	dissect_norm(tvb, pinfo, tree);
 	return TRUE; /* appears to be a NORM packet */
