@@ -3,7 +3,7 @@
  * [ very rough, but mininally functional ]
  * Copyright 2003, Brad Hards <bradh@frogmouth.net>
  *
- * $Id: packet-rsync.c 20062 2006-12-07 20:34:08Z etxrab $
+ * $Id: packet-rsync.c 23252 2007-10-23 05:50:00Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -191,7 +191,7 @@ dissect_rsync_encap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	proto_tree_add_item(rsync_tree, hf_rsync_motd_string, tvb, offset, -1, TRUE);
 
         if (check_col(pinfo->cinfo, COL_INFO)) {
-	  col_append_fstr(pinfo->cinfo, COL_INFO, "Server MOTD");
+	  col_append_str(pinfo->cinfo, COL_INFO, "Server MOTD");
 	}
 
 	conversation_data->state = RSYNC_SERV_RESPONSE;
@@ -216,7 +216,7 @@ dissect_rsync_encap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	  proto_tree_add_item(rsync_tree, hf_rsync_response_string, tvb, offset, -1, TRUE);
 
 	  if (check_col(pinfo->cinfo, COL_INFO)) {
-	    col_append_fstr(pinfo->cinfo, COL_INFO, "Module list");
+	    col_append_str(pinfo->cinfo, COL_INFO, "Module list");
 	  }
 
 	  /* we need to check the end of the buffer for magic string */
