@@ -6,7 +6,7 @@
  * Copyright 2000, Philips Electronics N.V.
  * Written by Andreas Sikkema <h323@ramdyne.nl>
  *
- * $Id: packet-rtp.c 24583 2008-03-07 18:15:46Z martinm $
+ * $Id: packet-rtp.c 25465 2008-06-17 17:10:51Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -478,11 +478,6 @@ dissect_rtp_heur( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	if (! global_rtp_heur)
 		return FALSE;
 
-	/* Was it sent between 2 even-numbered ports? */
-	if ((pinfo->srcport % 2) || (pinfo->destport % 2)) {
-		return FALSE;
-	}
-
 	/* Get the fields in the first octet */
 	octet1 = tvb_get_guint8( tvb, offset );
 	version = RTP_VERSION( octet1 );
@@ -507,6 +502,11 @@ dissect_rtp_heur( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 		return FALSE;
 	}
 
+	/* Was it sent between 2 even-numbered ports? */
+	if ((pinfo->srcport % 2) || (pinfo->destport % 2)) {
+		return FALSE;
+	}
+
 	/* Get the fields in the second octet */
 	octet2 = tvb_get_guint8( tvb, offset + 1 );
 	payload_type = RTP_PAYLOAD_TYPE( octet2 );
@@ -941,6 +941,7 @@ dissect_rtp( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	struct _rtp_conversation_info *p_conv_data = NULL;
 	struct srtp_info *srtp_info = NULL;
 	unsigned int srtp_offset;
+	unsigned int hdrext_offset = 0;
 	tvbuff_t *newtvb = NULL;
 
 	/* Can tap up to 4 RTP packets within same packet */
@@ -1185,8 +1186,10 @@ dissect_rtp( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 			newtvb = tvb_new_subset(tvb, offset, hdr_extension * 4, hdr_extension * 4);
 			if ( !(rtp_info->info_payload_type_str && dissector_try_string(rtp_hdr_ext_dissector_table,
 				rtp_info->info_payload_type_str, newtvb, pinfo, rtp_hext_tree)) ) {
+				hdrext_offset = offset;
 				for ( i = 0; i < hdr_extension; i++ ) {
-					if ( tree ) proto_tree_add_uint( rtp_hext_tree, hf_rtp_hdr_ext, tvb, offset, 4, tvb_get_ntohl( tvb, offset ) );
+					if ( tree ) proto_tree_add_uint( rtp_hext_tree, hf_rtp_hdr_ext, tvb, hdrext_offset, 4, tvb_get_ntohl( tvb, hdrext_offset ) );
+					hdrext_offset += 4;
 				}
 			}
 			offset += hdr_extension * 4;
