@@ -12,7 +12,7 @@
  * version: 2004/04/15 9:40:45
  * dedication to Kj :]
  *
- * $Id: packet-rtps.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-rtps.c 23252 2007-10-23 05:50:00Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -480,7 +480,7 @@ dissect_rtps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
        g_snprintf(buff+buff_len, 200-buff_len, "vendor specific(%d) ",count_msg_type[10]);
    }
 
-   col_add_fstr(pinfo->cinfo, COL_INFO, buff);
+   col_add_str(pinfo->cinfo, COL_INFO, buff);
 
   }
 
