@@ -1,3 +1,4 @@
+/* based on the SMC 3 standard */
 /* packet-scsi-smc.c
  * Dissector for the SCSI SMC commandset
  * Extracted from packet-scsi.c
@@ -5,7 +6,7 @@
  * Dinesh G Dutt (ddutt@cisco.com)
  * Ronnie sahlberg 2006
  *
- * $Id: packet-scsi-smc.c 19964 2006-11-23 09:21:16Z sahlberg $
+ * $Id: packet-scsi-smc.c 21412 2007-04-13 17:16:24Z standel $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,31 +44,181 @@
 #include "packet-scsi-smc.h"
 
 
-static int proto_scsi_smc		= -1;
-int hf_scsi_smc_opcode			= -1;
-
+static int proto_scsi_smc			= -1;
+int hf_scsi_smc_opcode				= -1;
+static int hf_scsi_smc_mta			= -1;
+static int hf_scsi_smc_sa			= -1;
+static int hf_scsi_smc_da			= -1;
+static int hf_scsi_smc_fda			= -1;
+static int hf_scsi_smc_sda			= -1;
+static int hf_scsi_smc_medium_flags		= -1;
+static int hf_scsi_smc_inv1			= -1;
+static int hf_scsi_smc_inv2			= -1;
+static int hf_scsi_smc_range_flags		= -1;
+static int hf_scsi_smc_fast			= -1;
+static int hf_scsi_smc_range			= -1;
+static int hf_scsi_smc_sea			= -1;
+static int hf_scsi_smc_num_elements		= -1;
+static int hf_scsi_smc_invert			= -1;
+static int hf_scsi_smc_ea			= -1;
+static int hf_scsi_smc_action_code		= -1;
 
+static gint ett_scsi_exchange_medium		= -1;
+static gint ett_scsi_range			= -1;
+static gint ett_scsi_move			= -1;
 
 void
-dissect_smc2_movemedium (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
+dissect_smc_exchangemedium (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
+                    guint offset, gboolean isreq, gboolean iscdb,
+                    guint payload_len _U_, scsi_task_data_t *cdata _U_)
+{
+    guint8 flags;
+    static const int *exchg_fields[] = {
+        &hf_scsi_smc_inv1,
+        &hf_scsi_smc_inv2,
+	NULL
+    };
+
+    if (!tree) 
+        return;
+
+    if (isreq && iscdb) {
+        proto_tree_add_item (tree, hf_scsi_smc_mta, tvb, offset+1, 2, 0);
+        proto_tree_add_item (tree, hf_scsi_smc_sa,  tvb, offset+3, 2, 0);
+        proto_tree_add_item (tree, hf_scsi_smc_fda, tvb, offset+5, 2, 0);
+        proto_tree_add_item (tree, hf_scsi_smc_sda, tvb, offset+7, 2, 0);
+
+
+	proto_tree_add_bitmask(tree, tvb, offset+9, hf_scsi_smc_medium_flags, ett_scsi_exchange_medium, exchg_fields, FALSE);
+
+        flags = tvb_get_guint8 (tvb, offset+10);
+        proto_tree_add_uint_format (tree, hf_scsi_control, tvb, offset+10, 1,
+                                    flags,
+                                    "Vendor Unique = %u, NACA = %u, Link = %u",
+                                    flags & 0xC0, flags & 0x4, flags & 0x1);
+    }
+}
+
+void
+dissect_smc_position_to_element (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
+                    guint offset, gboolean isreq, gboolean iscdb,
+                    guint payload_len _U_, scsi_task_data_t *cdata _U_)
+{
+    guint8 flags;
+    static const int *pte_fields[] = {
+        &hf_scsi_smc_invert,
+	NULL
+    };
+
+    if (!tree) 
+        return;
+
+    if (isreq && iscdb) {
+        proto_tree_add_item (tree, hf_scsi_smc_mta, tvb, offset+1, 2, 0);
+        proto_tree_add_item (tree, hf_scsi_smc_da,  tvb, offset+3, 2, 0);
+
+	proto_tree_add_bitmask(tree, tvb, offset+7, hf_scsi_smc_medium_flags, ett_scsi_exchange_medium, pte_fields, FALSE);
+
+        flags = tvb_get_guint8 (tvb, offset+8);
+        proto_tree_add_uint_format (tree, hf_scsi_control, tvb, offset+8, 1,
+                                    flags,
+                                    "Vendor Unique = %u, NACA = %u, Link = %u",
+                                    flags & 0xC0, flags & 0x4, flags & 0x1);
+    }
+}
+
+void
+dissect_smc_initialize_element_status (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
                     guint offset, gboolean isreq, gboolean iscdb,
                     guint payload_len _U_, scsi_task_data_t *cdata _U_)
 {
     guint8 flags;
 
-    if (tree && isreq && iscdb) {
-        proto_tree_add_text (tree, tvb, offset+1, 2,
-                             "Medium Transport Address: %u",
-                             tvb_get_ntohs (tvb, offset+1));
-        proto_tree_add_text (tree, tvb, offset+3, 2,
-                             "Source Address: %u",
-                             tvb_get_ntohs (tvb, offset+3));
-        proto_tree_add_text (tree, tvb, offset+5, 2,
-                             "Destination Address: %u",
-                             tvb_get_ntohs (tvb, offset+5));
-        flags = tvb_get_guint8 (tvb, offset+9);
-        proto_tree_add_text (tree, tvb, offset+9, 1,
-                             "INV: %u", flags & 0x01);
+    if (!tree) 
+        return;
+
+    if (isreq && iscdb) {
+        flags = tvb_get_guint8 (tvb, offset+4);
+        proto_tree_add_uint_format (tree, hf_scsi_control, tvb, offset+4, 1,
+                                    flags,
+                                    "Vendor Unique = %u, NACA = %u, Link = %u",
+                                    flags & 0xC0, flags & 0x4, flags & 0x1);
+    }
+}
+
+void
+dissect_smc_initialize_element_status_with_range (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
+                    guint offset, gboolean isreq, gboolean iscdb,
+                    guint payload_len _U_, scsi_task_data_t *cdata _U_)
+{
+    guint8 flags;
+    static const int *range_fields[] = {
+        &hf_scsi_smc_fast,
+        &hf_scsi_smc_range,
+	NULL
+    };
+
+    if (!tree) 
+        return;
+
+    if (isreq && iscdb) {
+	proto_tree_add_bitmask(tree, tvb, offset, hf_scsi_smc_range_flags, ett_scsi_range, range_fields, FALSE);
+
+        proto_tree_add_item (tree, hf_scsi_smc_sa,  tvb, offset+1, 2, 0);
+
+        proto_tree_add_item (tree, hf_scsi_smc_num_elements,  tvb, offset+5, 2, 0);
+
+        flags = tvb_get_guint8 (tvb, offset+8);
+        proto_tree_add_uint_format (tree, hf_scsi_control, tvb, offset+8, 1,
+                                    flags,
+                                    "Vendor Unique = %u, NACA = %u, Link = %u",
+                                    flags & 0xC0, flags & 0x4, flags & 0x1);
+    }
+}
+
+void
+dissect_smc_openclose_importexport_element (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
+                    guint offset, gboolean isreq, gboolean iscdb,
+                    guint payload_len _U_, scsi_task_data_t *cdata _U_)
+{
+    guint8 flags;
+
+    if (!tree) 
+        return;
+
+    if (isreq && iscdb) {
+        proto_tree_add_item (tree, hf_scsi_smc_ea,  tvb, offset+1, 2, 0);
+
+        proto_tree_add_item (tree, hf_scsi_smc_action_code,  tvb, offset+3, 1, 0);
+
+        flags = tvb_get_guint8 (tvb, offset+4);
+        proto_tree_add_uint_format (tree, hf_scsi_control, tvb, offset+4, 1,
+                                    flags,
+                                    "Vendor Unique = %u, NACA = %u, Link = %u",
+                                    flags & 0xC0, flags & 0x4, flags & 0x1);
+    }
+}
+void
+dissect_smc_movemedium (tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree,
+                    guint offset, gboolean isreq, gboolean iscdb,
+                    guint payload_len _U_, scsi_task_data_t *cdata _U_)
+{
+    guint8 flags;
+    static const int *move_fields[] = {
+        &hf_scsi_smc_invert,
+	NULL
+    };
+
+    if (!tree)
+        return;
+
+    if (isreq && iscdb) {
+        proto_tree_add_item (tree, hf_scsi_smc_mta, tvb, offset+1, 2, 0);
+        proto_tree_add_item (tree, hf_scsi_smc_sa,  tvb, offset+3, 2, 0);
+        proto_tree_add_item (tree, hf_scsi_smc_da,  tvb, offset+5, 2, 0);
+
+	proto_tree_add_bitmask(tree, tvb, offset+9, hf_scsi_smc_range_flags, ett_scsi_move, move_fields, FALSE);
+
         flags = tvb_get_guint8 (tvb, offset+10);
         proto_tree_add_uint_format (tree, hf_scsi_control, tvb, offset+10, 1,
                                     flags,
@@ -90,6 +241,12 @@ static const value_string element_type_code_vals[] = {
     {0, NULL}
 };
 
+static const value_string action_code_vals[] = {
+    {0, "OPEN Import/Export Element"},
+    {1, "CLOSE Import/Export Element"},
+    {0, NULL}
+};
+
 #define PVOLTAG 0x80
 #define AVOLTAG 0x40
 
@@ -101,7 +258,7 @@ static const value_string element_type_code_vals[] = {
 #define SVALID 0x80
 
 static void
-dissect_scsi_smc2_volume_tag (tvbuff_t *tvb, packet_info *pinfo _U_,
+dissect_scsi_smc_volume_tag (tvbuff_t *tvb, packet_info *pinfo _U_,
                               proto_tree *tree, guint offset,
                               const char *name)
 {
@@ -125,7 +282,7 @@ dissect_scsi_smc2_volume_tag (tvbuff_t *tvb, packet_info *pinfo _U_,
 
 
 static void
-dissect_scsi_smc2_element (tvbuff_t *tvb, packet_info *pinfo _U_,
+dissect_scsi_smc_element (tvbuff_t *tvb, packet_info *pinfo _U_,
                          proto_tree *tree, guint offset,
                          guint elem_bytecnt, guint8 elem_type,
                          guint8 voltag_flags)
@@ -248,7 +405,7 @@ dissect_scsi_smc2_element (tvbuff_t *tvb, packet_info *pinfo _U_,
     if (voltag_flags & PVOLTAG) {
         if (elem_bytecnt < 36)
             return;
-        dissect_scsi_smc2_volume_tag (tvb, pinfo, tree, offset,
+        dissect_scsi_smc_volume_tag (tvb, pinfo, tree, offset,
                                       "Primary Volume Tag Information");
         offset += 36;
         elem_bytecnt -= 36;
@@ -257,7 +414,7 @@ dissect_scsi_smc2_element (tvbuff_t *tvb, packet_info *pinfo _U_,
     if (voltag_flags & AVOLTAG) {
         if (elem_bytecnt < 36)
             return;
-        dissect_scsi_smc2_volume_tag (tvb, pinfo, tree, offset,
+        dissect_scsi_smc_volume_tag (tvb, pinfo, tree, offset,
                                       "Alternate Volume Tag Information");
         offset += 36;
         elem_bytecnt -= 36;
@@ -317,7 +474,7 @@ dissect_scsi_smc2_element (tvbuff_t *tvb, packet_info *pinfo _U_,
 
 
 static void
-dissect_scsi_smc2_elements (tvbuff_t *tvb, packet_info *pinfo,
+dissect_scsi_smc_elements (tvbuff_t *tvb, packet_info *pinfo,
                             proto_tree *tree, guint offset,
                             guint desc_bytecnt, guint8 elem_type,
                             guint8 voltag_flags, guint16 elem_desc_len)
@@ -328,7 +485,7 @@ dissect_scsi_smc2_elements (tvbuff_t *tvb, packet_info *pinfo,
         elem_bytecnt = elem_desc_len;
         if (elem_bytecnt > desc_bytecnt)
             elem_bytecnt = desc_bytecnt;
-        dissect_scsi_smc2_element (tvb, pinfo, tree, offset, elem_bytecnt,
+        dissect_scsi_smc_element (tvb, pinfo, tree, offset, elem_bytecnt,
                                    elem_type, voltag_flags);
         offset += elem_bytecnt;
         desc_bytecnt -= elem_bytecnt;
@@ -337,7 +494,7 @@ dissect_scsi_smc2_elements (tvbuff_t *tvb, packet_info *pinfo,
 
 
 void
-dissect_smc2_readelementstatus (tvbuff_t *tvb, packet_info *pinfo,
+dissect_smc_readelementstatus (tvbuff_t *tvb, packet_info *pinfo,
                          proto_tree *tree, guint offset, gboolean isreq,
                          gboolean iscdb,
                          guint payload_len _U_, scsi_task_data_t *cdata _U_)
@@ -437,7 +594,7 @@ dissect_smc2_readelementstatus (tvbuff_t *tvb, packet_info *pinfo,
 
             if (desc_bytecnt > bytecnt)
                 desc_bytecnt = bytecnt;
-            dissect_scsi_smc2_elements (tvb, pinfo, tree, offset,
+            dissect_scsi_smc_elements (tvb, pinfo, tree, offset,
                                         desc_bytecnt, elem_type,
                                         voltag_flags, elem_desc_len);
             offset += desc_bytecnt;
@@ -450,49 +607,55 @@ dissect_smc2_readelementstatus (tvbuff_t *tvb, packet_info *pinfo,
 
 /* SMC Commands */
 const value_string scsi_smc_vals[] = {
-    {SCSI_SMC2_EXCHANGE_MEDIUM                , "Exchange Medium"},
-    {SCSI_SMC2_INITIALIZE_ELEMENT_STATUS      , "Initialize Element Status"},
-    {SCSI_SMC2_INITIALIZE_ELEMENT_STATUS_RANGE, "Initialize Element Status With Range"},
-    {SCSI_SPC2_INQUIRY                        , "Inquiry"},
-    {SCSI_SPC2_LOGSELECT                      , "Log Select"},
-    {SCSI_SPC2_LOGSENSE                       , "Log Sense"},
-    {SCSI_SPC2_MODESELECT6                    , "Mode Select(6)"},
-    {SCSI_SPC2_MODESELECT10                   , "Mode Select(10)"},
-    {SCSI_SPC2_MODESENSE6                     , "Mode Sense(6)"},
-    {SCSI_SPC2_MODESENSE10                    , "Mode Sense(10)"},
-    {SCSI_SMC2_MOVE_MEDIUM                    , "Move Medium"},
-    {SCSI_SMC2_MOVE_MEDIUM_ATTACHED           , "Move Medium Attached"},
-    {SCSI_SPC2_PERSRESVIN                     , "Persistent Reserve In"},
-    {SCSI_SPC2_PERSRESVOUT                    , "Persistent Reserve Out"},
-    {SCSI_SMC2_POSITION_TO_ELEMENT            , "Position To Element"},
-    {SCSI_SPC2_PREVMEDREMOVAL                 , "Prevent/Allow Medium Removal"},
-    {SCSI_SMC2_READ_ATTRIBUTE                 , "Read Attribute"},
-    {SCSI_SMC2_READ_ELEMENT_STATUS            , "Read Element Status"},
-    {SCSI_SMC2_READ_ELEMENT_STATUS_ATTACHED   , "Read Element Status Attached"},
-    {SCSI_SPC2_RELEASE6                       , "Release(6)"},
-    {SCSI_SPC2_RELEASE10                      , "Release(10)"},
-    {SCSI_SPC2_REPORTLUNS                     , "Report LUNs"},
-    {SCSI_SPC2_REQSENSE                       , "Request Sense"},
-    {SCSI_SMC2_REQUEST_VOLUME_ELEMENT_ADDRESS , "Request Volume Element Address"},
-    {SCSI_SPC2_RESERVE6                       , "Reserve(6)"},
-    {SCSI_SPC2_RESERVE10                      , "Reserve(10)"},
-    {SCSI_SMC2_SEND_VOLUME_TAG                , "Send Volume Tag"},
-    {SCSI_SPC2_SENDDIAG                       , "Send Diagnostic"},
-    {SCSI_SPC2_TESTUNITRDY                    , "Test Unit Ready"},
-    {SCSI_SMC2_WRITE_ATTRIBUTE                , "Write Attribute"},
-    {SCSI_SPC2_WRITEBUFFER                    , "Write Buffer"},
+    {SCSI_SPC_ACCESS_CONTROL_IN               , "Access Control In"},
+    {SCSI_SPC_ACCESS_CONTROL_OUT              , "Access Control Out"},
+    {SCSI_SMC_EXCHANGE_MEDIUM                 , "Exchange Medium"},
+    {SCSI_SMC_INITIALIZE_ELEMENT_STATUS       , "Initialize Element Status"},
+    {SCSI_SMC_INITIALIZE_ELEMENT_STATUS_RANGE , "Initialize Element Status With Range"},
+    {SCSI_SPC_INQUIRY                         , "Inquiry"},
+    {SCSI_SPC_LOGSELECT                       , "Log Select"},
+    {SCSI_SPC_LOGSENSE                        , "Log Sense"},
+    {SCSI_SPC_MODESELECT6                     , "Mode Select(6)"},
+    {SCSI_SPC_MODESELECT10                    , "Mode Select(10)"},
+    {SCSI_SPC_MODESENSE6                      , "Mode Sense(6)"},
+    {SCSI_SPC_MODESENSE10                     , "Mode Sense(10)"},
+    {SCSI_SMC_MOVE_MEDIUM                     , "Move Medium"},
+    {SCSI_SMC_MOVE_MEDIUM_ATTACHED            , "Move Medium Attached"},
+    {SCSI_SMC_OPENCLOSE_ELEMENT               , "Open/Close Import/Export Element"},
+    {SCSI_SPC_PERSRESVIN                      , "Persistent Reserve In"},
+    {SCSI_SPC_PERSRESVOUT                     , "Persistent Reserve Out"},
+    {SCSI_SMC_POSITION_TO_ELEMENT             , "Position To Element"},
+    {SCSI_SPC_PREVMEDREMOVAL                  , "Prevent/Allow Medium Removal"},
+    {SCSI_SMC_READ_ATTRIBUTE                  , "Read Attribute"},
+    {SCSI_SPC_READBUFFER                      , "Read Buffer"},
+    {SCSI_SMC_READ_ELEMENT_STATUS             , "Read Element Status"},
+    {SCSI_SMC_READ_ELEMENT_STATUS_ATTACHED    , "Read Element Status Attached"},
+    {SCSI_SPC_RCVDIAGRESULTS                  , "Receive Diagnostics Results"},
+    {SCSI_SPC_RELEASE6                        , "Release(6)"},
+    {SCSI_SPC_RELEASE10                       , "Release(10)"},
+    {SCSI_SPC_REPORTLUNS                      , "Report LUNs"},
+    {SCSI_SMC_REPORT_VOLUME_TYPES_SUPPORTED   , "Report Volume Types Supported"},
+    {SCSI_SPC_REQSENSE                        , "Request Sense"},
+    {SCSI_SMC_REQUEST_VOLUME_ELEMENT_ADDRESS  , "Request Volume Element Address"},
+    {SCSI_SPC_RESERVE6                        , "Reserve(6)"},
+    {SCSI_SPC_RESERVE10                       , "Reserve(10)"},
+    {SCSI_SMC_SEND_VOLUME_TAG                 , "Send Volume Tag"},
+    {SCSI_SPC_SENDDIAG                        , "Send Diagnostic"},
+    {SCSI_SPC_TESTUNITRDY                     , "Test Unit Ready"},
+    {SCSI_SMC_WRITE_ATTRIBUTE                 , "Write Attribute"},
+    {SCSI_SPC_WRITEBUFFER                     , "Write Buffer"},
     {0, NULL},
 };
 
 scsi_cdb_table_t scsi_smc_table[256] = {
-/*SPC 0x00*/{dissect_spc3_testunitready},
+/*SPC 0x00*/{dissect_spc_testunitready},
 /*SMC 0x01*/{NULL},
 /*SMC 0x02*/{NULL},
-/*SPC 0x03*/{dissect_spc3_requestsense},
+/*SPC 0x03*/{dissect_spc_requestsense},
 /*SMC 0x04*/{NULL},
 /*SMC 0x05*/{NULL},
 /*SMC 0x06*/{NULL},
-/*SMC 0x07*/{NULL},
+/*SMC 0x07*/{dissect_smc_initialize_element_status},
 /*SMC 0x08*/{NULL},
 /*SMC 0x09*/{NULL},
 /*SMC 0x0a*/{NULL},
@@ -503,19 +666,19 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0x0f*/{NULL},
 /*SMC 0x10*/{NULL},
 /*SMC 0x11*/{NULL},
-/*SPC 0x12*/{dissect_spc3_inquiry},
+/*SPC 0x12*/{dissect_spc_inquiry},
 /*SMC 0x13*/{NULL},
 /*SMC 0x14*/{NULL},
-/*SPC 0x15*/{dissect_spc3_modeselect6},
-/*SPC 0x16*/{dissect_spc2_reserve6},
-/*SPC 0x17*/{dissect_spc2_release6},
+/*SPC 0x15*/{dissect_spc_modeselect6},
+/*SPC 0x16*/{dissect_spc_reserve6},
+/*SPC 0x17*/{dissect_spc_release6},
 /*SMC 0x18*/{NULL},
 /*SMC 0x19*/{NULL},
-/*SPC 0x1a*/{dissect_spc3_modesense6},
-/*SMC 0x1b*/{NULL},
+/*SPC 0x1a*/{dissect_spc_modesense6},
+/*SMC 0x1b*/{dissect_smc_openclose_importexport_element},
 /*SMC 0x1c*/{NULL},
-/*SPC 0x1d*/{dissect_spc3_senddiagnostic},
-/*SMC 0x1e*/{dissect_spc3_preventallowmediaremoval},
+/*SPC 0x1d*/{dissect_spc_senddiagnostic},
+/*SMC 0x1e*/{dissect_spc_preventallowmediaremoval},
 /*SMC 0x1f*/{NULL},
 /*SMC 0x20*/{NULL},
 /*SMC 0x21*/{NULL},
@@ -528,7 +691,7 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0x28*/{NULL},
 /*SMC 0x29*/{NULL},
 /*SMC 0x2a*/{NULL},
-/*SMC 0x2b*/{NULL},
+/*SMC 0x2b*/{dissect_smc_position_to_element},
 /*SMC 0x2c*/{NULL},
 /*SMC 0x2d*/{NULL},
 /*SMC 0x2e*/{NULL},
@@ -540,11 +703,11 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0x34*/{NULL},
 /*SMC 0x35*/{NULL},
 /*SMC 0x36*/{NULL},
-/*SMC 0x37*/{NULL},
+/*SMC 0x37*/{dissect_smc_initialize_element_status_with_range},
 /*SMC 0x38*/{NULL},
 /*SMC 0x39*/{NULL},
 /*SMC 0x3a*/{NULL},
-/*SPC 0x3b*/{dissect_spc3_writebuffer},
+/*SPC 0x3b*/{dissect_spc_writebuffer},
 /*SMC 0x3c*/{NULL},
 /*SMC 0x3d*/{NULL},
 /*SMC 0x3e*/{NULL},
@@ -561,8 +724,8 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0x49*/{NULL},
 /*SMC 0x4a*/{NULL},
 /*SMC 0x4b*/{NULL},
-/*SPC 0x4c*/{dissect_spc3_logselect},
-/*SPC 0x4d*/{dissect_spc3_logsense},
+/*SPC 0x4c*/{dissect_spc_logselect},
+/*SPC 0x4d*/{dissect_spc_logsense},
 /*SMC 0x4e*/{NULL},
 /*SMC 0x4f*/{NULL},
 /*SMC 0x50*/{NULL},
@@ -570,17 +733,17 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0x52*/{NULL},
 /*SMC 0x53*/{NULL},
 /*SMC 0x54*/{NULL},
-/*SPC 0x55*/{dissect_spc3_modeselect10},
-/*SPC 0x56*/{dissect_spc2_reserve10},
-/*SPC 0x57*/{dissect_spc2_release10},
+/*SPC 0x55*/{dissect_spc_modeselect10},
+/*SPC 0x56*/{dissect_spc_reserve10},
+/*SPC 0x57*/{dissect_spc_release10},
 /*SMC 0x58*/{NULL},
 /*SMC 0x59*/{NULL},
-/*SPC 0x5a*/{dissect_spc3_modesense10},
+/*SPC 0x5a*/{dissect_spc_modesense10},
 /*SMC 0x5b*/{NULL},
 /*SMC 0x5c*/{NULL},
 /*SMC 0x5d*/{NULL},
-/*SPC 0x5e*/{dissect_spc3_persistentreservein},
-/*SPC 0x5f*/{dissect_spc3_persistentreserveout},
+/*SPC 0x5e*/{dissect_spc_persistentreservein},
+/*SPC 0x5f*/{dissect_spc_persistentreserveout},
 /*SMC 0x60*/{NULL},
 /*SMC 0x61*/{NULL},
 /*SMC 0x62*/{NULL},
@@ -645,14 +808,14 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0x9d*/{NULL},
 /*SMC 0x9e*/{NULL},
 /*SMC 0x9f*/{NULL},
-/*SPC 0xa0*/{dissect_spc3_reportluns},
+/*SPC 0xa0*/{dissect_spc_reportluns},
 /*SMC 0xa1*/{NULL},
 /*SMC 0xa2*/{NULL},
 /*SMC 0xa3*/{NULL},
 /*SMC 0xa4*/{NULL},
-/*SMC 0xa5*/{dissect_smc2_movemedium},
-/*SMC 0xa6*/{NULL},
-/*SMC 0xa7*/{dissect_smc2_movemedium},
+/*SMC 0xa5*/{dissect_smc_movemedium},
+/*SMC 0xa6*/{dissect_smc_exchangemedium},
+/*SMC 0xa7*/{dissect_smc_movemedium},
 /*SMC 0xa8*/{NULL},
 /*SMC 0xa9*/{NULL},
 /*SMC 0xaa*/{NULL},
@@ -665,11 +828,11 @@ scsi_cdb_table_t scsi_smc_table[256] = {
 /*SMC 0xb1*/{NULL},
 /*SMC 0xb2*/{NULL},
 /*SMC 0xb3*/{NULL},
-/*SMC 0xb4*/{dissect_smc2_readelementstatus},
+/*SMC 0xb4*/{dissect_smc_readelementstatus},
 /*SMC 0xb5*/{NULL},
 /*SMC 0xb6*/{NULL},
 /*SMC 0xb7*/{NULL},
-/*SMC 0xb8*/{dissect_smc2_readelementstatus},
+/*SMC 0xb8*/{dissect_smc_readelementstatus},
 /*SMC 0xb9*/{NULL},
 /*SMC 0xba*/{NULL},
 /*SMC 0xbb*/{NULL},
@@ -751,23 +914,71 @@ proto_register_scsi_smc(void)
         { &hf_scsi_smc_opcode,
           {"SMC Opcode", "scsi.smc.opcode", FT_UINT8, BASE_HEX,
            VALS (scsi_smc_vals), 0x0, "", HFILL}},
+        { &hf_scsi_smc_mta,
+          {"Medium Transport Address", "scsi.smc.mta", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+        { &hf_scsi_smc_sa,
+          {"Source Address", "scsi.smc.sa", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+        { &hf_scsi_smc_da,
+          {"Destination Address", "scsi.smc.da", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+        { &hf_scsi_smc_fda,
+          {"First Destination Address", "scsi.smc.fda", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+        { &hf_scsi_smc_sda,
+          {"Second Destination Address", "scsi.smc.sda", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+	{ &hf_scsi_smc_medium_flags,
+          {"Flags", "scsi.smc.medium_flags", FT_UINT8, BASE_HEX,
+           NULL, 0x0, "", HFILL}},
+	{ &hf_scsi_smc_inv1,
+          {"INV1", "scsi.smc.inv1", FT_BOOLEAN, 8,
+           NULL, 0x02, "", HFILL}},
+	{ &hf_scsi_smc_inv2,
+          {"INV2", "scsi.smc.inv2", FT_BOOLEAN, 8,
+           NULL, 0x01, "", HFILL}},
+	{ &hf_scsi_smc_range_flags,
+          {"Flags", "scsi.smc.range_flags", FT_UINT8, BASE_HEX,
+           NULL, 0x0, "", HFILL}},
+	{ &hf_scsi_smc_fast,
+          {"FAST", "scsi.smc.fast", FT_BOOLEAN, 8,
+           NULL, 0x02, "", HFILL}},
+	{ &hf_scsi_smc_range,
+          {"RANGE", "scsi.smc.range", FT_BOOLEAN, 8,
+           NULL, 0x01, "", HFILL}},
+        { &hf_scsi_smc_sea,
+          {"Starting Element Address", "scsi.smc.sea", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+        { &hf_scsi_smc_num_elements,
+          {"Number of Elements", "scsi.smc.num_elements", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+	{ &hf_scsi_smc_invert,
+          {"INVERT", "scsi.smc.invert", FT_BOOLEAN, 8,
+           NULL, 0x01, "", HFILL}},
+        { &hf_scsi_smc_ea,
+          {"Element Address", "scsi.smc.ea", FT_UINT16, BASE_DEC,
+           NULL, 0x0, "", HFILL}},
+        { &hf_scsi_smc_action_code,
+          {"Action Code", "scsi.smc.action_code", FT_UINT8, BASE_HEX,
+           VALS(action_code_vals), 0x1f, "", HFILL}},
 	};
 
 
 	/* Setup protocol subtree array */
-/*
 	static gint *ett[] = {
+		&ett_scsi_exchange_medium,
+		&ett_scsi_range,
+		&ett_scsi_move
 	};
-*/
 
 	/* Register the protocol name and description */
 	proto_scsi_smc = proto_register_protocol("SCSI_SMC", "SCSI_SMC", "scsi_smc");
 
 	/* Required function calls to register the header fields and subtrees used */
 	proto_register_field_array(proto_scsi_smc, hf, array_length(hf));
-/*
+
 	proto_register_subtree_array(ett, array_length(ett));
-*/
 }
 
 void
