@@ -1,7 +1,7 @@
 /* based on SSC3 spec */
-/* TODO: 
- * dissect READPOSITION data 
- * dissect REPORTDENSITYSUPPORT data 
+/* TODO:
+ * dissect READPOSITION data
+ * dissect REPORTDENSITYSUPPORT data
  */
 /* packet-scsi-ssc.c
  * Dissector for the SCSI SSC commandset
@@ -10,7 +10,7 @@
  * Dinesh G Dutt (ddutt@cisco.com)
  * Ronnie sahlberg 2006
  *
- * $Id: packet-scsi-ssc.c 21990 2007-05-29 18:52:42Z guy $
+ * $Id: packet-scsi-ssc.c 24643 2008-03-15 22:41:57Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1379,7 +1379,7 @@ proto_register_scsi_ssc(void)
           {"Count", "scsi.ssc.space6.count", FT_INT24, BASE_DEC, NULL, 0x0,
            "", HFILL}},
         { &hf_scsi_ssc_space6_code,
-          {"Code", "scsi.ssc.space6.code", FT_INT8, BASE_HEX, 
+          {"Code", "scsi.ssc.space6.code", FT_UINT8, BASE_HEX,
           VALS(space6_code_vals), 0x0f,
            "", HFILL}},
         { &hf_scsi_ssc_space16_count,
@@ -1389,100 +1389,100 @@ proto_register_scsi_ssc(void)
           {"Transfer Length", "scsi.ssc.rdwr10.xferlen", FT_UINT16, BASE_DEC, NULL,
            0x0, "", HFILL}},
         { &hf_scsi_ssc_erase_flags,
-          {"Flags", "scsi.ssc.erase_flags", FT_UINT8, BASE_HEX, 
+          {"Flags", "scsi.ssc.erase_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_fcs,
-          {"FCS", "scsi.ssc.fcs", FT_BOOLEAN, 8, 
+          {"FCS", "scsi.ssc.fcs", FT_BOOLEAN, 8,
            NULL, 0x08, "", HFILL}},
         { &hf_scsi_ssc_lcs,
-          {"LCS", "scsi.ssc.lcs", FT_BOOLEAN, 8, 
+          {"LCS", "scsi.ssc.lcs", FT_BOOLEAN, 8,
            NULL, 0x04, "", HFILL}},
         { &hf_scsi_ssc_erase_immed,
-          {"IMMED", "scsi.ssc.erase_immed", FT_BOOLEAN, 8, 
+          {"IMMED", "scsi.ssc.erase_immed", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_long,
-          {"LONG", "scsi.ssc.long", FT_BOOLEAN, 8, 
+          {"LONG", "scsi.ssc.long", FT_BOOLEAN, 8,
            NULL, 0x01, "", HFILL}},
         { &hf_scsi_ssc_partition,
-          {"Partition", "scsi.ssc.partition", FT_UINT8, BASE_HEX, 
+          {"Partition", "scsi.ssc.partition", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_lbi,
-          {"Logical Block Identifier", "scsi.ssc.lbi", FT_UINT64, BASE_HEX, 
+          {"Logical Block Identifier", "scsi.ssc.lbi", FT_UINT64, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_verify,
-          {"VERIFY", "scsi.ssc.verify", FT_BOOLEAN, 8, 
+          {"VERIFY", "scsi.ssc.verify", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_immed,
-          {"IMMED", "scsi.ssc.immed", FT_BOOLEAN, 8, 
+          {"IMMED", "scsi.ssc.immed", FT_BOOLEAN, 8,
            NULL, 0x01, "", HFILL}},
         { &hf_scsi_ssc_formatmedium_flags,
-          {"Flags", "scsi.ssc.formatmedium_flags", FT_UINT8, BASE_HEX, 
+          {"Flags", "scsi.ssc.formatmedium_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_format,
-          {"Format", "scsi.ssc.format", FT_UINT8, BASE_HEX, 
+          {"Format", "scsi.ssc.format", FT_UINT8, BASE_HEX,
            VALS(format_vals), 0x0f, "", HFILL}},
         { &hf_scsi_ssc_loadunload_immed_flags,
-          {"Immed", "scsi.ssc.loadunload_immed_flags", FT_UINT8, BASE_HEX, 
+          {"Immed", "scsi.ssc.loadunload_immed_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_loadunload_flags,
-          {"Flags", "scsi.ssc.loadunload_flags", FT_UINT8, BASE_HEX, 
+          {"Flags", "scsi.ssc.loadunload_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_hold,
-          {"HOLD", "scsi.ssc.hold", FT_BOOLEAN, 8, 
+          {"HOLD", "scsi.ssc.hold", FT_BOOLEAN, 8,
            NULL, 0x08, "", HFILL}},
         { &hf_scsi_ssc_eot,
-          {"EOT", "scsi.ssc.eot", FT_BOOLEAN, 8, 
+          {"EOT", "scsi.ssc.eot", FT_BOOLEAN, 8,
            NULL, 0x04, "", HFILL}},
         { &hf_scsi_ssc_reten,
-          {"RETEN", "scsi.ssc.reten", FT_BOOLEAN, 8, 
+          {"RETEN", "scsi.ssc.reten", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_load,
-          {"LOAD", "scsi.ssc.load", FT_BOOLEAN, 8, 
+          {"LOAD", "scsi.ssc.load", FT_BOOLEAN, 8,
            NULL, 0x01, "", HFILL}},
         { &hf_scsi_ssc_locate_flags,
-          {"Flags", "scsi.ssc.locate_flags", FT_UINT8, BASE_HEX, 
+          {"Flags", "scsi.ssc.locate_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_bt,
-          {"BT", "scsi.ssc.bt", FT_BOOLEAN, 8, 
+          {"BT", "scsi.ssc.bt", FT_BOOLEAN, 8,
            NULL, 0x04, "", HFILL}},
         { &hf_scsi_ssc_cp,
-          {"CP", "scsi.ssc.cp", FT_BOOLEAN, 8, 
+          {"CP", "scsi.ssc.cp", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_dest_type,
-          {"Dest Type", "scsi.ssc.dest_type", FT_UINT8, BASE_HEX, 
+          {"Dest Type", "scsi.ssc.dest_type", FT_UINT8, BASE_HEX,
            VALS(dest_type_vals), 0x18, "", HFILL}},
         { &hf_scsi_ssc_bam_flags,
-          {"Flags", "scsi.ssc.bam_flags", FT_UINT8, BASE_HEX, 
+          {"Flags", "scsi.ssc.bam_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_bam,
-          {"BAM", "scsi.ssc.bam", FT_BOOLEAN, 8, 
+          {"BAM", "scsi.ssc.bam", FT_BOOLEAN, 8,
            NULL, 0x01, "", HFILL}},
         { &hf_scsi_ssc_read6_flags,
-          {"Flags", "scsi.ssc.read6_flags", FT_UINT8, BASE_HEX, 
+          {"Flags", "scsi.ssc.read6_flags", FT_UINT8, BASE_HEX,
            NULL, 0x0, "", HFILL}},
         { &hf_scsi_ssc_sili,
-          {"SILI", "scsi.ssc.sili", FT_BOOLEAN, 8, 
+          {"SILI", "scsi.ssc.sili", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_fixed,
-          {"FIXED", "scsi.ssc.fixed", FT_BOOLEAN, 8, 
+          {"FIXED", "scsi.ssc.fixed", FT_BOOLEAN, 8,
            NULL, 0x01, "", HFILL}},
         { &hf_scsi_ssc_bytord,
-          {"BYTORD", "scsi.ssc.bytord", FT_BOOLEAN, 8, 
+          {"BYTORD", "scsi.ssc.bytord", FT_BOOLEAN, 8,
            NULL, 0x04, "", HFILL}},
         { &hf_scsi_ssc_bytcmp,
-          {"BYTCMP", "scsi.ssc.bytcmp", FT_BOOLEAN, 8, 
+          {"BYTCMP", "scsi.ssc.bytcmp", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_verify16_immed,
-          {"IMMED", "scsi.ssc.verify16_immed", FT_BOOLEAN, 8, 
+          {"IMMED", "scsi.ssc.verify16_immed", FT_BOOLEAN, 8,
            NULL, 0x04, "", HFILL}},
         { &hf_scsi_ssc_medium_type,
-          {"Medium Type", "scsi.ssc.medium_type", FT_BOOLEAN, 8, 
+          {"Medium Type", "scsi.ssc.medium_type", FT_BOOLEAN, 8,
            NULL, 0x02, "", HFILL}},
         { &hf_scsi_ssc_media,
-          {"Media", "scsi.ssc.media", FT_BOOLEAN, 8, 
+          {"Media", "scsi.ssc.media", FT_BOOLEAN, 8,
            NULL, 0x01, "", HFILL}},
         { &hf_scsi_ssc_capacity_prop_value,
-          {"Capacity Proportion Value", "scsi.ssc.cpv", FT_UINT16, BASE_DEC, 
+          {"Capacity Proportion Value", "scsi.ssc.cpv", FT_UINT16, BASE_DEC,
            NULL, 0, "", HFILL}},
 	};
 
