@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-sdp.c 20043 2006-12-05 06:53:28Z etxrab $
+ * $Id: packet-sdp.c 24286 2008-02-07 15:44:45Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -23,6 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Ref http://www.ietf.org/rfc/rfc4566.txt?number=4566
  */
 
 #include "config.h"
@@ -49,11 +50,13 @@
 # include "inet_v6defs.h"
 #endif
 
-#include <glib.h> 
+#include <glib.h>
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/strutil.h>
 #include <epan/emem.h>
+#include <epan/base64.h>
+#include <epan/asn1.h>
 
 #include "tap.h"
 #include "packet-sdp.h"
@@ -62,17 +65,20 @@
 #include <epan/rtp_pt.h>
 
 #include <epan/prefs.h>
+#include <epan/expert.h>
 
 #include "packet-rtcp.h"
 #include "packet-t38.h"
 #include "packet-msrp.h"
 #include "packet-per.h"
 #include "packet-h245.h"
+#include "packet-h264.h"
 
 static dissector_handle_t rtp_handle=NULL;
 static dissector_handle_t rtcp_handle=NULL;
 static dissector_handle_t t38_handle=NULL;
 static dissector_handle_t msrp_handle=NULL;
+static dissector_handle_t h264_handle = NULL;
 
 static int sdp_tap = -1;
 
@@ -156,10 +162,17 @@ static int hf_media_attribute_field = -1;
 static int hf_media_attribute_value = -1;
 static int hf_media_encoding_name = -1;
 static int hf_media_format_specific_parameter = -1;
-static int hf_sdp_fmtp_profile_level_id = -1;
+static int hf_sdp_fmtp_mpeg4_profile_level_id = -1;
 static int hf_sdp_fmtp_h263_profile = -1;
+static int hf_sdp_h264_packetization_mode = -1;
+static int hf_sdp_h264_sprop_parameter_sets = -1;
 static int hf_SDPh223LogicalChannelParameters = -1;
 
+/* hf_session_attribute hf_media_attribute subfields */
+static int hf_key_mgmt_att_value = -1;
+static int hf_key_mgmt_prtcl_id = -1;
+static int hf_key_mgmt_data = -1;
+
 /* trees */
 static int ett_sdp = -1;
 static int ett_sdp_owner = -1;
@@ -173,6 +186,7 @@ static int ett_sdp_session_attribute = -1;
 static int ett_sdp_media = -1;
 static int ett_sdp_media_attribute = -1;
 static int ett_sdp_fmtp = -1;
+static int ett_sdp_key_mgmt = -1;
 
 
 #define SDP_MAX_RTP_CHANNELS 4
@@ -200,6 +214,12 @@ static gboolean msrp_transport_address_set = FALSE;
 static guint32  msrp_ipaddr[4];
 static guint16  msrp_port_number;
 
+/* key-mgmt dissector
+ * IANA registry:
+ * http://www.iana.org/assignments/sdp-parameters
+ */
+static dissector_table_t key_mgmt_dissector_table;
+
 
 /* Protocol registration */
 void proto_register_sdp(void);
@@ -220,7 +240,7 @@ static void dissect_sdp_time(tvbuff_t *tvb, proto_item* ti);
 static void dissect_sdp_repeat_time(tvbuff_t *tvb, proto_item* ti);
 static void dissect_sdp_timezone(tvbuff_t *tvb, proto_item* ti);
 static void dissect_sdp_encryption_key(tvbuff_t *tvb, proto_item * ti);
-static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item *ti);
+static void dissect_sdp_session_attribute(tvbuff_t *tvb, packet_info *pinfo, proto_item *ti);
 static void dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
                               transport_info_t *transport_info);
 static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto_item *ti, transport_info_t *transport_info);
@@ -247,6 +267,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   guint32     port=0;
   gboolean    is_rtp=FALSE;
+  gboolean    is_srtp=FALSE;
   gboolean    is_t38=FALSE;
   gboolean    is_msrp=FALSE;
   gboolean    set_rtp=FALSE;
@@ -269,7 +290,13 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     transport_info.media_port[n]=NULL;
     transport_info.media_proto[n]=NULL;
     transport_info.media[n].pt_count = 0;
-    transport_info.media[n].rtp_dyn_payload = g_hash_table_new( g_int_hash, g_int_equal);
+#if GLIB_MAJOR_VERSION < 2
+    transport_info.media[n].rtp_dyn_payload = g_hash_table_new( g_int_hash, 
+	g_int_equal);
+#else
+    transport_info.media[n].rtp_dyn_payload = g_hash_table_new_full( g_int_hash, 
+	g_int_equal, g_free, g_free);
+#endif
   }
   transport_info.media_count = 0;
 
@@ -302,12 +329,15 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
    * Show the SDP message a line at a time.
    */
   in_media_description = FALSE;
+
   while (tvb_reported_length_remaining(tvb, offset) > 0) {
     /*
      * Find the end of the line.
      */
     linelen = tvb_find_line_end_unquoted(tvb, offset, -1, &next_offset);
 
+
+
     /*
      * Line must contain at least e.g. "v=".
      */
@@ -317,7 +347,9 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     type = tvb_get_guint8(tvb,offset);
     delim = tvb_get_guint8(tvb,offset + 1);
     if (delim != '=') {
-      proto_tree_add_item(sdp_tree, hf_invalid, tvb, offset, linelen, FALSE);
+      proto_item *ti = proto_tree_add_item(sdp_tree, hf_invalid, tvb, offset, linelen, FALSE);
+      expert_add_info_format(pinfo, ti, PI_MALFORMED, PI_NOTE,
+                             "Invalid SDP line (no '=' delimiter)");
       offset = next_offset;
       continue;
     }
@@ -396,7 +428,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     call_sdp_subdissector(tvb_new_subset(tvb,offset+tokenoffset,
                                          linelen-tokenoffset,
                                          linelen-tokenoffset),
-						  pinfo,	
+						  pinfo,
                           hf,sub_ti,&transport_info),
     offset = next_offset;
   }
@@ -415,18 +447,20 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     }
     if(transport_info.media_proto[n]!=NULL) {
       /* Check if media protocol is RTP
-       * and stream decoding is enabled in preferences 
+       * and stream decoding is enabled in preferences
        */
        if(global_sdp_establish_conversation){
             /* Check if media protocol is RTP */
             is_rtp = (strcmp(transport_info.media_proto[n],"RTP/AVP")==0);
+            /* Check if media protocol is SRTP */
+            is_srtp = (strcmp(transport_info.media_proto[n],"RTP/SAVP")==0);
             /* Check if media protocol is T38 */
             is_t38 = ( (strcmp(transport_info.media_proto[n],"UDPTL")==0) || (strcmp(transport_info.media_proto[n],"udptl")==0) );
             /* Check if media protocol is MSRP/TCP */
             is_msrp = (strcmp(transport_info.media_proto[n],"msrp/tcp")==0);
        }
     }
-    
+
 
     if(transport_info.connection_address!=NULL) {
       if(transport_info.connection_type!=NULL) {
@@ -449,12 +483,18 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       }
     }
     set_rtp = FALSE;
-    /* Add rtp and rtcp conversation, if available (overrides t38 if conversation already set) */
-    if((!pinfo->fd->flags.visited) && port!=0 && is_rtp && (is_ipv4_addr || is_ipv6_addr)){
+    /* Add (s)rtp and (s)rtcp conversation, if available (overrides t38 if conversation already set) */
+    if((!pinfo->fd->flags.visited) && port!=0 && (is_rtp||is_srtp) && (is_ipv4_addr || is_ipv6_addr)){
       src_addr.data=(guint8*)&ipaddr;
       if(rtp_handle){
-        rtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num,
-                        transport_info.media[n].rtp_dyn_payload);
+        if (is_srtp) {
+          struct srtp_info *dummy_srtp_info = se_alloc0(sizeof(struct srtp_info));
+          srtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num,
+                           transport_info.media[n].rtp_dyn_payload, dummy_srtp_info);
+        } else {
+          rtp_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num,
+                          transport_info.media[n].rtp_dyn_payload);
+        }
         set_rtp = TRUE;
       }
       if(rtcp_handle){
@@ -494,16 +534,16 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
           g_snprintf(sdp_pi->summary_str, 50, "%s %s", sdp_pi->summary_str, str_dyn_pt);
         else
           g_snprintf(sdp_pi->summary_str, 50, "%s %d", sdp_pi->summary_str, transport_info.media[n].pt[i]);
-      } else 
+      } else
         g_snprintf(sdp_pi->summary_str, 50, "%s %s", sdp_pi->summary_str, val_to_str(transport_info.media[n].pt[i], rtp_payload_type_short_vals, "%u"));
     }
 
     /* Free the hash table if we did't assigned it to a conv use it */
-    if (set_rtp == FALSE) 
+    if (set_rtp == FALSE)
       rtp_free_hash_dyn_payload(transport_info.media[n].rtp_dyn_payload);
 
     /* Create the T38 summary str for the Voip Call analysis */
-    if (is_t38) g_snprintf(sdp_pi->summary_str, 50, "%s t38", sdp_pi->summary_str);  
+    if (is_t38) g_snprintf(sdp_pi->summary_str, 50, "%s t38", sdp_pi->summary_str);
   }
 
   /* Free the remainded hash tables not used */
@@ -540,7 +580,7 @@ call_sdp_subdissector(tvbuff_t *tvb, packet_info *pinfo, int hf, proto_tree* ti,
   } else if ( hf == hf_encryption_key ) {
     dissect_sdp_encryption_key(tvb,ti);
   } else if ( hf == hf_session_attribute ){
-    dissect_sdp_session_attribute(tvb,ti);
+    dissect_sdp_session_attribute(tvb,pinfo,ti);
   } else if ( hf == hf_media ) {
     dissect_sdp_media(tvb,ti,transport_info);
   } else if ( hf == hf_media_attribute ){
@@ -861,13 +901,81 @@ static void dissect_sdp_encryption_key(tvbuff_t *tvb, proto_item * ti){
                       tvb, offset, -1, FALSE);
 }
 
+/* Return a tvb that contains the binary representation of a base64
+   string */
+
+static tvbuff_t *
+base64_to_tvb(const char *base64)
+{
+  tvbuff_t *tvb;
+  char *data = g_strdup(base64);
+  size_t len;
+
+  len = epan_base64_decode(data);
+  tvb = tvb_new_real_data((const guint8 *)data, len, len);
+
+  tvb_set_free_cb(tvb, g_free);
+
+  return tvb;
+}
 
 
-static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item * ti){
+static void dissect_key_mgmt(tvbuff_t *tvb, packet_info * pinfo, proto_item * ti){
+  gchar *data = NULL;
+  gchar *prtcl_id = NULL;
+  gint len;
+  tvbuff_t *keymgmt_tvb;
+  gboolean found_match = FALSE;
+  proto_tree *key_tree;
+  gint next_offset;
+  gint offset = 0;
+  gint tokenlen;
+
+  key_tree = proto_item_add_subtree(ti, ett_sdp_key_mgmt);
+
+  next_offset = tvb_find_guint8(tvb,offset,-1,' ');
+
+  if (next_offset == -1)
+    return;
+
+  tokenlen = next_offset - offset;
+  prtcl_id = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+
+  proto_tree_add_item(key_tree, hf_key_mgmt_prtcl_id, tvb, offset, tokenlen, FALSE);
+
+  offset = next_offset + 1;
+
+  len = tvb_length_remaining(tvb, offset);
+  if (len < 0)
+    return;
+
+  data = tvb_get_ephemeral_string(tvb, offset, len);
+  keymgmt_tvb = base64_to_tvb(data);
+  tvb_set_child_real_data_tvbuff(tvb, keymgmt_tvb);
+  add_new_data_source(pinfo, keymgmt_tvb, "Key Management Data");
+
+  if ( prtcl_id != NULL && key_mgmt_dissector_table != NULL ) {
+    found_match = dissector_try_string(key_mgmt_dissector_table,
+				       prtcl_id,
+				       keymgmt_tvb, pinfo,
+				       key_tree);
+  }
+
+  if (found_match)
+    proto_tree_add_item_hidden(key_tree, hf_key_mgmt_data,
+			       keymgmt_tvb, 0, -1, FALSE);
+  else
+    proto_tree_add_item(key_tree, hf_key_mgmt_data,
+			keymgmt_tvb, 0, -1, FALSE);
+  return;
+}
+
+
+static void dissect_sdp_session_attribute(tvbuff_t *tvb, packet_info * pinfo, proto_item * ti){
   proto_tree *sdp_session_attribute_tree;
   gint offset, next_offset, tokenlen;
   guint8 *field_name;
-  
+
   offset = 0;
   next_offset = 0;
   tokenlen = 0;
@@ -886,7 +994,7 @@ static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item * ti){
                       tvb, offset, tokenlen, FALSE);
 
   field_name = tvb_get_ephemeral_string(tvb, offset, tokenlen);
-  
+
   offset = next_offset + 1;
 
   if (strcmp((char*)field_name, "ipbcp") == 0) {
@@ -894,14 +1002,14 @@ static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item * ti){
 
     if (offset == -1)
       return;
-    
+
     next_offset = tvb_find_guint8(tvb,offset,-1,' ');
-    
+
     if (next_offset == -1)
       return;
-    
+
     tokenlen = next_offset - offset;
-    
+
     proto_tree_add_item(sdp_session_attribute_tree,hf_ipbcp_version,tvb,offset,tokenlen,FALSE);
 
     offset = tvb_pbrk_guint8(tvb,offset,-1,(guint8 *)"ABCDEFGHIJKLMNOPQRSTUVWXYZ");
@@ -910,18 +1018,26 @@ static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item * ti){
       return;
 
     tokenlen = tvb_find_line_end(tvb,offset,-1, &next_offset, FALSE);
-    
-    if (tokenlen == -1) 
+
+    if (tokenlen == -1)
       return;
-    
+
     proto_tree_add_item(sdp_session_attribute_tree,hf_ipbcp_type,tvb,offset,tokenlen,FALSE);
-    
+  } else if (strcmp((char*)field_name, "key-mgmt") == 0) {
+    tvbuff_t *key_tvb;
+    proto_item *key_ti;
+
+    key_tvb = tvb_new_subset(tvb, offset, -1, -1);
+    key_ti = proto_tree_add_item(sdp_session_attribute_tree, hf_key_mgmt_att_value, key_tvb, 0, -1, FALSE);
+
+    dissect_key_mgmt(key_tvb, pinfo, key_ti);
   } else {
     proto_tree_add_item(sdp_session_attribute_tree, hf_session_attribute_value,
                         tvb, offset, -1, FALSE);
   }
 }
 
+/* Dissect media description */
 static void
 dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
                   transport_info_t *transport_info){
@@ -936,6 +1052,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
   /* Re-initialise for a new media description */
   msrp_transport_address_set = FALSE;
 
+  /* Create tree for media session */
   sdp_media_tree = proto_item_add_subtree(ti,ett_sdp_media);
 
   next_offset = tvb_find_guint8(tvb,offset, -1, ' ');
@@ -945,6 +1062,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
 
   tokenlen = next_offset - offset;
 
+  /* Type of media session */
   proto_tree_add_item(sdp_media_tree, hf_media_media, tvb, offset, tokenlen,
                       FALSE);
 
@@ -962,7 +1080,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
     transport_info->media_port[transport_info->media_count] = (char*)tvb_get_ephemeral_string(tvb, offset, tokenlen);
 
     proto_tree_add_uint(sdp_media_tree, hf_media_port, tvb, offset, tokenlen,
-                        atoi((char*)tvb_get_string(tvb, offset, tokenlen)));
+                        atoi((char*)tvb_get_ephemeral_string(tvb, offset, tokenlen)));
     offset = next_offset + 1;
     next_offset = tvb_find_guint8(tvb,offset, -1, ' ');
     if(next_offset == -1)
@@ -982,7 +1100,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
 
     /* XXX Remember Port */
     proto_tree_add_uint(sdp_media_tree, hf_media_port, tvb, offset, tokenlen,
-                        atoi((char*)tvb_get_string(tvb, offset, tokenlen)));
+                        atoi((char*)tvb_get_ephemeral_string(tvb, offset, tokenlen)));
     offset = next_offset + 1;
   }
 
@@ -999,7 +1117,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
   proto_tree_add_item(sdp_media_tree, hf_media_proto, tvb, offset, tokenlen,
                       FALSE);
 
-  do{
+  do {
     offset = next_offset + 1;
     next_offset = tvb_find_guint8(tvb,offset,-1,' ');
 
@@ -1010,7 +1128,7 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
     } else {
       tokenlen = next_offset - offset;
     }
-    
+
     if (strcmp(transport_info->media_proto[transport_info->media_count],
                "RTP/AVP") == 0) {
       media_format = tvb_get_ephemeral_string(tvb, offset, tokenlen);
@@ -1041,9 +1159,82 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
 
 }
 
+tvbuff_t *ascii_bytes_to_tvb(tvbuff_t *tvb, packet_info *pinfo, gint len, gchar *msg)
+{
+	guint8 *buf = ep_alloc(10240);
+
+	/* arbitrary maximum length */
+	if(len<20480){
+		int i;
+		tvbuff_t *bytes_tvb;
+
+		/* first, skip to where the encoded pdu starts, this is
+		   the first hex digit after the '=' char.
+		*/
+		while(1){
+			if((*msg==0)||(*msg=='\n')){
+				return NULL;
+			}
+			if(*msg=='='){
+				msg++;
+				break;
+			}
+			msg++;
+		}
+		while(1){
+			if((*msg==0)||(*msg=='\n')){
+				return NULL;
+			}
+			if( ((*msg>='0')&&(*msg<='9'))
+			||  ((*msg>='a')&&(*msg<='f'))
+			||  ((*msg>='A')&&(*msg<='F'))){
+				break;
+			}
+			msg++;
+		}
+		i=0;
+		while( ((*msg>='0')&&(*msg<='9'))
+		     ||((*msg>='a')&&(*msg<='f'))
+		     ||((*msg>='A')&&(*msg<='F'))  ){
+			int val;
+			if((*msg>='0')&&(*msg<='9')){
+				val=(*msg)-'0';
+			} else if((*msg>='a')&&(*msg<='f')){
+				val=(*msg)-'a'+10;
+			} else if((*msg>='A')&&(*msg<='F')){
+				val=(*msg)-'A'+10;
+			} else {
+				return NULL;
+			}
+			val<<=4;
+			msg++;
+			if((*msg>='0')&&(*msg<='9')){
+				val|=(*msg)-'0';
+			} else if((*msg>='a')&&(*msg<='f')){
+				val|=(*msg)-'a'+10;
+			} else if((*msg>='A')&&(*msg<='F')){
+				val|=(*msg)-'A'+10;
+			} else {
+				return NULL;
+			}
+			msg++;
+
+			buf[i]=(guint8)val;
+			i++;
+		}
+		if(i==0){
+			return NULL;
+		}
+		bytes_tvb = tvb_new_real_data(buf,i,i);
+		tvb_set_child_real_data_tvbuff(tvb,bytes_tvb);
+		add_new_data_source(pinfo, bytes_tvb, "ASCII bytes to tvb");
+		return bytes_tvb;
+	}
+	return NULL;
+}
 /*
 14496-2, Annex G, Table G-1.
-Table G-1 FLC table for profile_and_level_indication Profile/Level Code 
+Table G-1 FLC table for profile_and_level_indication Profile/Level Code
 */
 static const value_string mpeg4es_level_indication_vals[] =
 {
@@ -1082,7 +1273,7 @@ static const value_string mpeg4es_level_indication_vals[] =
   /* Reserved 01110011 - 10000000 */
   { 0x81, "Hybrid Profile/Level 1" },
   { 0x82, "Hybrid Profile/Level 2" },
-  /* Reserved 10000011 - 10010000 */ 
+  /* Reserved 10000011 - 10010000 */
   { 0x91, "Advanced Real Time Simple Profile/Level 1" },
   { 0x92, "Advanced Real Time Simple Profile/Level 2" },
   { 0x93, "Advanced Real Time Simple Profile/Level 3" },
@@ -1145,16 +1336,25 @@ static const value_string h263_profile_vals[] =
   { 0, NULL },
 };
 
-/* 
+static const value_string h264_packetization_mode_vals[] =
+{
+  { 0,    "Single NAL mode" },
+  { 1,    "Non-interleaved mode" },
+  { 2,    "Interleaved mode" },
+  { 0, NULL },
+};
+
+/*
  * TODO: Make this a more generic routine to dissect fmtp parameters depending on media types
  */
 static void
-decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, gint offset, gint tokenlen, guint8 *mime_type){
+decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset, gint tokenlen, guint8 *mime_type){
   gint next_offset;
   gint end_offset;
   guint8 *field_name;
-  guint8 *format_specific_parameter;
+  gchar *format_specific_parameter;
   proto_item *item;
+  tvbuff_t *data_tvb;
 
   end_offset = offset + tokenlen;
 
@@ -1179,7 +1379,7 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, gint offset, gint tokenlen, gui
       offset++;
       tokenlen = end_offset - offset;
       format_specific_parameter = tvb_get_ephemeral_string(tvb, offset, tokenlen);
-      item = proto_tree_add_uint(tree, hf_sdp_fmtp_profile_level_id, tvb, offset, tokenlen,
+      item = proto_tree_add_uint(tree, hf_sdp_fmtp_mpeg4_profile_level_id, tvb, offset, tokenlen,
                                  atol((char*)format_specific_parameter));
       PROTO_ITEM_SET_GENERATED(item);
     }
@@ -1197,20 +1397,73 @@ decode_sdp_fmtp(proto_tree *tree, tvbuff_t *tvb, gint offset, gint tokenlen, gui
     }
   }
 
-#if 0
-  /* TODO: Add code to dissect H264 fmtp parameters wehen an example can be found */
+
+  /* Dissect the H264 profile-level-id parameter */
   if (mime_type != NULL && strcmp(mime_type, "H264") == 0) {
     if (strcmp(field_name, "profile-level-id") == 0) {
-      char **endptr;
-
+ 	
+	  /* Length includes "=" */
+      tokenlen = end_offset - offset;
+      format_specific_parameter = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+	  data_tvb = ascii_bytes_to_tvb(tvb, pinfo, tokenlen, format_specific_parameter);
+	  if(h264_handle && data_tvb){
+		  dissect_h264_profile(data_tvb, pinfo, tree);
+	  }
+	}else if (strcmp(field_name, "packetization-mode") == 0) {
       offset++;
       tokenlen = end_offset - offset;
       format_specific_parameter = tvb_get_ephemeral_string(tvb, offset, tokenlen);
-      proto_tree_add_text(tree, tvb, offset, tokenlen,
-		                    "Test %u", strtoul(format_specific_parameter, endptr, 16));
+      item = proto_tree_add_uint(tree, hf_sdp_h264_packetization_mode, tvb, offset, tokenlen,
+                                 atol((char*)format_specific_parameter));
+
+	}else if (strcmp(field_name, "sprop-parameter-sets") == 0) {
+		/* The value of the parameter is the
+                        base64 [6] representation of the initial
+                        parameter set NAL units as specified in
+                        sections 7.3.2.1 and 7.3.2.2 of [1].  The
+                        parameter sets are conveyed in decoding order,
+                        and no framing of the parameter set NAL units
+                        takes place.  A comma is used to separate any
+                        pair of parameter sets in the list.
+		*/
+		gchar *data = NULL;
+		gint comma_offset;
+
+
+		/* Move past '=' */
+		offset++;
+		comma_offset = tvb_find_guint8(tvb,offset,-1,',');
+		if (comma_offset != -1){
+			tokenlen = comma_offset - offset;
+		}else{
+			tokenlen = end_offset - offset;
+		}
+		
+		data = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+	    proto_tree_add_text(tree, tvb, offset, tokenlen, "NAL unit 1 string: %s", data);
+
+		/* proto_tree_add_text(tree, tvb, offset, tokenlen, "String %s",data); */
+		data_tvb = base64_to_tvb(data);
+		tvb_set_child_real_data_tvbuff(tvb, data_tvb);
+		add_new_data_source(pinfo, data_tvb, "h264 prop-parameter-sets");
+
+		if(h264_handle && data_tvb){
+			dissect_h264_nal_unit(data_tvb, pinfo, tree);
+			if (comma_offset != -1){
+				/* Second NAL unit */
+				offset = comma_offset +1;
+				tokenlen = end_offset - offset;
+				data = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+				proto_tree_add_text(tree, tvb, offset, tokenlen, "NAL unit 2 string: %s", data);
+				data_tvb = base64_to_tvb(data);
+				tvb_set_child_real_data_tvbuff(tvb, data_tvb);
+				add_new_data_source(pinfo, data_tvb, "h264 prop-parameter-sets 2");
+				dissect_h264_nal_unit(data_tvb, pinfo, tree);
+			}
+		}
 	}
   }
-#endif
+
 }
 
 typedef struct {
@@ -1227,7 +1480,7 @@ static const sdp_names_t sdp_media_attribute_names[] = {
 		{ "rtpmap"},		/* 1 */
 		{ "fmtp"},			/* 2 */
 		{ "path"},			/* 3 */
-		{ "h248item"},		/* 4 */		
+		{ "h248item"},		/* 4 */
 };
 
 static gint find_sdp_media_attribute_names(tvbuff_t *tvb, int offset, guint len)
@@ -1255,6 +1508,8 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
   gint	sdp_media_attrbute_code;
   const char *msrp_res = "msrp://";
   const char *h324ext_h223lcparm = "h324ext/h223lcparm";
+  gboolean has_more_pars = TRUE;
+  tvbuff_t *h245_tvb;
 
   offset = 0;
   next_offset = 0;
@@ -1281,7 +1536,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
   offset = next_offset + 1;
 
   /* Value is the remainder of the line */
-  attribute_value = tvb_get_string(tvb, offset, tvb_length_remaining(tvb, offset));
+  attribute_value = tvb_get_ephemeral_string(tvb, offset, tvb_length_remaining(tvb, offset));
 
 
 
@@ -1316,7 +1571,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 	  proto_tree_add_item(sdp_media_attribute_tree, hf_media_encoding_name, tvb,
                         offset, tokenlen, FALSE);
 	  /* get_string is needed here as the string is "saved" in a hashtable */
-	  transport_info->encoding_name = (char*)tvb_get_string(tvb, offset, tokenlen);
+	  transport_info->encoding_name = (char*)tvb_get_ephemeral_string(tvb, offset, tokenlen);
 
 	  key=g_malloc( sizeof(gint) );
 	  *key=atol((char*)payload_type);
@@ -1330,25 +1585,25 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
             m=audio 49172 RTP/AVP 97 101
             a=rtpmap:97 G726-24/8000
 
-		The Media attributes ("a="s) after the "m=" only apply for that "m=". 
+		The Media attributes ("a="s) after the "m=" only apply for that "m=".
 		If there is an "a=" before the first "m=", that attribute applies for
 		all the session (all the "m="s).
 	  */
 
 	  /* so, if this "a=" appear before any "m=", we add it to all the dynamic
 	   * hash tables
-	   */ 
+	   */
 	  if (transport_info->media_count == 0) {
 		  for (n=0; n < SDP_MAX_RTP_CHANNELS; n++) {
 			  if (n==0)
 				  g_hash_table_insert(transport_info->media[n].rtp_dyn_payload,
-                                    key, transport_info->encoding_name);
+                                    key, g_strdup(transport_info->encoding_name));
 			  else {    /* we create a new key and encoding_name to assign to the other hash tables */
 				  gint *key2;
 				  key2=g_malloc( sizeof(gint) );
 				  *key2=atol((char*)payload_type);
 				  g_hash_table_insert(transport_info->media[n].rtp_dyn_payload,
-					  key2, transport_info->encoding_name);
+					  key2, g_strdup(transport_info->encoding_name));
 			  }
 		  }
 		  return;
@@ -1357,66 +1612,60 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
 		  /* in case there is an overflow in SDP_MAX_RTP_CHANNELS, we keep always the last "m=" */
 		  if (transport_info->media_count == SDP_MAX_RTP_CHANNELS-1)
 			  g_hash_table_insert(transport_info->media[ transport_info->media_count ].rtp_dyn_payload,
-					key, transport_info->encoding_name);
+					key, g_strdup(transport_info->encoding_name));
 		  else
 			  g_hash_table_insert(transport_info->media[ transport_info->media_count-1 ].rtp_dyn_payload,
-					key, transport_info->encoding_name);
-   	  return;
+					key, g_strdup(transport_info->encoding_name));
 	  break;
   case SDP_FMTP:
-	  /* Reading the Format parameter(fmtp) */
-	  next_offset = tvb_find_guint8(tvb,offset,-1,' ');
+	  if(sdp_media_attribute_tree){
+		  /* Reading the Format parameter(fmtp) */
+		  next_offset = tvb_find_guint8(tvb,offset,-1,' ');
 
-	  if(next_offset == -1)
-		  return;
+		  if(next_offset == -1)
+			  return;
 
-	  tokenlen = next_offset - offset;
+		  tokenlen = next_offset - offset;
 
-	  /* Media format extends to the next space */
-	  media_format_item = proto_tree_add_item(sdp_media_attribute_tree,
+		  /* Media format extends to the next space */
+		  media_format_item = proto_tree_add_item(sdp_media_attribute_tree,
                                             hf_media_format, tvb, offset,
                                             tokenlen, FALSE);
-	  /* Append encoding name to format if known */
-	  if (transport_info->encoding_name)
-		  proto_item_append_text(media_format_item, " [%s]",
+		  /* Append encoding name to format if known */
+		  if (transport_info->encoding_name)
+			  proto_item_append_text(media_format_item, " [%s]",
                              transport_info->encoding_name);
 
-	  payload_type = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+		  payload_type = tvb_get_ephemeral_string(tvb, offset, tokenlen);
+		  /* Offset past space after ':' */
+		  offset = next_offset + 1;
 
-	  offset = next_offset + 1;
+		  while(has_more_pars==TRUE){
+			  next_offset = tvb_find_guint8(tvb,offset,-1,';');
+			  offset = tvb_skip_wsp(tvb,offset,tvb_length_remaining(tvb,offset));
 
-	  /* There may be 2 parameters given
-	   * TODO: Handle arbitary number of parameters.
-	   */
-	  next_offset = tvb_find_guint8(tvb,offset,-1,';');
+			  if(next_offset == -1){
+				  has_more_pars = FALSE;
+				  next_offset= tvb_length(tvb);
+			  }else{
+	
+			  }
 
-	  if(next_offset != -1){
-		  /* There are 2 - add the first parameter */
-		  tokenlen = next_offset - offset;
-		  fmtp_item = proto_tree_add_item(sdp_media_attribute_tree,
+			  /* There are 2 - add the first parameter */
+			  tokenlen = next_offset - offset;
+			  fmtp_item = proto_tree_add_item(sdp_media_attribute_tree,
                                       hf_media_format_specific_parameter, tvb,
                                       offset, tokenlen, FALSE);
 
-		  fmtp_tree = proto_item_add_subtree(fmtp_item, ett_sdp_fmtp);
-		  
-		  decode_sdp_fmtp(fmtp_tree, tvb, offset, tokenlen,
+			  fmtp_tree = proto_item_add_subtree(fmtp_item, ett_sdp_fmtp);
+
+			  decode_sdp_fmtp(fmtp_tree, tvb, pinfo, offset, tokenlen,
                       (guint8 *)transport_info->encoding_name);
 
-		  offset = next_offset + 1;
+			  /* Move offset past "; " and onto firts char */	
+			  offset = next_offset + 1;
+		  }
 	  }
-
-	  /* Now add remaining (or only) parameter */
-	  tokenlen = tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
-
-	  fmtp_item = proto_tree_add_item(sdp_media_attribute_tree,
-                                    hf_media_format_specific_parameter, tvb,
-                                    offset, tokenlen, FALSE);
-
-	  fmtp_tree = proto_item_add_subtree(fmtp_item, ett_sdp_fmtp);
-
-	  decode_sdp_fmtp(fmtp_tree, tvb, offset, tokenlen,
-                    (guint8 *)transport_info->encoding_name);
-	  return;
 	  break;
   case SDP_PATH:
 	  /* msrp attributes that contain address needed for conversation */
@@ -1444,89 +1693,25 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, packet_info *pinfo, proto
   case SDP_H248_ITEM:
 	  /* Decode h248 item ITU-T Rec. H.248.12 (2001)/Amd.1 (11/2002)*/
 	  if (strncmp((char*)attribute_value, h324ext_h223lcparm, strlen(msrp_res)) == 0){
-		  /* A.5.1.3 H.223 Logical channel parameters 
+		  /* A.5.1.3 H.223 Logical channel parameters
 		   * This property indicates the H.245
 		   * H223LogicalChannelsParameters structure encoded by applying the PER specified in
 		   * ITU-T Rec. X.691. Value encoded as per A.5.1.2. For text encoding the mechanism defined
 		   * in ITU-T Rec. H.248.15 is used.
 		   */
-		  guint8 *buf = ep_alloc(256);
 		  gint len;
 		  asn1_ctx_t actx;
 
 		  len = strlen(attribute_value);
+		  h245_tvb = ascii_bytes_to_tvb(tvb, pinfo, len, attribute_value);
 		  /* arbitrary maximum length */
-		  if(len<20480){
-			  int i;
-			  tvbuff_t *h245_tvb;
-
-			  /* first, skip to where the encoded pdu starts, this is
-		    	 the first hex digit after the '=' char.
-			  */
-			  while(1){
-				  if((*attribute_value==0)||(*attribute_value=='\n')){
-					  return;
-				  }
-				  if(*attribute_value=='='){
-					  attribute_value++;
-					  break;
-				  }
-				  attribute_value++;
-			  }
-			  while(1){
-				  if((*attribute_value==0)||(*attribute_value=='\n')){
-					  return;
-				  }
-				  if( ((*attribute_value>='0')&&(*attribute_value<='9'))
-				  ||  ((*attribute_value>='a')&&(*attribute_value<='f'))
-				  ||  ((*attribute_value>='A')&&(*attribute_value<='F'))){
-					  break;
-				  }
-				  attribute_value++;
-			  }
-			  i=0;
-			  while( ((*attribute_value>='0')&&(*attribute_value<='9'))
-		     	  ||((*attribute_value>='a')&&(*attribute_value<='f'))
-		     	  ||((*attribute_value>='A')&&(*attribute_value<='F'))  ){
-				  int val;
-				  if((*attribute_value>='0')&&(*attribute_value<='9')){
-					  val=(*attribute_value)-'0';
-				  } else if((*attribute_value>='a')&&(*attribute_value<='f')){
-					  val=(*attribute_value)-'a'+10;
-				  } else if((*attribute_value>='A')&&(*attribute_value<='F')){
-					  val=(*attribute_value)-'A'+10;
-				  } else {
-					  return;
-				  }
-				  val<<=4;
-				  attribute_value++;
-				  if((*attribute_value>='0')&&(*attribute_value<='9')){
-					  val|=(*attribute_value)-'0';
-				  } else if((*attribute_value>='a')&&(*attribute_value<='f')){
-					  val|=(*attribute_value)-'a'+10;
-				  } else if((*attribute_value>='A')&&(*attribute_value<='F')){
-					  val|=(*attribute_value)-'A'+10;
-				  } else {
-					  return;
-				  }
-				  attribute_value++;
-
-				  buf[i]=(guint8)val;
-				  i++;
-			  }
-			  if(i==0){
-				  return;
-			  }
-			  h245_tvb = tvb_new_real_data(buf,i,i);
-			  tvb_set_child_real_data_tvbuff(tvb,h245_tvb);
-			  add_new_data_source(pinfo, h245_tvb, "H.245 in SDP");
-			  /* should go through a handle, however,  the two h245 entry
-		   	  points are different, one is over tpkt and the other is raw
-			  */
-			  asn1_ctx_init(&actx, ASN1_ENC_PER, TRUE, pinfo);
-			  dissect_h245_H223LogicalChannelParameters(h245_tvb, 0, &actx, sdp_media_attribute_tree, hf_SDPh223LogicalChannelParameters);
+		  /* should go through a handle, however,  the two h245 entry
+	   	  points are different, one is over tpkt and the other is raw
+		  */
+		  if (h245_tvb){
+			asn1_ctx_init(&actx, ASN1_ENC_PER, TRUE, pinfo);
+			dissect_h245_H223LogicalChannelParameters(h245_tvb, 0, &actx, sdp_media_attribute_tree, hf_SDPh223LogicalChannelParameters);
 		  }
-		  
 		}
 	  break;
   default:
@@ -1741,11 +1926,11 @@ proto_register_sdp(void)
       { "Media Attribute Value",
         "sdp.media_attribute.value",FT_STRING, BASE_NONE, NULL, 0x0,
         "Media Attribute Value", HFILL }},
-        { &hf_media_encoding_name,
+    { &hf_media_encoding_name,
       { "MIME Type",
         "sdp.mime.type",FT_STRING, BASE_NONE, NULL, 0x0,
         "SDP MIME Type", HFILL }},
-        { &hf_media_format_specific_parameter,
+    { &hf_media_format_specific_parameter,
       { "Media format specific parameters",
         "sdp.fmtp.parameter",FT_STRING, BASE_NONE, NULL, 0x0,
         "Format specific parameter(fmtp)", HFILL }},
@@ -1757,7 +1942,7 @@ proto_register_sdp(void)
       { "IPBCP Command Type",
         "ipbcp.command",FT_STRING, BASE_NONE, NULL, 0x0,
         "IPBCP Command Type", HFILL }},
-	{&hf_sdp_fmtp_profile_level_id,
+	{&hf_sdp_fmtp_mpeg4_profile_level_id,
       { "Level Code",
         "sdp.fmtp.profile_level_id",FT_UINT32, BASE_DEC,VALS(mpeg4es_level_indication_vals), 0x0,
         "Level Code", HFILL }},
@@ -1765,11 +1950,30 @@ proto_register_sdp(void)
       { "Profile",
         "sdp.fmtp.h263profile",FT_UINT32, BASE_DEC,VALS(h263_profile_vals), 0x0,
         "Profile", HFILL }},
+	{ &hf_sdp_h264_packetization_mode,
+      { "Packetization mode",
+        "sdp.fmtp.h264_packetization_mode",FT_UINT32, BASE_DEC,VALS(h264_packetization_mode_vals), 0x0,
+        "Packetization mode", HFILL }},
+	{ &hf_sdp_h264_sprop_parameter_sets,
+      { "Sprop_parameter_sets",
+        "sdp.h264.sprop_parameter_sets", FT_BYTES, BASE_NONE, NULL, 0x0,
+        "Sprop_parameter_sets", HFILL }},
     { &hf_SDPh223LogicalChannelParameters,
       { "h223LogicalChannelParameters", "sdp.h223LogicalChannelParameters",
         FT_NONE, BASE_NONE, NULL, 0,
         "sdp.h223LogicalChannelParameters", HFILL }},
-
+    { &hf_key_mgmt_att_value,
+      { "Key Management",
+        "sdp.key_mgmt", FT_STRING, BASE_NONE, NULL, 0x0,
+        "Key Management", HFILL }},
+    { &hf_key_mgmt_prtcl_id,
+      { "Key Management Protocol (kmpid)",
+        "sdp.key_mgmt.kmpid", FT_STRING, BASE_NONE, NULL, 0x0,
+        "Key Management Protocol", HFILL }},
+    { &hf_key_mgmt_data,
+      { "Key Management Data",
+        "sdp.key_mgmt.data", FT_BYTES, BASE_NONE, NULL, 0x0,
+        "Key Management Data", HFILL }},
   };
   static gint *ett[] = {
     &ett_sdp,
@@ -1784,6 +1988,7 @@ proto_register_sdp(void)
     &ett_sdp_media,
     &ett_sdp_media_attribute,
     &ett_sdp_fmtp,
+    &ett_sdp_key_mgmt,
   };
 
   module_t *sdp_module;
@@ -1793,6 +1998,9 @@ proto_register_sdp(void)
   proto_register_field_array(proto_sdp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
+  key_mgmt_dissector_table = register_dissector_table("key_mgmt",
+	    "Key Management", FT_STRING, BASE_NONE);
+
   /*
    * Preferences registration
    */
@@ -1800,9 +2008,9 @@ proto_register_sdp(void)
    prefs_register_bool_preference(sdp_module, "establish_conversation",
        "Establish Media Conversation",
        "Specifies that RTP/RTCP/T.38/MSRP/etc streams are decoded based "
-       "upon port numbers found in SIP/SDP payload",
+       "upon port numbers found in SDP payload",
        &global_sdp_establish_conversation);
- 
+
   /*
    * Register the dissector by name, so other dissectors can
    * grab it by name rather than just referring to it directly.
@@ -1822,7 +2030,9 @@ proto_reg_handoff_sdp(void)
   rtcp_handle = find_dissector("rtcp");
   msrp_handle = find_dissector("msrp");
   t38_handle = find_dissector("t38");
+  h264_handle = find_dissector("h264");
 
   sdp_handle = find_dissector("sdp");
   dissector_add_string("media_type", "application/sdp", sdp_handle);
+  dissector_add("bctp.tpi", 0x20, sdp_handle);
 }
