@@ -2,7 +2,7 @@
 *
 * Routine to dissect ITU-T Rec. X.225 (1995 E)/ISO 8327-1 OSI Session Protocol packets
 *
-* $Id: packet-ses.c 19917 2006-11-17 01:52:15Z sfisher $
+* $Id: packet-ses.c 23412 2007-11-09 06:01:18Z etxrab $
 *
 * Yuriy Sidelnikov <YSidelnikov@hotmail.com>
 *
@@ -35,11 +35,13 @@
 #include <stdio.h>
 #include <string.h>
 
+#include <epan/asn1.h>
+#include "packet-ber.h"
 #include "packet-ses.h"
 #include "packet-frame.h"
-#include "packet-ber.h"
-#include <epan/prefs.h>
 
+#include <epan/prefs.h>
+#include <epan/emem.h>
 #include <epan/strutil.h>
 
 /* ses header fields             */
@@ -266,6 +268,9 @@ static const value_string reason_vals[] =
 /* desegmentation of OSI over ses  */
 /*static gboolean ses_desegment = TRUE;*/
 
+/* RTSE reassembly data */
+static guint ses_pres_ctx_id = 0;
+static gboolean ses_rtse_reassemble = FALSE;
 
 /* find the dissector for data */
 static dissector_handle_t data_handle;
@@ -336,6 +341,8 @@ dissect_parameter(tvbuff_t *tvb, int offset, proto_tree *tree,
 	guint16       flags;
 	proto_item   *tf;
 	proto_tree   *flags_tree;
+	asn1_ctx_t asn1_ctx;
+	asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
 
 	switch (param_type)
 	{
@@ -660,7 +667,7 @@ dissect_parameter(tvbuff_t *tvb, int offset, proto_tree *tree,
 			break;
 		if (tree)
 		{
-			dissect_ber_integer(FALSE, pinfo, param_tree, tvb, offset,
+			dissect_ber_integer(FALSE, &asn1_ctx, param_tree, tvb, offset,
 			    hf_activity_identifier, NULL);
 		}
 		break;
@@ -967,6 +974,7 @@ dissect_spdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 	guint16 parameters_len;
 	tvbuff_t *next_tvb;
 	void *save_private_data;
+	guint32 *pres_ctx_id = NULL;
 	struct SESSION_DATA_STRUCTURE session;
 
 	/*
@@ -976,6 +984,7 @@ dissect_spdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 	session.spdu_type = type;
 	session.abort_type = SESSION_NO_ABORT;
 	session.ros_op = 0;
+	session.rtse_reassemble = FALSE;
 
 	if (tokens) {
 	  	if (check_col(pinfo->cinfo, COL_INFO))
@@ -1010,6 +1019,21 @@ dissect_spdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 		case SES_TYPED_DATA:
 			has_user_information = TRUE;
 			break;
+		case SES_MAJOR_SYNC_POINT:
+			pres_ctx_id = p_get_proto_data (pinfo->fd, proto_ses);
+			if (ses_rtse_reassemble != 0 && !pres_ctx_id) {
+				/* First time visited - save pres_ctx_id */
+				pres_ctx_id = se_alloc (sizeof (guint32));
+				*pres_ctx_id = ses_pres_ctx_id;
+				p_add_proto_data (pinfo->fd, proto_ses, pres_ctx_id);
+			}
+			if (pres_ctx_id) {
+				session.pres_ctx_id = *pres_ctx_id;
+				session.rtse_reassemble = TRUE;
+				has_user_information = TRUE;
+			}
+			ses_rtse_reassemble = FALSE;
+			break;
 		}
 	}
 	offset++;
@@ -1031,7 +1055,7 @@ dissect_spdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 
 	/* Dissect user information, if present */
 	if (has_user_information) {
-		if (tvb_reported_length_remaining(tvb, offset) > 0) {
+		if (tvb_reported_length_remaining(tvb, offset) > 0 || type == SES_MAJOR_SYNC_POINT) {
 			next_tvb = tvb_new_subset(tvb, offset, -1, -1);
 
 			/* do we have OSI presentation packet dissector ? */
@@ -1055,6 +1079,10 @@ dissect_spdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 			 * end of the tvbuff.
 			 */
 			offset = tvb_length(tvb);
+			if (session.rtse_reassemble && type == SES_DATA_TRANSFER) {
+				ses_pres_ctx_id = session.pres_ctx_id;
+				ses_rtse_reassemble = TRUE;
+			}
 		}
 	}
 	return offset;
@@ -1777,7 +1805,7 @@ dissect_ses_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	guint16 len;
 
 	/* first, check do we have at least 4 bytes (type+length) */
-	if (!tvb_bytes_exist(tvb, 0, 2))
+	if (tvb_length(tvb) < 2)
 		return FALSE;	/* no */
 
 	/* can we recognize session PDU ? Return FALSE if  not */
@@ -1805,7 +1833,7 @@ dissect_ses_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	 * misinterpreted as SES.
 	 * the starter in this case is fixed to 0x32 (SES_MINOR_SYNC_ACK for SES), 
 	 * so if the parameter type is unknown, it's probably SIMATIC */
-	if(type == 0x32 && tvb_bytes_exist(tvb, 0, 3)) {
+	if(type == 0x32 && tvb_length(tvb) >= 3) {
 		type = tvb_get_guint8(tvb, offset+2);
 		if (match_strval(type, param_vals) == NULL) {
 			return FALSE; /* it's probably a SIMATIC protocol */
@@ -1819,7 +1847,7 @@ dissect_ses_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	/*  add header length     */
 	len+=len_len;
 	/* do we have enough bytes ? */
-	if (!tvb_bytes_exist(tvb, 0, len))
+	if (tvb_length(tvb) < len)
 		return FALSE;	/* no */
 
 	dissect_ses(tvb, pinfo, parent_tree);
