@@ -2,7 +2,7 @@
  * Routines for SMB net logon packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-smb-logon.c 19986 2006-11-26 13:22:14Z jake $
+ * $Id: packet-smb-logon.c 21073 2007-03-20 15:07:28Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -36,12 +36,9 @@
 #include "packet-smb-common.h"
 
 static int proto_smb_logon = -1;
-static int proto_smb_netlogon = -1;
-static int proto_smb_ntlogon = -1;
 static int hf_command = -1;
 static int hf_computer_name = -1;
 static int hf_unicode_computer_name = -1;
-static int hf_unknown_int = -1;
 static int hf_server_name = -1;
 static int hf_user_name = -1;
 static int hf_domain_name = -1;
