@@ -9,7 +9,7 @@
  *       In particular I have not had an opportunity to see how it
  *       responds to SRVLOC over TCP.
  *
- * $Id: packet-srvloc.c 19060 2006-08-28 12:24:24Z gmorris $
+ * $Id: packet-srvloc.c 24249 2008-02-02 17:25:40Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -156,6 +156,7 @@ static int hf_srvloc_srvrply_svcname = -1;
 
 
 static gint ett_srvloc = -1;
+static gint ett_srvloc_attr = -1;
 static gint ett_srvloc_flags = -1;
 
 
@@ -559,7 +560,7 @@ attr_list(proto_tree *tree, int hf, tvbuff_t *tvb, int offset, int length,
                 type_len = strcspn(tmp, ")");
                 add_v1_string(tree, hf_srvloc_srvrply_svcname, tvb, offset, type_len*2, encoding);
                 offset += (type_len*2)+4;
-                strcpy(attr_type, "\0");
+                attr_type[0] = '\0';
             }
             /* If this is the attribute svcaddr */
             if (strcmp(attr_type, "svcaddr-ws")==0) {
@@ -567,7 +568,7 @@ attr_list(proto_tree *tree, int hf, tvbuff_t *tvb, int offset, int length,
                 for (foffset = offset; foffset<length; foffset += 2) {
         
                     ti = proto_tree_add_text(tree, tvb, foffset, -1, "Item %d", i);
-                    srvloc_tree = proto_item_add_subtree(ti, ett_srvloc);
+                    srvloc_tree = proto_item_add_subtree(ti, ett_srvloc_attr);
         
                     svc = tvb_get_guint8(tvb, foffset+1);
         			proto_tree_add_text(srvloc_tree, tvb, foffset+1, 1,
@@ -624,7 +625,7 @@ attr_list(proto_tree *tree, int hf, tvbuff_t *tvb, int offset, int length,
                     foffset += 57;
                 }
                 offset = foffset;
-                strcpy(attr_type, "\0");
+                attr_type[0] = '\0';
             }
             /* If there are no more supported attributes available then abort dissection */
             if (strcmp(attr_type, "svcaddr-ws")!=0 && strcmp(attr_type, "svcname-ws")!=0 && strcmp(attr_type, "\0")!=0) {
@@ -641,7 +642,7 @@ attr_list(proto_tree *tree, int hf, tvbuff_t *tvb, int offset, int length,
         for (foffset = offset + (type_len); foffset<length; foffset++) {
 
             ti = proto_tree_add_text(tree, tvb, foffset, -1, "Item %d", i);
-            srvloc_tree = proto_item_add_subtree(ti, ett_srvloc);
+            srvloc_tree = proto_item_add_subtree(ti, ett_srvloc_attr);
 
             svc = tvb_get_guint8(tvb, foffset+1);
 			proto_tree_add_text(srvloc_tree, tvb, foffset+1, 1,
@@ -707,6 +708,53 @@ attr_list(proto_tree *tree, int hf, tvbuff_t *tvb, int offset, int length,
     }
 }
 
+static void
+attr_list2(proto_tree *tree, int hf, tvbuff_t *tvb, int offset, int length, guint16 encoding _U_)
+{
+    guint8      *start;
+    guint8       c;
+    guint32      x;
+    guint32      cnt;
+    proto_item  *ti;
+    proto_tree  *attr_tree;
+
+    /* if we were to decode:
+     * For slp, these 9 characters: (),\!<=>~ and 0x00-1F, 0x7f are reserved and must be escaped in the form \HH
+     */
+
+    /* create a sub tree for attributes */
+    ti = proto_tree_add_item(tree, hf, tvb, offset, length, TRUE);
+    attr_tree = proto_item_add_subtree(ti, ett_srvloc_attr);
+
+    /* this will ensure there is a terminating null */
+    start = tvb_get_ephemeral_string(tvb, offset, length);
+
+    cnt = 0;
+    x = 0;
+    c = start[x];
+    while (c) {
+        if  (c == ',') {
+            cnt++; /* Attribute count */
+            start[x] = 0;
+            proto_tree_add_text(attr_tree, tvb, offset, x, "Item %d: %s", cnt, start);
+            offset += x+1;
+            start += x+1;
+            /* reset string length */
+            x = 0;
+            c = start[x];
+        } else {
+            /* increment and get next */
+            x++;
+            c = start[x];
+        }
+    }
+    /* display anything remaining */
+    if (x) {
+        cnt++;
+        proto_tree_add_text(attr_tree, tvb, offset, x, "Item %d: %s", cnt, start);
+    }
+}
+
 static int
 dissect_url_entry_v1(tvbuff_t *tvb, int offset, proto_tree *tree,
                      guint16 encoding, guint16 flags)
@@ -859,7 +907,7 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     offset = dissect_url_entry_v1(tvb, offset, srvloc_tree,
                                                   encoding, flags);
                     count--;
-                };
+                }
             break;
 
             case SRVREG:
@@ -1010,13 +1058,13 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                     add_v1_string(srvloc_tree, hf_srvloc_srvtyperply_srvtype, tvb, offset, length, encoding);
                     offset += length;
                     count--;
-                };
+                }
             break;
 
             default:
                 expert_item = proto_tree_add_text(srvloc_tree, tvb, offset, -1, "Unknown Function Type");
                 expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "Unknown Function Type: %d", function);
-	    };
+	    }
 	}
 	else { /* Version 2 */
 	    length = tvb_get_ntoh24(tvb, offset + 2);
@@ -1050,28 +1098,38 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreq_prlistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_prlist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_prlist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
 		length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreq_srvtypelen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_srvtypelist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_srvtypelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
 		length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreq_scopelistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_scopelist, tvb, offset, length, TRUE);
-		offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_scopelist, tvb, offset, length, TRUE);
+		    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreq_predicatelen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_predicate, tvb, offset, length, TRUE);
-		offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_predicate, tvb, offset, length, TRUE);
+		    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreq_slpspilen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_slpspi, tvb, offset, length, TRUE);
-		offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreq_slpspi, tvb, offset, length, TRUE);
+		    offset += length;
+                }
 		break;
 
             case SRVRPLY: /* RFC2608 8.2 */
@@ -1087,7 +1145,7 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 while (count > 0) {
 		    offset = dissect_url_entry_v2(tvb, offset, srvloc_tree);
                     count--;
-                };
+                }
             break;
 
             case SRVREG: /* RFC2608 8.3 */
@@ -1095,18 +1153,24 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreg_srvtypelen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreg_srvtype, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreg_srvtype, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreg_scopelistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreg_scopelist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvreg_scopelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreg_attrlistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvreg_attrlist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    attr_list2(srvloc_tree, hf_srvloc_srvreg_attrlist, tvb, offset, length, CHARSET_UTF_8);
+                    offset += length;
+                }
 		count = tvb_get_guint8(tvb, offset);
 		proto_tree_add_uint(srvloc_tree, hf_srvloc_srvreg_attrauthcount, tvb, offset, 1, count);
 		offset += 1;
@@ -1120,14 +1184,18 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvdereg_scopelistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvdereg_scopelist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvdereg_scopelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
 		offset = dissect_url_entry_v2(tvb, offset, srvloc_tree);
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvdereg_taglistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvdereg_taglist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvdereg_taglist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
 		break;
 
             case SRVACK: /* RFC2608 8.4 */
@@ -1143,28 +1211,38 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_attrreq_prlistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_prlist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_prlist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_attrreq_urllen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_url, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_url, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_attrreq_scopelistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_scopelist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_scopelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_attrreq_taglistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_taglist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_taglist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_attrreq_slpspilen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_slpspi, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_attrreq_slpspi, tvb, offset, length, TRUE);
+                    offset += length;
+                }
             break;
 
             case ATTRRPLY: /* RFC2608 10.4 */
@@ -1176,17 +1254,17 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 offset += 2;
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_attrrply_attrlistlen, tvb, offset, 2, length);
-                if (length > 0) {
-                    offset += 2;
-                    attr_list(srvloc_tree, hf_srvloc_attrrply_attrlist, tvb, offset, length, CHARSET_UTF_8);
+                offset += 2;
+                if (length) {
+                    attr_list2(srvloc_tree, hf_srvloc_attrrply_attrlist, tvb, offset, length, CHARSET_UTF_8);
                     offset += length;
-            		count = tvb_get_guint8(tvb, offset);
-            		proto_tree_add_uint(srvloc_tree, hf_srvloc_attrrply_attrauthcount, tvb, offset, 1, count);
-            		offset += 1;
-            		while (count > 0) {
-            		    offset = dissect_attrauthblk_v2(tvb, offset, srvloc_tree);
-            		    count--;
-            		}
+                }
+                count = tvb_get_guint8(tvb, offset);
+                proto_tree_add_uint(srvloc_tree, hf_srvloc_attrrply_attrauthcount, tvb, offset, 1, count);
+                offset += 1;
+                while (count > 0) {
+                    offset = dissect_attrauthblk_v2(tvb, offset, srvloc_tree);
+                    count--;
                 }
             break;
 
@@ -1205,23 +1283,31 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_daadvert_urllen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_url, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_url, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_daadvert_scopelistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_scopelist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_scopelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_daadvert_attrlistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_attrlist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_attrlist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_daadvert_slpspilen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_slpspi, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_daadvert_slpspi, tvb, offset, length, TRUE);
+                    offset += length;
+                }
 		count = tvb_get_guint8(tvb, offset);
 		proto_tree_add_uint(srvloc_tree, hf_srvloc_daadvert_authcount, tvb, offset, 1, count);
 		offset += 1;
@@ -1235,8 +1321,10 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvtypereq_prlistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvtypereq_prlist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvtypereq_prlist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
                 length = tvb_get_ntohs(tvb, offset);
 		if (0xFFFF == length) {
 		    proto_tree_add_uint(srvloc_tree, hf_srvloc_srvtypereq_nameauthlistlenall, tvb, offset, 2, length);
@@ -1244,14 +1332,18 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		} else {
 		    proto_tree_add_uint(srvloc_tree, hf_srvloc_srvtypereq_nameauthlistlen, tvb, offset, 2, length);
 		    offset += 2;
-		    proto_tree_add_item(srvloc_tree, hf_srvloc_srvtypereq_nameauthlist, tvb, offset, length, TRUE);
-		    offset += length;
-		}
+                    if (length) {
+		        proto_tree_add_item(srvloc_tree, hf_srvloc_srvtypereq_nameauthlist, tvb, offset, length, TRUE);
+		        offset += length;
+		    }
+                }
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvtypereq_scopelistlen, tvb, offset, 2, length);
                 offset += 2;
-                proto_tree_add_item(srvloc_tree, hf_srvloc_srvtypereq_scopelist, tvb, offset, length, TRUE);
-                offset += length;
+                if (length) {
+                    proto_tree_add_item(srvloc_tree, hf_srvloc_srvtypereq_scopelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
             break;
 
 	    case SRVTYPERPLY: /* rfc2608 10.2 */
@@ -1264,26 +1356,34 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 length = tvb_get_ntohs(tvb, offset);
                 proto_tree_add_uint(srvloc_tree, hf_srvloc_srvtyperply_srvtypelistlen, tvb, offset, 2, length);
                 offset += 2;
-		proto_tree_add_item(srvloc_tree, hf_srvloc_srvtyperply_srvtypelist, tvb, offset, length, TRUE);
+                if (length) {
+		    proto_tree_add_item(srvloc_tree, hf_srvloc_srvtyperply_srvtypelist, tvb, offset, length, TRUE);
+                    offset += length;
+                }
             break;
 
 	    case SAADVERT: /* rfc2608 10.2 */
 		length = tvb_get_ntohs(tvb, offset);
-		proto_tree_add_uint(srvloc_tree, hf_srvloc_saadvert_urllen, tvb, offset, 2,
-				    length);
+                  proto_tree_add_uint(srvloc_tree, hf_srvloc_saadvert_urllen, tvb, offset, 2, length);
 		offset += 2;
-		proto_tree_add_item(srvloc_tree, hf_srvloc_saadvert_url, tvb, offset, length, TRUE);
-		offset += length;
+                  if (length) {
+			proto_tree_add_item(srvloc_tree, hf_srvloc_saadvert_url, tvb, offset, length, TRUE);
+			offset += length;
+                  }
 		length = tvb_get_ntohs(tvb, offset);
 		proto_tree_add_uint(srvloc_tree, hf_srvloc_saadvert_scopelistlen, tvb, offset, 2, length);
 		offset += 2;
-		proto_tree_add_item(srvloc_tree, hf_srvloc_saadvert_scopelist, tvb, offset, length, TRUE);
-		offset += length;
+                  if (length) {
+			proto_tree_add_item(srvloc_tree, hf_srvloc_saadvert_scopelist, tvb, offset, length, TRUE);
+			offset += length;
+                  }
 		length = tvb_get_ntohs(tvb, offset);
 		proto_tree_add_uint(srvloc_tree, hf_srvloc_saadvert_attrlistlen, tvb, offset, 2, length);
 		offset += 2;
-		proto_tree_add_item(srvloc_tree, hf_srvloc_saadvert_attrlist, tvb, offset, length, TRUE);
-		offset += length;
+                  if (length) {
+			proto_tree_add_item(srvloc_tree, hf_srvloc_saadvert_attrlist, tvb, offset, length, TRUE);
+			offset += length;
+                  }
 		count = tvb_get_guint8(tvb, offset);
 		proto_tree_add_uint(srvloc_tree, hf_srvloc_saadvert_authcount, tvb, offset, 1, length);
 		offset += 1;
@@ -1296,13 +1396,13 @@ dissect_srvloc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
             default:
                 expert_item = proto_tree_add_text(srvloc_tree, tvb, offset, -1, "Unknown Function Type");
                 expert_add_info_format(pinfo, expert_item, PI_RESPONSE_CODE, PI_ERROR, "Unknown Function Type: %d", function);
-	    };
-	};
+	    }
+	}
     }
 }
 
 static guint
-get_srvloc_pdu_len(tvbuff_t *tvb, int offset)
+get_srvloc_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
 {
     /*
      * Get the length of the SRVLOC packet.
@@ -1788,6 +1888,7 @@ proto_register_srvloc(void)
 
     static gint *ett[] = {
 	&ett_srvloc,
+	&ett_srvloc_attr,
 	&ett_srvloc_flags,
     };
 	module_t *srvloc_module;
