@@ -2,7 +2,7 @@
  * Routines for Simple Traversal of UDP Through NAT dissection
  * Copyright 2003, Shiang-Ming Huang <smhuang@pcs.csie.nctu.edu.tw>
  *
- * $Id: packet-stun.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-stun.c 23412 2007-11-09 06:01:18Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -67,7 +67,7 @@ static int stun_att_lifetime = -1;
 static int stun_att_magic_cookie = -1;
 static int stun_att_bandwidth = -1;
 static int stun_att_data = -1;
-
+static int stun_att_connection_request_binding = -1;
 
 
 /* Message Types */
@@ -88,6 +88,7 @@ static int stun_att_data = -1;
 #define SET_ACTIVE_DESTINATION_RESPONSE	0x0106
 #define SET_ACTIVE_DESTINATION_ERROR_RESPONSE	0x0116
 
+
 /* Attribute Types */
 #define MAPPED_ADDRESS		0x0001
 #define RESPONSE_ADDRESS	0x0002
@@ -113,6 +114,8 @@ static int stun_att_data = -1;
 #define XOR_MAPPED_ADDRESS	0x8020
 #define XOR_ONLY		0x0021
 #define SERVER			0x8022
+#define CONNECTION_REQUEST_BINDING      0xc001
+#define BINDING_CHANGE                  0xc002
 
 
 
@@ -126,7 +129,7 @@ static gint ett_stun_att = -1;
 #define TCP_PORT_STUN	3478
 
 
-#define STUN_HDR_LEN	20	/* STUN message header length */
+#define STUN_HDR_LEN	((guint)20)	/* STUN message header length */
 #define ATTR_HDR_LEN	4	/* STUN attribute header length */
 
 
@@ -179,6 +182,8 @@ static const value_string attributes[] = {
 	{XOR_MAPPED_ADDRESS, "XOR_MAPPED_ADDRESS"},
 	{XOR_ONLY, "XOR_ONLY"},
 	{SERVER, "SERVER"},
+	{CONNECTION_REQUEST_BINDING, "CONNECTION-REQUEST-BINDING"},
+	{BINDING_CHANGE, "BINDING-CHANGE"},
 	{0x00, NULL}
 };
 
@@ -203,14 +208,15 @@ dissect_stun(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint16 att_type;
 	guint16 att_length;
 	guint16 offset;
+	guint   len;
 	guint i;
 
 	/*
 	 * First check if the frame is really meant for us.
 	 */
-
+	len = tvb_length(tvb);
 	/* First, make sure we have enough data to do the check. */
-	if (!tvb_bytes_exist(tvb, 0, STUN_HDR_LEN))
+	if (len < STUN_HDR_LEN)
 		return 0;
 	
 	msg_type = tvb_get_ntohs(tvb, 0);
@@ -223,11 +229,7 @@ dissect_stun(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	msg_length = tvb_get_ntohs(tvb, 2);
 	
 	/* check if payload enough */
-	if (!tvb_bytes_exist(tvb, 0, STUN_HDR_LEN+msg_length))
-		return 0;
-
-	/* Check if too much payload */
-	if (tvb_bytes_exist(tvb, 0, STUN_HDR_LEN+msg_length+1))
+	if (len != STUN_HDR_LEN+msg_length)
 		return 0;
 
 	/* The message seems to be a valid STUN message! */
@@ -423,6 +425,10 @@ dissect_stun(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					proto_tree_add_item(att_tree, stun_att_family, tvb, offset+1, 1, FALSE);
 					break;
 
+				case CONNECTION_REQUEST_BINDING:
+					proto_tree_add_item(att_tree, stun_att_connection_request_binding, tvb, offset, att_length, FALSE);
+					break;				    
+
 				default:
 					break;
 			}
@@ -552,6 +558,10 @@ proto_register_stun(void)
 			{ "Data",	"stun.att.data",	FT_BYTES,
 			BASE_HEX,	NULL,	0x0, 	"",	HFILL }
 		},
+		{ &stun_att_connection_request_binding,
+		        { "Connection Request Binding", "stun.att.connection_request_binding", FT_STRING,
+			  BASE_NONE,      NULL, 0x0,    "",     HFILL }
+		},
 	};
 
 /* Setup protocol subtree array */
