@@ -7,7 +7,7 @@
  * Joerg Mayer (see AUTHORS file)
  *      RFC2348 TFTP Blocksize Option
  *
- * $Id: packet-tftp.c 20670 2007-02-01 18:40:28Z gerald $
+ * $Id: packet-tftp.c 24341 2008-02-16 01:33:48Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -51,6 +51,10 @@
 #include <epan/emem.h>
 #include <epan/expert.h>
 
+#ifdef NEED_G_ASCII_STRCASECMP_H
+#include "g_ascii_strcasecmp.h"
+#endif
+
 /* Things we may want to remember for a whole conversation */
 typedef struct _tftp_conv_info_t {
 	guint16 blocksize;
@@ -120,8 +124,8 @@ tftp_dissect_options(tvbuff_t *tvb, packet_info *pinfo, int offset,
 	  option_len = tvb_strsize(tvb, offset);	/* length of option */
 	  value_offset = offset + option_len;
 	  value_len = tvb_strsize(tvb, value_offset);	/* length of value */
-	  optionname = tvb_get_ptr(tvb, offset, option_len);
-	  optionvalue = tvb_get_ptr(tvb, value_offset, value_len);
+	  optionname = tvb_format_text(tvb, offset, option_len);
+	  optionvalue = tvb_format_text(tvb, value_offset, value_len);
 	  opt_item = proto_tree_add_text(tree, tvb, offset, option_len+value_len,
 	          "Option: %s = %s", optionname, optionvalue);
 
@@ -139,7 +143,7 @@ tftp_dissect_options(tvbuff_t *tvb, packet_info *pinfo, int offset,
 	  }
 
 	  /* Special code to handle individual options */
-	  if (!strcasecmp((const char *)optionname, "blksize") &&
+	  if (!g_ascii_strcasecmp((const char *)optionname, "blksize") &&
 	      opcode == TFTP_OACK) {
 		gint blocksize = strtol((const char *)optionvalue, NULL, 10);
 		if (blocksize < 8 || blocksize > 65464) {
@@ -216,7 +220,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 
-	  col_add_fstr(pinfo->cinfo, COL_INFO, "%s",
+	  col_add_str(pinfo->cinfo, COL_INFO,
 	    val_to_str(opcode, tftp_opcode_vals, "Unknown (0x%04x)"));
 
 	}
@@ -241,7 +245,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  }
 	  if (check_col(pinfo->cinfo, COL_INFO)) {
 	    col_append_fstr(pinfo->cinfo, COL_INFO, ", File: %s",
-			    tvb_get_ptr(tvb, offset, i1));
+			    tvb_format_text(tvb, offset, i1));
 	  }
 	  offset += i1;
 
@@ -252,7 +256,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  }
 	  if (check_col(pinfo->cinfo, COL_INFO)) {
 	    col_append_fstr(pinfo->cinfo, COL_INFO, ", Transfer type: %s",
-			    tvb_get_ptr(tvb, offset, i1));
+			    tvb_format_text(tvb, offset, i1));
 	  }
 	  offset += i1;
 
@@ -269,7 +273,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  }
 	  if (check_col(pinfo->cinfo, COL_INFO)) {
 	    col_append_fstr(pinfo->cinfo, COL_INFO, ", File: %s",
-			    tvb_get_ptr(tvb, offset, i1));
+			    tvb_format_text(tvb, offset, i1));
 	  }
 	  offset += i1;
 
@@ -280,7 +284,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  }
 	  if (check_col(pinfo->cinfo, COL_INFO)) {
 	    col_append_fstr(pinfo->cinfo, COL_INFO, ", Transfer type: %s",
-			    tvb_get_ptr(tvb, offset, i1));
+			    tvb_format_text(tvb, offset, i1));
 	  }
 	  offset += i1;
 
@@ -344,7 +348,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	  }
 	  if (check_col(pinfo->cinfo, COL_INFO)) {
 	    col_append_fstr(pinfo->cinfo, COL_INFO, ", Message: %s",
-			    tvb_get_ptr(tvb, offset, i1));
+			    tvb_format_text(tvb, offset, i1));
 	  }
 	  expert_add_info_format(pinfo, NULL, PI_RESPONSE_CODE,
 		PI_NOTE, "TFTP blocksize out of range");
