@@ -2,7 +2,7 @@
  * Routines for Token-Ring packet disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-tr.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-tr.c 21572 2007-04-25 23:54:54Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -378,17 +378,17 @@ dissect_tr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	SET_ADDRESS(&trh->src,	AT_ETHER, 6, tvb_get_ptr(tr_tvb, 8, 6));
 	SET_ADDRESS(&trh->dst,	AT_ETHER, 6, tvb_get_ptr(tr_tvb, 2, 6));
 
+	/* if the high bit on the first byte of src hwaddr is 1, then
+		this packet is source-routed */
 	memcpy(trn_shost_nonsr, trh->src.data, 6);
+	source_routed = trn_shost_nonsr[0] & 128;
 	trn_shost_nonsr[0] &= 127;
+
 	frame_type = (trh->fc & 192) >> 6;
 
 	if (check_col(pinfo->cinfo, COL_INFO))
 		col_add_fstr(pinfo->cinfo, COL_INFO, "Token-Ring %s", fc[frame_type]);
 
-	/* if the high bit on the first byte of src hwaddr is 1, then
-		this packet is source-routed */
-	source_routed = trh->src.data[0] & 128;
-
 	trn_rif_bytes = tvb_get_guint8(tr_tvb, 14) & 31;
 
 	if (fix_linux_botches) {
