@@ -1,7 +1,7 @@
 /* packet-vtp.c
  * Routines for the disassembly of Cisco's Virtual Trunking Protocol
  *
- * $Id: packet-vtp.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-vtp.c 21210 2007-03-26 11:06:26Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -142,7 +142,7 @@ dissect_vtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 			upd_timestamp = tvb_get_ptr(tvb, offset, 12);
 			proto_tree_add_string_format(vtp_tree, hf_vtp_upd_ts, tvb,
-			    offset, 12, upd_timestamp,
+			    offset, 12, (gchar*)upd_timestamp,
 			    "Update Timestamp: %.2s-%.2s-%.2s %.2s:%.2s:%.2s",
 			    &upd_timestamp[0], &upd_timestamp[2], &upd_timestamp[4],
 			    &upd_timestamp[6], &upd_timestamp[8], &upd_timestamp[10]);
