@@ -5,7 +5,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
 *
-* $Id: dtd_parse.h 18234 2006-05-28 19:49:07Z etxrab $
+* $Id: dtd_parse.h 24717 2008-03-23 02:42:30Z gerald $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -27,7 +27,11 @@
 */
 
 extern void DtdParse(void*,int,dtd_token_data_t*,dtd_build_data_t*);
+#if (GLIB_MAJOR_VERSION > 2 || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 16))
+extern void *DtdParseAlloc(void *(*)(gsize));
+#else
 extern void *DtdParseAlloc(void *(*)(gulong));
+#endif
 extern void DtdParseFree( void*, void(*)(void*) );
 extern void DtdParseTrace(FILE *TraceFILE, char *zTracePrompt);	
 extern int Dtd_Parse_lex(void);
