@@ -1,7 +1,7 @@
 /* filesystem.c
  * Filesystem utility routines
  *
- * $Id: filesystem.c 22616 2007-08-24 00:03:02Z richardv $
+ * $Id: filesystem.c 24640 2008-03-15 18:31:52Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,6 +26,10 @@
 # include "config.h"
 #endif
 
+#ifdef HAVE_DIRENT_H
+#include <dirent.h>
+#endif
+
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -55,10 +59,12 @@
 #include "privileges.h"
 #include <wiretap/file_util.h>
 
+#define PROFILES_DIR    "profiles"
 #define U3_MY_CAPTURES  "\\My Captures"
 
 char *persconffile_dir = NULL;
 char *persdatafile_dir = NULL;
+char *persconfprofile = NULL;
 
 /*
  * Given a pathname, return a pointer to the last pathname separator
@@ -218,7 +224,8 @@ test_for_fifo(const char *path)
 static char *progfile_dir;
 
 /*
- * TRUE if we're running from the build directory.
+ * TRUE if we're running from the build directory and we aren't running
+ * with special privileges.
  */
 static gboolean running_in_build_directory_flag = FALSE;
 
@@ -380,10 +387,7 @@ init_progfile_dir(const char *arg0
 			return g_strdup_printf("getcwd failed: %s\n",
 			    strerror(errno));
 		}
-		path = g_malloc(strlen(curdir) + 1 + strlen(arg0) + 1);
-		strcpy(path, curdir);
-		strcat(path, "/");
-		strcat(path, arg0);
+		path = g_strdup_printf("%s/%s", curdir, arg0);
 		g_free(curdir);
 		prog_pathname = path;
 	} else {
@@ -405,8 +409,8 @@ init_progfile_dir(const char *arg0
 				    + strlen(arg0) + 1);
 				memcpy(path, path_start, path_component_len);
 				path[path_component_len] = '\0';
-				strcat(path, "/");
-				strcat(path, arg0);
+				strncat(path, "/", 2);
+				strncat(path, arg0, strlen(arg0) + 1);
 				if (access(path, X_OK) == 0) {
 					/*
 					 * Found it!
@@ -608,10 +612,19 @@ get_datafile_dir(void)
 		datafile_dir = progfile_dir;
 	} else {
 		/*
-		 * Return the directory specified when the build
-		 * was configured.
+		 * Return the directory specified when the build was
+		 * configured, prepending the run path prefix if it exists.
 		 */
-		datafile_dir = DATAFILE_DIR;
+		if (getenv("WIRESHARK_DATA_DIR") && !started_with_special_privs()) {
+			/*
+			 * The user specified a different directory for data files
+			 * and we aren't running with special privileges.
+			 * XXX - We might be able to dispense with the priv check
+			 */
+			datafile_dir = g_strdup(getenv("WIRESHARK_DATA_DIR"));
+		} else {
+			datafile_dir = DATAFILE_DIR;
+		}
 	}
 
 #endif
@@ -684,8 +697,17 @@ init_plugin_dir(void)
 		 * (the datafile directory is the build directory).
 		 */
 		plugin_dir = g_strdup_printf("%s/plugins", get_datafile_dir());
-	} else
-		plugin_dir = PLUGIN_DIR;
+	} else {
+		if (getenv("WIRESHARK_PLUGIN_DIR") && !started_with_special_privs()) {
+			/*
+			 * The user specified a different directory for plugins
+			 * and we aren't running with special privileges.
+			 */
+			plugin_dir = g_strdup(getenv("WIRESHARK_PLUGIN_DIR"));
+		} else {
+			plugin_dir = PLUGIN_DIR;
+		}
+	}
 #endif
 }
 #endif /* HAVE_PLUGINS */
@@ -700,7 +722,7 @@ get_plugin_dir(void)
 	if (!plugin_dir) init_plugin_dir();
 	return plugin_dir;
 #else
-        return NULL;
+	return NULL;
 #endif
 }
 
@@ -780,6 +802,32 @@ char *getenv_utf8(const char *varname)
 }
 #endif
 
+void
+set_profile_name(const gchar *profilename)
+{
+	if (persconfprofile) {
+		g_free (persconfprofile);
+	}
+
+	if (profilename && strlen(profilename) > 0 &&
+	    strcmp(profilename, DEFAULT_PROFILE) != 0) {
+		persconfprofile = g_strdup (profilename);
+	} else {
+		/* Default Profile */
+		persconfprofile = NULL;
+	}
+}
+
+const char *
+get_profile_name(void)
+{
+	if (persconfprofile) {
+		return persconfprofile;
+	} else {
+		return DEFAULT_PROFILE;
+	}
+}
+
 /*
  * Get the directory in which personal configuration files reside;
  * in UNIX-compatible systems, it's ".wireshark", under the user's home
@@ -788,7 +836,7 @@ char *getenv_utf8(const char *varname)
  * (which is what %APPDATA% normally is on Windows 2000).
  */
 static const char *
-get_persconffile_dir(void)
+get_persconffile_dir_no_profile(void)
 {
 #ifdef _WIN32
 	char *appdatadir;
@@ -828,7 +876,7 @@ get_persconffile_dir(void)
 			 * Concatenate %APPDATA% with "\Wireshark".
 			 */
 			persconffile_dir = g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s",
-			    appdatadir, PF_DIR);
+							   appdatadir, PF_DIR);
 		} else {
 			/*
 			 * OK, %APPDATA% wasn't set, so use
@@ -874,6 +922,121 @@ get_persconffile_dir(void)
 	return persconffile_dir;
 }
 
+const char *
+get_profiles_dir(void)
+{
+	static char *profiles_dir = NULL;
+
+	if (profiles_dir) {
+		g_free (profiles_dir);
+	}
+
+	profiles_dir = g_strdup_printf ("%s%s%s", get_persconffile_dir_no_profile (),
+					G_DIR_SEPARATOR_S, PROFILES_DIR);
+
+	return profiles_dir;
+}
+
+static const char *
+get_persconffile_dir(const gchar *profilename)
+{
+	static char *persconffile_profile_dir = NULL;
+
+	if (persconffile_profile_dir) {
+		g_free (persconffile_profile_dir);
+	}
+
+	if (profilename && strlen(profilename) > 0 &&
+	    strcmp(profilename, DEFAULT_PROFILE) != 0) {
+	  persconffile_profile_dir = g_strdup_printf ("%s%s%s", get_profiles_dir (),
+						      G_DIR_SEPARATOR_S, profilename);
+	} else {
+	  persconffile_profile_dir = g_strdup_printf (get_persconffile_dir_no_profile ());
+	}
+
+	return persconffile_profile_dir;
+}
+
+gboolean
+profile_exists(const gchar *profilename)
+{
+	if (test_for_directory (get_persconffile_dir (profilename)) == EISDIR) {
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static int
+delete_directory (const char *directory, char **pf_dir_path_return)
+{
+	ETH_DIR *dir;
+	ETH_DIRENT *file;
+	gchar *filename;
+	int ret = 0;
+
+	if ((dir = eth_dir_open(directory, 0, NULL)) != NULL) {
+		while ((file = eth_dir_read_name(dir)) != NULL) {
+			filename = g_strdup_printf ("%s%s%s", directory, G_DIR_SEPARATOR_S,
+						    eth_dir_get_name(file));
+			if (test_for_directory(filename) != EISDIR) {
+				ret = eth_remove(filename);
+#if 0
+			} else {
+				/* The user has manually created a directory in the profile directory */
+				/* I do not want to delete the directory recursively yet */
+				ret = delete_directory (filename, pf_dir_path_return);
+#endif
+			}
+			if (ret != 0) {
+				*pf_dir_path_return = filename;
+				break;
+			}
+			g_free (filename);
+		}
+		eth_dir_close(dir);
+	}
+
+	if (ret == 0 && (ret = eth_remove(directory)) != 0) {
+		*pf_dir_path_return = g_strdup (directory);
+	}
+
+	return ret;
+}
+
+int
+delete_persconffile_profile(const char *profilename, char **pf_dir_path_return)
+{
+	const char *profile_dir = get_persconffile_dir(profilename);
+	int ret = 0;
+
+	if (test_for_directory (profile_dir) == EISDIR) {
+		ret = delete_directory (profile_dir, pf_dir_path_return);
+	}
+
+	return ret;
+}
+
+int
+rename_persconffile_profile(const char *fromname, const char *toname,
+			    char **pf_from_dir_path_return, char **pf_to_dir_path_return)
+{
+	char *from_dir = g_strdup (get_persconffile_dir(fromname));
+	char *to_dir = g_strdup (get_persconffile_dir(toname));
+	int ret = 0;
+
+	ret = eth_rename (from_dir, to_dir);
+	if (ret != 0) {
+		*pf_from_dir_path_return = g_strdup (from_dir);
+		*pf_to_dir_path_return = g_strdup (to_dir);
+	}
+
+	g_free (from_dir);
+	g_free (to_dir);
+
+	return ret;
+}
+
 /*
  * Create the directory that holds personal configuration files, if
  * necessary.  If we attempted to create it, and failed, return -1 and
@@ -882,7 +1045,7 @@ get_persconffile_dir(void)
  * return 0.
  */
 int
-create_persconffile_dir(char **pf_dir_path_return)
+create_persconffile_profile(const char *profilename, char **pf_dir_path_return)
 {
 	const char *pf_dir_path;
 #ifdef _WIN32
@@ -892,7 +1055,22 @@ create_persconffile_dir(char **pf_dir_path_return)
 	struct stat s_buf;
 	int ret;
 
-	pf_dir_path = get_persconffile_dir();
+	if (profilename) {
+		/*
+		 * Check if profiles directory exists.
+		 * If not then create it.
+		 */
+		pf_dir_path = get_profiles_dir ();
+		if (eth_stat(pf_dir_path, &s_buf) != 0 && errno == ENOENT) {
+			ret = eth_mkdir(pf_dir_path, 0755);
+			if (ret == -1) {
+				*pf_dir_path_return = g_strdup(pf_dir_path);
+				return ret;
+			}
+		}
+	}
+
+	pf_dir_path = get_persconffile_dir(profilename);
 	if (eth_stat(pf_dir_path, &s_buf) != 0 && errno == ENOENT) {
 #ifdef _WIN32
 		/*
@@ -940,6 +1118,12 @@ create_persconffile_dir(char **pf_dir_path_return)
 	return ret;
 }
 
+int
+create_persconffile_dir(char **pf_dir_path_return)
+{
+  return create_persconffile_profile(persconfprofile, pf_dir_path_return);
+}
+
 /*
  * Get the (default) directory in which personal data is stored.
  *
@@ -952,8 +1136,8 @@ extern char *
 get_persdatafile_dir(void)
 {
 #ifdef _WIN32
-    char *u3devicedocumentpath;
-    TCHAR tszPath[MAX_PATH];
+	char *u3devicedocumentpath;
+	TCHAR tszPath[MAX_PATH];
 	char *szPath;
 	BOOL bRet;
 
@@ -968,18 +1152,16 @@ get_persdatafile_dir(void)
 	u3devicedocumentpath = getenv_utf8("U3_DEVICE_DOCUMENT_PATH");
 
 	if (u3devicedocumentpath != NULL) {
-	  
-	  /* the "My Captures" sub-directory is created (if it doesn't exist) 
-	     by u3util.exe when the U3 Wireshark is first run */
-	  
-	  szPath = g_malloc(strlen(u3devicedocumentpath) + strlen(U3_MY_CAPTURES) + 1);
-	  strcpy(szPath, u3devicedocumentpath);
-	  strcat(szPath, U3_MY_CAPTURES);
+
+	  /* the "My Captures" sub-directory is created (if it doesn't exist)
+		 by u3util.exe when the U3 Wireshark is first run */
+
+	  szPath = g_strdup_printf("%s%s", u3devicedocumentpath, U3_MY_CAPTURES);
 
 	  persdatafile_dir = szPath;
 	  return szPath;
 
-        } else {
+		} else {
 	/* Hint: SHGetFolderPath is not available on MSVC 6 - without Platform SDK */
 	bRet = SHGetSpecialFolderPath(NULL, tszPath, CSIDL_PERSONAL, FALSE);
 	if(bRet == TRUE) {
@@ -989,7 +1171,7 @@ get_persdatafile_dir(void)
 	} else {
 		return "";
 	}
- }
+}
 #else
   return "";
 #endif
@@ -1024,10 +1206,7 @@ get_home_dir(void)
 			 * This is cached, so we don't need to worry about
 			 * allocating multiple ones of them.
 			 */
-			homestring =
-			    g_malloc(strlen(homedrive) + strlen(homepath) + 1);
-			strcpy(homestring, homedrive);
-			strcat(homestring, homepath);
+			homestring = g_strdup_printf("%s%s", homedrive, homepath);
 
 			/*
 			 * Trim off any trailing slash or backslash.
@@ -1063,9 +1242,12 @@ get_home_dir(void)
  * subdirectory of the user's home directory, and check whether that
  * exists; if it does, we return that, so that configuration files
  * from earlier versions can be read.
+ *
+ * The returned file name was g_malloc()'d so it must be g_free()d when the
+ * caller is done with it.
  */
 char *
-get_persconffile_path(const char *filename, gboolean for_writing
+get_persconffile_path(const char *filename, gboolean from_profile, gboolean for_writing
 #ifndef _WIN32
 	_U_
 #endif
@@ -1077,8 +1259,13 @@ get_persconffile_path(const char *filename, gboolean for_writing
 	char *old_path;
 #endif
 
-	path = g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s", get_persconffile_dir(),
-	    filename);
+	if (from_profile) {
+	  path = g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s",
+				 get_persconffile_dir(persconfprofile), filename);
+	} else {
+	  path = g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s",
+				 get_persconffile_dir(NULL), filename);
+	}
 #ifdef _WIN32
 	if (!for_writing) {
 		if (eth_stat(path, &s_buf) != 0 && errno == ENOENT) {
@@ -1104,74 +1291,77 @@ get_persconffile_path(const char *filename, gboolean for_writing
 	return path;
 }
 
-/* 
+/*
  * process command line option belonging to the filesystem settings
  * (move this e.g. to main.c and have set_persconffile_dir() instead in this file?)
  */
 int
 filesystem_opt(int opt _U_, const char *optarg)
 {
-  gchar *p, *colonp;
+	gchar *p, *colonp;
 
-  colonp = strchr(optarg, ':');
-  if (colonp == NULL) {
-    return 1;
-  }
+	colonp = strchr(optarg, ':');
+	if (colonp == NULL) {
+		return 1;
+	}
 
-  p = colonp;
-  *p++ = '\0';
+	p = colonp;
+	*p++ = '\0';
 
-  /*
-   * Skip over any white space (there probably won't be any, but
-   * as we allow it in the preferences file, we might as well
-   * allow it here).
-   */
-  while (isspace((guchar)*p))
-    p++;
-  if (*p == '\0') {
-    /*
-     * Put the colon back, so if our caller uses, in an
-     * error message, the string they passed us, the message
-     * looks correct.
-     */
-    *colonp = ':';
-    return 1;
-  }
+	/*
+	* Skip over any white space (there probably won't be any, but
+	* as we allow it in the preferences file, we might as well
+	* allow it here).
+	*/
+	while (isspace((guchar)*p))
+	p++;
+	if (*p == '\0') {
+		/*
+		 * Put the colon back, so if our caller uses, in an
+		 * error message, the string they passed us, the message
+		 * looks correct.
+		 */
+		*colonp = ':';
+		return 1;
+	}
 
-  /* directory should be existing */
-  /* XXX - is this a requirement? */
-  if(test_for_directory(p) != EISDIR) {
-    /*
-     * Put the colon back, so if our caller uses, in an
-     * error message, the string they passed us, the message
-     * looks correct.
-     */
-    *colonp = ':';
-    return 1;
-  }
+	/* directory should be existing */
+	/* XXX - is this a requirement? */
+	if(test_for_directory(p) != EISDIR) {
+		/*
+		 * Put the colon back, so if our caller uses, in an
+		 * error message, the string they passed us, the message
+		 * looks correct.
+		 */
+		*colonp = ':';
+		return 1;
+	}
 
-  if (strcmp(optarg,"persconf") == 0) {
-    persconffile_dir = p;
-  } else if (strcmp(optarg,"persdata") == 0) {
-    persdatafile_dir = p;
-  /* XXX - might need to add the temp file path */
-  } else {
-    return 1;
-  }
-  *colonp = ':'; /* put the colon back */
-  return 0;
+	if (strcmp(optarg,"persconf") == 0) {
+		persconffile_dir = p;
+	} else if (strcmp(optarg,"persdata") == 0) {
+		persdatafile_dir = p;
+		/* XXX - might need to add the temp file path */
+	} else {
+		return 1;
+	}
+	*colonp = ':'; /* put the colon back */
+	return 0;
 }
 
 /*
  * Construct the path name of a global configuration file, given the
  * file name.
+ *
+ * The returned file name was g_malloc()'d so it must be g_free()d when the
+ * caller is done with it.
  */
 char *
 get_datafile_path(const char *filename)
 {
 
 	return g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s", get_datafile_dir(),
-	    filename);
+		filename);
 }
 
 /* Delete a file */
@@ -1187,7 +1377,6 @@ deletefile(const char *path)
  */
 char *get_tempfile_path(const char *filename)
 {
-
 	return g_strdup_printf("%s" G_DIR_SEPARATOR_S "%s", g_get_tmp_dir(), filename);
 }
 
@@ -1282,31 +1471,29 @@ file_write_error_message(int err)
 gboolean
 file_exists(const char *fname)
 {
-  struct stat   file_stat;
-
+	struct stat   file_stat;
 
 #ifdef _WIN32
-  /*
-   * This is a bit tricky on win32. The st_ino field is documented as:
-   * "The inode, and therefore st_ino, has no meaning in the FAT, ..."
-   * but it *is* set to zero if stat() returns without an error,
-   * so this is working, but maybe not quite the way expected. ULFL
-   */
-   file_stat.st_ino = 1;   /* this will make things work if an error occured */
-   eth_stat(fname, &file_stat);
-   if (file_stat.st_ino == 0) {
-       return TRUE;
-   } else {
-       return FALSE;
-   }
+	/*
+	 * This is a bit tricky on win32. The st_ino field is documented as:
+	 * "The inode, and therefore st_ino, has no meaning in the FAT, ..."
+	 * but it *is* set to zero if stat() returns without an error,
+	 * so this is working, but maybe not quite the way expected. ULFL
+	 */
+	file_stat.st_ino = 1;   /* this will make things work if an error occured */
+	eth_stat(fname, &file_stat);
+	if (file_stat.st_ino == 0) {
+		return TRUE;
+	} else {
+		return FALSE;
+	}
 #else
-   if (eth_stat(fname, &file_stat) != 0 && errno == ENOENT) {
-       return FALSE;
-   } else {
-       return TRUE;
-   }
+	if (eth_stat(fname, &file_stat) != 0 && errno == ENOENT) {
+		return FALSE;
+	} else {
+		return TRUE;
+	}
 #endif
-
 }
 
 /*
@@ -1319,49 +1506,62 @@ file_exists(const char *fname)
 gboolean
 files_identical(const char *fname1, const char *fname2)
 {
-    /* Two different implementations, because:
-     *
-     * - _fullpath is not available on UN*X, so we can't get full
-     *   paths and compare them (which wouldn't work with hard links
-     *   in any case);
-     *
-     * - st_ino isn't filled in with a meaningful value on Windows.
-     */
+	/* Two different implementations, because:
+	 *
+	 * - _fullpath is not available on UN*X, so we can't get full
+	 *   paths and compare them (which wouldn't work with hard links
+	 *   in any case);
+	 *
+	 * - st_ino isn't filled in with a meaningful value on Windows.
+	 */
 #ifdef _WIN32
-    char full1[MAX_PATH], full2[MAX_PATH];
+	char full1[MAX_PATH], full2[MAX_PATH];
 
-    /*
-     * Get the absolute full paths of the file and compare them.
-     * That won't work if you have hard links, but those aren't
-     * much used on Windows, even though NTFS supports them.
-     *
-     * XXX - will _fullpath work with UNC?
-     */
-    if( _fullpath( full1, fname1, MAX_PATH ) == NULL ) {
-        return FALSE;
-    }
+	/*
+	 * Get the absolute full paths of the file and compare them.
+	 * That won't work if you have hard links, but those aren't
+	 * much used on Windows, even though NTFS supports them.
+	 *
+	 * XXX - will _fullpath work with UNC?
+	 */
+	if( _fullpath( full1, fname1, MAX_PATH ) == NULL ) {
+		return FALSE;
+	}
 
-    if( _fullpath( full2, fname2, MAX_PATH ) == NULL ) {
-        return FALSE;
-    }
+	if( _fullpath( full2, fname2, MAX_PATH ) == NULL ) {
+		return FALSE;
+	}
 
-    if(strcmp(full1, full2) == 0) {
-        return TRUE;
-    } else {
-        return FALSE;
-    }
+	if(strcmp(full1, full2) == 0) {
+		return TRUE;
+	} else {
+		return FALSE;
+	}
 #else
-  struct stat   filestat1, filestat2;
+	struct stat   filestat1, filestat2;
 
-   /*
-    * Compare st_dev and st_ino.
-    */
-   if (eth_stat(fname1, &filestat1) == -1)
-       return FALSE;	/* can't get info about the first file */
-   if (eth_stat(fname2, &filestat2) == -1)
-       return FALSE;	/* can't get info about the second file */
-   return (filestat1.st_dev == filestat2.st_dev &&
-           filestat1.st_ino == filestat2.st_ino);
+	/*
+	 * Compare st_dev and st_ino.
+	 */
+	if (eth_stat(fname1, &filestat1) == -1)
+		return FALSE;	/* can't get info about the first file */
+	if (eth_stat(fname2, &filestat2) == -1)
+		return FALSE;	/* can't get info about the second file */
+	return (filestat1.st_dev == filestat2.st_dev &&
+		filestat1.st_ino == filestat2.st_ino);
 #endif
 }
 
+/*
+ * Editor modelines
+ *
+ * Local Variables:
+ * c-basic-offset: 4
+ * tab-width: 4
+ * indent-tabs-mode: tabs
+ * End:
+ *
+ * ex: set shiftwidth=4 tabstop=4 noexpandtab
+ * :indentSize=4:tabSize=4:noTabs=false:
+ */
+
