@@ -1,7 +1,7 @@
 /* frame_data.h
  * Definitions for frame_data structures and routines
  *
- * $Id: frame_data.h 19814 2006-11-05 22:46:44Z ulfl $
+ * $Id: frame_data.h 24511 2008-03-01 05:16:45Z sfisher $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -46,7 +46,8 @@ typedef struct _frame_data {
   guint32      cum_bytes;   /* Cumulative bytes into the capture */
   nstime_t     abs_ts;      /* Absolute timestamp */
   nstime_t     rel_ts;      /* Relative timestamp (yes, it can be negative) */
-  nstime_t     del_ts;      /* Delta timestamp (yes, it can be negative) */
+  nstime_t     del_dis_ts;  /* Delta timestamp to previous displayed frame (yes, it can be negative) */
+  nstime_t     del_cap_ts;  /* Delta timestamp to previous captured frame (yes, it can be negative) */
   gint64       file_off;    /* File offset */
   int          lnk_t;       /* Per-packet encapsulation/data-link type */
   struct {
@@ -57,6 +58,7 @@ typedef struct _frame_data {
 	unsigned int ref_time		: 1; /* 1 = marked as a reference time frame, 0 = normal */
   } flags;
   void *color_filter;       /* Per-packet matching color_filter_t object */
+  col_expr_t   col_expr;   /* Column expressions & values */
 } frame_data;
 
 /*
