@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-ipv4.c 20205 2006-12-23 00:10:49Z sahlberg $
+ * $Id: ftype-ipv4.c 23375 2007-11-06 09:19:59Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,7 +33,7 @@
 
 
 static void
-set_integer(fvalue_t *fv, guint32 value)
+set_uinteger(fvalue_t *fv, guint32 value)
 {
 	ipv4_addr_set_net_order_addr(&(fv->value.ipv4), value);
 	ipv4_addr_set_netmask_bits(&(fv->value.ipv4), 32);
@@ -99,7 +99,7 @@ val_from_unparsed(fvalue_t *fv, char *s, gboolean allow_partial_value _U_, LogFu
 		if (!nmask_fvalue) {
 			return FALSE;
 		}
-		nmask_bits = fvalue_get_integer(nmask_fvalue);
+		nmask_bits = fvalue_get_uinteger(nmask_fvalue);
 		FVALUE_FREE(nmask_fvalue);
 
 		if (nmask_bits > 32) {
@@ -168,25 +168,15 @@ cmp_le(fvalue_t *a, fvalue_t *b)
 	return ipv4_addr_le(&a->value.ipv4, &b->value.ipv4);
 }
 
-static gboolean cmp_bytes_bitwise_and(fvalue_t *fv_a, fvalue_t *fv_b)
+static gboolean
+cmp_bitwise_and(fvalue_t *fv_a, fvalue_t *fv_b)
 {
-	GByteArray	*a = fv_a->value.bytes;
-	GByteArray	*b = fv_b->value.bytes;
-	guint i = 0;
-	unsigned char *p_a, *p_b;
+	guint32		addr_a;
+	guint32		addr_b;
 
-	if (b->len != a->len) {
-		return FALSE;
-	}
-	p_a = a->data;
-	p_b = b->data;
-	while (i < b->len) {
-		if (p_a[i] & p_b[i])
-			i++;
-		else
-			return FALSE;
-	}
-	return TRUE;
+	addr_a = fv_a->value.ipv4.addr & fv_a->value.ipv4.nmask;
+	addr_b = fv_b->value.ipv4.addr & fv_b->value.ipv4.nmask;
+	return ((addr_a & addr_b) != 0);
 }
 
 void
@@ -206,12 +196,14 @@ ftype_register_ipv4(void)
 		val_repr_len,			/* len_string_repr */
 
 		NULL,				/* set_value */
-		set_integer,			/* set_value_integer */
+		set_uinteger,		/* set_value_uinteger */
+		NULL,				/* set_value_sinteger */
 		NULL,				/* set_value_integer64 */
 		NULL,				/* set_value_floating */
 
 		value_get,			/* get_value */
-		NULL,				/* get_value_integer */
+		NULL,				/* get_value_uinteger */
+		NULL,				/* get_value_sinteger */
 		NULL,				/* get_value_integer64 */
 		NULL,				/* get_value_floating */
 
@@ -221,7 +213,7 @@ ftype_register_ipv4(void)
 		cmp_ge,
 		cmp_lt,
 		cmp_le,
-		cmp_bytes_bitwise_and,
+		cmp_bitwise_and,
 		NULL,				/* cmp_contains */
 		NULL,				/* cmp_matches */
 
