@@ -1,7 +1,7 @@
 /* guid-utils.c
  * GUID handling
  *
- * $Id: guid-utils.c 19291 2006-09-22 21:14:54Z gerald $
+ * $Id: guid-utils.c 21104 2007-03-22 00:40:04Z ulfl $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -114,7 +114,7 @@ guids_add_guid(e_guid_t *guid, const gchar *name)
 	guidkey[0].length=4;
 	guidkey[1].length=0;
 
-	pe_tree_insert32_array(guid_to_name_tree, &guidkey[0], name);
+	pe_tree_insert32_array(guid_to_name_tree, &guidkey[0], (gchar *) name);
 }
 
 
