@@ -1,7 +1,7 @@
 /* packet.h
  * Definitions for packet disassembly structures and routines
  *
- * $Id: packet.h 20373 2007-01-10 07:47:00Z jake $
+ * $Id: packet.h 22463 2007-08-07 21:26:07Z lego $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -46,6 +46,10 @@
 #include "epan.h"
 #include "tfs.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #define hi_nibble(b) (((b) & 0xf0) >> 4)
 #define lo_nibble(b) ((b) & 0x0f)
 
@@ -127,11 +131,11 @@ typedef int (*new_dissector_t)(tvbuff_t *, packet_info *, proto_tree *);
 typedef gboolean (*heur_dissector_t)(tvbuff_t *tvb, packet_info *pinfo,
 	proto_tree *tree);
 
-typedef void (*DATFunc) (gchar *table_name, ftenum_t selector_type,
+typedef void (*DATFunc) (const gchar *table_name, ftenum_t selector_type,
     gpointer key, gpointer value, gpointer user_data);
 typedef void (*DATFunc_handle) (const gchar *table_name, gpointer value,
     gpointer user_data);
-typedef void (*DATFunc_table) (gchar *table_name, const gchar *ui_name,
+typedef void (*DATFunc_table) (const gchar *table_name, const gchar *ui_name,
     gpointer user_data);
 
 /* Opaque structure - provides type checking but no access to components */
@@ -139,9 +143,9 @@ typedef struct dtbl_entry dtbl_entry_t;
 
 extern dissector_handle_t dtbl_entry_get_handle (dtbl_entry_t *dtbl_entry);
 extern dissector_handle_t dtbl_entry_get_initial_handle (dtbl_entry_t * entry);
-extern void dissector_table_foreach_changed (char *name, DATFunc func,
+extern void dissector_table_foreach_changed (const char *name, DATFunc func,
     gpointer user_data);
-extern void dissector_table_foreach (char *name, DATFunc func,
+extern void dissector_table_foreach (const char *name, DATFunc func,
     gpointer user_data);
 extern void dissector_all_tables_foreach_changed (DATFunc func,
     gpointer user_data);
@@ -266,6 +270,15 @@ extern gboolean dissector_try_heuristic(heur_dissector_list_t sub_dissectors,
 extern void heur_dissector_add(const char *name, heur_dissector_t dissector,
     int proto);
 
+/** Remove a sub-dissector from a heuristic dissector list.
+ *  Call this in the prefs_reinit function of the sub-dissector.
+ *
+ * @param name the name of the "parent" protocol, e.g. "tcp"
+ * @param dissector the sub-dissector to be unregistered
+ * @param proto the protocol id of the sub-dissector
+ */
+extern void heur_dissector_delete(const char *name, heur_dissector_t dissector, int proto);
+
 /* Register a dissector. */
 extern void register_dissector(const char *name, dissector_t dissector,
     int proto);
@@ -402,4 +415,8 @@ extern void dissector_dump_decodes(void);
 extern void register_postdissector(dissector_handle_t);
 extern void call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* packet.h */
