@@ -1,7 +1,7 @@
 /* strutil.h
  * String utility definitions
  *
- * $Id: strutil.h 20734 2007-02-07 13:45:28Z lego $
+ * $Id: strutil.h 23373 2007-11-06 05:51:49Z sahlberg $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -217,7 +217,8 @@ char * epan_strcasestr(const char *haystack, const char *needle);
 
 /* g_strlcat() does not exist in GLib 1.2[.x] */
 #if GLIB_MAJOR_VERSION < 2
-gsize g_strlcat(gchar *dst, gchar *src, gsize size);
+gsize g_strlcat(gchar *dst, const gchar *src, gsize size);
+gsize g_strlcpy(gchar *dest, const gchar *src, gsize dest_size);
 #endif
 
 #if GLIB_MAJOR_VERSION < 2
@@ -234,4 +235,9 @@ gsize g_strlcat(gchar *dst, gchar *src, gsize size);
 
 #endif
 
+#if GLIB_MAJOR_VERSION < 2
+/* g_byte_array_sized_new() doesnt exist in glib-1.2 */
+GByteArray *g_byte_array_sized_new(guint reserved_size);
+#endif
+
 #endif /* __STRUTIL_H__ */
