@@ -2,7 +2,7 @@
  * T.35 and H.221 tables
  * 2003  Tomas Kukosa
  *
- * $Id: t35.c 18197 2006-05-21 05:12:17Z sahlberg $
+ * $Id: t35.c 25467 2008-06-17 19:09:35Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -118,7 +118,7 @@ const value_string T35CountryCode_vals[] = {
 	{ 0x57, "Ireland"},
 	{ 0x58, "Israel"},
 	{ 0x59, "Italy"},
-	{ 0x5a, "Cte d'Ivoire"},
+	{ 0x5a, "Cote d'Ivoire"},
 	{ 0x5b, "Jamaica"},
 	{ 0x5c, "Afghanistan"},
 	{ 0x5d, "Jersey"},
@@ -247,9 +247,9 @@ const value_string H221ManufacturerCode_vals[] = {
 	{  0x0400008b, "Ferrari electronik GmbH" },                         /* From Ref. 3 */
 	{  0x0400008c, "mbp Kommunikationssysteme GmbH" },                  /* From Ref. 3 */
 	{  0x0400008d, "Schneider Rundfunkwerke AG" },                      /* From Ref. 3 */
-	{  0x0400008e, "Digitronic computersysteme gmbh" },                 /* From Ref. 3 */
+	{  0x0400008e, "Digitronic computersysteme GmbH" },                 /* From Ref. 3 */
 	{  0x0400008f, "DeTeWe - Deutsche Telephonwerke AG &Co" },          /* From Ref. 3 */
-	{  0x04000082, "SITK Institut fr Telekommunikation GmbH & Co KG" },/* From Ref. 3 */
+	{  0x04000082, "SITK Institut fuer Telekommunikation GmbH & Co KG" },/* From Ref. 3 */
 	{  0x0900003D, "Equivalence (OpenH323)" },                          /* From captures */
 	{  0x20000081, "Mediatrix Telecom" },                               /* From Ref. 1 */
 	{  0x3c000000, "Nokia" },											/* From captures */
