@@ -1,7 +1,7 @@
 /* to_str.h
  * Definitions for utilities to convert various other types to strings.
  *
- * $Id: to_str.h 20625 2007-01-30 17:44:11Z gerald $
+ * $Id: to_str.h 22659 2007-08-25 17:29:55Z lego $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -30,7 +30,6 @@
 #include "nstime.h"
 #include "epan/packet_info.h"
 
-#define MAX_OID_STR_LEN 256
 #define GUID_STR_LEN 37
 #define MAX_IP_STR_LEN 16
 #define MAX_ADDR_STR_LEN 256
@@ -78,8 +77,6 @@ extern void	display_epoch_time(gchar *, int, time_t,  gint32, time_res_t);
 
 extern gchar*	rel_time_to_str(nstime_t*);
 extern gchar*	rel_time_to_secs_str(nstime_t*);
-extern gchar*	oid_to_str(const guint8*, gint);
-extern gchar*	oid_to_str_buf(const guint8*, gint, gchar*, int);
 extern gchar*	guid_to_str(const e_guid_t*);
 extern gchar*	guid_to_str_buf(const e_guid_t*, gchar*, int);
 
