@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
  *
- * $Id: init_wslua.c 23207 2007-10-16 15:58:25Z morriss $
+ * $Id: init_wslua.c 24483 2008-02-26 23:30:40Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,7 +50,8 @@ static int wslua_not_register_menu(lua_State* LS) {
     return 0;
 }
 
-void dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
+int dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
+    int consumed_bytes = tvb->length;
     lua_pinfo = pinfo;
     lua_tvb = tvb;
 
@@ -80,12 +81,20 @@ void dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
         push_Pinfo(L,pinfo);
         push_TreeItem(L,lua_tree);
 
-        if  ( lua_pcall(L,3,0,0) ) {
+        if  ( lua_pcall(L,3,1,0) ) {
             const gchar* error = lua_tostring(L,-1);
 
             proto_item* pi = proto_tree_add_text(tree,tvb,0,0,"Lua Error: %s",error);
             expert_add_info_format(pinfo, pi, PI_DEBUG, PI_ERROR ,"Lua Error");
+        } else {
+
+            /* if the Lua dissector reported the consumed bytes, pass it to our caller */
+            if (lua_isnumber(L, -1)) {
+                consumed_bytes = (int) lua_tonumber(L, -1);
+                lua_pop(L, 1);  /* pop returned value */
         }
+	}
+	
     } else {
         proto_item* pi = proto_tree_add_text(tree,tvb,0,0,"Lua Error: did not find the %s dissector"
                                              " in the dissectors table",pinfo->current_proto);
@@ -102,6 +111,8 @@ void dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
     lua_tree = NULL;
     lua_tvb = NULL;
 
+    return consumed_bytes;
+
 }
 
 static void iter_table_and_call(lua_State* LS, int env, const gchar* table_name, lua_CFunction error_handler) {
@@ -221,7 +232,7 @@ static int wslua_panic(lua_State* LS) {
 }
 
 int wslua_init(lua_State* LS) {
-    const gchar* filename;
+    gchar* filename;
     const funnel_ops_t* ops = funnel_get_funnel_ops();
     gboolean run_anyway = FALSE;
 
@@ -263,6 +274,9 @@ int wslua_init(lua_State* LS) {
         lua_load_script(filename);
     }
 
+    g_free(filename);
+    filename = NULL;
+
     /* check if lua is to be disabled */
     lua_pushstring(L,"disable_lua");
     lua_gettable(L, LUA_GLOBALSINDEX);
@@ -285,13 +299,15 @@ int wslua_init(lua_State* LS) {
 
     /* if we are indeed superuser run user scripts only if told to do so */
     if ( (!started_with_special_privs()) || run_anyway ) {
-        filename = get_persconffile_path("init.lua", FALSE);
+        filename = get_persconffile_path("init.lua", FALSE, FALSE);
 
         if (( file_exists(filename))) {
             lua_load_script(filename);
+	    g_free(filename);
+	    filename = NULL;
         }
 
-        while((filename = ex_opt_get_next("lua_script"))) {
+        while((filename = (gchar *)ex_opt_get_next("lua_script"))) {
             lua_load_script(filename);
         }
     }
