@@ -4,8 +4,9 @@
  * Wireshark's interface to the Lua Programming Language
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  *
- * $Id: wslua.h 19992 2006-11-26 18:31:53Z wmeier $
+ * $Id: wslua.h 24199 2008-01-26 15:28:37Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,6 +53,9 @@
 #include <epan/funnel.h>
 #include <epan/tvbparse.h>
 #include <epan/epan.h>
+#if GLIB_MAJOR_VERSION < 2
+#include <dirent.h>
+#endif
 
 #include "declare_wslua.h"
 
@@ -76,7 +80,19 @@ typedef struct _wslua_field_t {
     guint32 mask;
 } wslua_field_t;
 
-typedef enum {PREF_NONE,PREF_BOOL,PREF_UINT,PREF_STRING} pref_type_t;
+/*
+ * PREF_OBSOLETE is used for preferences that a module used to support
+ * but no longer supports; we give different error messages for them.
+ */
+typedef enum {
+	PREF_UINT,
+	PREF_BOOL,
+	PREF_ENUM,
+	PREF_STRING,
+	PREF_RANGE,
+	PREF_STATIC_TEXT,
+	PREF_OBSOLETE
+} pref_type_t;
 
 typedef struct _wslua_pref_t {
     gchar* name;
@@ -87,8 +103,20 @@ typedef struct _wslua_pref_t {
         gboolean b;
         guint u;
         const gchar* s;
-		void* p;
+        gint e;
+	range_t *r;
+	void* p;
     } value;
+    union {
+  	guint32 max_value;		/* maximum value of a range */
+  	struct {
+  	    const enum_val_t *enumvals;	/* list of name & values */
+  	    gboolean radio_buttons;	/* TRUE if it should be shown as
+  					   radio buttons rather than as an
+  					   option menu or combo box in
+  					   the preferences tab */
+  	} enum_info;			/* for PREF_ENUM */
+    } info;			        /* display/text file information */
     
     struct _wslua_pref_t* next;
     struct _wslua_proto_t* proto;
@@ -276,7 +304,7 @@ int dummy##C
 #define WSLUA_META static const luaL_reg
 #define WSLUA_CLASS_FNREG(class,name) { #name, class##_##name }
 
-#define WSLUA_ERROR(name,error) { luaL_error(L, #name  ": " error); return 0; }
+#define WSLUA_ERROR(name,error) { luaL_error(L, ep_strdup_printf("%s%s", #name ": " ,error) ); return 0; }
 #define WSLUA_ARG_ERROR(name,attr,error) { luaL_argerror(L,WSLUA_ARG_ ## name ## _ ## attr, #name  ": " error); return 0; }
 #define WSLUA_OPTARG_ERROR(name,attr,error) { luaL_argerror(L,WSLUA_OPTARG_##name##_ ##attr, #name  ": " error); return 0; }
 
@@ -317,7 +345,7 @@ extern lua_State* wslua_state(void);
 
 extern gboolean wslua_optbool(lua_State* L, int n, gboolean def);
 extern const gchar* lua_shiftstring(lua_State* L,int idx);
-extern void dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree);
+extern int dissect_lua(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree);
 
 extern void proto_register_lua(void);
 extern GString* lua_register_all_taps(void);
