@@ -4,8 +4,9 @@
  * wireshark's interface to the Lua Programming Language
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ * (c) 2007, Tamas Regos <tamas.regos@ericsson.com>
  *
- * $Id: wslua_proto.c 19676 2006-10-24 22:21:04Z gerald $
+ * $Id: wslua_proto.c 24026 2008-01-07 21:24:23Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,6 +33,72 @@
 
 WSLUA_CLASS_DEFINE(Pref,NOP,NOP); /* A preference of a Protocol. */
 
+static range_t* get_range(lua_State *L, int idx_r, int idx_m)
+{
+  static range_t *ret;
+    range_convert_str(&ret,g_strdup(lua_tostring(L, idx_r)),(guint32)lua_tonumber(L, idx_m));
+  return ret;
+}
+
+static enum_val_t* get_enum(lua_State *L, int idx)
+{
+  double seq;
+  const gchar *str1, *str2;
+  enum_val_t *ret, last = {NULL, NULL, -1};
+  GArray* es = g_array_new(TRUE,TRUE,sizeof(enum_val_t));
+
+  luaL_checktype(L, idx, LUA_TTABLE);
+  lua_pushnil(L);  /* first key */
+
+  while (lua_next(L, idx)) {
+    enum_val_t e = {NULL, NULL, -1};
+
+    luaL_checktype(L, -1, LUA_TTABLE);
+    lua_pushnil(L);
+    lua_next(L, -2);
+    if (! lua_isstring(L,-1)) {
+        luaL_argerror(L,idx,"First value of an enum table must be string");
+        g_array_free(es,TRUE);
+        return NULL;
+    }
+    str1 = lua_tostring(L, -1);
+    
+    lua_pop(L, 1);
+    lua_next(L, -2);
+    if (! lua_isstring(L,-1)) {
+        luaL_argerror(L,idx,"Second value of an enum table must be string");
+        g_array_free(es,TRUE);
+        return NULL;
+    }
+    str2 = lua_tostring(L, -1);
+    
+    lua_pop(L, 1);
+    lua_next(L, -2);
+    if (! lua_isnumber(L,-1)) {
+        luaL_argerror(L,idx,"Third value of an enum table must be an integer");
+        g_array_free(es,TRUE);
+        return NULL;
+    }
+    seq = lua_tonumber(L, -1);
+
+    e.name = g_strdup(str1);
+    e.description = g_strdup(str2);
+    e.value = (guint32)seq;
+    
+    g_array_append_val(es,e);
+    
+    lua_pop(L, 3);  /* removes 'value'; keeps 'key' for next iteration */
+  }
+  
+  g_array_append_val(es,last);
+  
+  ret = (enum_val_t*)es->data;
+
+  g_array_free(es,FALSE);
+
+  return ret;
+}
+
 static int new_pref(lua_State* L, pref_type_t type) {
     const gchar* label = luaL_optstring(L,1,NULL);
     const gchar* descr = luaL_optstring(L,3,"");
@@ -60,6 +127,26 @@ static int new_pref(lua_State* L, pref_type_t type) {
             pref->value.s = def;
             break;
         }
+        case PREF_ENUM: {
+            guint32 def = (guint32)luaL_optnumber(L,2,0);
+            enum_val_t *enum_val = get_enum(L,4);
+            gboolean radio = lua_toboolean(L,5);
+            pref->value.e = def;
+            pref->info.enum_info.enumvals = enum_val;
+            pref->info.enum_info.radio_buttons = radio;
+            break;
+        }
+        case PREF_RANGE: {
+            range_t *range = get_range(L,4,5);
+            guint32 max = (guint32)luaL_optnumber(L,5,0);
+            pref->value.r = range;
+            pref->info.max_value = max;
+            break;
+        }
+        case PREF_STATIC_TEXT: {
+            /* This is just a static text. */
+	    break;
+        }
         default:
             g_assert_not_reached();
             break;
@@ -75,9 +162,9 @@ WSLUA_CONSTRUCTOR Pref_bool(lua_State* L) {
 	/*
 	 * Creates a boolean preference to be added to a Protocol's prefs table.
 	 */
-#define WSLUA_ATTR_Pref_bool_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
-#define WSLUA_ATTR_Pref_bool_DEFAULT 2 /* The default value for this preference */
-#define WSLUA_ATTR_Pref_bool_DESCR 3 /* A description of what this preference is */
+#define WSLUA_ARG_Pref_bool_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
+#define WSLUA_ARG_Pref_bool_DEFAULT 2 /* The default value for this preference */
+#define WSLUA_ARG_Pref_bool_DESCR 3 /* A description of what this preference is */
     return new_pref(L,PREF_BOOL);
 }
 
@@ -85,9 +172,9 @@ WSLUA_CONSTRUCTOR Pref_uint(lua_State* L) {
 	/*
 	 * Creates an (unsigned) integer preference to be added to a Protocol's prefs table.
 	 */
-#define WSLUA_ATTR_Pref_uint_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
-#define WSLUA_ATTR_Pref_uint_DEFAULT 2 /* The default value for this preference */
-#define WSLUA_ATTR_Pref_uint_DESCR 3 /* A description of what this preference is */
+#define WSLUA_ARG_Pref_uint_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
+#define WSLUA_ARG_Pref_uint_DEFAULT 2 /* The default value for this preference */
+#define WSLUA_ARG_Pref_uint_DESCR 3 /* A description of what this preference is */
     return new_pref(L,PREF_UINT);
 }
 
@@ -95,12 +182,45 @@ WSLUA_CONSTRUCTOR Pref_string(lua_State* L) {
 	/*
 	 * Creates a string preference to be added to a Protocol's prefs table.
 	 */
-#define WSLUA_ATTR_Pref_string_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
-#define WSLUA_ATTR_Pref_string_DEFAULT 2 /* The default value for this preference */
-#define WSLUA_ATTR_Pref_string_DESCR 3 /* A description of what this preference is */
+#define WSLUA_ARG_Pref_string_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
+#define WSLUA_ARG_Pref_string_DEFAULT 2 /* The default value for this preference */
+#define WSLUA_ARG_Pref_string_DESCR 3 /* A description of what this preference is */
     return new_pref(L,PREF_STRING);
 }
 
+WSLUA_CONSTRUCTOR Pref_enum(lua_State* L) {
+	/*
+	 * Creates an enum preference to be added to a Protocol's prefs table.
+	 */
+#define WSLUA_ARG_Pref_enum_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
+#define WSLUA_ARG_Pref_enum_DEFAULT 2 /* The default value for this preference */
+#define WSLUA_ARG_Pref_enum_DESCR 3 /* A description of what this preference is */
+#define WSLUA_ARG_Pref_enum_ENUM 4 /* enum */
+#define WSLUA_ARG_Pref_enum_RADIO 5 /* radio_button or combobox */
+    return new_pref(L,PREF_ENUM);
+}
+
+WSLUA_CONSTRUCTOR Pref_range(lua_State* L) {
+	/*
+	 * Creates a range preference to be added to a Protocol's prefs table.
+	 */
+#define WSLUA_ARG_Pref_enum_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
+#define WSLUA_ARG_Pref_enum_DEFAULT 2 /* The default value for this preference */
+#define WSLUA_ARG_Pref_enum_DESCR 3 /* A description of what this preference is */
+#define WSLUA_ARG_Pref_enum_RANGE 4 /* The range */
+#define WSLUA_ARG_Pref_enum_MAX 5 /* The maximum value */
+    return new_pref(L,PREF_RANGE);
+}
+
+WSLUA_CONSTRUCTOR Pref_stext(lua_State* L) {
+	/*
+	 * Creates a static text preference to be added to a Protocol's prefs table.
+	 */
+#define WSLUA_ARG_Pref_enum_LABEL 1 /* The Label (text in the right side of the preference input) for this preference */
+#define WSLUA_ARG_Pref_enum_TEXT 2 /* The static text */
+    return new_pref(L,PREF_STATIC_TEXT);
+}
+
 static int Pref_gc(lua_State* L) {
     Pref pref = checkPref(L,1);
     
@@ -117,7 +237,10 @@ static int Pref_gc(lua_State* L) {
 WSLUA_METHODS Pref_methods[] = {
     {"bool",   Pref_bool},
     {"uint",   Pref_uint},
-    {"string",   Pref_string},
+    {"string", Pref_string},
+    {"enum",   Pref_enum},
+    {"range",  Pref_range},
+    {"statictext",  Pref_stext},
     {0,0}
 };
 
@@ -202,6 +325,29 @@ WSLUA_METAMETHOD Prefs__newindex(lua_State* L) {
                                                      pref->desc,
                                                      &(pref->value.s));
                     break;
+                case PREF_ENUM:
+                    prefs_register_enum_preference(prefs->proto->prefs_module, 
+                                                     pref->name,
+                                                     pref->label,
+                                                     pref->desc,
+                                                     &(pref->value.e),
+                                                     pref->info.enum_info.enumvals,
+                                                     pref->info.enum_info.radio_buttons);
+                    break;
+                case PREF_RANGE:
+                    prefs_register_range_preference(prefs->proto->prefs_module, 
+                                                     pref->name,
+                                                     pref->label,
+                                                     pref->desc,
+                                                     &(pref->value.r),
+						     pref->info.max_value);
+                    break;
+                case PREF_STATIC_TEXT:
+                    prefs_register_static_text_preference(prefs->proto->prefs_module, 
+                                                     pref->name,
+                                                     pref->label,
+                                                     "This is just a static text");
+                    break;
                 default:
                     WSLUA_ERROR(Prefs__newindex,"unknow Pref type");
             }
@@ -234,6 +380,8 @@ WSLUA_METAMETHOD Prefs__index(lua_State* L) {
                 case PREF_BOOL: lua_pushboolean(L, prefs->value.b); break;
                 case PREF_UINT: lua_pushnumber(L,(lua_Number)prefs->value.u); break;
                 case PREF_STRING: lua_pushstring(L,prefs->value.s); break;
+                case PREF_ENUM: lua_pushnumber(L,(lua_Number)prefs->value.e); break;
+                case PREF_RANGE: lua_pushstring(L,range_convert_range(prefs->value.r)); break;
                 default: WSLUA_ERROR(Prefs__index,"unknow Pref type");
             }
             WSLUA_RETURN(1); /* the current value of the preference */
@@ -474,23 +622,105 @@ static int ProtoField_integer(lua_State* L, enum ftenum type) {
 }
 
 #define PROTOFIELD_INTEGER(lower,FT) static int ProtoField_##lower(lua_State* L) { return ProtoField_integer(L,FT); }
-/* WSLUA_SECTION Protofield integer constructors */
-/* WSLUA_TEXT integer type ProtoField constructors use the following arguments */
-/* WSLUA_ARG_DESC Protofield_integer ABBR abbreviated name of the field (the string used in filters)  */
-/* WSLUA_OPTARG_DESC Protofield_integer NAME Actual name of the field (the string that appears in the tree)  */
-/* WSLUA_ARGDESC Protofield_integer DESC description of the field  */
-/* _WSLUA_RETURNS_ Protofield_integer a protofiled item to be added to a ProtoFieldArray */
 /* _WSLUA_CONSTRUCTOR_ ProtoField_uint8 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_uint16 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_uint24 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_uint32 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_uint64 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_int8 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_int16 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_int24 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_int32 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_int64 */
-/* _WSLUA_CONSTRUCTOR_ ProtoField_framenum */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
+/* _WSLUA_CONSTRUCTOR_ ProtoField_framenum a frame number (for hyperlinks between frames) */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_BASE one of base.DEC, base.HEX or base.OCT */
+/* WSLUA_OPTARG_Protofield_uint8_VALUESTRING a table containing the text that corresponds to the values  */
+/* WSLUA_OPTARG_Protofield_uint8_MASK integer mask of this field  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 PROTOFIELD_INTEGER(uint8,FT_UINT8)
 PROTOFIELD_INTEGER(uint16,FT_UINT16)
 PROTOFIELD_INTEGER(uint24,FT_UINT24)
@@ -525,24 +755,78 @@ static int ProtoField_other(lua_State* L,enum ftenum type) {
 }
 
 #define PROTOFIELD_OTHER(lower,FT) static int ProtoField_##lower(lua_State* L) { return ProtoField_other(L,FT); }
-/* WSLUA_SECTION Protofield integer constructors */
-/* WSLUA_TEXT integer type ProtoField constructors use the following arguments */
-/* WSLUA_ARG_DESC Protofield_integer ABBR abbreviated name of the field (the string used in filters)  */
-/* WSLUA_OPTARG_DESC Protofield_integer NAME Actual name of the field (the string that appears in the tree)  */
-/* WSLUA_ARGDESC Protofield_integer DESC : description of the field  */
-/* _WSLUA_RETURNS_ Protofield non integer : a protofiled item to be added to a ProtoFieldArray */
 /* _WSLUA_CONSTRUCTOR_ ProtoField_ipv4 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_ipv6 */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_ether */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_float */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_double */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_string */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_strigz */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_bytes */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_ubytes */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_guid */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_oid */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 /* _WSLUA_CONSTRUCTOR_ ProtoField_bool */
+/* WSLUA_ARG_Protofield_uint8_ABBR abbreviated name of the field (the string used in filters)  */
+/* WSLUA_OPTARG_Protofield_uint8_NAME Actual name of the field (the string that appears in the tree)  */
+/* WSLUA_OPTARG_Protofield_uint8_DESC description of the field  */
+/* _WSLUA_RETURNS_ a protofield item to be added to a ProtoFieldArray */
+
 PROTOFIELD_OTHER(ipv4,FT_IPv4)
 PROTOFIELD_OTHER(ipv6,FT_IPv6)
 PROTOFIELD_OTHER(ipx,FT_IPXNET)
@@ -560,7 +844,8 @@ PROTOFIELD_OTHER(oid,FT_OID)
 PROTOFIELD_OTHER(bool,FT_BOOLEAN)
 
 
-static int ProtoField_tostring(lua_State* L) {
+WSLUA_METAMETHOD ProtoField_tostring(lua_State* L) {
+	/* Returns a string w/ info about a protofiled (for debugging purposes) */
     ProtoField f = checkProtoField(L,1);
     gchar* s = g_strdup_printf("ProtoField(%i): %s %s %s %s %p %.8x %s",f->hfid,f->name,f->abbr,ftenum_to_string(f->type),base_to_string(f->base),f->vs,f->mask,f->blob);
     
@@ -717,13 +1002,15 @@ static int Proto_tostring(lua_State* L) {
     return 1;
 }
 
-WSLUA_FUNCTION wslua_register_postdissector(lua_State* L) { 
+WSLUA_FUNCTION wslua_register_postdissector(lua_State* L) {
+	/* make a protocol (with a dissector) a postdissector. It will be called for every frame after dissection */
+#define WSLUA_ARG_register_postdissector_PROTO 1 /* the protocol to be used as postdissector */
     Proto proto = checkProto(L,1);
     if (!proto) return 0;
     
     if(!proto->is_postdissector) {
         if (! proto->handle) {
-            proto->handle = create_dissector_handle(dissect_lua, proto->hfid);
+            proto->handle = new_create_dissector_handle(dissect_lua, proto->hfid);
         }
         
         register_postdissector(proto->handle);
@@ -753,15 +1040,19 @@ static int Proto_set_dissector(lua_State* L) {
 
 	if (lua_isfunction(L,3)) {
         /* insert the dissector into the dissectors table */
-       
+		gchar* loname = ep_strdup(proto->name);
+		g_strdown(loname);
+
         lua_rawgeti(L, LUA_REGISTRYINDEX, lua_dissectors_table_ref);
         lua_replace(L, 1);
         lua_pushstring(L,proto->name);
         lua_replace(L, 2);
         lua_settable(L,1);
         
-        proto->handle = create_dissector_handle(dissect_lua, proto->hfid);
+        proto->handle = new_create_dissector_handle(dissect_lua, proto->hfid);
         
+	new_register_dissector(loname, dissect_lua, proto->hfid);
+		
         return 0;
     } else {
         luaL_argerror(L,3,"The dissector of a protocol must be a function");
@@ -858,10 +1149,10 @@ typedef struct {
 } proto_actions_t;
 
 static const proto_actions_t proto_actions[] = {
-	/* WSLUA_ATTRIBUTE Pinfo_dissector RW the protocol's dissector, a function you define */
+	/* WSLUA_ATTRIBUTE Proto_dissector RW the protocol's dissector, a function you define */
     {"dissector",Proto_get_dissector, Proto_set_dissector},
 
-	/* WSLUA_ATTRIBUTE Pinfo_fields RO the Fields Table of this dissector */
+	/* WSLUA_ATTRIBUTE Proto_fields RO the Fields Table of this dissector */
     {"fields" ,Proto_get_fields, Proto_set_fields},
 	
 	/* WSLUA_ATTRIBUTE Proto_get_prefs RO the preferences of this dissector */
@@ -870,7 +1161,7 @@ static const proto_actions_t proto_actions[] = {
 	/* WSLUA_ATTRIBUTE Proto_init WO the init routine of this dissector, a function you define */
     {"init",NULL,Proto_set_init},
 
-	/* WSLUA_ATTRIBUTE Proto_init RO the name given to this dissector */
+	/* WSLUA_ATTRIBUTE Proto_name RO the name given to this dissector */
     {"name",Proto_get_name,NULL},
     {NULL,NULL,NULL}
 };
@@ -1021,7 +1312,8 @@ WSLUA_METHOD Dissector_call(lua_State* L) {
     Tvb tvb = checkTvb(L,WSLUA_ARG_Dissector_call_TVB);
     Pinfo pinfo = checkPinfo(L,WSLUA_ARG_Dissector_call_PINFO);
     TreeItem ti = checkTreeItem(L,WSLUA_ARG_Dissector_call_TREE);
-    
+    char* error = NULL;
+	
     if (! ( d && tvb && pinfo) ) return 0;
     
     TRY {
@@ -1029,15 +1321,16 @@ WSLUA_METHOD Dissector_call(lua_State* L) {
 		/* XXX Are we sure about this??? is this the right/only thing to catch */
     } CATCH(ReportedBoundsError) {
         proto_tree_add_protocol_format(lua_tree->tree, lua_malformed, lua_tvb, 0, 0, "[Malformed Frame: Packet Length]" );
-        WSLUA_ERROR(Dissector_call,"malformed frame");
-        return 0;
+	error = "malformed frame";
     } ENDTRY;
-    
+
+     if (error) { WSLUA_ERROR(Dissector_call,error); }
+
     return 0;
 }
 
 
-static int Dissector_tostring(lua_State* L) {
+WSLUA_METAMETHOD Dissector_tostring(lua_State* L) {
     Dissector d = checkDissector(L,1);
     if (!d) return 0;
     lua_pushstring(L,dissector_handle_get_short_name(d));
@@ -1221,7 +1514,8 @@ WSLUA_METHOD DissectorTable_try (lua_State *L) {
     Pinfo pinfo = checkPinfo(L,4);
     TreeItem ti = checkTreeItem(L,5);
     ftenum_t type;
-    
+    gchar* error = NULL;
+	
     if (! (dt && tvb && pinfo && ti) ) return 0;
     
     type = get_dissector_table_selector_type(dt->name);
@@ -1251,9 +1545,11 @@ WSLUA_METHOD DissectorTable_try (lua_State *L) {
 		/* XXX Are we sure about this??? is this the right/only thing to catch */
 	} CATCH(ReportedBoundsError) {
 		proto_tree_add_protocol_format(lua_tree->tree, lua_malformed, lua_tvb, 0, 0, "[Malformed Frame: Packet Length]" );
-		WSLUA_ERROR(DissectorTable_try,"malformed frame");
+		error = "malformed frame";
 	} ENDTRY;
 
+	if (error) { WSLUA_ERROR(DissectorTable_try,error); }
+
 	return 0;
 	
 }
@@ -1293,7 +1589,8 @@ WSLUA_METHOD DissectorTable_get_dissector (lua_State *L) {
 }
 
 
-static int DissectorTable_tostring(lua_State* L) {
+WSLUA_METAMETHOD DissectorTable_tostring(lua_State* L) {
+/**/
 	/* XXX It would be nice to iterate and print which dissectors it has */
     DissectorTable dt = checkDissectorTable(L,1);
     GString* s;
@@ -1350,3 +1647,4 @@ int DissectorTable_register(lua_State* L) {
 
 
 
+
