@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
  *
- * $Id: wslua_tvb.c 20628 2007-01-30 19:19:21Z gerald $
+ * $Id: wslua_tvb.c 23211 2007-10-16 23:42:33Z sake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -213,7 +213,7 @@ WSLUA_METHOD ByteArray_len(lua_State* L) {
 WSLUA_METHOD ByteArray_subset(lua_State* L) {
 	/* obtain a segment of a ByteArray */
 #define WSLUA_ARG_ByteArray_set_index_OFFSET 2 /* the position of the first byte */
-#define WSLUA_ARG_ByteArray_set_index_LENGTH 2 /* the lenght of the segment */
+#define WSLUA_ARG_ByteArray_set_index_LENGTH 2 /* the length of the segment */
     ByteArray ba = checkByteArray(L,1);
     int offset = luaL_checkint(L,2);
     int len = luaL_checkint(L,3);
@@ -305,7 +305,7 @@ int ByteArray_register(lua_State* L) {
  * Tvb & TvbRange
  *
  * a Tvb represents a tvbuff_t in Lua.
- * a TvbRange represents a range in a tvb (tvb,offset,lenght) it's main purpose is to do bounds checking,
+ * a TvbRange represents a range in a tvb (tvb,offset,length) it's main purpose is to do bounds checking,
  *            it helps too simplifing argument passing to Tree. In wireshark terms this is worthless nothing
  *            not already done by the TVB itself. In lua's terms is necessary to avoid abusing TRY{}CATCH(){}
  *            via preemptive bounds checking.
@@ -415,7 +415,7 @@ WSLUA_METHOD Tvb_len(lua_State* L) {
     if (!tvb) return 0;
 
     lua_pushnumber(L,tvb_length(tvb));
-    WSLUA_RETURN(1); /* the lenght of the Tvb. */
+    WSLUA_RETURN(1); /* the length of the Tvb. */
 }
 
 WSLUA_METHOD Tvb_offset(lua_State* L) {
@@ -439,7 +439,7 @@ WSLUA_METAMETHOD Tvb__call(lua_State* L) {
 WSLUA_CLASS_DEFINE(TvbRange,FAIL_ON_NULL("expired tvbrange"),NOP);
 /*
  *  a TvbRange represents an usable range of a Tvb and is used to extract data from the Tvb that generated it
- * TvbRanges are created by calling a tvb (e.g. tvb(offset,lenght)). If the TvbRange span is outside the Tvb's range the creation will cause a runtime error.
+ * TvbRanges are created by calling a tvb (e.g. tvb(offset,length)). If the TvbRange span is outside the Tvb's range the creation will cause a runtime error.
  */
 
 TvbRange new_TvbRange(lua_State* L, tvbuff_t* tvb, int offset, int len) {
@@ -510,7 +510,7 @@ int Tvb_register(lua_State* L) {
  */
 static int TvbRange_get_index(lua_State* L) {
 	/* WSLUA_ATTRIBUTE TvbRange_tvb RO The Tvb from which this TvbRange was generated */
-	/* WSLUA_ATTRIBUTE TvbRange_len RW The lenght (in octets) of this TvbRange */
+	/* WSLUA_ATTRIBUTE TvbRange_len RW The length (in octets) of this TvbRange */
 	/* WSLUA_ATTRIBUTE TvbRange_offset RW The offset (in octets) of this TvbRange */
 
     TvbRange tvbr = checkTvbRange(L,1);
@@ -694,7 +694,7 @@ WSLUA_METHOD TvbRange_get_ipv4(lua_State* L) {
     addr = g_malloc(sizeof(address));
 
     ip_addr = g_malloc(sizeof(guint32));
-    *ip_addr = tvb_get_ntohl(tvbr->tvb,tvbr->offset);
+    *ip_addr = tvb_get_ipv4(tvbr->tvb,tvbr->offset);
 
     SET_ADDRESS(addr, AT_IPv4, 4, ip_addr);
     pushAddress(L,addr);
@@ -702,6 +702,30 @@ WSLUA_METHOD TvbRange_get_ipv4(lua_State* L) {
 	WSLUA_RETURN(1); /* the IPv4 Address */
 }
 
+WSLUA_METHOD TvbRange_get_le_ipv4(lua_State* L) {
+	/* get an Little Endian IPv4 Address from a TvbRange. */
+	
+    TvbRange tvbr = checkTvbRange(L,1);
+    Address addr;
+    guint32* ip_addr;
+	
+    if ( !tvbr ) return 0;
+	
+	if (tvbr->len != 4)
+		WSLUA_ERROR(TvbRange_get_ipv4,"The range must be 4 octets long");
+	
+    addr = g_malloc(sizeof(address));
+	
+    ip_addr = g_malloc(sizeof(guint32));
+    *ip_addr = tvb_get_ipv4(tvbr->tvb,tvbr->offset);
+    *((guint32 *)ip_addr) = GUINT32_SWAP_LE_BE(*((guint32 *)ip_addr));
+	
+    SET_ADDRESS(addr, AT_IPv4, 4, ip_addr);
+    pushAddress(L,addr);
+	
+	WSLUA_RETURN(1); /* the IPv4 Address */
+}
+
 WSLUA_METHOD TvbRange_get_ether(lua_State* L) {
 	/* get an Ethernet Address from a TvbRange. */
     TvbRange tvbr = checkTvbRange(L,1);
@@ -769,6 +793,7 @@ static const luaL_reg TvbRange_methods[] = {
     {"le_float", TvbRange_get_le_float},
     {"ether", TvbRange_get_ether},
     {"ipv4", TvbRange_get_ipv4},
+	{"le_ipv4", TvbRange_get_le_ipv4},
     {"string", TvbRange_get_string},
     {"bytes", TvbRange_get_bytes},
     {"tvb", Tvb_new_subset},
