@@ -104,7 +104,7 @@ extern void xmlCheckVersion(int version);
 /*
  * Whether iconv support is available
  */
-#ifdef HAVE_ICONV_H
+#ifdef HAVE_ICONV
 #define LIBXML_ICONV_ENABLED
 #include <iconv.h>
 #else
@@ -1092,7 +1092,7 @@ typedef struct {
 	xmlNodePtr         (*xmlDocGetRootElement)(xmlDocPtr);
 	void             (*xmlFreeDoc)(xmlDocPtr);
 	char            *(*xmlNodeListGetString)(xmlDocPtr, xmlNodePtr, int);
-	char            *(*xmlGetProp)(xmlNodePtr, char *);
+	char            *(*xmlGetProp)(xmlNodePtr, const char *);
 	int              (*xmlKeepBlanksDefault)(int);
 	int              (*xmlSubstituteEntitiesDefault)(int);
 #ifdef WIRESHARK_XML_DO_VALIDITY_CHECKING
