@@ -1,7 +1,7 @@
 /* conversations_fc.c
  * conversations_fc   2003 Ronnie Sahlberg
  *
- * $Id: conversations_fc.c 19492 2006-10-11 10:38:59Z sahlberg $
+ * $Id: conversations_fc.c 23516 2007-11-20 18:35:41Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,7 @@
 #include <epan/tap.h>
 #include "../register.h"
 #include "conversations_table.h"
+#include <epan/conversation.h>
 #include <epan/dissectors/packet-scsi.h>
 #include <epan/dissectors/packet-fc.h>
 
@@ -48,7 +49,7 @@ fc_conversation_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_, c
 {
 	const fc_hdr *fchdr=vip;
 
-	add_conversation_table_data((conversations_table *)pct, &fchdr->s_id, &fchdr->d_id, 0, 0, 1, pinfo->fd->pkt_len, SAT_NONE, PT_NONE);
+	add_conversation_table_data((conversations_table *)pct, &fchdr->s_id, &fchdr->d_id, 0, 0, 1, pinfo->fd->pkt_len, &pinfo->fd->rel_ts, SAT_NONE, PT_NONE);
 
 	return 1;
 }
