@@ -5,7 +5,7 @@
  *
  * (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
  *
- * $Id: funnel_stat.c 20223 2006-12-27 01:46:42Z lego $
+ * $Id: funnel_stat.c 21526 2007-04-23 10:59:26Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -549,7 +549,7 @@ static void funnel_retap_packets(void) {
 	cf_retap_packets(&cfile, FALSE);
 }
 
-static gboolean funnel_open_file(const char* fname, const char* filter, char** err_str) {
+static gboolean funnel_open_file(const char* fname, const char* filter, const char** err_str) {
 	int err = 0;
 	dfilter_t   *rfcode = NULL;
 	
