@@ -1,7 +1,7 @@
 /* hostlist_fc.c   2004 Ian Schorr
  * modified from endpoint_talkers_fc.c   2003 Ronnie Sahlberg
  *
- * $Id: hostlist_fc.c 19492 2006-10-11 10:38:59Z sahlberg $
+ * $Id: hostlist_fc.c 24368 2008-02-17 00:35:55Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -72,7 +72,7 @@ gtk_fc_hostlist_init(const char *optarg, void* userdata _U_)
 		filter=NULL;
 	}
 
-	init_hostlist_table(TRUE, "Fibre Channel Hosts", "fc", filter, fc_hostlist_packet);
+	init_hostlist_table(TRUE, "Fibre Channel", "fc", filter, fc_hostlist_packet);
 
 }
 
