@@ -1,7 +1,7 @@
 /* prefs_dlg.c
  * Routines for handling preferences
  *
- * $Id: prefs_dlg.c 19674 2006-10-24 21:50:59Z gerald $
+ * $Id: prefs_dlg.c 24513 2008-03-01 10:23:57Z tuexen $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,12 +45,15 @@
 #include "layout_prefs.h"
 #include "capture_prefs.h"
 #include "nameres_prefs.h"
+#include "rtp_player_prefs.h"
 #include "gui_utils.h"
 #include "dlg_utils.h"
 #include "simple_dialog.h"
 #include "compat_macros.h"
 #include "help_dlg.h"
 #include "keys.h"
+#include "uat_gui.h"
+#include <epan/strutil.h>
 
 #include <epan/prefs-int.h>
 
@@ -58,13 +61,16 @@
 #ifdef _WIN32
 #include "capture-wpcap.h"
 #endif /* _WIN32 */
-#endif /* HAVE_LIBPCAP */
-
 #ifdef HAVE_AIRPCAP
 #include "airpcap.h"
 #include "airpcap_loader.h"
 #include "airpcap_gui_utils.h"
 #endif
+#endif
+
+#ifdef NEED_G_ASCII_STRCASECMP_H
+#include "../epan/g_ascii_strcasecmp.h"
+#endif
 
 static void     prefs_main_ok_cb(GtkWidget *, gpointer);
 static void     prefs_main_apply_cb(GtkWidget *, gpointer);
@@ -79,6 +85,7 @@ static void	prefs_tree_select_cb(GtkCTree *, GtkCTreeNode *, gint,
 static void	prefs_tree_select_cb(GtkTreeSelection *, gpointer);
 #endif
 
+
 #define E_PREFSW_SCROLLW_KEY    "prefsw_scrollw"
 #define E_PREFSW_TREE_KEY       "prefsw_tree"
 #define E_PREFSW_NOTEBOOK_KEY   "prefsw_notebook"
@@ -95,6 +102,7 @@ static void	prefs_tree_select_cb(GtkTreeSelection *, gpointer);
 #define E_CAPTURE_PAGE_KEY      "capture_options_page"
 #define E_PRINT_PAGE_KEY        "printer_options_page"
 #define E_NAMERES_PAGE_KEY      "nameres_options_page"
+#define E_RTP_PLAYER_PAGE_KEY   "rtp_player_options_page"
 
 /*
  * Keep a static pointer to the current "Preferences" window, if any, so that
@@ -125,6 +133,8 @@ struct ct_struct {
   gboolean     is_protocol;
 };
 
+static gint blank_page = 0;
+
 static guint
 pref_exists(pref_t *pref _U_, gpointer user_data _U_)
 {
@@ -138,14 +148,22 @@ pref_show(pref_t *pref, gpointer user_data)
   GtkWidget *main_tb = user_data;
   const char *title;
   char *label_string;
+  size_t label_len;
   char uint_str[10+1];
 
   /* Give this preference a label which is its title, followed by a colon,
      and left-align it. */
   title = pref->title;
-  label_string = g_malloc(strlen(title) + 2);
-  strcpy(label_string, title);
-  strcat(label_string, ":");
+  label_len = strlen(title) + 2;
+  label_string = g_malloc(label_len);
+  g_strlcpy(label_string, title, label_len);
+
+  /*
+   * Sometimes we don't want to append a ':' after a static text string...
+   * If it is needed, we will specify it in the string itself.
+   */
+  if(pref->type != PREF_STATIC_TEXT)
+    g_strlcat(label_string, ":", label_len);
 
   /* Save the current value of the preference, so that we can revert it if
      the user does "Apply" and then "Cancel", and create the control for
@@ -225,6 +243,21 @@ pref_show(pref_t *pref, gpointer user_data)
     break;
   }
 
+  case PREF_STATIC_TEXT:
+  {
+    pref->control = create_preference_static_text(main_tb, pref->ordinal,
+					    label_string, pref->description);
+    break;
+  }
+
+  case PREF_UAT:
+  {
+    pref->control = create_preference_uat(main_tb, pref->ordinal,
+                                          label_string, pref->description,
+										  pref->varp.uat);
+    break;
+  }
+	  
   case PREF_OBSOLETE:
     g_assert_not_reached();
     break;
@@ -254,7 +287,7 @@ module_prefs_show(module_t *module, gpointer user_data)
   /*
    * Is this module a subtree, with modules underneath it?
    */
-  if (!module->is_subtree) {
+  if (!prefs_module_has_submodules(module)) {
     /*
      * No.
      * Does it have any preferences (other than possibly obsolete ones)?
@@ -273,28 +306,27 @@ module_prefs_show(module_t *module, gpointer user_data)
   /*
    * Add this module to the tree.
    */
-  strcpy(label_str, module->title);
+  g_strlcpy(label_str, module->title, MAX_TREE_NODE_NAME_LEN);
 #if GTK_MAJOR_VERSION < 2
   ct_node = gtk_ctree_insert_node(GTK_CTREE(cts->tree), cts->node, NULL,
-  		&label_ptr, 5, NULL, NULL, NULL, NULL, !module->is_subtree,
+  		&label_ptr, 5, NULL, NULL, NULL, NULL, !prefs_module_has_submodules(module),
   		FALSE);
 #else
   model = GTK_TREE_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(cts->tree)));
-  if (module->is_subtree)
-      gtk_tree_store_append(model, &iter, NULL);
-  else
-      gtk_tree_store_append(model, &iter, &cts->iter);
+  if (prefs_module_has_submodules(module) && !cts->iter.stamp)
+    gtk_tree_store_append(model, &iter, NULL);
+  else 
+    gtk_tree_store_append(model, &iter, &cts->iter);
 #endif
 
   /*
    * Is this a subtree?
    */
-  if (module->is_subtree) {
+  if (prefs_module_has_submodules(module)) {
     /*
      * Yes.
      */
 
-    /* Note that there's no page attached to this item */
 #if GTK_MAJOR_VERSION < 2
     gtk_ctree_node_set_row_data(GTK_CTREE(cts->tree), ct_node,
   		GINT_TO_POINTER(-1));
@@ -313,10 +345,15 @@ module_prefs_show(module_t *module, gpointer user_data)
 #endif
     if (module == protocols_module)
       child_cts.is_protocol = TRUE;
-    prefs_module_list_foreach(module->prefs, module_prefs_show, &child_cts);
-  } else {
+    prefs_modules_foreach_submodules(module, module_prefs_show, &child_cts);
+
+    /* keep the page count right */
+    cts->page = child_cts.page;
+
+  } 
+  if(module->prefs) {
     /*
-     * No.  Create a notebook page for it.
+     * Has preferences.  Create a notebook page for it.
      */
 
     /* Scrolled window */
@@ -360,10 +397,21 @@ module_prefs_show(module_t *module, gpointer user_data)
     OBJECT_SET_DATA(frame, E_PAGE_ITER_KEY, gtk_tree_iter_copy(&iter));
 #endif
 
-    cts->page++;
+  cts->page++;
 
     /* Show 'em what we got */
     gtk_widget_show_all(main_sw);
+  } else {
+    /* show the blank page */
+
+#if GTK_MAJOR_VERSION < 2
+    gtk_ctree_node_set_row_data(GTK_CTREE(cts->tree), ct_node,
+  		GINT_TO_POINTER(blank_page));
+#else
+    gtk_tree_store_set(model, &iter, 0, label_str, 1, blank_page, -1);
+#endif
+    
+
   }
 
   return 0;
@@ -411,8 +459,10 @@ prefs_nb_page_add(GtkWidget *notebook, const gchar *title, GtkWidget *page, cons
 
   frame = gtk_frame_new(title);
   gtk_widget_show(frame);
-  gtk_container_add(GTK_CONTAINER(frame), page);
-  OBJECT_SET_DATA(prefs_w, page_key, page);
+  if(page) {
+    gtk_container_add(GTK_CONTAINER(frame), page);
+    OBJECT_SET_DATA(prefs_w, page_key, page);
+  }
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), frame, NULL);
 
   return frame;
@@ -495,6 +545,7 @@ prefs_cb(GtkWidget *w _U_, gpointer dummy _U_)
 #else
   store = gtk_tree_store_new(2, G_TYPE_STRING, G_TYPE_INT);
   cts.tree = tree_view_new(GTK_TREE_MODEL(store));
+  cts.iter.stamp = 0; /* mark this as the toplevel */
   OBJECT_SET_DATA(prefs_w, E_PREFSW_TREE_KEY, cts.tree);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(cts.tree), FALSE);
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(cts.tree));
@@ -522,26 +573,31 @@ prefs_cb(GtkWidget *w _U_, gpointer dummy _U_)
 
   cts.page = 0;
 
+  /* Blank Page */
+  g_strlcpy(label_str, "(No Specific Preferences)", MAX_TREE_NODE_NAME_LEN);
+  prefs_nb_page_add(prefs_nb, label_str, NULL, NULL);
+  blank_page = cts.page++;
+
   /* GUI prefs */
-  strcpy(label_str, "User Interface");
+  g_strlcpy(label_str, "User Interface", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, gui_prefs_show(), E_GUI_PAGE_KEY);
   gui_iter = prefs_tree_page_add(label_str, cts.page, store, NULL, TRUE);
   cts.page++;
 
   /* GUI layout prefs */
-  strcpy(label_str, "Layout");
+  g_strlcpy(label_str, "Layout", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, layout_prefs_show(), E_GUI_LAYOUT_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, &gui_iter, FALSE);
   cts.page++;
 
   /* GUI Column prefs */
-  strcpy(label_str, "Columns");
+  g_strlcpy(label_str, "Columns", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, column_prefs_show(), E_GUI_COLUMN_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, &gui_iter, FALSE);
   cts.page++;
 
   /* GUI Font prefs */
-  strcpy(label_str, "Font");
+  g_strlcpy(label_str, "Font", MAX_TREE_NODE_NAME_LEN);
   gui_font_pg = gui_font_prefs_show();
   prefs_nb_page_add(prefs_nb, label_str, gui_font_pg, E_GUI_FONT_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, &gui_iter, FALSE);
@@ -581,7 +637,7 @@ prefs_cb(GtkWidget *w _U_, gpointer dummy _U_)
 #endif
 
   /* GUI Colors prefs */
-  strcpy(label_str, "Colors");
+  g_strlcpy(label_str, "Colors", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, stream_prefs_show(), E_GUI_COLORS_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, &gui_iter, FALSE);
   cts.page++;
@@ -601,7 +657,7 @@ prefs_cb(GtkWidget *w _U_, gpointer dummy _U_)
   if (has_wpcap) {
 #endif /* _WIN32 */
   /* capture prefs */
-  strcpy(label_str, "Capture");
+  g_strlcpy(label_str, "Capture", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, capture_prefs_show(), E_CAPTURE_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, NULL, FALSE);
   cts.page++;
@@ -611,21 +667,31 @@ prefs_cb(GtkWidget *w _U_, gpointer dummy _U_)
 #endif /* HAVE_LIBPCAP */
 
   /* Printing prefs */
-  strcpy(label_str, "Printing");
+  g_strlcpy(label_str, "Printing", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, printer_prefs_show(), E_PRINT_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, NULL, FALSE);
   cts.page++;
 
   /* Name resolution prefs */
-  strcpy(label_str, "Name Resolution");
+  g_strlcpy(label_str, "Name Resolution", MAX_TREE_NODE_NAME_LEN);
   prefs_nb_page_add(prefs_nb, label_str, nameres_prefs_show(), E_NAMERES_PAGE_KEY);
   prefs_tree_page_add(label_str, cts.page, store, NULL, FALSE);
   cts.page++;
 
+#ifdef HAVE_LIBPORTAUDIO
+#if GTK_MAJOR_VERSION >= 2
+  /* RTP player prefs */
+  g_strlcpy(label_str, "RTP Player", MAX_TREE_NODE_NAME_LEN);
+  prefs_nb_page_add(prefs_nb, label_str, rtp_player_prefs_show(), E_RTP_PLAYER_PAGE_KEY);
+  prefs_tree_page_add(label_str, cts.page, store, NULL, FALSE);
+  cts.page++;
+#endif
+#endif
+
   /* Registered prefs */
   cts.notebook = prefs_nb;
   cts.is_protocol = FALSE;
-  prefs_module_list_foreach(NULL, module_prefs_show, &cts);
+  prefs_modules_foreach_submodules(NULL, module_prefs_show, &cts);
 
   /* Button row: OK and alike buttons */
 
@@ -780,7 +846,7 @@ label_to_enum_val(GtkWidget *label, const enum_val_t *enumvals)
 	gtk_label_get(GTK_LABEL(label), &label_string);
 
 	for (i = 0; enumvals[i].name != NULL; i++) {
-		if (strcasecmp(label_string, enumvals[i].description) == 0) {
+		if (g_ascii_strcasecmp(label_string, enumvals[i].description) == 0) {
 			return enumvals[i].value;
 		}
 	}
@@ -906,6 +972,54 @@ create_preference_entry(GtkWidget *main_tb, int table_position,
 	return entry;
 }
 
+GtkWidget *
+create_preference_static_text(GtkWidget *main_tb, int table_position,
+    const gchar *label_text, const gchar *tooltip_text)
+{
+	GtkTooltips *tooltips;
+	GtkWidget *label;
+
+	tooltips = OBJECT_GET_DATA(main_tb, E_TOOLTIPS_KEY);
+
+	if(label_text != NULL)
+		label = gtk_label_new(label_text);
+	else
+		label = gtk_label_new("");
+	gtk_table_attach_defaults(GTK_TABLE(main_tb), label, 0, 2,
+	    table_position, table_position + 1);
+	if (tooltip_text != NULL && tooltips != NULL)
+		gtk_tooltips_set_tip(tooltips, label, tooltip_text, NULL);
+	gtk_widget_show(label);
+
+	return label;
+}
+
+GtkWidget *
+create_preference_uat(GtkWidget *main_tb, int table_position,
+    const gchar *label_text, const gchar *tooltip_text, void* uat)
+{
+	GtkTooltips *tooltips;
+	GtkWidget *button = NULL;
+	
+	tooltips = OBJECT_GET_DATA(main_tb, E_TOOLTIPS_KEY);
+	
+	set_option_label(main_tb, table_position, label_text, tooltip_text,
+					 tooltips);
+	
+	button = BUTTON_NEW_FROM_STOCK(WIRESHARK_STOCK_EDIT);
+	
+	SIGNAL_CONNECT(button, "clicked", uat_window_cb, uat);
+
+	gtk_table_attach_defaults(GTK_TABLE(main_tb), button, 1, 2,
+							  table_position, table_position+1);
+	if (tooltip_text != NULL && tooltips != NULL)
+		gtk_tooltips_set_tip(tooltips, button, tooltip_text, NULL);
+	gtk_widget_show(button);
+	
+	return button;
+}
+
+
 static guint
 pref_check(pref_t *pref, gpointer user_data)
 {
@@ -953,6 +1067,11 @@ pref_check(pref_t *pref, gpointer user_data)
     }
     break;
 
+  case PREF_STATIC_TEXT:
+  case PREF_UAT:
+    /* Value can't be bad. */
+    break;
+
   case PREF_OBSOLETE:
     g_assert_not_reached();
     break;
@@ -1051,6 +1170,10 @@ pref_fetch(pref_t *pref, gpointer user_data)
     break;
   }
 
+  case PREF_STATIC_TEXT:
+  case PREF_UAT:
+    break;
+
   case PREF_OBSOLETE:
     g_assert_not_reached();
     break;
@@ -1085,56 +1208,56 @@ module_prefs_fetch(module_t *module, gpointer user_data)
 static void
 prefs_airpcap_update()
 {
-GtkWidget *decryption_cm;
-GtkWidget *decryption_en;
-gboolean wireshark_decryption_was_enabled;
-gboolean airpcap_decryption_was_enabled;
-gboolean wireshark_decryption_is_now_enabled;
+  GtkWidget *decryption_cm;
+  GtkWidget *decryption_en;
+  gboolean wireshark_decryption_was_enabled;
+  gboolean airpcap_decryption_was_enabled;
+  gboolean wireshark_decryption_is_now_enabled;
 
-decryption_cm = GTK_WIDGET(OBJECT_GET_DATA(airpcap_tb,AIRPCAP_TOOLBAR_DECRYPTION_KEY));
-decryption_en = GTK_WIDGET(GTK_ENTRY(GTK_COMBO(decryption_cm)->entry));
+  decryption_cm = GTK_WIDGET(OBJECT_GET_DATA(airpcap_tb,AIRPCAP_TOOLBAR_DECRYPTION_KEY));
+  decryption_en = GTK_WIDGET(GTK_ENTRY(GTK_COMBO(decryption_cm)->entry));
 
-if( g_strcasecmp(gtk_entry_get_text(GTK_ENTRY(decryption_en)),AIRPCAP_DECRYPTION_TYPE_STRING_WIRESHARK) == 0 )
-{
-wireshark_decryption_was_enabled = TRUE;
-airpcap_decryption_was_enabled = FALSE;
-}
-else if( g_strcasecmp(gtk_entry_get_text(GTK_ENTRY(decryption_en)),AIRPCAP_DECRYPTION_TYPE_STRING_AIRPCAP) == 0 )
-{
-wireshark_decryption_was_enabled = FALSE;
-airpcap_decryption_was_enabled = TRUE;
-}
-else if( g_strcasecmp(gtk_entry_get_text(GTK_ENTRY(decryption_en)),AIRPCAP_DECRYPTION_TYPE_STRING_NONE) == 0 )
-{
-wireshark_decryption_was_enabled = FALSE;
-airpcap_decryption_was_enabled = FALSE;
-}
+  if( g_ascii_strcasecmp(gtk_entry_get_text(GTK_ENTRY(decryption_en)),AIRPCAP_DECRYPTION_TYPE_STRING_WIRESHARK) == 0 )
+  {
+    wireshark_decryption_was_enabled = TRUE;
+    airpcap_decryption_was_enabled = FALSE;
+  }
+  else if( g_ascii_strcasecmp(gtk_entry_get_text(GTK_ENTRY(decryption_en)),AIRPCAP_DECRYPTION_TYPE_STRING_AIRPCAP) == 0 )
+  {
+    wireshark_decryption_was_enabled = FALSE;
+    airpcap_decryption_was_enabled = TRUE;
+  }
+  else if( g_ascii_strcasecmp(gtk_entry_get_text(GTK_ENTRY(decryption_en)),AIRPCAP_DECRYPTION_TYPE_STRING_NONE) == 0 )
+  {
+    wireshark_decryption_was_enabled = FALSE;
+    airpcap_decryption_was_enabled = FALSE;
+  }
 
-wireshark_decryption_is_now_enabled = wireshark_decryption_on();
+  wireshark_decryption_is_now_enabled = wireshark_decryption_on();
 
-if(wireshark_decryption_is_now_enabled && airpcap_decryption_was_enabled)
-	{
-	set_airpcap_decryption(FALSE);
-	gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_WIRESHARK);
-	}
-if(wireshark_decryption_is_now_enabled && !airpcap_decryption_was_enabled)
-	{
-	set_airpcap_decryption(FALSE);
-	gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_WIRESHARK);
-	}
-else if(!wireshark_decryption_is_now_enabled && wireshark_decryption_was_enabled)
-	{
-	if(airpcap_decryption_was_enabled)
-		{
-		set_airpcap_decryption(TRUE);
-		gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_AIRPCAP);
-		}
-	else
-		{
-		set_airpcap_decryption(FALSE);
-		gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_NONE);
-		}
-	}
+  if(wireshark_decryption_is_now_enabled && airpcap_decryption_was_enabled)
+  {
+    set_airpcap_decryption(FALSE);
+    gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_WIRESHARK);
+  }
+  if(wireshark_decryption_is_now_enabled && !airpcap_decryption_was_enabled)
+  {
+    set_airpcap_decryption(FALSE);
+    gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_WIRESHARK);
+  }
+  else if(!wireshark_decryption_is_now_enabled && wireshark_decryption_was_enabled)
+  {
+    if(airpcap_decryption_was_enabled)
+    {
+      set_airpcap_decryption(TRUE);
+      gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_AIRPCAP);
+    }
+    else
+    {
+      set_airpcap_decryption(FALSE);
+      gtk_entry_set_text(GTK_ENTRY(decryption_en),AIRPCAP_DECRYPTION_TYPE_STRING_NONE);
+    }
+  }
 }
 #endif
 
@@ -1166,6 +1289,10 @@ pref_clean(pref_t *pref, gpointer user_data _U_)
     }
     break;
 
+  case PREF_STATIC_TEXT:
+  case PREF_UAT:
+    break;
+
   case PREF_OBSOLETE:
     g_assert_not_reached();
     break;
@@ -1233,7 +1360,11 @@ prefs_main_fetch_all(GtkWidget *dlg, gboolean *must_redissect)
 #endif /* HAVE_LIBPCAP */
   printer_prefs_fetch(OBJECT_GET_DATA(dlg, E_PRINT_PAGE_KEY));
   nameres_prefs_fetch(OBJECT_GET_DATA(dlg, E_NAMERES_PAGE_KEY));
-
+#ifdef HAVE_LIBPORTAUDIO
+#if GTK_MAJOR_VERSION >= 2
+  rtp_player_prefs_fetch(OBJECT_GET_DATA(dlg, E_RTP_PLAYER_PAGE_KEY));
+#endif
+#endif
   prefs_modules_foreach(module_prefs_fetch, must_redissect);
 
   return TRUE;
@@ -1241,7 +1372,7 @@ prefs_main_fetch_all(GtkWidget *dlg, gboolean *must_redissect)
 
 /* apply all pref values to the real world */
 static void
-prefs_main_apply_all(GtkWidget *dlg)
+prefs_main_apply_all(GtkWidget *dlg, gboolean redissect)
 {
   GtkWidget *save_bt;
 
@@ -1252,7 +1383,7 @@ prefs_main_apply_all(GtkWidget *dlg)
    */
   prefs_apply_all();
 
-  gui_prefs_apply(OBJECT_GET_DATA(dlg, E_GUI_PAGE_KEY));
+  gui_prefs_apply(OBJECT_GET_DATA(dlg, E_GUI_PAGE_KEY), redissect);
   layout_prefs_apply(OBJECT_GET_DATA(dlg, E_GUI_LAYOUT_PAGE_KEY));
   column_prefs_apply(OBJECT_GET_DATA(dlg, E_GUI_COLUMN_PAGE_KEY));
   stream_prefs_apply(OBJECT_GET_DATA(dlg, E_GUI_COLORS_PAGE_KEY));
@@ -1269,6 +1400,11 @@ prefs_main_apply_all(GtkWidget *dlg)
 #endif /* HAVE_LIBPCAP */
   printer_prefs_apply(OBJECT_GET_DATA(dlg, E_PRINT_PAGE_KEY));
   nameres_prefs_apply(OBJECT_GET_DATA(dlg, E_NAMERES_PAGE_KEY));
+#ifdef HAVE_LIBPORTAUDIO
+#if GTK_MAJOR_VERSION >= 2
+  rtp_player_prefs_apply(OBJECT_GET_DATA(dlg, E_RTP_PLAYER_PAGE_KEY));
+#endif
+#endif
 
   /* show/hide the Save button - depending on setting */
   save_bt = OBJECT_GET_DATA(prefs_w, E_PREFSW_SAVE_BT_KEY);
@@ -1313,6 +1449,11 @@ prefs_main_destroy_all(GtkWidget *dlg)
 #endif /* HAVE_LIBPCAP */
   printer_prefs_destroy(OBJECT_GET_DATA(dlg, E_PRINT_PAGE_KEY));
   nameres_prefs_destroy(OBJECT_GET_DATA(dlg, E_NAMERES_PAGE_KEY));
+#ifdef HAVE_LIBPORTAUDIO
+#if GTK_MAJOR_VERSION >= 2
+  rtp_player_prefs_destroy(OBJECT_GET_DATA(dlg, E_RTP_PLAYER_PAGE_KEY));
+#endif
+#endif
 
   /* Free up the saved preferences (both for "prefs" and for registered
      preferences). */
@@ -1347,11 +1488,11 @@ prefs_main_write(void)
   }
 
 #ifdef HAVE_AIRPCAP
-/* 
- * Load the Wireshark decryption keys (just set) and save 
- * the changes to the adapters' registry 
- */ 
-airpcap_load_decryption_keys(airpcap_if_list);
+  /*
+   * Load the Wireshark decryption keys (just set) and save
+   * the changes to the adapters' registry
+   */
+  airpcap_load_decryption_keys(airpcap_if_list);
 #endif
 }
 
@@ -1369,11 +1510,14 @@ prefs_main_ok_cb(GtkWidget *ok_bt _U_, gpointer parent_w)
       prefs_main_write();
   }
 
-  prefs_main_apply_all(parent_w);
+  prefs_main_apply_all(parent_w, must_redissect);
 
-	#ifdef HAVE_AIRPCAP
-	prefs_airpcap_update();
-	#endif
+  /* Fill in capture options with values from the preferences */
+  prefs_to_capture_opts();
+
+#ifdef HAVE_AIRPCAP
+  prefs_airpcap_update();
+#endif
 
   /* Now destroy the "Preferences" dialog. */
   window_destroy(GTK_WIDGET(parent_w));
@@ -1398,11 +1542,14 @@ prefs_main_apply_cb(GtkWidget *apply_bt _U_, gpointer parent_w)
       prefs_main_write();
   }
 
-  prefs_main_apply_all(parent_w);
+  prefs_main_apply_all(parent_w, must_redissect);
 
-  	#ifdef HAVE_AIRPCAP
-	prefs_airpcap_update();
-	#endif
+  /* Fill in capture options with values from the preferences */
+  prefs_to_capture_opts();
+
+#ifdef HAVE_AIRPCAP
+  prefs_airpcap_update();
+#endif
 
   if (must_redissect) {
     /* Redissect all the packets, and re-evaluate the display filter. */
@@ -1434,7 +1581,10 @@ prefs_main_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
 	   "Apply" after this, we know we have to redissect;
 
 	4) we did apply the protocol preferences, at least, in the past. */
-  prefs_main_apply_all(parent_w);
+  prefs_main_apply_all(parent_w, must_redissect);
+
+  /* Fill in capture options with values from the preferences */
+  prefs_to_capture_opts();
 
   if (must_redissect) {
     /* Redissect all the packets, and re-evaluate the display filter. */
@@ -1487,6 +1637,10 @@ pref_revert(pref_t *pref, gpointer user_data)
     }
     break;
 
+  case PREF_STATIC_TEXT:
+  case PREF_UAT:
+    break;
+
   case PREF_OBSOLETE:
     g_assert_not_reached();
     break;
@@ -1528,7 +1682,7 @@ prefs_main_cancel_cb(GtkWidget *cancel_bt _U_, gpointer parent_w)
   prefs_modules_foreach(module_prefs_revert, &must_redissect);
 
   /* Now apply the reverted-to preferences. */
-  prefs_main_apply_all(parent_w);
+  prefs_main_apply_all(parent_w, must_redissect);
 
   window_destroy(GTK_WIDGET(parent_w));
 
@@ -1573,9 +1727,31 @@ module_search_properties(module_t *module, gpointer user_data)
     p->module = module;
     return 1;	/* stops the search */
   }
+  
+  if(prefs_module_has_submodules(module))
+    return prefs_modules_foreach_submodules(module, module_search_properties, p);
+
   return 0;
 }
 
+#if GTK_MAJOR_VERSION >= 2
+static void
+tree_expand_row(GtkTreeModel *model, GtkTreeView *tree_view, GtkTreeIter *iter)
+{
+  GtkTreeIter   parent;
+  GtkTreePath   *path;
+
+  /* expand the parent first */
+  if(gtk_tree_model_iter_parent(model, &parent, iter))
+    tree_expand_row(model, tree_view, &parent);
+
+  path = gtk_tree_model_get_path(model, iter);
+  gtk_tree_view_expand_row(tree_view, path, FALSE);
+  /*expand_tree(tree_view, &parent, NULL, NULL);*/
+
+  gtk_tree_path_free(path);
+}
+#endif 
 
 /* select a node in the tree view */
 /* XXX - this is almost 100% copied from byte_view_select() in proto_draw.c,
@@ -1586,13 +1762,12 @@ tree_select_node(GtkWidget *tree, prefs_tree_iter *iter)
 #if GTK_MAJOR_VERSION < 2
     GtkCTree     *ctree = GTK_CTREE(tree);
     GtkCTreeNode *node = (GtkCTreeNode *) iter;
-	GtkCTreeNode *parent;
+    GtkCTreeNode *parent;
 #else
-	GtkTreeIter  local_iter = *iter;
+    GtkTreeIter  local_iter = *iter;
     GtkTreeView  *tree_view = GTK_TREE_VIEW(tree);
     GtkTreeModel *model;
-    GtkTreePath  *first_path, *path;
-    GtkTreeIter   parent;
+    GtkTreePath  *first_path;
 #endif
 
 #if GTK_MAJOR_VERSION < 2
@@ -1618,17 +1793,9 @@ tree_select_node(GtkWidget *tree, prefs_tree_iter *iter)
 
     /* Expand our field's row */
     first_path = gtk_tree_model_get_path(model, &local_iter);
-    gtk_tree_view_expand_row(tree_view, first_path, FALSE);
-    /*expand_tree(tree_view, &iter, NULL, NULL);*/
 
-    /* ... and its parents */
-    while (gtk_tree_model_iter_parent(model, &parent, &local_iter)) {
-        path = gtk_tree_model_get_path(model, &parent);
-        gtk_tree_view_expand_row(tree_view, path, FALSE);
-        /*expand_tree(tree_view, &parent, NULL, NULL);*/
-        local_iter = parent;
-        gtk_tree_path_free(path);
-    }
+    /* expand from the top down */
+    tree_expand_row(model, tree_view, &local_iter);
 
     /* select our field's row */
     gtk_tree_selection_select_path(gtk_tree_view_get_selection(tree_view),
@@ -1674,7 +1841,7 @@ properties_cb(GtkWidget *w, gpointer dummy)
      XXX - should we just associate protocols with modules directly? */
   p.title = title;
   p.module = NULL;
-  prefs_module_list_foreach(protocols_module->prefs, module_search_properties,
+  prefs_modules_foreach_submodules(protocols_module, module_search_properties,
                             &p);
   if (p.module == NULL) {
     /* We didn't find it - that protocol probably has no preferences. */
@@ -1695,16 +1862,18 @@ properties_cb(GtkWidget *w, gpointer dummy)
        page_num++) {
     /* Get the frame from the scrollable window */
     frame = OBJECT_GET_DATA(sw, E_PAGESW_FRAME_KEY);
-    /* Get the module for this page. */
-    page_module = OBJECT_GET_DATA(frame, E_PAGE_MODULE_KEY);
-    if (page_module == NULL)
-      continue;	/* It doesn't have one. */
-    if (page_module == p.module) {
+    /* Get the module for this page (non-protocol prefs don't have one). */
+    if(frame) {
+      page_module = OBJECT_GET_DATA(frame, E_PAGE_MODULE_KEY);
+      if (page_module != NULL) {
+	if (page_module == p.module) {
 	  tree_select_node(
 		  OBJECT_GET_DATA(prefs_w, E_PREFSW_TREE_KEY),
 		  OBJECT_GET_DATA(frame, E_PAGE_ITER_KEY));
 	  return;
 	}
+      }
+    }
   }
 }
 
