@@ -1,7 +1,7 @@
 /* progress_dlg.c
  * Routines for progress-bar (modal) dialog
  *
- * $Id: progress_dlg.c 19942 2006-11-21 00:40:36Z ulfl $
+ * $Id: progress_dlg.c 24239 2008-02-01 01:07:58Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -96,7 +96,7 @@ create_progress_dlg(const gchar *task_title, const gchar *item_title,
     /* limit the item_title to some reasonable length */
     item_title_dup = g_strdup(item_title);
     if (strlen(item_title_dup) > 110) {
-        strcpy(&item_title_dup[100], "...");
+        strncpy(&item_title_dup[100], "...", 4);
     }
 
     dlg->title = g_strdup_printf("%s: %s", task_title, item_title_dup);
