@@ -1,7 +1,7 @@
 /*
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_graph_dlg.c 19844 2006-11-07 07:39:16Z jake $
+ * $Id: sctp_graph_dlg.c 24513 2008-03-01 10:23:57Z tuexen $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,6 +42,7 @@
 #include "compat_macros.h"
 #include "simple_dialog.h"
 #include "sctp_stat.h"
+#include <epan/strutil.h>
 
 #define DEFAULT_PIXELS_PER_TICK 2
 #define MAX_PIXELS_PER_TICK 4
@@ -90,6 +91,11 @@ struct init_chunk_header {
 	guint32 initial_tsn;
 };
 
+struct gaps {
+	guint16 start;
+	guint16 end;
+};
+
 struct sack_chunk_header {
 	guint8  type;
 	guint8  flags;
@@ -98,12 +104,7 @@ struct sack_chunk_header {
 	guint32 a_rwnd;
 	guint16 nr_of_gaps;
 	guint16 nr_of_dups;
-	guint8  *tsns;
-};
-
-struct gaps {
-	guint16 start;
-	guint16 end;
+	struct gaps gaps[1];
 };
 
 
@@ -112,6 +113,9 @@ static guint32 max_tsn=0, min_tsn=0;
 static void sctp_graph_set_title(struct sctp_udata *u_data);
 static void create_draw_area(GtkWidget *box, struct sctp_udata *u_data);
 static GtkWidget *zoomout_bt;
+#if defined(_WIN32) && !defined(__MINGW32__)
+static int rint (double );	/* compiler template for Windows */
+#endif
 
 static void draw_sack_graph(struct sctp_udata *u_data)
 {
@@ -198,18 +202,18 @@ static void draw_sack_graph(struct sctp_udata *u_data)
 			if (type == SCTP_SACK_CHUNK_ID)
 			{
 				sack_header =(struct sack_chunk_header *)tlist->data;
-				nr=ntohs(sack_header->nr_of_gaps);
+				nr=g_ntohs(sack_header->nr_of_gaps);
 				tsnumber = g_ntohl(sack_header->cum_tsn_ack);
 
 				if (sack->secs>=u_data->io->x1_tmp_sec)
 				{
 					if (nr>0)
 					{
-						gap = (struct gaps *)(&(sack_header->tsns));
+						gap = &sack_header->gaps[0];
 						for(i=0;i<nr; i++)
 						{
-							gap_start=ntohs(gap->start);
-							gap_end = ntohs(gap->end);
+							gap_start=g_ntohs(gap->start);
+							gap_end = g_ntohs(gap->end);
 							max_num=gap_end+tsnumber;
 							for (j=gap_start; j<=gap_end; j++)
 							{
@@ -363,8 +367,8 @@ static void sctp_graph_draw(struct sctp_udata *u_data)
 	}
 	else
 	{
-		u_data->io->min_x=u_data->io->x1_tmp_sec*1000000.0+u_data->io->x1_tmp_usec;
-		u_data->io->max_x=u_data->io->x2_tmp_sec*1000000.0+u_data->io->x2_tmp_usec;		
+		u_data->io->min_x=(guint32)(u_data->io->x1_tmp_sec*1000000.0+u_data->io->x1_tmp_usec);
+		u_data->io->max_x=(guint32)(u_data->io->x2_tmp_sec*1000000.0+u_data->io->x2_tmp_usec);
 		u_data->io->uoff = FALSE;
 	}
 
@@ -607,7 +611,7 @@ static void sctp_graph_draw(struct sctp_udata *u_data)
 		
 	}
 
-	strcpy(label_string, "sec");
+	g_strlcpy(label_string, "sec", 15);
 
 #if GTK_MAJOR_VERSION < 2
 	lwidth=gdk_string_width(font, label_string);
@@ -981,12 +985,16 @@ static gint
 on_button_release (GtkWidget *widget _U_, GdkEventButton *event, struct sctp_udata *u_data)
 {
 	sctp_graph_t *ios;
-	guint32 helpx, helpy, x1_tmp, x2_tmp,  y_value;
+	guint32 helpx, helpy, x1_tmp, x2_tmp,  y_value, t_size=0, s_size=0, i, y_tolerance;
 	gint label_width, label_height;
-	gdouble x_value, position;
+	gdouble x_value, position, s_diff=0, t_diff=0, x_tolerance=0.0001;
 	gint lwidth;
 	char label_string[30];
 	GdkGC *text_color;
+	GPtrArray *tsnlist = NULL, *sacklist=NULL;
+	struct tsn_sort *tsn, *sack=NULL;
+	gboolean sack_found = FALSE;
+
 	#if GTK_MAJOR_VERSION < 2
 		GdkFont *font;
 #else
@@ -1100,24 +1108,82 @@ on_button_release (GtkWidget *widget _U_, GdkEventButton *event, struct sctp_uda
 		}
 		else
 		{
-			x_value = ((event->x-LEFT_BORDER-u_data->io->offset) * ((u_data->io->x2_tmp_sec+u_data->io->x2_tmp_usec/1000000.0)-(u_data->io->x1_tmp_sec+u_data->io->x1_tmp_usec/1000000.0)) / (u_data->io->pixmap_width-LEFT_BORDER-u_data->io->offset))+u_data->io->x1_tmp_sec+u_data->io->x1_tmp_usec/1000000.0;
-			y_value = floor((u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset-event->y) * (max_tsn - min_tsn) / (u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)) + min_tsn;
+			x_value = ((event->x-LEFT_BORDER-u_data->io->offset) * ((u_data->io->x2_tmp_sec+u_data->io->x2_tmp_usec/1000000.0)-(u_data->io->x1_tmp_sec+u_data->io->x1_tmp_usec/1000000.0)) / (u_data->io->pixmap_width-LEFT_BORDER-RIGHT_BORDER-u_data->io->offset))+u_data->io->x1_tmp_sec+u_data->io->x1_tmp_usec/1000000.0;
+			y_value = (gint)rint((u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset-event->y) * (max_tsn - min_tsn) / (u_data->io->pixmap_height-BOTTOM_BORDER-u_data->io->offset)) + min_tsn;
 			text_color = u_data->io->draw_area->style->black_gc;
+
+			if (u_data->dir == 1)
+			{
+				tsnlist = u_data->assoc->sort_tsn1;
+				t_size = u_data->assoc->n_data_chunks_ep1;
+				sacklist = u_data->assoc->sort_sack1;
+				s_size = u_data->assoc->n_sack_chunks_ep1;
+			}
+			else
+			{
+				tsnlist = u_data->assoc->sort_tsn2;
+				t_size = u_data->assoc->n_data_chunks_ep2;
+				sacklist = u_data->assoc->sort_sack2;
+				s_size = u_data->assoc->n_sack_chunks_ep2;
+			}
+			x_tolerance = (gdouble)((u_data->io->tmp_width / u_data->io->axis_width*1.0))*5/1000000.0;
+			y_tolerance = (guint32)(((u_data->io->max_y - u_data->io->min_y) / (u_data->io->pixmap_height-TOP_BORDER-BOTTOM_BORDER-u_data->io->offset)) * 2.0);
+			if (y_tolerance==0)
+				y_tolerance = 2;
+			else if (y_tolerance > 5)
+				y_tolerance = 5;
+
+			for (i=0; i<s_size; i++)
+			{
+				sack = (struct tsn_sort*)(g_ptr_array_index(sacklist, i));
+				if ((guint32)abs(sack->tsnumber - y_value)<y_tolerance)
+				{
+					s_diff = fabs((sack->secs+sack->usecs/1000000.0)- x_value);
+					if (s_diff < x_tolerance)
+						sack_found = TRUE;
+					break;
+				}
+			}
+
+			for (i=0; i<t_size; i++)
+			{
+				tsn = (struct tsn_sort*)(g_ptr_array_index(tsnlist, i));
+				if ((guint32)abs(tsn->tsnumber - y_value)<y_tolerance)
+				{
+					t_diff = fabs((tsn->secs+tsn->usecs/1000000.0)- x_value);
+					if (sack_found && s_diff < t_diff)
+					{
+						cf_goto_frame(&cfile, sack->framenumber);
+						x_value = sack->secs+sack->usecs/1000000.0;
+						y_value = sack->tsnumber;
+					}
+					else if (t_diff < x_tolerance)
+					{
+						cf_goto_frame(&cfile, tsn->framenumber);
+						x_value = tsn->secs+tsn->usecs/1000000.0;
+						y_value = tsn->tsnumber;
+					}
+					break;
+				}
+			}
+
 			g_snprintf(label_string, 30, "(%.6lf, %u)", x_value, y_value);
+
 			label_set = TRUE;
 
-			gdk_draw_line(u_data->io->pixmap,text_color, event->x-2, event->y, event->x+2, event->y);
-			gdk_draw_line(u_data->io->pixmap,text_color, event->x, event->y-2, event->x, event->y+2);
+			gdk_draw_line(u_data->io->pixmap,text_color, (gint)(event->x-2), (gint)(event->y), (gint)(event->x+2), (gint)(event->y));
+			gdk_draw_line(u_data->io->pixmap,text_color, (gint)(event->x), (gint)(event->y-2), (gint)(event->x), (gint)(event->y+2));
 			if (event->x+150>=u_data->io->pixmap_width)
 				position = event->x - 150;
 			else
 				position = event->x + 5;
 
+
 #if GTK_MAJOR_VERSION < 2
 			lwidth=gdk_string_width(font, label_string);
 		                            gdk_draw_string(u_data->io->pixmap,font,text_color,
-		                            position,
-		                            event->y-10,
+					    (gint)position,
+					    (gint)(event->y-10),
 		                            label_string);
 #else
 			memcpy(label_string,(gchar *)g_locale_to_utf8(label_string, -1 , NULL, NULL, NULL), 15);
@@ -1125,10 +1191,11 @@ on_button_release (GtkWidget *widget _U_, GdkEventButton *event, struct sctp_uda
 			pango_layout_get_pixel_size(layout, &lwidth, NULL);
 
 			gdk_draw_layout(u_data->io->pixmap,text_color,
-							position,
-							event->y-10,
-							layout);
+					    (gint)position,
+					    (gint)(event->y-10),
+					    layout);
 	#endif
+
 			ios=(sctp_graph_t *)OBJECT_GET_DATA(u_data->io->draw_area, "sctp_graph_t");
 
 			if(!ios){
@@ -1333,3 +1400,19 @@ void create_graph(guint16 dir, struct sctp_analyse* userdata)
 		gtk_sctpgraph_init(u_data);
 	}
 }
+
+#if defined(_WIN32) && !defined(__MINGW32__)
+/* replacement of Unix rint() for Windows */
+static int rint (double x)
+{
+	char *buf;
+	int i,dec,sig;
+
+	buf = _fcvt(x, 0, &dec, &sig);
+	i = atoi(buf);
+	if(sig == 1) {
+		i = i * -1;
+	}
+	return(i);
+}
+#endif
