@@ -1,7 +1,7 @@
 /* 
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_stat.c 24239 2008-02-01 01:07:58Z stig $
+ * $Id: sctp_stat.c 24513 2008-03-01 10:23:57Z tuexen $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -39,6 +39,7 @@
 #include "sctp_stat.h"
 #include <math.h>
 #include "epan/address.h"
+#include <epan/strutil.h>
 
 #define SCTP_HEARTBEAT_CHUNK_ID          4
 #define SCTP_HEARTBEAT_ACK_CHUNK_ID      5
@@ -264,7 +265,7 @@ static sctp_assoc_info_t *calc_checksum(struct _sctp_info *check_data, sctp_asso
 	{
 		if ((float)(data->n_adler32_correct*1.0/data->n_adler32_calculated) > 0.5)
 		{
-			strncpy(data->checksum_type,"ADLER32",8);
+			g_strlcpy(data->checksum_type,"ADLER32",8);
 			data->n_checksum_errors=(data->n_adler32_calculated-data->n_adler32_correct);
 			ok = TRUE;
 		}
@@ -274,7 +275,7 @@ static sctp_assoc_info_t *calc_checksum(struct _sctp_info *check_data, sctp_asso
 	{
 		if ((float)(data->n_crc32c_correct*1.0/data->n_crc32c_calculated) > 0.5)
 		{
-			strncpy(data->checksum_type,"CRC32C",8);
+			g_strlcpy(data->checksum_type,"CRC32C",8);
 			data->n_checksum_errors=data->n_crc32c_calculated-data->n_crc32c_correct;
 			ok = TRUE;
 		}
@@ -282,7 +283,7 @@ static sctp_assoc_info_t *calc_checksum(struct _sctp_info *check_data, sctp_asso
 
 	if (!ok)
 	{
-		strncpy(data->checksum_type,"UNKNOWN",8);
+		g_strlcpy(data->checksum_type,"UNKNOWN",8);
 		data->n_checksum_errors=0;
 	}
 
@@ -886,11 +887,10 @@ packet(void *tapdata _U_, packet_info *pinfo , epan_dissect_t *edt _U_ , const v
 				str[0] = '\0';
 				error->chunk_info[0] = '\0';
 				if ((tvb_get_guint8(sctp_info->tvb[0],0)) == SCTP_INIT_CHUNK_ID)
-					strncpy(error->chunk_info, val_to_str(tvb_get_guint8(sctp_info->tvb[0],0),chunk_type_values,"Reserved"), 200);
+					g_strlcpy(error->chunk_info, val_to_str(tvb_get_guint8(sctp_info->tvb[0],0),chunk_type_values,"Reserved"), 200);
 				else
 					for (chunk_number = 0; chunk_number < sctp_info->number_of_tvbs; chunk_number++)
-						strncat(error->chunk_info, val_to_str(tvb_get_guint8(sctp_info->tvb[chunk_number],0),chunk_type_values,"Reserved"), 200 - strlen (error->chunk_info));
-				error->chunk_info[199] = '\0';
+						g_strlcat(error->chunk_info, val_to_str(tvb_get_guint8(sctp_info->tvb[chunk_number],0),chunk_type_values,"Reserved"), 200);
 				error->info_text = "INFOS";
 				info->error_info_list = g_list_append(info->error_info_list, error);
 			}
