@@ -3,7 +3,7 @@
  * Helper routines common to all service response time statistics
  * tap.
  *
- * $Id: service_response_time_table.c 18197 2006-05-21 05:12:17Z sahlberg $
+ * $Id: service_response_time_table.c 23816 2007-12-09 09:04:58Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -137,30 +137,40 @@ srt_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 
 
 
-/* action is encoded as 
-   filter_action*256+filter_type
+/* Filter actions */
+#define ACTION_MATCH		0
+#define ACTION_PREPARE		1
+#define ACTION_FIND_FRAME	2
+#define ACTION_FIND_NEXT	3
+#define ACTION_FIND_PREVIOUS	4
+#define ACTION_COLORIZE		5
+
+/* Action type - says what to do with the filter */
+#define	ACTYPE_SELECTED		0
+#define ACTYPE_NOT_SELECTED	1
+#define ACTYPE_AND_SELECTED	2
+#define ACTYPE_OR_SELECTED	3
+#define ACTYPE_AND_NOT_SELECTED	4
+#define ACTYPE_OR_NOT_SELECTED	5
+
+/* Encoded callback arguments */
+#define CALLBACK_MATCH(type)		((ACTION_MATCH<<8) | (type))
+#define CALLBACK_PREPARE(type)		((ACTION_PREPARE<<8) | (type))
+#define CALLBACK_FIND_FRAME(type)	((ACTION_FIND_FRAME<<8) | (type))
+#define CALLBACK_FIND_NEXT(type)	((ACTION_FIND_NEXT<<8) | (type))
+#define CALLBACK_FIND_PREVIOUS(type)	((ACTION_FIND_PREVIOUS<<8) | (type))
+#define CALLBACK_COLORIZE(type)		((ACTION_COLORIZE<<8) | (type))
+
+/* Extract components of callback argument */
+#define FILTER_ACTION(cb_arg)		(((cb_arg)>>8) & 0xff)
+#define FILTER_ACTYPE(cb_arg)		((cb_arg) & 0xff)
 
-   filter_action:
-	0: Match
-	1: Prepare
-	2: Find Frame
-	3:   Find Next
-	4:   Find Previous
-	5: Colorize Procedure
-   filter_type:
-	0: Selected
-	1: Not Selected
-	2: And Selected
-	3: Or Selected
-	4: And Not Selected
-	5: Or Not Selected
-*/
 static void
 srt_select_filter_cb(GtkWidget *widget _U_, gpointer callback_data, guint callback_action)
 {
 	int action, type, selection;
 	srt_stat_table *rst = (srt_stat_table *)callback_data;
-	char str[256];
+	char *str = NULL;
 	const char *current_filter;
 
 
@@ -168,8 +178,8 @@ srt_select_filter_cb(GtkWidget *widget _U_, gpointer callback_data, guint callba
 		return;
 	}
 
-	action=(callback_action>>8)&0xff;
-	type=callback_action&0xff;
+	action = FILTER_ACTION(callback_action);
+	type = FILTER_ACTYPE(callback_action);
 
 	selection=GPOINTER_TO_INT(g_list_nth_data(GTK_CLIST(rst->table)->selection, 0));
 	if(selection>=(int)rst->num_procs){
@@ -182,60 +192,67 @@ srt_select_filter_cb(GtkWidget *widget _U_, gpointer callback_data, guint callba
 	current_filter=gtk_entry_get_text(GTK_ENTRY(main_display_filter_widget));
 
 	switch(type){
-	case 0:
-		/* selected */
-		g_snprintf(str, 255, "%s==%d", rst->filter_string, selection);
+	case ACTYPE_SELECTED:
+		str = g_strdup_printf("%s==%d", rst->filter_string, selection);
 		break;
-	case 1:
-		/* not selected */
-		g_snprintf(str, 255, "!(%s==%d)", rst->filter_string, selection);
+	case ACTYPE_NOT_SELECTED:
+		str = g_strdup_printf("!(%s==%d)", rst->filter_string,
+				      selection);
 		break;
-	case 2:
-		/* and selected */
-		g_snprintf(str, 255, "(%s) && (%s==%d)", current_filter, rst->filter_string, selection);
+	case ACTYPE_AND_SELECTED:
+		if ((!current_filter) || (0 == strlen(current_filter)))
+			str = g_strdup_printf("%s==%d", rst->filter_string, selection);
+		else
+			str = g_strdup_printf("(%s) && (%s==%d)", current_filter,
+					      rst->filter_string, selection);
 		break;
-	case 3:
-		/* or selected */
-		g_snprintf(str, 255, "(%s) || (%s==%d)", current_filter, rst->filter_string, selection);
+	case ACTYPE_OR_SELECTED:
+		if ((!current_filter) || (0 == strlen(current_filter)))
+			str = g_strdup_printf("%s==%d", rst->filter_string, selection);
+		else
+			str = g_strdup_printf("(%s) || (%s==%d)", current_filter,
+					      rst->filter_string, selection);
 		break;
-	case 4:
-		/* and not selected */
-		g_snprintf(str, 255, "(%s) && !(%s==%d)", current_filter, rst->filter_string, selection);
+	case ACTYPE_AND_NOT_SELECTED:
+		if ((!current_filter) || (0 == strlen(current_filter)))
+			str = g_strdup_printf("!(%s==%d)", rst->filter_string, selection);
+		else
+			str = g_strdup_printf("(%s) && !(%s==%d)", current_filter,
+					      rst->filter_string, selection);
 		break;
-	case 5:
-		/* or not selected */
-		g_snprintf(str, 255, "(%s) || !(%s==%d)", current_filter, rst->filter_string, selection);
+	case ACTYPE_OR_NOT_SELECTED:
+		if ((!current_filter) || (0 == strlen(current_filter)))
+			str = g_strdup_printf("!(%s==%d)", rst->filter_string, selection);
+		else
+			str = g_strdup_printf("(%s) || !(%s==%d)", current_filter,
+					      rst->filter_string, selection);
 		break;
 	}
 
 	gtk_entry_set_text(GTK_ENTRY(main_display_filter_widget), str);
 
 	switch(action){
-	case 0:
-		/* match */
+	case ACTION_MATCH:
 		main_filter_packets(&cfile, str, FALSE);
-	case 1:
-		/* prepare */
+		break;
+	case ACTION_PREPARE:
 		/* do nothing */
 		break;
-	case 2:
-		/* find frame */
+	case ACTION_FIND_FRAME:
 		find_frame_with_filter(str);
 		break;
-	case 3:
-		/* find next */
+	case ACTION_FIND_NEXT:
 		find_previous_next_frame_with_filter(str, FALSE);
 		break;
-	case 4:
-		/* find previous */
+	case ACTION_FIND_PREVIOUS:
 		find_previous_next_frame_with_filter(str, TRUE);
 		break;
-	case 5:
-		/* colorize procedure */
+	case ACTION_COLORIZE:
 		color_display_with_filter(str);
 		break;
 	}
 
+	g_free(str);
 }
 
 static gint
@@ -256,60 +273,60 @@ static GtkItemFactoryEntry srt_list_menu_items[] =
 	/* Match */
 	ITEM_FACTORY_ENTRY("/Apply as Filter", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Apply as Filter/Selected", NULL,
-		srt_select_filter_cb, 0*256+0, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_MATCH(ACTYPE_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Apply as Filter/... not Selected", NULL,
-		srt_select_filter_cb, 0*256+1, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_MATCH(ACTYPE_NOT_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Apply as Filter/.. and Selected", NULL,
-		srt_select_filter_cb, 0*256+2, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_MATCH(ACTYPE_AND_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Apply as Filter/... or Selected", NULL,
-		srt_select_filter_cb, 0*256+3, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_MATCH(ACTYPE_OR_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Apply as Filter/... and not Selected", NULL,
-		srt_select_filter_cb, 0*256+4, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_MATCH(ACTYPE_AND_NOT_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Apply as Filter/... or not Selected", NULL,
-		srt_select_filter_cb, 0*256+5, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_MATCH(ACTYPE_OR_NOT_SELECTED), NULL, NULL),
 
 	/* Prepare */
 	ITEM_FACTORY_ENTRY("/Prepare a Filter", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Prepare a Filter/Selected", NULL,
-		srt_select_filter_cb, 1*256+0, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_PREPARE(ACTYPE_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Prepare a Filter/Not Selected", NULL,
-		srt_select_filter_cb, 1*256+1, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_PREPARE(ACTYPE_NOT_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Prepare a Filter/... and Selected", NULL,
-		srt_select_filter_cb, 1*256+2, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_PREPARE(ACTYPE_AND_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Prepare a Filter/... or Selected", NULL,
-		srt_select_filter_cb, 1*256+3, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_PREPARE(ACTYPE_OR_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Prepare a Filter/... and not Selected", NULL,
-		srt_select_filter_cb, 1*256+4, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_PREPARE(ACTYPE_AND_NOT_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Prepare a Filter/... or not Selected", NULL,
-		srt_select_filter_cb, 1*256+5, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_PREPARE(ACTYPE_OR_NOT_SELECTED), NULL, NULL),
 
 	/* Find Frame */
 	ITEM_FACTORY_ENTRY("/Find Frame", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Frame", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Frame/Selected", NULL,
-		srt_select_filter_cb, 2*256+0, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_FIND_FRAME(ACTYPE_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Frame/Not Selected", NULL,
-		srt_select_filter_cb, 2*256+1, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_FIND_FRAME(ACTYPE_NOT_SELECTED), NULL, NULL),
 	/* Find Next */
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Next", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Next/Selected", NULL,
-		srt_select_filter_cb, 3*256+0, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_FIND_NEXT(ACTYPE_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Next/Not Selected", NULL,
-		srt_select_filter_cb, 3*256+1, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_FIND_NEXT(ACTYPE_NOT_SELECTED), NULL, NULL),
 
 	/* Find Previous */
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Previous", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Previous/Selected", NULL,
-		srt_select_filter_cb, 4*256+0, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_FIND_PREVIOUS(ACTYPE_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Find Frame/Find Previous/Not Selected", NULL,
-		srt_select_filter_cb, 4*256+1, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_FIND_PREVIOUS(ACTYPE_NOT_SELECTED), NULL, NULL),
 
 	/* Colorize Procedure */
 	ITEM_FACTORY_ENTRY("/Colorize Procedure", NULL, NULL, 0, "<Branch>", NULL),
 	ITEM_FACTORY_ENTRY("/Colorize Procedure/Selected", NULL,
-		srt_select_filter_cb, 5*256+0, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_COLORIZE(ACTYPE_SELECTED), NULL, NULL),
 	ITEM_FACTORY_ENTRY("/Colorize Procedure/Not Selected", NULL,
-		srt_select_filter_cb, 5*256+1, NULL, NULL),
+		srt_select_filter_cb, CALLBACK_COLORIZE(ACTYPE_NOT_SELECTED), NULL, NULL),
 
 };
 
@@ -479,7 +496,7 @@ add_srt_table_data(srt_stat_table *rst, int index, const nstime_t *req_time, pac
 	 */
 	if (rp->stats.num==0){
 		row=gtk_clist_append(rst->table, rst->procedures[index].entries);
-		gtk_clist_set_row_data(rst->table, row, (gpointer) index);
+		gtk_clist_set_row_data(rst->table, row, (gpointer)(long) index);
 	}
 
 	/* calculate time delta between request and reply */
@@ -508,7 +525,7 @@ draw_srt_table_data(srt_stat_table *rst)
 		td=td*100000+(int)rst->procedures[i].stats.tot.nsecs/10000;
 		td/=rst->procedures[i].stats.num;
 
-		j=gtk_clist_find_row_from_data(rst->table, (gpointer)i);
+		j=gtk_clist_find_row_from_data(rst->table, (gpointer)(long)i);
 		strp=g_strdup_printf("%d", rst->procedures[i].stats.num);
 		gtk_clist_set_text(rst->table, j, 2, strp);
 		g_free(rst->procedures[i].entries[2]);
@@ -530,7 +547,7 @@ draw_srt_table_data(srt_stat_table *rst)
 		g_free(rst->procedures[i].entries[4]);
 		rst->procedures[i].entries[4]=strp;
 
-		strp=g_strdup_printf("%3" PRId64 ".%05" PRId64,
+		strp=g_strdup_printf("%3" G_GINT64_MODIFIER "d.%05" G_GINT64_MODIFIER "d",
 		    td/100000, td%100000);
 		gtk_clist_set_text(rst->table, j, 5, strp);
 		g_free(rst->procedures[i].entries[5]);
