@@ -1,8 +1,9 @@
+
 /* stats_tree_stat.c
  * GTK Tap implementation of stats_tree
  * 2005, Luis E. G. Ontanon
  *
- * $Id: stats_tree_stat.c 19055 2006-08-27 19:15:20Z etxrab $
+ * $Id: stats_tree_stat.c 24230 2008-01-31 16:37:56Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -131,7 +132,8 @@ static void draw_gtk_node(stat_node* node) {
 	static gchar percent[NUM_BUF_SIZE];
 	stat_node* child;
 	
-	stats_tree_get_strs_from_node(node, value, rate, percent);
+	stats_tree_get_strs_from_node(node, value, rate,
+				      percent);
 	
 #if GTK_MAJOR_VERSION >= 2
 	if (node->st->pr->store && node->pr->iter) {
@@ -233,8 +235,8 @@ static void init_gtk_tree(const char* optarg, void *userdata _U_) {
 	stats_tree* st = NULL;
 	stats_tree_cfg* cfg = NULL;
 	tree_pres* pr = g_malloc(sizeof(tree_pres));
-	guint8* title = NULL;
-	guint8* window_name = NULL;
+	gchar* title = NULL;
+	gchar* window_name = NULL;
 	GString* error_string;
 	GtkWidget *scr_win;
 	guint init_strlen;
@@ -268,7 +270,7 @@ static void init_gtk_tree(const char* optarg, void *userdata _U_) {
 				if (init_strlen == strlen(optarg)) {
 					st = stats_tree_new(cfg,pr,NULL);
 				} else { 
-					st = stats_tree_new(cfg,pr,((guint8*)optarg)+init_strlen+1);
+					st = stats_tree_new(cfg,pr,(char*)optarg+init_strlen+1);
 				}
 				
 			} else {
@@ -317,7 +319,8 @@ static void init_gtk_tree(const char* optarg, void *userdata _U_) {
 									G_TYPE_STRING, G_TYPE_STRING);
 	
 	st->pr->tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (st->pr->store));
-	
+	g_object_unref(G_OBJECT(st->pr->store));
+
 	gtk_container_add( GTK_CONTAINER(scr_win), st->pr->tree);
 	
 	/* the columns */
@@ -371,11 +374,11 @@ static void init_gtk_tree(const char* optarg, void *userdata _U_) {
 	gtk_container_add( GTK_CONTAINER(main_vb), scr_win);
 	
 	error_string = register_tap_listener( cfg->tapname,
-										  st,
-										  st->filter,
-										  reset_tap,
-										  stats_tree_packet,
-										  draw_gtk_tree);
+					      st,
+					      st->filter,
+					      reset_tap,
+					      stats_tree_packet,
+					      draw_gtk_tree);
 	
 	if (error_string) {
 		/* error, we failed to attach to the tap. clean up */
@@ -398,10 +401,6 @@ static void init_gtk_tree(const char* optarg, void *userdata _U_) {
 	gtk_widget_show_all(st->pr->win);
 	window_present(st->pr->win);
 	
-#if GTK_MAJOR_VERSION >= 2
-	gtk_tree_view_set_model(GTK_TREE_VIEW(st->pr->tree),GTK_TREE_MODEL(st->pr->store));
-#endif
-	
 	cf_retap_packets(&cfile, FALSE);
 }
 
