@@ -2,7 +2,7 @@
  * Routines for Agent Extensibility (AgentX) Protocol disassembly
  * RFC 2257
  *
- * $Id: packet-agentx.c 18197 2006-05-21 05:12:17Z sahlberg $
+ * $Id: packet-agentx.c 24274 2008-02-05 22:30:32Z stig $
  *
  * Copyright (c) 2005 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -315,7 +315,7 @@ static int dissect_octet_string(tvbuff_t *tvb, proto_tree *tree, int offset, cha
 
 }
 
-/* XXX - Is there a particular reason we're not using oid_to_str() here? */
+/* XXX - Is there a particular reason we're not using oid_encoded2string() here? */
 static int convert_oid_to_str(guint32 *oid, int len, char* str, int slen, char prefix)
 {
 	int i, tlen = 0;
@@ -326,11 +326,11 @@ static int convert_oid_to_str(guint32 *oid, int len, char* str, int slen, char p
 	if(slen < len) return 0;
 
 	if(prefix) {
-		tlen+= sprintf(str,".1.3.6.1.%d",prefix);
+		tlen += g_snprintf(str,slen,".1.3.6.1.%d",prefix);
 	}
 
 	for(i=0; i < len && tlen < slen; i++) {
-		tlen += sprintf(str+tlen,".%d",oid[i]);
+		tlen += g_snprintf(str+tlen,slen-tlen,".%d",oid[i]);
 	}
 	return tlen;
 }
@@ -758,7 +758,7 @@ static void dissect_rem_caps_pdu(tvbuff_t *tvb, proto_tree *tree,int offset,int
 }
 
 
-static guint get_agentx_pdu_len(tvbuff_t *tvb, int offset)
+static guint get_agentx_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
 {
 	guint8  flags;
 	guint32 plen;
