@@ -1,7 +1,7 @@
 /* asn1.c
  * Routines for ASN.1 BER dissection
  *
- * $Id: asn1.c 20372 2007-01-10 07:09:30Z kukosa $
+ * $Id: asn1.c 22651 2007-08-25 01:14:24Z lego $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,10 +66,13 @@
 
 #include <glib.h>
 
+#define subid_t guint32 /* ugly hack to get it to compile this symbol should be suppressed! */
+
 #include <epan/tvbuff.h>
 #include <plugins/asn1/asn1.h>
 #include <epan/emem.h>
 
+
 /*
  * NAME:        asn1_open                                   [API]
  * SYNOPSIS:    void asn1_open
@@ -316,7 +319,8 @@ asn1_header_decode(ASN1_SCK *asn1, guint *cls, guint *con, guint *tag,
 			gboolean *defp, guint *lenp)
 {
     int   ret;
-    guint def, len = 0;
+    guint len = 0;
+    gboolean def;
 
     ret = asn1_id_decode (asn1, cls, con, tag);
     if (ret != ASN1_ERR_NOERROR)
@@ -781,7 +785,7 @@ asn1_string_decode ( ASN1_SCK *asn1, guchar **octets, guint *str_len,
 {
     int          ret;
     int          start;
-    int          enc_len;
+    guint          enc_len;
     guint        cls;
     guint        con;
     guint        tag;
