@@ -2,7 +2,7 @@
  * Routines for UCD Message dissection
  * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-ucd.c 18231 2006-05-28 16:32:49Z etxrab $
+ * $Id: packet-ucd.c 23088 2007-10-07 23:46:44Z richardv $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -662,142 +662,142 @@ proto_register_docsis_ucd (void)
    /* Setup list of header fields  See Section 1.6.1 for details*/
    static hf_register_info hf[] = {
     {&hf_docsis_ucd_upstream_chid,
-     {"Upstream Channel ID", "docsis.ucd.upchid",
+     {"Upstream Channel ID", "docsis_ucd.upchid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Upstream Channel ID", HFILL}
      },
     {&hf_docsis_ucd_config_ch_cnt,
-     {"Config Change Count", "docsis.ucd.confcngcnt",
+     {"Config Change Count", "docsis_ucd.confcngcnt",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Configuration Change Count", HFILL}
      },
     {&hf_docsis_ucd_mini_slot_size,
-     {"Mini Slot Size (6.25us TimeTicks)", "docsis.ucd.mslotsize",
+     {"Mini Slot Size (6.25us TimeTicks)", "docsis_ucd.mslotsize",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Mini Slot Size (6.25us TimeTicks)", HFILL}
      },
     {&hf_docsis_ucd_down_chid,
-     {"Downstream Channel ID", "docsis.ucd.downchid",
+     {"Downstream Channel ID", "docsis_ucd.downchid",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Management Message", HFILL}
      },
     {&hf_docsis_ucd_type,
-     {"TLV Type", "docsis.ucd.type",
+     {"TLV Type", "docsis_ucd.type",
       FT_UINT8, BASE_DEC, VALS(channel_tlv_vals), 0x0,
       "Channel TLV type", HFILL}
      },
     {&hf_docsis_ucd_length,
-     {"TLV Length", "docsis.ucd.length",
+     {"TLV Length", "docsis_ucd.length",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Channel TLV length", HFILL}
      },
     {&hf_docsis_ucd_symbol_rate,
-     {"Symbol Rate (ksym/sec)", "docsis.ucd.symrate",
+     {"Symbol Rate (ksym/sec)", "docsis_ucd.symrate",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Symbol Rate", HFILL}
      },
     {&hf_docsis_ucd_frequency,
-     {"Frequency (Hz)", "docsis.ucd.freq",
+     {"Frequency (Hz)", "docsis_ucd.freq",
       FT_UINT32, BASE_DEC, NULL, 0x0,
       "Upstream Center Frequency", HFILL}
      },
     {&hf_docsis_ucd_preamble_pat,
-     {"Preamble Pattern", "docsis.ucd.preamble",
+     {"Preamble Pattern", "docsis_ucd.preamble",
       FT_BYTES, BASE_HEX, NULL, 0x0,
       "Preamble Superstring", HFILL}
      },
     {&hf_docsis_ucd_iuc,
-     {"Interval Usage Code", "docsis.ucd.iuc",
+     {"Interval Usage Code", "docsis_ucd.iuc",
       FT_UINT8, BASE_DEC, VALS (iuc_vals), 0x0,
       "Interval Usage Code", HFILL}
      },
     {&hf_docsis_burst_mod_type,
-     {"1 Modulation Type", "docsis.ucd.burst.modtype",
+     {"1 Modulation Type", "docsis_ucd.burst.modtype",
       FT_UINT8, BASE_DEC, VALS (mod_vals), 0x0,
       "Modulation Type", HFILL}
      },
     {&hf_docsis_burst_diff_encoding,
-     {"2 Differential Encoding", "docsis.ucd.burst.diffenc",
+     {"2 Differential Encoding", "docsis_ucd.burst.diffenc",
       FT_UINT8, BASE_DEC, VALS (on_off_vals), 0x0,
       "Differential Encoding", HFILL}
      },
     {&hf_docsis_burst_preamble_len,
-     {"3 Preamble Length (Bits)", "docsis.ucd.burst.preamble_len",
+     {"3 Preamble Length (Bits)", "docsis_ucd.burst.preamble_len",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Preamble Length (Bits)", HFILL}
      },
     {&hf_docsis_burst_preamble_val_off,
-     {"4 Preamble Offset (Bits)", "docsis.ucd.burst.preamble_off",
+     {"4 Preamble Offset (Bits)", "docsis_ucd.burst.preamble_off",
       FT_UINT16, BASE_DEC, NULL, 0x0,
       "Preamble Offset (Bits)", HFILL}
      },
     {&hf_docsis_burst_fec,
-     {"5 FEC (T)", "docsis.ucd.burst.fec",
+     {"5 FEC (T)", "docsis_ucd.burst.fec",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "FEC (T) Codeword Parity Bits = 2^T", HFILL}
      },
     {&hf_docsis_burst_fec_codeword,
-     {"6 FEC Codeword Info bytes (k)", "docsis.ucd.burst.fec_codeword",
+     {"6 FEC Codeword Info bytes (k)", "docsis_ucd.burst.fec_codeword",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "FEC Codeword Info Bytes (k)", HFILL}
      },
     {&hf_docsis_burst_scrambler_seed,
-     {"7 Scrambler Seed", "docsis.ucd.burst.scrambler_seed",
+     {"7 Scrambler Seed", "docsis_ucd.burst.scrambler_seed",
       FT_UINT16, BASE_HEX, NULL, 0x0,
       "Burst Descriptor", HFILL}
      },
     {&hf_docsis_burst_max_burst,
-     {"8 Max Burst Size (Minislots)", "docsis.ucd.burst.maxburst",
+     {"8 Max Burst Size (Minislots)", "docsis_ucd.burst.maxburst",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Max Burst Size (Minislots)", HFILL}
      },
     {&hf_docsis_burst_guard_time,
-     {"9 Guard Time Size (Symbol Times)", "docsis.ucd.burst.guardtime",
+     {"9 Guard Time Size (Symbol Times)", "docsis_ucd.burst.guardtime",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Guard Time Size", HFILL}
      },
     {&hf_docsis_burst_last_cw_len,
-     {"10 Last Codeword Length", "docsis.ucd.burst.last_cw_len",
+     {"10 Last Codeword Length", "docsis_ucd.burst.last_cw_len",
       FT_UINT8, BASE_DEC, VALS (last_cw_len_vals), 0x0,
       "Last Codeword Length", HFILL}
      },
     {&hf_docsis_burst_scrambler_onoff,
-     {"11 Scrambler On/Off", "docsis.ucd.burst.scrambleronoff",
+     {"11 Scrambler On/Off", "docsis_ucd.burst.scrambleronoff",
       FT_UINT8, BASE_DEC, VALS (on_off_vals), 0x0,
       "Scrambler On/Off", HFILL}
      },
     {&hf_docsis_rs_int_depth,
-     {"12 RS Interleaver Depth", "docsis.ucd.burst.rsintdepth",
+     {"12 RS Interleaver Depth", "docsis_ucd.burst.rsintdepth",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "R-S Interleaver Depth", HFILL}
     },
     {&hf_docsis_rs_int_block,
-     {"13 RS Interleaver Block Size", "docsis.ucd.burst.rsintblock",
+     {"13 RS Interleaver Block Size", "docsis_ucd.burst.rsintblock",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "R-S Interleaver Block", HFILL}
     },
     {&hf_docsis_preamble_type,
-     {"14 Preamble Type", "docsis.ucd.burst.preambletype",
+     {"14 Preamble Type", "docsis_ucd.burst.preambletype",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "Preamble Type", HFILL}
     },
     {&hf_docsis_scdma_scrambler_onoff,
-     {"15 SCDMA Scrambler On/Off", "docsis.ucd.burst.scdmascrambleronoff",
+     {"15 SCDMA Scrambler On/Off", "docsis_ucd.burst.scdmascrambleronoff",
       FT_UINT8, BASE_DEC, VALS (on_off_vals), 0x0,
       "SCDMA Scrambler On/Off", HFILL}
     },
     {&hf_docsis_scdma_codes_per_subframe,
-     {"16 SCDMA Codes per Subframe", "docsis.ucd.burst.scdmacodespersubframe",
+     {"16 SCDMA Codes per Subframe", "docsis_ucd.burst.scdmacodespersubframe",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "SCDMA Codes per Subframe", HFILL}
     },
     {&hf_docsis_scdma_framer_int_step_size,
-     {"17 SDMA Framer Int Step Size", "docsis.ucd.burst.scdmaframerintstepsize",
+     {"17 SDMA Framer Int Step Size", "docsis_ucd.burst.scdmaframerintstepsize",
       FT_UINT8, BASE_DEC, NULL, 0x0,
       "SCDMA Framer Interleaving Step Size", HFILL}
     },
     {&hf_docsis_tcm_enabled,
-     {"18 TCM Enable", "docsis.ucd.burst.tcmenabled",
+     {"18 TCM Enable", "docsis_ucd.burst.tcmenabled",
       FT_UINT8, BASE_DEC, VALS (on_off_vals), 0x0,
       "TCM Enabled", HFILL}
     },
