@@ -1,7 +1,7 @@
 /* print.c
  * Routines for printing packet analysis trees.
  *
- * $Id: print.c 24604 2008-03-11 18:23:16Z stig $
+ * $Id: print.c 25467 2008-06-17 19:09:35Z gerald $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -1569,9 +1569,8 @@ get_field_hex_value(GSList* src_list, field_info *fi)
         p = buffer;
         /* Print a simple hex dump */
         for (i = 0 ; i < fi->length; i++) {
-            g_snprintf(p, len, "%02x", pd[i]);
+            g_snprintf(p, chars_per_byte+1, "%02x", pd[i]);
             p += chars_per_byte;
-            len -= chars_per_byte;
         }
         return buffer;
     } else {
