@@ -1,7 +1,7 @@
 /* version_info.c
  * Routines to report version information for stuff used by Wireshark
  *
- * $Id: version_info.c 20625 2007-01-30 17:44:11Z gerald $
+ * $Id: version_info.c 24563 2008-03-05 09:59:15Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,6 +29,7 @@
 #include <glib.h>
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <errno.h>
 
@@ -40,10 +41,6 @@
 #include <pcre.h>	/* to get the libpcre version number */
 #endif /* HAVE_LIBPCRE */
 
-#ifdef HAVE_NET_SNMP
-#include <net-snmp/version.h>
-#endif /* HAVE_NET_SNMP */
-
 #if (defined(HAVE_LIBGCRYPT) || defined(HAVE_LIBGNUTLS)) && defined(_WIN32)
 #include <winposixtype.h>
 #endif
@@ -74,10 +71,22 @@
 #include <lua.h>
 #endif
 
+#ifdef HAVE_LIBSMI
+#include <smi.h>
+#endif
+
+#ifdef HAVE_OS_X_FRAMEWORKS
+#include <CoreServices/CoreServices.h>
+#endif
+
+#ifdef HAVE_LIBCAP
+# include <sys/capability.h>
+#endif
+
 #ifdef SVNVERSION
-	const char *svnversion = " (" SVNVERSION ")";
+	const char *wireshark_svnversion = " (" SVNVERSION ")";
 #else
-	const char *svnversion = "";
+	const char *wireshark_svnversion = "";
 #endif
 
 /*
@@ -149,6 +158,17 @@ get_compiled_version_info(GString *str, void (*additional_info)(GString *))
 	g_string_append(str, "without libz");
 #endif /* HAVE_LIBZ */
 
+        /* LIBCAP */
+	g_string_append(str, ", ");
+#ifdef HAVE_LIBCAP
+	g_string_append(str, "with POSIX capabilities");
+#ifdef _LINUX_CAPABILITY_VERSION
+	g_string_append(str, " (Linux)");
+#endif /* _LINUX_CAPABILITY_VERSION */
+#else /* HAVE_LIBCAP */
+	g_string_append(str, "without POSIX capabilities");
+#endif /* HAVE_LIBCAP */
+
 	/* Additional application-dependent information */
 	if (additional_info)
 		(*additional_info)(str);
@@ -189,14 +209,14 @@ get_epan_compiled_version_info(GString *str)
 
         /* SNMP */
 	g_string_append(str, ", ");
-#ifdef HAVE_NET_SNMP
-	g_string_append(str, "with Net-SNMP ");
-	g_string_append(str, netsnmp_get_version());
+#ifdef HAVE_LIBSMI
+	g_string_append(str, "with SMI ");
+	g_string_append(str, SMI_VERSION_STRING);
 #else /* no SNMP library */
-	g_string_append(str, "without Net-SNMP");
-#endif /* HAVE_NET_SNMP */
+	g_string_append(str, "without SMI");
+#endif /* _SMI_H */
 
-        /* ADNS */
+	/* ADNS */
 	g_string_append(str, ", ");
 #ifdef HAVE_GNU_ADNS
 	g_string_append(str, "with ADNS");
@@ -256,6 +276,9 @@ get_runtime_version_info(GString *str, void (*additional_info)(GString *))
 #elif defined(HAVE_SYS_UTSNAME_H)
 	struct utsname name;
 #endif
+#if HAVE_OS_X_FRAMEWORKS
+	long macosx_ver, macosx_major_ver, macosx_minor_ver, macosx_bugfix_ver;
+#endif
 
 	g_string_append(str, "on ");
 
@@ -408,6 +431,26 @@ get_runtime_version_info(GString *str, void (*additional_info)(GString *))
 		 * thing.
 		 */
 		g_string_sprintfa(str, "%s %s", name.sysname, name.release);
+#ifdef HAVE_OS_X_FRAMEWORKS
+		Gestalt(gestaltSystemVersion, &macosx_ver);
+
+		/* The following functions are only available in MacOS 10.4+ */
+		if(macosx_ver >= 0x1040) {
+			Gestalt(gestaltSystemVersionMajor, &macosx_major_ver);
+			Gestalt(gestaltSystemVersionMinor, &macosx_minor_ver);
+			Gestalt(gestaltSystemVersionBugFix, &macosx_bugfix_ver);
+
+			g_string_sprintfa(str, " (MacOS %ld.%ld.%ld)",
+					  macosx_major_ver,
+					  macosx_minor_ver,
+					  macosx_bugfix_ver);
+		} else {
+			g_string_sprintfa(str, " (MacOS X < 10.4 [%lx])",
+					  macosx_ver);
+			/* See Apple's Gestalt Manager Reference for meanings
+			 * of the macosx_ver values. */
+		}
+#endif /* HAVE_OS_X_FRAMEWORKS */
 	}
 #else
 	g_string_append(str, "an unknown OS");
@@ -498,7 +541,37 @@ const char *
 get_copyright_info(void)
 {
 	return
-"Copyright 1998-2007 Gerald Combs <gerald@wireshark.org> and contributors.\n"
+"Copyright 1998-2008 Gerald Combs <gerald@wireshark.org> and contributors.\n"
 "This is free software; see the source for copying conditions. There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
 }
+
+#if defined(_WIN32)
+/*
+ * Get the major OS version.
+ */
+/* XXX - Should this return the minor version as well, e.g. 0x00050002? */
+guint32
+get_os_major_version()
+{
+	OSVERSIONINFO info;
+	info.dwOSVersionInfoSize = sizeof info;
+	if (GetVersionEx(&info)) {
+		return info.dwMajorVersion;
+	}
+	return 0;
+}
+#endif
+
+/*
+ * Editor modelines
+ *
+ * Local Variables:
+ * c-basic-offset: 8
+ * tab-width: 8
+ * indent-tabs-mode: tabs
+ * End:
+ *
+ * ex: set shiftwidth=8 tabstop=8 noexpandtab
+ * :indentSize=8:tabSize=8:noTabs=false:
+ */
