@@ -1,7 +1,7 @@
 /* airopeek9.c
  * Routines for opening EtherPeek and AiroPeek V9 files
  *
- * $Id: airopeek9.c 19814 2006-11-05 22:46:44Z ulfl $
+ * $Id: airopeek9.c 21862 2007-05-21 16:16:18Z jmayer $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -179,7 +179,7 @@ int airopeek9_open(wtap *wth, int *err, gchar **err_info)
     int ret;
     guint32 fileVersion;
     guint32 mediaType;
-    guint32 mediaSubType;
+    guint32 mediaSubType = 0;
     int file_encap;
     static const int airopeek9_encap[] = {
 	WTAP_ENCAP_ETHERNET,
