@@ -1,6 +1,6 @@
 /* catapult_dct2000.c
  *
- * $Id: catapult_dct2000.c 24258 2008-02-03 15:38:20Z stig $
+ * $Id: catapult_dct2000.c 25463 2008-06-16 23:29:12Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -412,7 +412,7 @@ gboolean catapult_dct2000_read(wtap *wth, int *err, gchar **err_info _U_,
             }
 
             /* Add packet entry into table */
-            pkey = g_malloc(sizeof(pkey));
+            pkey = g_malloc(sizeof(*pkey));
             *pkey = this_offset;
             g_hash_table_insert(file_externals->packet_prefix_table, pkey, line_prefix_info);
 
