@@ -1,6 +1,6 @@
 /* file_access.c
  *
- * $Id: file_access.c 20013 2006-11-29 06:44:07Z etxrab $
+ * $Id: file_access.c 24263 2008-02-03 21:11:53Z stig $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -72,6 +72,12 @@
 #include "k12.h"
 #include "ber.h"
 #include "catapult_dct2000.h"
+#include "mpeg.h"
+#include "netscreen.h"
+#include "commview.h"
+#include "pcapng.h"
+#include "btsnoop.h"
+
 
 /* The open_file_* routines should return:
  *
@@ -90,7 +96,8 @@
  * should be discovered as a libpcap file, not a toshiba file.
  */
 
-static int (*const open_routines[])(wtap *, int *, char **) = {
+
+static wtap_open_routine_t open_routines_base[] = {
 	/* Files that have magic bytes in fixed locations. These
 	 * are easy to identify.
 	 */
@@ -111,13 +118,22 @@ static int (*const open_routines[])(wtap *, int *, char **) = {
 	k12_open,
 	catapult_dct2000_open,
 	ber_open,
+	mpeg_open,
+	pcapng_open,
+	btsnoop_open,
 	/* Files that don't have magic bytes at a fixed location,
 	 * but that instead require a heuristic of some sort to
 	 * identify them.  This includes the ASCII trace files that
 	 * would be, for example, saved copies of a Telnet session
 	 * to some box.
 	 */
+
+	/* I put NetScreen *before* erf, because there were some
+	 * false positives with my test-files (Sake Blok, July 2007)
+	 */
+	netscreen_open, 
 	erf_open,
+	k12text_open,
 	etherpeek_open,
 	pppdump_open,
 	iseries_open,
@@ -129,9 +145,38 @@ static int (*const open_routines[])(wtap *, int *, char **) = {
 	vms_open,
 	cosine_open,
 	hcidump_open,
+	commview_open
 };
 
-#define	N_FILE_TYPES	(sizeof open_routines / sizeof open_routines[0])
+#define	N_FILE_TYPES	(sizeof open_routines_base / sizeof open_routines_base[0])
+
+static wtap_open_routine_t* open_routines = NULL;
+
+static GArray* open_routines_arr = NULL;
+
+
+/* initialize the open routines array if it has not being initialized yet */
+static void init_open_routines(void) {
+	
+	if (open_routines_arr) return;
+
+	open_routines_arr = g_array_new(FALSE,TRUE,sizeof(wtap_open_routine_t));
+	
+	g_array_append_vals(open_routines_arr,open_routines_base,N_FILE_TYPES);
+	
+	open_routines = (void*)open_routines_arr->data;
+}
+
+void wtap_register_open_routine(wtap_open_routine_t open_routine, gboolean has_magic) {
+	init_open_routines();
+
+	if (has_magic)
+		g_array_prepend_val(open_routines_arr,open_routine);
+	else
+		g_array_append_val(open_routines_arr,open_routine);
+	
+	open_routines = (void*)open_routines_arr->data;
+}
 
 /*
  * Visual C++ on Win32 systems doesn't define these.  (Old UNIX systems don't
@@ -274,9 +319,11 @@ wtap* wtap_open_offline(const char *filename, int *err, char **err_info,
 	wth->subtype_sequential_close = NULL;
 	wth->subtype_close = NULL;
 	wth->tsprecision = WTAP_FILE_TSPREC_USEC;
-
+	
+	init_open_routines();
+	
 	/* Try all file types */
-	for (i = 0; i < N_FILE_TYPES; i++) {
+	for (i = 0; i < open_routines_arr->len; i++) {
 		/* Seek back to the beginning of the file; the open routine
 		   for the previous file type may have left the file
 		   position somewhere other than the beginning, and the
@@ -329,34 +376,7 @@ success:
 }
 
 /* Table of the file types we know about. */
-static const struct file_type_info {
-    /* the file type name */
-    /* should be NULL for all "pseudo" types that are only internally used and not read/writeable */
-	const char *name;
-
-    /* the file type short name, used as a shortcut for the command line tools */
-    /* should be NULL for all "pseudo" types that are are only internally used and not read/writeable */
-	const char *short_name;
-    
-    /* the common file extensions for this type (seperated by semicolon) */
-    /* should be *.* if no common extension is applicable */
-    const char *file_extensions;
-    
-    /* the default file extension, used to save this type */
-    /* should be NULL if no default extension is known */
-    const char *file_extension_default;
-    
-    /* can this type be compressed with gzip? */
-	gboolean	can_compress;
-    
-    /* can this type write this encapsulation format? */
-    /* should be NULL is this file type don't have write support */
-	int	(*can_write_encap)(int);
-    
-    /* the function to open the capture file for writing */
-    /* should be NULL is this file type don't have write support */
-	int	(*dump_open)(wtap_dumper *, gboolean, int *);
-} dump_open_table[WTAP_NUM_FILE_TYPES] = {
+static const struct file_type_info dump_open_table_base[] = {
 	/* WTAP_FILE_UNKNOWN (only used internally for initialization) */
 	{ NULL, NULL, NULL, NULL, FALSE,
 	  NULL, NULL },
@@ -438,7 +458,7 @@ static const struct file_type_info {
 	  NULL, NULL},
 
 	/* WTAP_FILE_ERF */
-	{ "Endace DAG capture", "erf", "*.erf", ".erf", FALSE,
+	{ "Endace ERF capture", "erf", "*.erf", ".erf", FALSE,
 	  NULL, NULL },
 
 	/* WTAP_FILE_EYESDN */
@@ -518,7 +538,7 @@ static const struct file_type_info {
 	  NULL, NULL},
 
 	/* WTAP_FILE_K12 */
-	{ "Tektronix K12xx 32-bit .rf5 format", "rf5", "*.rf5", ".rf5", FALSE,
+	{ "Tektronix K12xx 32-bit .rf5 format", "rf5", "*.rf5", ".rf5", TRUE,
 		k12_dump_can_write_encap, k12_dump_open },
 
 	/* WTAP_FILE_TOSHIBA */
@@ -541,12 +561,66 @@ static const struct file_type_info {
 	{ "Wildpacket Ether/AiroPeek (V9)", "peek9", "*.tpc;*.apc;*.pkt;*.wpz", ".pkt", FALSE,
 	  NULL, NULL },
     
+	/* WTAP_FILE_MPEG */
+	{ "MPEG", "mpeg", "*.mpeg;*.mpg;*.mp3", ".mpeg", FALSE,
+	  NULL, NULL },
+
+	/* WTAP_FILE_K12TEXT  */
+	{ "K12 text file", "k12text", "*.txt", ".txt", TRUE,
+	  k12text_dump_can_write_encap, k12text_dump_open },
+
+	/* WTAP_FILE_NETSCREEN */
+	{ "NetScreen snoop text file", "netscreen", "*.*", NULL, FALSE,
+	  NULL, NULL },
+
+	/* WTAP_FILE_COMMVIEW */
+	{ "TamoSoft CommView", "commview", "*.ncf", ".ncf", TRUE,
+	  commview_dump_can_write_encap, commview_dump_open },
+	  
+	/* WTAP_FILE_PCAPNG */
+	{ "Wireshark - pcapng (experimental)", "pcapng", "*.pcapng", NULL, FALSE,
+	  pcapng_dump_can_write_encap, pcapng_dump_open },
+
+	/* WTAP_FILE_BTSNOOP */
+	{ "Symbian OS btsnoop", "btsnoop", "*.log", NULL, FALSE, NULL, NULL }
 };
 
+gint wtap_num_file_types = sizeof(dump_open_table_base) / sizeof(struct file_type_info);
+
+static GArray*  dump_open_table_arr = NULL;
+static const struct file_type_info* dump_open_table = dump_open_table_base;
+
+/* initialize the open routines array if it has not being initialized yet */
+static void init_file_types(void) {
+	
+	if (dump_open_table_arr) return;
+
+	dump_open_table_arr = g_array_new(FALSE,TRUE,sizeof(struct file_type_info));
+	
+	g_array_append_vals(dump_open_table_arr,dump_open_table_base,wtap_num_file_types);
+	
+	dump_open_table = (void*)dump_open_table_arr->data;
+}
+
+int wtap_register_file_type(const struct file_type_info* fi) {
+	init_file_types();
+
+	g_array_append_val(dump_open_table_arr,*fi);
+	
+	dump_open_table = (void*)dump_open_table_arr->data;
+	
+	return wtap_num_file_types++;
+}
+
+int wtap_get_num_file_types(void)
+{
+	return wtap_num_file_types;
+}
+
 /* Name that should be somewhat descriptive. */
 const char *wtap_file_type_string(int filetype)
 {
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES) {
+	if (filetype < 0 || filetype >= wtap_num_file_types) {
 		g_error("Unknown capture file type %d", filetype);
 		return NULL;
 	} else
@@ -556,7 +630,7 @@ const char *wtap_file_type_string(int filetype)
 /* Name to use in, say, a command-line flag specifying the type. */
 const char *wtap_file_type_short_string(int filetype)
 {
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES)
+	if (filetype < 0 || filetype >= wtap_num_file_types)
 		return NULL;
 	else
 		return dump_open_table[filetype].short_name;
@@ -567,7 +641,7 @@ int wtap_short_string_to_file_type(const char *short_name)
 {
 	int filetype;
 
-	for (filetype = 0; filetype < WTAP_NUM_FILE_TYPES; filetype++) {
+	for (filetype = 0; filetype < wtap_num_file_types; filetype++) {
 		if (dump_open_table[filetype].short_name != NULL &&
 		    strcmp(short_name, dump_open_table[filetype].short_name) == 0)
 			return filetype;
@@ -578,7 +652,7 @@ int wtap_short_string_to_file_type(const char *short_name)
 /* file extensions to use. */
 const char *wtap_file_extensions_string(int filetype)
 {
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES)
+	if (filetype < 0 || filetype >= wtap_num_file_types)
 		return NULL;
 	else
 		return dump_open_table[filetype].file_extensions;
@@ -587,7 +661,7 @@ const char *wtap_file_extensions_string(int filetype)
 /* default file extension to use. */
 const char *wtap_file_extension_default_string(int filetype)
 {
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES)
+	if (filetype < 0 || filetype >= wtap_num_file_types)
 		return NULL;
 	else
 		return dump_open_table[filetype].file_extension_default;
@@ -595,7 +669,7 @@ const char *wtap_file_extension_default_string(int filetype)
 
 gboolean wtap_dump_can_open(int filetype)
 {
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES
+	if (filetype < 0 || filetype >= wtap_num_file_types
 	    || dump_open_table[filetype].dump_open == NULL)
 		return FALSE;
 
@@ -604,7 +678,7 @@ gboolean wtap_dump_can_open(int filetype)
 
 gboolean wtap_dump_can_write_encap(int filetype, int encap)
 {
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES
+	if (filetype < 0 || filetype >= wtap_num_file_types
 	    || dump_open_table[filetype].can_write_encap == NULL)
 		return FALSE;
 
@@ -617,7 +691,7 @@ gboolean wtap_dump_can_write_encap(int filetype, int encap)
 gboolean wtap_dump_can_compress(int filetype)
 {
 #ifdef HAVE_LIBZ
-	if (filetype < 0 || filetype >= WTAP_NUM_FILE_TYPES
+	if (filetype < 0 || filetype >= wtap_num_file_types
 	    || dump_open_table[filetype].can_compress == FALSE)
 		return FALSE;
 
