@@ -1,6 +1,6 @@
 /* libpcap.c
  *
- * $Id: libpcap.c 24119 2008-01-17 17:55:38Z morriss $
+ * $Id: libpcap.c 24622 2008-03-14 00:01:51Z gerald $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -442,14 +442,25 @@ static const struct {
 	{ 188,		WTAP_ENCAP_IEEE802_16_MAC_CPS },
 	/* USB packets with Linux-specified header */
 	{ 189, 		WTAP_ENCAP_USB_LINUX },
+	/* CAN 2.0b frame */
+	{ 190, 		WTAP_ENCAP_CAN20B },
         /* Per-Packet Information header */
         { 192,          WTAP_ENCAP_PPI },
+	/* IEEE 802.15.4 Wireless PAN */
+	{ 195,		WTAP_ENCAP_IEEE802_15_4 },
 	/* SITA File Encapsulation */
 	{ 196,	        WTAP_ENCAP_SITA },
 	/* Endace Record File Encapsulation */
 	{ 197,	        WTAP_ENCAP_ERF },
+	{ 199,		WTAP_ENCAP_IPMB },
 	/* Bluetooth HCI UART transport (part H:4) frames, like hcidump */
 	{ 201, 		WTAP_ENCAP_BLUETOOTH_H4_WITH_PHDR },
+	/* FlexRay frame */
+	{ 210, 		WTAP_ENCAP_FLEXRAY },
+	/* MOST frame */
+	{ 211, 		WTAP_ENCAP_MOST },
+	/* LIN frame */
+	{ 212, 		WTAP_ENCAP_LIN },
 
 	/*
 	 * To repeat:
