@@ -1,6 +1,6 @@
 /* nettl.c
  *
- * $Id: nettl.c 18945 2006-08-18 09:01:20Z guy $
+ * $Id: nettl.c 23290 2007-10-27 15:44:12Z etxrab $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -175,8 +175,8 @@ struct nettlrec_ns_ls_drv_eth_hdr {
 /* header is followed by data and once again the total length (2 bytes) ! */
 
 static gboolean nettl_read(wtap *wth, int *err, gchar **err_info,
-		long *data_offset);
-static gboolean nettl_seek_read(wtap *wth, long seek_off,
+		gint64 *data_offset);
+static gboolean nettl_seek_read(wtap *wth, gint64 seek_off,
 		union wtap_pseudo_header *pseudo_header, guchar *pd,
 		int length, int *err, gchar **err_info);
 static int nettl_read_rec_header(wtap *wth, FILE_T fh,
@@ -263,11 +263,16 @@ int nettl_open(wtap *wth, int *err, gchar **err_info _U_)
         case NETTL_SUBSYS_NS_LS_UDP :
         case NETTL_SUBSYS_NS_LS_IPV6 :
 		wth->file_encap = WTAP_ENCAP_NETTL_RAW_IP;
+		break;
         case NETTL_SUBSYS_NS_LS_ICMP :
 		wth->file_encap = WTAP_ENCAP_NETTL_RAW_ICMP;
+		break;
         case NETTL_SUBSYS_NS_LS_ICMPV6 :
 		wth->file_encap = WTAP_ENCAP_NETTL_RAW_ICMPV6;
 		break;
+        case NETTL_SUBSYS_NS_LS_TELNET :
+		wth->file_encap = WTAP_ENCAP_NETTL_RAW_TELNET;
+		break;
 	default:
 		/* If this assumption is bad, the read will catch it */
 		wth->file_encap = WTAP_ENCAP_NETTL_ETHERNET;
@@ -285,7 +290,7 @@ int nettl_open(wtap *wth, int *err, gchar **err_info _U_)
 
 /* Read the next packet */
 static gboolean nettl_read(wtap *wth, int *err, gchar **err_info,
-    long *data_offset)
+    gint64 *data_offset)
 {
     int ret;
     gboolean fddihack=FALSE;
@@ -327,7 +332,7 @@ static gboolean nettl_read(wtap *wth, int *err, gchar **err_info,
 }
 
 static gboolean
-nettl_seek_read(wtap *wth, long seek_off,
+nettl_seek_read(wtap *wth, gint64 seek_off,
 		union wtap_pseudo_header *pseudo_header, guchar *pd,
 		int length, int *err, gchar **err_info)
 {
@@ -405,7 +410,16 @@ nettl_read_rec_header(wtap *wth, FILE_T fh, struct wtap_pkthdr *phdr,
 	return -1;
     offset += hdr_len;
 
-    switch (subsys) {
+    if ( ( (pntohl(&rec_hdr.kind) & ~NETTL_HDR_SUBSYSTEM_BITS_MASK)
+         & (NETTL_HDR_PROCEDURE_TRACE |
+            NETTL_HDR_STATE_TRACE |
+            NETTL_HDR_ERROR_TRACE) ) != 0) {
+        /* not actually a packet trace record */
+        phdr->pkt_encap = WTAP_ENCAP_NETTL_RAW_IP;
+        length = pntohl(&rec_hdr.length);
+        caplen = pntohl(&rec_hdr.caplen);
+        padlen = 0;
+    } else switch (subsys) {
 	case NETTL_SUBSYS_LAN100 :
 	case NETTL_SUBSYS_EISA100BT :
 	case NETTL_SUBSYS_BASE100 :
@@ -434,16 +448,21 @@ nettl_read_rec_header(wtap *wth, FILE_T fh, struct wtap_pkthdr *phdr,
 	case NETTL_SUBSYS_NS_LS_IPV6 :
 	case NETTL_SUBSYS_NS_LS_ICMPV6 :
 	case NETTL_SUBSYS_NS_LS_ICMP :
+	case NETTL_SUBSYS_NS_LS_TELNET :
+	case NETTL_SUBSYS_NS_LS_SCTP :
 	    if( (subsys == NETTL_SUBSYS_NS_LS_IP)
 	     || (subsys == NETTL_SUBSYS_NS_LS_LOOPBACK)
 	     || (subsys == NETTL_SUBSYS_NS_LS_UDP)
 	     || (subsys == NETTL_SUBSYS_NS_LS_TCP)
+	     || (subsys == NETTL_SUBSYS_NS_LS_SCTP)
 	     || (subsys == NETTL_SUBSYS_NS_LS_IPV6)) {
 		phdr->pkt_encap = WTAP_ENCAP_NETTL_RAW_IP;
 	    } else if (subsys == NETTL_SUBSYS_NS_LS_ICMP) {
 		phdr->pkt_encap = WTAP_ENCAP_NETTL_RAW_ICMP;
 	    } else if (subsys == NETTL_SUBSYS_NS_LS_ICMPV6) {
 		phdr->pkt_encap = WTAP_ENCAP_NETTL_RAW_ICMPV6;
+	    } else if (subsys == NETTL_SUBSYS_NS_LS_TELNET) {
+		phdr->pkt_encap = WTAP_ENCAP_NETTL_RAW_TELNET;
 	    } else if( (subsys == NETTL_SUBSYS_HPPB_FDDI)
 		    || (subsys == NETTL_SUBSYS_EISA_FDDI)
 		    || (subsys == NETTL_SUBSYS_PCI_FDDI)
@@ -498,6 +517,21 @@ nettl_read_rec_header(wtap *wth, FILE_T fh, struct wtap_pkthdr *phdr,
                     return -1;
                 padlen = 26;
 		offset += padlen;
+            } else if (subsys == NETTL_SUBSYS_NS_LS_SCTP) {
+                /*
+                 * SCTP 8 byte header that we will ignore...
+                 * 32 bit integer defines format
+                 *   1 = Log
+                 *   2 = ASCII
+                 *   3 = Binary (PDUs should be Binary format)
+                 * 32 bit integer defines type
+                 *   1 = Inbound
+                 *   2 = Outbound
+                 */
+                if (file_seek(fh, 8, SEEK_CUR, err) == -1)
+                    return -1;
+                padlen = 8;
+                offset += padlen;   
 	    } else {
 	    	padlen = 0;
 	    }
@@ -571,16 +605,16 @@ nettl_read_rec_header(wtap *wth, FILE_T fh, struct wtap_pkthdr *phdr,
             break;
     }
 
-    if (length <= padlen) {
+    if (length < padlen) {
 	*err = WTAP_ERR_BAD_RECORD;
-	*err_info = g_strdup_printf("nettl: packet length %u in record header too short, <= %u",
+	*err_info = g_strdup_printf("nettl: packet length %u in record header too short, less than %u",
 	    length, padlen);
 	return -1;
     }
     phdr->len = length - padlen;
-    if (caplen <= padlen) {
+    if (caplen < padlen) {
 	*err = WTAP_ERR_BAD_RECORD;
-	*err_info = g_strdup_printf("nettl: captured length %u in record header too short, <= %u",
+	*err_info = g_strdup_printf("nettl: captured length %u in record header too short, less than %u",
 	    caplen, padlen);
 	return -1;
     }
@@ -660,6 +694,7 @@ int nettl_dump_can_write_encap(int encap)
 		case WTAP_ENCAP_NETTL_RAW_IP:
 		case WTAP_ENCAP_NETTL_RAW_ICMP:
 		case WTAP_ENCAP_NETTL_RAW_ICMPV6:
+		case WTAP_ENCAP_NETTL_RAW_TELNET:
 /*
 		case WTAP_ENCAP_NETTL_X25:
 */
@@ -742,6 +777,7 @@ static gboolean nettl_dump(wtap_dumper *wdh,
 		case WTAP_ENCAP_NETTL_RAW_IP:
 		case WTAP_ENCAP_NETTL_RAW_ICMP:
 		case WTAP_ENCAP_NETTL_RAW_ICMPV6:
+		case WTAP_ENCAP_NETTL_RAW_TELNET:
 		case WTAP_ENCAP_NETTL_UNKNOWN:
 			rec_hdr.subsys = g_htons(pseudo_header->nettl.subsys);
 			rec_hdr.devid = g_htonl(pseudo_header->nettl.devid);
