@@ -1,6 +1,6 @@
 /* pppdump.c
  *
- * $Id: pppdump.c 19814 2006-11-05 22:46:44Z ulfl $
+ * $Id: pppdump.c 21904 2007-05-23 06:03:48Z jake $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -615,6 +615,9 @@ collate(pppdump_t* state, FILE_T fh, int *err, gchar **err_info, guint8 *pd,
 					pkt->sd_offset = state->offset;
 				}
 
+				if (n == 0)
+					continue;
+
 				g_assert(num_bytes_to_skip < n);
 				while (num_bytes_to_skip) {
 					if (file_getc(fh) == EOF)
